(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    807039,      21790]*)
(*NotebookOutlinePosition[    844867,      23111]*)
(*  CellTagsIndexPosition[    844823,      23107]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Computer Graphics",
    FontFamily->"Comic Sans MS",
    FontSize->36],
  "\n",
  StyleBox["Louis J. Nachman",
    FontSize->14]
}], "PrefaceTitle"],

Cell["Animation", "Title",
  CellMargins->{{Inherited, 5}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["Initializations", "Subsubsection"],

Cell["\<\
(* :Title:  Vectors  *)

(* :Author: BillDavis/Bruce Carpenter *)

(* License Agreement:  This package may not be used or distributed, in whole \
or in part, for any commercial purpose whatsoever. *)

(* :Summary:  Constructs 2 and 3 dimensional vectors,
     arrows, and arrowheads.
*)

(* :Date:  Copyright 2000 by Math Everywhere, Inc.. 
*)

(*  :Drawbacks:  Since the vectors are drawn out of 
     context, the shapes of the arrowheads are only 
     correct with AspectRatio set to Automatic.
*)

Off[General::spell1];
Off[General::spell];

BeginPackage[\"Vector3D`\", \"Graphics`Colors`\"];
\
\>", "Input",
  PageWidth->WindowWidth,
  ShowSpecialCharacters->False],

Cell["\<\
Aperture;Arrow;ArrowHead;Axes3D;Axes3DColor;Axes3DLabels;EdgesQ;\
HeadRatio;HeadSize;HeadType;Norm;Normalize;Perpendicular;ScalingFactor;ShaftQ;\
ShaftStyle;ShaftType;Tail;TipRatio;TipSize;Vector;VectorAxesOrigin;\
VectorColor;VectorGraphic;VectorLabel;VectorText;VectorTail;VectorTip;\
ZeroVectorPointSize;

Options[Vector] = Options[VectorGraphic] = 
Options[Arrow] =
{Aperture->0.3, EdgesQ->True, HeadRatio->0.18, 
HeadSize->Automatic, HeadType->Automatic, 
ScalingFactor->1, ShaftQ->True, ShaftStyle->Thickness[0.005], 
ShaftType->Line, Tail->VectorAxesOrigin, TipRatio->0.14, 
TipSize->Automatic, VectorColor->GrayLevel[0], 
VectorLabel->None, ZeroVectorPointSize->0.01};

Options[ArrowHead] =
{Aperture->0.3, EdgesQ->True, HeadRatio->0.18, 
HeadSize->Automatic, HeadType->Automatic, TipRatio->0.14, 
TipSize->Automatic, VectorColor->GrayLevel[0], ZeroVectorPointSize->0.01};

Options[Axes3D] = {Axes3DLabels->{\"x\",\"y\",\"z\"}, 
Axes3DColor->RGBColor[0,0,1]};

Begin[\"`Private`\"];

SetOptions[Graphics, AspectRatio->Automatic];
SetOptions[Graphics3D, BoxRatios->Automatic];

Unprotect[Graphics, Graphics3D, Show];
 Graphics[x___]:=With[{newx={x}/.{Vector->VectorGraphic}/.{Graphics->Sequence}\
}, Graphics[Sequence@@newx]]/;!FreeQ[{x},Vector]
 Graphics3D[x___]:=With[{newx={x}/.{Vector->VectorGraphic}/.{Graphics3D->\
Sequence}}, Graphics3D[Sequence@@newx]]/;!FreeQ[{x},Vector];

Show[x___] := \
Show[Sequence@@({x}/.{Vector->VectorGraphic}),AspectRatio->Automatic]/;!FreeQ[\
{x},Vector]
Attributes[Show]=Union[Attributes[Show],{ReadProtected}];

Protect[Graphics, Graphics3D, Show];

Axes3D[u_,v_,opts___] := Module[{axlab,axcol},
{axlab,axcol} = {Axes3DLabels,Axes3DColor} /. {opts} /. Options[Axes3D];
Graphics3D[{ {axcol,
    Line[{{-u/3,0,0},{u,0,0}}],
    Line[{{0,-u/3,0},{0,u,0}}],
    Line[{{0,0,-u/3},{0,0,u}}]},
    Text[ToString[axlab[[1]]],{u + v,0,0}],
    Text[ToString[axlab[[2]]],{0, u + v,0}],
    Text[ToString[axlab[[3]]],{0,0,u + v}]}] ]; 
    
Axes3D[u_] := Axes3D[u,u/8];

Norm[a_?VectorQ] := Sqrt[a.a];

Norm[a_] := Norm[a[[1]]]

Normalize[a_] := If[Chop[N[a.a]]===0, a, a/Norm[a]];

Perpendicular[a_?VectorQ] := Normalize[{-a[[2]],a[[1]]}]/;Length[a]==2

Perpendicular[a_?VectorQ] := If[Chop[N[a[[1]]]]===0,{1,0,0},
   Normalize[{-a[[2]],a[[1]],0}]]/;Length[a]==3

Base3D = Table[{Cos[2 k Pi/8.], Sin[2 k Pi/8.]},{k,0,8}];

InternalVectorText[VectorText[tx_,coords_List,opts___], bot_, axesdir_, \
perp_]:= Text[tx,bot + axesdir coords[[1]] + perp \
coords[[2]],opts]/;Length[coords]>=2

InternalVectorText[None,___] := {};

InternalVectorText[else_, bot_, axesdir_, perp_]:= Text[else,bot + 0.5 \
axesdir];
  
VectorGraphic[dir_, opts___] := Module[
   {from,to,sq, ss, st, ht, hs, hr, ts, tr, ap, sf, vc, vl, zvps, diff, tip},
from=Tail/.{opts}/.{Tail->Table[0,{Length[dir]}]}/.{VectorAxesOrigin->(Table[\
0,{Length[dir]}])};
   to = from+dir;diff=dir;
   {sq, ss, st, ht, hs, hr, ts, tr, ap, sf, vc, vl, zvps} = {ShaftQ, \
ShaftStyle, ShaftType, HeadType, HeadSize, HeadRatio, TipSize, TipRatio, \
Aperture, ScalingFactor, VectorColor, VectorLabel, ZeroVectorPointSize} /. \
{opts} /. Options[VectorGraphic];
   If[from==to, Return[Graphics[{PointSize[zvps],vc,Point[from]}]]];
   diff = If[NumericQ[sf], sf diff, sf[diff]];
   tip = from + diff;
   If[NumberQ[hs], hr = hs/Norm[diff]; tr = 0.75 hr];
   If[NumberQ[ts], tr = ts/Norm[diff]];
Graphics[{If[sq,{vc,If[Head[ss]===List,Sequence@@ss,ss], st[{from,tip - tr \
diff}]},{}],
With[{trans = ap hr Norm[diff] Perpendicular[diff]},
      With[{ptlist={tip, (tip - hr diff - trans),
       (tip - tr diff), (tip - hr diff + trans),tip}},{vc, \
If[ht===Automatic,{Polygon[ptlist],Line[ptlist]},ht[ptlist]]}]],\
InternalVectorText[vl, from, diff, Perpendicular[diff]]}]
] /; Length[dir]==2

VectorGraphic[dir_, opts___] := Module[
   {from, to, sq, eq, ss, st, hs, hr, tr, ap, sf, vc, vl, zvps, diff, tip},
from=Tail/.{opts}/.{Tail->Table[0,{Length[dir]}]}/.{VectorAxesOrigin->(Table[\
0,{Length[dir]}])};
If[Length[from]=!=Length[dir], Return[Message[Vector::taildim, \
Vector[dir,opts]];Graphics3D[{}]]];
   to=from+dir; diff=dir;
   {sq, eq, ss, st, hs, hr, ap, sf, vc, vl, zvps} = {ShaftQ, EdgesQ, \
ShaftStyle, ShaftType, HeadSize, HeadRatio, Aperture, ScalingFactor, \
VectorColor, VectorLabel, ZeroVectorPointSize} /. {opts} /. \
Options[VectorGraphic];
   If[from==to, Return[Graphics3D[{PointSize[zvps],vc,Point[from]}]]];
   diff = If[NumericQ[sf], sf diff, sf[diff]];
   tip = from + diff;
   If[NumberQ[hs], hr = hs/Norm[diff]];
   tr = hr/2;
   Graphics3D[{If[sq, {vc,
   If[Head[ss]===List,Sequence@@ss,ss], st[{from,tip-tr diff}]},{}],
   If[eq, {}, EdgeForm[]], {SurfaceColor[vc],
      With[{temp = Perpendicular[diff]},
      Polygon[Append[#,tip]]& /@ Partition[(tip - hr diff + #)&/@((ap hr \
Norm[diff] Base3D) . \
{temp,Normalize[Cross[temp,diff]]}),2,1]]},InternalVectorText[vl, from, diff, \
Perpendicular[diff]]}]
] /; Length[dir]==3

VectorGraphic[___] := Graphics[{}];

Arrow[a_List, b_List, opts___] := \
Vector[b-a,Tail->a,opts]/;Length[a]==Length[b]

ArrowHead[a_List, b_List, opts___] := \
Arrow[a-b,a,ShaftQ->False,ScalingFactor->1,opts]/;Length[a]==Length[b]


End[];
EndPackage[];
Null\
\>", "Input",
  PageWidth->WindowWidth,
  ShowSpecialCharacters->False],

Cell["\<\
Off[General::spell1];
Off[ParametricPlot::ppcom];
Off[ParametricPlot3D::ppcom];\
\>", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Needs["\<GLExplorer`GLRenderer`\>"];\)\)], "Input"],

Cell[BoxData[
    \(Grid::"shdw" \(\(:\)\(\ \)\) 
      "Symbol \!\(\"Grid\"\) appears in multiple contexts \
\!\({\"GLExplorer`GLRenderer`\", \"System`\"}\); definitions in context \
\!\(\"GLExplorer`GLRenderer`\"\) may shadow or be shadowed by other \
definitions."\)], "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "Subsubtitle"],

Cell[TextData[{
  "We dealt with animation before in the chapters on two dimensional computer \
graphics.  There we looked at the capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and OpenGL/3D Explorer for producing two dimensional animations.  In this \
chapter we look at three-dimensional animation.  Our main focus here will be \
on key-frame and in-betweening techniques.  We look at classical film \
animation from a production viewpoint, from a How? viewpoint.  For a \
directorial view of ",
  Cell[BoxData[
      \(3\)]],
  " dimensional computer graphics, a What? point of view, see the paper by \
John Lasseter (LA).  This chapter just begins to touch on the exciting and \
active field of computer graphics animation production and research.  The \
list of topics not discussed here includes motion capture animation, \
realistic cloth animation, hair and fuzzy animation, etc., etc.  The student \
interested in all aspects of computer animation, with several hours \
available, could begin his or her study at the Animation World Network \
homepage (",
  ButtonBox["http://www.awn.com/",
    ButtonData:>{
      URL[ "http://www.awn.com/"], None},
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Animation Process - Key Frames 1", "Subsubtitle"],

Cell["\<\
Constructing a scene in classical film animation, for example the \
Disney classics Snow White, Pinocchio, Cinderella, etc., consists of one or \
more of the following steps: storyboarding, sound track, key frames, \
in-between frames and painting.  Each scene is laid out in a sequence of \
rough sketches (storyboard).  Key frames are drawn by senior artists and the \
frames in-between the key frames and the painting of the frames are then \
assigned to others.  (See (TJ)).\
\>", "Text"],

Cell[TextData[{
  "The process of creating a computer animation is similar (see ",
  ButtonBox["http://www.pixar.com/funstuff/how-its-done.html",
    ButtonData:>{
      URL[ "http://www.pixar.com/funstuff/how-its-done.html"], None},
    ButtonStyle->"Hyperlink"],
  "). Scenes are laid out using storyboards.  Computer models of the elements \
of a scene; actors, scenery, etc., are created.  Key frames or poses for each \
scene are constructed.  The computer is used to create these frames and then \
used to construct the in-between frames.  Shading and lighting are then added \
via computer.  Finally the entire frame is rendered, using the computer model \
of the frame."
}], "Text"],

Cell["\<\
We have spent some time on modeling, lighting, shading and \
rendering (and will spend more time on lighting, shading and rendering in the \
next chapter).  In this chapter we concern ourselves with the computer \
graphics techniques needed to perform the keyframe/in-between step.\
\>", \
"Text"],

Cell[TextData[{
  "Suppose we have a simple scene:  a block of wood slides down an inclined \
plane.  What physical parameters must we describe in order to be able to \
construct a sequence of pictures which would constitute an animation of this \
scene?  We would have to describe the position of the block at time ",
  StyleBox["t", "Output",
    FontSize->16,
    FontWeight->"Plain"],
  ", the orientation of the block at time ",
  StyleBox["t", "Output",
    FontSize->16,
    FontWeight->"Plain"],
  ", ie, does it twist and turn or remain parallel to the edges of the wedge. \
   For this proposed animation, it's a fairly simple matter to describe the \
position of the block, the orientation of the block, and the speed of the \
block as it slides down the plane."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6113
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0448481 1.04485 -0.203462 1.04485 [
[ 0 0 0 0 ]
[ 1 .6113 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .6113 L
0 .6113 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.09278 .55685 m .10744 .36568 L .04376 .30674 L p .938 .685 .528 r
F P
0 g
s
.10744 .36568 m .09278 .55685 L .94808 .08865 L closepath p .548 .33 .536 r
F P
0 g
s
.04376 .30674 m .10744 .36568 L .94808 .08865 L p .662 .744 .911 r
F P
0 g
s
.04376 .30674 m .02616 .50017 L .09278 .55685 L p .938 .685 .528 r
F P
0 g
s
.94808 .08865 m .8991 .01585 L .04376 .30674 L p .662 .744 .911 r
F P
0 g
s
.04376 .30674 m .8991 .01585 L .02616 .50017 L closepath p .539 .318 .527 r
F P
0 g
s
.09278 .55685 m .02616 .50017 L .8991 .01585 L p .735 .772 .883 r
F P
0 g
s
.8991 .01585 m .94808 .08865 L .09278 .55685 L p .735 .772 .883 r
F P
0 g
s
.07366 .49771 m .10668 .52632 L .1559 .49928 L p .735 .772 .883 r
F P
0 g
s
.16504 .54425 m .1559 .49928 L .10668 .52632 L p .546 .327 .534 r
F P
0 g
s
.10668 .52632 m .11521 .57142 L .16504 .54425 L p .546 .327 .534 r
F P
0 g
s
.11521 .57142 m .10668 .52632 L .07366 .49771 L p .939 .594 .342 r
F P
0 g
s
.1559 .49928 m .12335 .47023 L .07366 .49771 L p .735 .772 .883 r
F P
0 g
s
.12335 .47023 m .1559 .49928 L .16504 .54425 L p .94 .589 .324 r
F P
0 g
s
.07366 .49771 m .08192 .54304 L .11521 .57142 L p .939 .594 .342 r
F P
0 g
s
.16504 .54425 m .11521 .57142 L .08192 .54304 L p .735 .776 .886 r
F P
0 g
s
.13222 .51542 m .08192 .54304 L .07366 .49771 L p .542 .321 .529 r
F P
0 g
s
.07366 .49771 m .12335 .47023 L .13222 .51542 L p .542 .321 .529 r
F P
0 g
s
1 0 0 r
5 Mabswid
.07366 .49771 Mdot
.5 Mabswid
.08192 .54304 m .13222 .51542 L .16504 .54425 L p .735 .776 .886 r
F P
0 g
s
.16504 .54425 m .13222 .51542 L .12335 .47023 L p .94 .589 .324 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{340.688, 208.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005D0000d1000`40O003h00OogoLEGoL003oOmaE
Om`00?mog5Eog000ogoLEGoL003oOmaEOm`00?mog5Eog000ogoL<GoL0P008WoL003oOm`^Om`30000
0elL001og00QOm`00?mog2]og0@000AO7003001og7oL01mog000ogoL:7oL0`0000=5D000Ga`01UlL
00<007oLOm`07WoL003oOm`UOm`30002AE020008Ga`00`00Omaog00NOm`00?mog29og0<000=5D080
00]O7003001og7oL01eog000ogoL7goL0`0014E@0P003UlL00<007oLOm`077oL003oOm`LOm`30005
AE02000@Ga`00`00Omaog00LOm`00?mog1Uog0<000M5D003001O75lL015O7003001og7oL01]og000
ogoL5WoL0`0024E@0P005ElL00<007oLOm`06WoL003oOm`COm`30009AE02000GGa`00`00Omaog00J
Om`00?mog11og0<000Y5D08001YO7003001og7oL01Uog000ogoL3GoL0`002dE@0P007ElL00<007oL
Om`067oL003oOm`:Om`3000=AE000`00GaaO700MGa`00`00Omaog00HOm`00?mog0Mog0<000i5D080
025O7003001og7oL01Mog000ogoL17oL0`003dE@0P0095lL00<007oLOm`05WoL003oOm`1Om`3000@
AE02000VGa`00`00Omaog00FOm`00?eog0<00155D08002UO7003001og7oL01Eog000nWoL0`004dE@
00<005lLGa`0:UlL00<007oLOm`057oL003gOm`3000DAE02000]Ga`00`00Omaog00DOm`00?Aog0<0
01E5D080031O7003001og7oL01=og000lGoL0`005TE@0P00<elL00<007oLOm`04WoL003^Om`3000G
AE02000eGa`00`00Omaog00BOm`00>]og0<001U5D003001O75lL03IO7003001og7oL015og000j7oL
0`006TE@0P00>ElL0P004WoL003VOm`2000KAE02000iGa`2000DOm`00>=og0<001]5D08003UO7080
01Iog000h7oL0`0074E@0P00>UlL00<007oLOm`05WoL003MOm`3000NAE000`00GaaO700hGa`2000I
Om`00=Yog0<001m5D08003UO708001]og000egoL0`0084E@0P00>ElL0P007GoL003DOm`3000QAE02
000iGa`2000OOm`00=5og0<00295D08003UO7080025og000cWoL0`0094E@00<005lLGa`0>5lL00<0
07oLOm`08GoL003;Om`3000UAE02000iGa`2000TOm`00<Qog0<002I5D08003UO708002Iog000aGoL
0`009dE@0P00>ElL0P00:7oL0032Om`3000XAE02000iGa`2000ZOm`00;mog0<002Y5D003001O75lL
03QO7003001og7oL02Yog000_7oL0`00:dE@0P00>ElL0P00;GoL002iOm`3000/AE02000iGa`2000_
Om`00;Iog0<002e5D08003UO7080035og000/goL0`00;TE@0P00>ElL0P00<goL002`Om`3000_AE02
000iGa`2000eOm`00:eog0<00355D003001O75lL03QO7003001og7oL03Eog000ZWoL0`00<TE@0P00
>ElL0P00>7oL002WOm`3000cAE02000iGa`2000jOm`00:Aog0<003A5D08003UO708003aog000XGoL
0`00=DE@0P00>ElL0P00?WoL002OOm`2000gAE000`00GaaO700gGa`20010Om`009aog0<003M5D080
03UO7003001og7oL041og000VGoL0`00>4E@0P00>ElL0P00@goL002FOm`3000iAE02000iGa`20015
Om`009=og0<003Y5D08003UO708004Mog000T7oL0`00?4E@00<005lLGa`0=elL0P00BGoL002=Om`3
000mAE02000iGa`00`00Omaog019Om`008Yog0<003i5D08003UO708004aog000QgoL0`00?dE@0P00
>ElL0P00CWoL0024Om`30010AE02000iGa`2001@Om`0085og0<00495D003001O75lL03MO7080059o
g000OWoL0`00@dE@0P00>5lL0P00E7oL001kOm`30014AE02000iGa`00`00Omaog01DOm`007Qog0<0
04E5D08003UO708005Mog000MGoL0`00ATE@0P00>ElL0P00FGoL001bOm`30018AE000`00GaaO700g
Ga`2001KOm`006mog0<004U5D08003QO708005eog000K7oL0`00BTE@0P00>5lL0P00GgoL001YOm`3
001;AE02000iGa`00`00Omaog01OOm`006Iog0<004a5D08003UO7080069og000HgoL0`00CTE@00<0
05lLGa`0=elL0P00I7oL001POm`3001?AE02000hGa`2001VOm`005eog0<00515D08003QO708006Qo
g000FWoL0`00DDE@0P00>ElL00<007oLOm`0J7oL001GOm`3001BAE02000iGa`2001[Om`005Eog080
05A5D003001O75lL03MO708006eog000DWoL0`00E4E@0P00>5lL0P00KgoL001?Om`3001EAE02000h
Ga`2001aOm`004aog0<005I5D08003QO708007=og000BGoL0`00EdE@0P00>ElL00<007oLOm`0LgoL
0016Om`3001IAE000`00GaaO700gGa`2001fOm`004=og0<005Y5D08003QO708007Qog000@7oL0`00
FdE@0P00>5lL0P00NWoL000mOm`3001LAE02000hGa`2001lOm`003Yog0<005e5D08003QO708007io
g000=goL0`00GTE@0P00>ElL00<007oLOm`0OWoL000dOm`3001PAE000`00GaaO700gGa`20021Om`0
035og0<00655D08003QO708008=og000;WoL0`00HTE@0P00>5lL0P00QGoL000[Om`3001SAE02000h
Ga`20027Om`002Qog0<006A5D08003UO7003001og7oL08Mog0009GoL0`00ITE@00<005lLGa`0=elL
0P00RWoL000ROm`3001WAE02000hGa`2002<Om`001mog0<006Q5D08003QO708008iog00077oL0`00
JDE@0P00>5lL0P00T7oL000IOm`3001ZAE02000hGa`2002BOm`001Iog0<006a5D003001O75lL03MO
7003001og7oL099og0004goL0`00KDE@0P00>5lL0P00UGoL000@Om`3001^AE02000hGa`2002GOm`0
00mog0030015D4E@06e5D08003QO708009Uog0003goL00<004E@AE00JdE@0P00>5lL0P00VgoL000?
Om`00`00AE15D01ZAE000`00GaaO700fGa`2002MOm`000mog0030015D4E@06Q5D08003QO7003001o
g7oL09eog0003goL00<004E@AE00ITE@0P00>5lL0P00X7oL000?Om`00`00AE15D01TAE02000hGa`2
002ROm`000iog0030015D4E@06=5D08003QO70800:Aog0003WoL00<004E@AE00HTE@00<005lLGa`0
=UlL0P00YWoL000>Om`00`00AE15D01PAE02000hGa`00`00Omaog02VOm`000iog0030015D4E@05i5
D08003QO70800:Uog0003WoL00<004E@AE00G4E@0P00>5lL0P00ZgoL000>Om`00`00AE15D01JAE02
000hGa`2002]Om`000iog0030015D4E@05U5D003001O75lL03IO70800:mog0003WoL00<004E@AE00
EdE@0P00=elL0P00/GoL000>Om`00`00AE15D01EAE02000hGa`00`00Omaog02aOm`000iog0030015
D4E@05=5D08003QO70800;Aog0003WoL00<004E@AE00DDE@0P00>5lL0P00]WoL000=Om`00`00AE15
D01AAE000`00GaaO700fGa`2002hOm`000eog0030015D4E@04m5D08003MO70800;Yog0003GoL00<0
04E@AE00CDE@0P00=elL0P00_7oL000=Om`00`00AE15D01;AE02000hGa`00`00Omaog02lOm`000eo
g0030015D4E@04U5D08003QO70800;mog0003GoL00<004E@AE00B4E@00<005lLGa`0=UlL0P00`GoL
000=Om`00`00AE15D016AE02000gGa`20033Om`000eog0030015D4E@04A5D08003MO70800<Eog000
3GoL00<004E@AE00@TE@0P00>5lL00<007oLOm`0aGoL000=Om`00`00AE15D010AE02000hGa`20038
Om`000eog0030015D4E@03i5D08003QO70800<Yog00037oL00<004E@AE00?TE@00<005lLGa`0=UlL
0P00c7oL000<Om`00`00AE15D00lAE02000gGa`2003>Om`000aog0030015D4E@03Y5D08003MO7080
0=1og00037oL00<004E@AE00>4E@0P00>5lL00<007oLOm`0d7oL000<Om`00`00AE15D00fAE02000h
Ga`2003COm`000aog0030015D4E@03E5D003001O75lL03IO70800=Eog00037oL00<004E@AE00<dE@
0P00=elL0P00egoL000<Om`00`00AE15D00aAE02000gGa`2003IOm`000aog0030015D4E@02m5D080
03MO70800=]og00037oL00<004E@AE00;DE@0P00>5lL00<007oLOm`0fgoL000<Om`00`00AE15D00/
AE000`00GaaO700fGa`2003NOm`000]og0030015D4E@02]5D08003MO70800>1og0002goL00<004E@
AE00:DE@0P00=elL0P00hWoL000;Om`00`00AE15D00WAE02000gGa`2003TOm`000]og0030015D4E@
02E5D08003QO7003001og7oL0>Aog0002goL00<004E@AE0094E@00<005lLGa`0=UlL0P00igoL000;
Om`00`00AE15D00RAE02000gGa`2003YOm`000]og0030015D4E@0215D08003MO70800>]og0002goL
00<004E@AE007TE@0P00=elL0P00kGoL000;Om`00`00AE15D00LAE02000gGa`2003_Om`000]og003
0015D4E@01]5D003001O75lL03IO7003001og7oL0>mog0002goL00<004E@AE006DE@0P00=elL0P00
lWoL000:Om`00`00AE15D00HAE02000gGa`2003dOm`000Yog0030015D4E@01I5D08003MO70800?Io
g0002WoL00<004E@AE0054E@0P00=elL0P00n7oL000:Om`00`00AE15D00CAE000`00GaaO700eGa`2
003jOm`000Yog0030015D4E@0155D08003MO7003001og7oL0?Yog0002WoL00<004E@AE003dE@0P00
=elL0P00oGoL000:Om`00`00AE15D00=AE02000=Ga`3000WGa`2003oOm`000Yog0030015D4E@00]5
D08000eO70800004AE0007Y:000TGa`2003oOm`2Om`000Yog0030015D4E@00Y5D003001O75lL00]O
708000=5D004001jBWY:000QGa`2003oOm`4Om`000Yog0030015D4E@00Q5D08000aO708000I5D004
001jBWY:000OGa`00`00Omaog03oOm`4Om`000Yog0030015D4E@00I5D08000aO708000Q5D005001j
BWY:NTX0000LGa`2003oOm`7Om`000Uog0030015D4E@00E5D08000eO70030015D4E@00Q5D003001j
BWY:009jBP03001O75lL01MO70800?mog0Uog0002GoL00<004E@AE000dE@0P003ElL0P002dE@00<0
07Y:NTX00gY:00<005lLGa`055lL0P00ogoL2goL0009Om`00`00AE15D002AE000`00GaaO7007Ga`3
O0000elL0000000=AE000`00NTYjBP04NTX00`00GaaO700AGa`2003oOm`=Om`000Uog0030015D4E@
008000UO70El0115D003001jBWY:00AjBP03001O75lL00iO70800?mog0mog0002GoL0`002elL1G`0
44E@00<007Y:NTX01GY:00<005lLGa`035lL00<007oLOm`0ogoL3goL0009Om`2000<Ga`5O00@AE00
0`00NTYjBP06NTX00`00GaaO7009Ga`2003oOm`BOm`000]og003001O75lL00YO70=l0155D003001j
BWY:00IjBP03001O75lL00MO70800?mog1Aog00037oL00<005lLGa`02elL00<004E@AE003dE@00<0
07Y:NTX01WY:00<005lLGa`01ElL0P00ogoL5WoL000=Om`00`00GaaO700:Ga`00`00AE15D00@AE00
0`00NTYjBP06NTX00`00GaaO7002Ga`2003oOm`HOm`000iog003001O75lL00UO70030015D4E@0115
D003001jBWY:00IjBP03001O75lL00800?mog1Yog0003goL00<005lLGa`025lL00<004E@AE003dE@
0`001gY:00<005lL0000ogoL77oL000@Om`20008Ga`00`00AE15D00=AE020003Ga`00`00NTYjBP04
NTX2003oOm`MOm`0019og003001O75lL00IO70030015D4E@00Y5D08000IO7003001jBWY:00=jBP03
001og7oL0?mog1aog0004goL00<005lLGa`01ElL00<004E@AE0024E@0P002ElL00<007Y:NTX00gY:
00<007oLOm`0ogoL6goL000DOm`00`00GaaO7004Ga`00`00AE15D006AE02000<Ga`00`00NTYjBP02
NTX00`00Omaog03oOm`KOm`001Eog003001O75lL00=O70030015D4E@00E5D003001O75lL00eO7005
001jBWY:NTX0003oOm`MOm`001Iog003001O75lL009O70030015D4E@00=5D080015O7004001jBWY:
003oOm`MOm`001Mog003001O75lL009O70030015D4E@008001AO7003001jBP000?mog1eog00067oL
0P000UlL0`005elL00<007Y:0000ogoL77oL000JOm`00`00Ga`0000JGa`2003oOm`LOm`001]og004
001O75lL000IGa`00`00Omaog03oOm`JOm`001aog004001O75lL000EGa`2003oOm`NOm`001eog004
001O75lL000BGa`2003oOm`POm`001iog004001O7000000?Ga`2003oOm`ROm`001mog004001og7oL
000<Ga`2003oOm`TOm`002=og003001O75lL00QO7003001og7oL0?mog2Aog00097oL00<005lLGa`0
1ElL0P00ogoL9goL000UOm`00`00GaaO7002Ga`2003oOm`YOm`002Iog004001O7000003oOm`[Om`0
02Mog003001og7oL0?mog2]og000ogoLEGoL003oOmaEOm`00?mog5Eog000ogoLEGoL003oOmaEOm`0
0?mog5Eog000ogoLEGoL003oOmaEOm`00?mog5Eog000ogoLEGoL003oOmaEOm`00?mog5Eog000ogoL
EGoL0000\
\>"],
  ImageRangeCache->{{{0, 339.688}, {207.125, 0}} -> {0.041703, 0.194725, \
0.0028247, 0.0028247}}],

Cell["\<\
Suppose we had a circular wedge and the block was to slide down the \
plane so that one face was always perpendicular to a radius of the plane and \
the color changes continuously from red to blue through the color spectrum.  \
Suppose further that the block slides a little way after it reaches the \
bottom of the ramp.\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59255
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00460769 1.00461 -0.17772 1.00461 [
[ 0 0 0 0 ]
[ 1 .59255 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .59255 L
0 .59255 L
closepath
clip
newpath
.37278 .40512 m .30839 .40263 L .37268 .4084 L .787 .211 .013 r
F
.37278 .40512 m .30855 .39907 L .30839 .40263 L F
.43735 .40511 m .37278 .40512 L .37268 .4084 L F
.43735 .40511 m .37268 .4084 L .4373 .40808 L F
.50104 .39903 m .43735 .40511 L .4373 .40808 L F
.4373 .40808 m .37259 .41168 L .43726 .41105 L F
.4373 .40808 m .37268 .4084 L .37259 .41168 L F
.50104 .40167 m .4373 .40808 L .43726 .41105 L F
.50104 .39903 m .4373 .40808 L .50104 .40167 L F
.37268 .4084 m .30823 .40619 L .37259 .41168 L F
.37268 .4084 m .30839 .40263 L .30823 .40619 L F
.43726 .41105 m .37249 .41496 L .43722 .41402 L F
.43726 .41105 m .37259 .41168 L .37249 .41496 L F
.50104 .40431 m .43726 .41105 L .43722 .41402 L F
.50104 .40167 m .43726 .41105 L .50104 .40431 L F
.37259 .41168 m .30806 .40976 L .37249 .41496 L F
.37259 .41168 m .30823 .40619 L .30806 .40976 L F
.43722 .41402 m .37239 .41825 L .43718 .417 L F
.43722 .41402 m .37249 .41496 L .37239 .41825 L F
.50105 .40696 m .43722 .41402 L .43718 .417 L F
.50104 .40431 m .43722 .41402 L .50105 .40696 L F
.37249 .41496 m .3079 .41333 L .37239 .41825 L F
.37249 .41496 m .30806 .40976 L .3079 .41333 L F
.43718 .417 m .37229 .42155 L .43713 .41999 L F
.43718 .417 m .37239 .41825 L .37229 .42155 L F
.50105 .40961 m .43718 .417 L .43713 .41999 L F
.50105 .40696 m .43718 .417 L .50105 .40961 L F
.30855 .39907 m .24564 .39081 L .30839 .40263 L F
.30855 .39907 m .24587 .38701 L .24564 .39081 L F
.56264 .38694 m .50104 .39903 L .50104 .40167 L F
.37239 .41825 m .30774 .41691 L .37229 .42155 L F
.37239 .41825 m .3079 .41333 L .30774 .41691 L F
.56268 .38924 m .50104 .40167 L .50104 .40431 L F
.56264 .38694 m .50104 .40167 L .56268 .38924 L F
.43713 .41999 m .37219 .42485 L .43709 .42298 L F
.43713 .41999 m .37229 .42155 L .37219 .42485 L F
.50105 .41226 m .43713 .41999 L .43709 .42298 L F
.50105 .40961 m .43713 .41999 L .50105 .41226 L F
.30839 .40263 m .24541 .39463 L .30823 .40619 L F
.30839 .40263 m .24564 .39081 L .24541 .39463 L F
.37229 .42155 m .30758 .4205 L .37219 .42485 L F
.37229 .42155 m .30774 .41691 L .30758 .4205 L F
.56272 .39154 m .50104 .40431 L .50105 .40696 L F
.56268 .38924 m .50104 .40431 L .56272 .39154 L F
.43709 .42298 m .37209 .42816 L .43705 .42597 L F
.43709 .42298 m .37219 .42485 L .37209 .42816 L F
.50105 .41492 m .43709 .42298 L .43705 .42597 L F
.50105 .41226 m .43709 .42298 L .50105 .41492 L F
.30823 .40619 m .24518 .39844 L .30806 .40976 L F
.30823 .40619 m .24541 .39463 L .24518 .39844 L F
.37219 .42485 m .30741 .42409 L .37209 .42816 L F
.37219 .42485 m .30758 .4205 L .30741 .42409 L F
.56275 .39385 m .50105 .40696 L .50105 .40961 L F
.56272 .39154 m .50105 .40696 L .56275 .39385 L F
.43705 .42597 m .37199 .43147 L .437 .42897 L F
.43705 .42597 m .37209 .42816 L .37199 .43147 L F
.50105 .41758 m .43705 .42597 L .437 .42897 L F
.50105 .41492 m .43705 .42597 L .50105 .41758 L F
.56279 .39616 m .50105 .40961 L .50105 .41226 L F
.56275 .39385 m .50105 .40961 L .56279 .39616 L F
.30806 .40976 m .24495 .40227 L .3079 .41333 L F
.30806 .40976 m .24518 .39844 L .24495 .40227 L F
.37209 .42816 m .30725 .42769 L .37199 .43147 L F
.37209 .42816 m .30741 .42409 L .30725 .42769 L F
.437 .42897 m .37189 .43479 L .43696 .43197 L F
.437 .42897 m .37199 .43147 L .37189 .43479 L F
.50106 .42024 m .437 .42897 L .43696 .43197 L F
.50105 .41758 m .437 .42897 L .50106 .42024 L F
.56283 .39847 m .50105 .41226 L .50105 .41492 L F
.56279 .39616 m .50105 .41226 L .56283 .39847 L F
.3079 .41333 m .24471 .4061 L .30774 .41691 L F
.3079 .41333 m .24495 .40227 L .24471 .4061 L F
.37199 .43147 m .30708 .4313 L .37189 .43479 L F
.37199 .43147 m .30725 .42769 L .30708 .4313 L F
.43696 .43197 m .37179 .43811 L .43691 .43498 L F
.43696 .43197 m .37189 .43479 L .37179 .43811 L F
.50106 .42291 m .43696 .43197 L .43691 .43498 L F
.50106 .42024 m .43696 .43197 L .50106 .42291 L F
.56286 .40079 m .50105 .41492 L .50105 .41758 L F
.56283 .39847 m .50105 .41492 L .56286 .40079 L F
.37189 .43479 m .30692 .43491 L .37179 .43811 L F
.37189 .43479 m .30708 .4313 L .30692 .43491 L F
.30774 .41691 m .24448 .40994 L .30758 .4205 L F
.30774 .41691 m .24471 .4061 L .24448 .40994 L F
.43691 .43498 m .37169 .44144 L .43687 .43799 L F
.43691 .43498 m .37179 .43811 L .37169 .44144 L F
.50106 .42558 m .43691 .43498 L .43687 .43799 L F
.50106 .42291 m .43691 .43498 L .50106 .42558 L F
.5629 .4031 m .50105 .41758 L .50106 .42024 L F
.56286 .40079 m .50105 .41758 L .5629 .4031 L F
.43687 .43799 m .37159 .44477 L .43683 .441 L F
.43687 .43799 m .37169 .44144 L .37159 .44477 L F
.50106 .42826 m .43687 .43799 L .43683 .441 L F
.50106 .42558 m .43687 .43799 L .50106 .42826 L F
.37179 .43811 m .30675 .43853 L .37169 .44144 L F
.37179 .43811 m .30692 .43491 L .30675 .43853 L F
.56293 .40542 m .50106 .42024 L .50106 .42291 L F
.5629 .4031 m .50106 .42024 L .56293 .40542 L F
.30758 .4205 m .24425 .41379 L .30741 .42409 L F
.30758 .4205 m .24448 .40994 L .24425 .41379 L F
.24587 .38701 m .18568 .37309 L .24564 .39081 L F
.24587 .38701 m .18598 .36908 L .18568 .37309 L F
.62094 .36898 m .56264 .38694 L .56268 .38924 L F
.43683 .441 m .37149 .44811 L .43678 .44402 L F
.43683 .441 m .37159 .44477 L .37149 .44811 L F
.50107 .43093 m .43683 .441 L .43678 .44402 L F
.50106 .42826 m .43683 .441 L .50107 .43093 L F
.56297 .40774 m .50106 .42291 L .50106 .42558 L F
.56293 .40542 m .50106 .42291 L .56297 .40774 L F
.37169 .44144 m .30659 .44215 L .37159 .44477 L F
.37169 .44144 m .30675 .43853 L .30659 .44215 L F
.30741 .42409 m .24401 .41764 L .30725 .42769 L F
.30741 .42409 m .24425 .41379 L .24401 .41764 L F
.621 .37094 m .56268 .38924 L .56272 .39154 L F
.62094 .36898 m .56268 .38924 L .621 .37094 L F
.56301 .41007 m .50106 .42558 L .50106 .42826 L F
.56297 .40774 m .50106 .42558 L .56301 .41007 L F
.43678 .44402 m .37139 .45145 L .43674 .44704 L F
.43678 .44402 m .37149 .44811 L .37139 .45145 L F
.50107 .43361 m .43678 .44402 L .43674 .44704 L F
.50107 .43093 m .43678 .44402 L .50107 .43361 L F
.24564 .39081 m .18538 .37711 L .24541 .39463 L F
.24564 .39081 m .18568 .37309 L .18538 .37711 L F
.37159 .44477 m .30642 .44578 L .37149 .44811 L F
.37159 .44477 m .30659 .44215 L .30642 .44578 L F
.62105 .3729 m .56272 .39154 L .56275 .39385 L F
.621 .37094 m .56272 .39154 L .62105 .3729 L F
.30725 .42769 m .24378 .4215 L .30708 .4313 L F
.30725 .42769 m .24401 .41764 L .24378 .4215 L F
.56304 .41239 m .50106 .42826 L .50107 .43093 L F
.56301 .41007 m .50106 .42826 L .56304 .41239 L F
.43674 .44704 m .37129 .4548 L .4367 .45007 L F
.43674 .44704 m .37139 .45145 L .37129 .4548 L F
.50107 .4363 m .43674 .44704 L .4367 .45007 L F
.50107 .43361 m .43674 .44704 L .50107 .4363 L F
.62111 .37486 m .56275 .39385 L .56279 .39616 L F
.62105 .3729 m .56275 .39385 L .62111 .37486 L F
.37149 .44811 m .30626 .44942 L .37139 .45145 L F
.37149 .44811 m .30642 .44578 L .30626 .44942 L F
.24541 .39463 m .18507 .38114 L .24518 .39844 L F
.24541 .39463 m .18538 .37711 L .18507 .38114 L F
.56308 .41472 m .50107 .43093 L .50107 .43361 L F
.56304 .41239 m .50107 .43093 L .56308 .41472 L F
.30708 .4313 m .24354 .42537 L .30692 .43491 L F
.30708 .4313 m .24378 .4215 L .24354 .42537 L F
.4367 .45007 m .37119 .45815 L .43665 .4531 L F
.4367 .45007 m .37129 .4548 L .37119 .45815 L F
.50107 .43899 m .4367 .45007 L .43665 .4531 L F
.50107 .4363 m .4367 .45007 L .50107 .43899 L F
.62117 .37682 m .56279 .39616 L .56283 .39847 L F
.62111 .37486 m .56279 .39616 L .62117 .37682 L F
.37139 .45145 m .30609 .45306 L .37129 .4548 L F
.37139 .45145 m .30626 .44942 L .30609 .45306 L F
.56312 .41706 m .50107 .43361 L .50107 .4363 L F
.56308 .41472 m .50107 .43361 L .56312 .41706 L F
.24518 .39844 m .18477 .38517 L .24495 .40227 L F
.24518 .39844 m .18507 .38114 L .18477 .38517 L F
.62123 .37879 m .56283 .39847 L .56286 .40079 L F
.62117 .37682 m .56283 .39847 L .62123 .37879 L F
.30692 .43491 m .24331 .42925 L .30675 .43853 L F
.30692 .43491 m .24354 .42537 L .24331 .42925 L F
.43665 .4531 m .37109 .46151 L .43661 .45614 L F
.43665 .4531 m .37119 .45815 L .37109 .46151 L F
.50107 .44168 m .43665 .4531 L .43661 .45614 L F
.50107 .43899 m .43665 .4531 L .50107 .44168 L F
.56315 .41939 m .50107 .4363 L .50107 .43899 L F
.56312 .41706 m .50107 .4363 L .56315 .41939 L F
.37129 .4548 m .30593 .45671 L .37119 .45815 L F
.37129 .4548 m .30609 .45306 L .30593 .45671 L F
.62129 .38075 m .56286 .40079 L .5629 .4031 L F
.62123 .37879 m .56286 .40079 L .62129 .38075 L F
.43661 .45614 m .37099 .46488 L .43656 .45918 L F
.43661 .45614 m .37109 .46151 L .37099 .46488 L F
.50108 .44437 m .43661 .45614 L .43656 .45918 L F
.50107 .44168 m .43661 .45614 L .50108 .44437 L F
.24495 .40227 m .18446 .38922 L .24471 .4061 L F
.24495 .40227 m .18477 .38517 L .18446 .38922 L F
.30675 .43853 m .24307 .43313 L .30659 .44215 L F
.30675 .43853 m .24331 .42925 L .24307 .43313 L F
.56319 .42173 m .50107 .43899 L .50107 .44168 L F
.56315 .41939 m .50107 .43899 L .56319 .42173 L F
.62135 .38272 m .5629 .4031 L .56293 .40542 L F
.62129 .38075 m .5629 .4031 L .62135 .38272 L F
.37119 .45815 m .30576 .46037 L .37109 .46151 L F
.37119 .45815 m .30593 .45671 L .30576 .46037 L F
.43656 .45918 m .37089 .46825 L .43652 .46222 L F
.43656 .45918 m .37099 .46488 L .37089 .46825 L F
.50108 .44707 m .43656 .45918 L .43652 .46222 L F
.50108 .44437 m .43656 .45918 L .50108 .44707 L F
.62141 .38469 m .56293 .40542 L .56297 .40774 L F
.62135 .38272 m .56293 .40542 L .62141 .38469 L F
.56323 .42407 m .50107 .44168 L .50108 .44437 L F
.56319 .42173 m .50107 .44168 L .56323 .42407 L F
.24471 .4061 m .18416 .39327 L .24448 .40994 L F
.24471 .4061 m .18446 .38922 L .18416 .39327 L F
.30659 .44215 m .24283 .43702 L .30642 .44578 L F
.30659 .44215 m .24307 .43313 L .24283 .43702 L F
.37109 .46151 m .30559 .46403 L .37099 .46488 L F
.37109 .46151 m .30576 .46037 L .30559 .46403 L F
.62147 .38667 m .56297 .40774 L .56301 .41007 L F
.62141 .38469 m .56297 .40774 L .62147 .38667 L F
.436 .45934 m .37089 .46825 L .43652 .46222 L .479 .526 .746 r
F
.50108 .44707 m .43652 .46222 L .50108 .44977 L .787 .211 .013 r
F
.4998 .44695 m .43652 .46222 L .50108 .44977 L .479 .526 .746 r
F
.4998 .44695 m .436 .45934 L .43652 .46222 L F
.56326 .42641 m .50108 .44437 L .50108 .44707 L .787 .211 .013 r
F
.56323 .42407 m .50108 .44437 L .56326 .42641 L F
.30642 .44578 m .2426 .44091 L .30626 .44942 L F
.30642 .44578 m .24283 .43702 L .2426 .44091 L F
.24448 .40994 m .18385 .39733 L .24425 .41379 L F
.24448 .40994 m .18416 .39327 L .18385 .39733 L F
.62153 .38864 m .56301 .41007 L .56304 .41239 L F
.62147 .38667 m .56301 .41007 L .62153 .38864 L F
.37099 .46488 m .30543 .4677 L .37089 .46825 L F
.37099 .46488 m .30559 .46403 L .30543 .4677 L F
.5633 .42876 m .50108 .44707 L .50108 .44977 L F
.56326 .42641 m .50108 .44707 L .5633 .42876 L F
.62158 .39062 m .56304 .41239 L .56308 .41472 L F
.62153 .38864 m .56304 .41239 L .62158 .39062 L F
.30626 .44942 m .24236 .44482 L .30609 .45306 L F
.30626 .44942 m .2426 .44091 L .24236 .44482 L F
.24425 .41379 m .18354 .4014 L .24401 .41764 L F
.24425 .41379 m .18385 .39733 L .18354 .4014 L F
.5633 .42876 m .50108 .44977 L .56334 .4311 L F
.56131 .4284 m .50108 .44977 L .56334 .4311 L .479 .526 .746 r
F
.56131 .4284 m .4998 .44695 L .50108 .44977 L F
.436 .45934 m .37114 .46537 L .37089 .46825 L F
.43548 .45645 m .37114 .46537 L .436 .45934 L F
.49851 .44412 m .436 .45934 L .4998 .44695 L F
.49851 .44412 m .43548 .45645 L .436 .45934 L F
.37114 .46537 m .30543 .4677 L .37089 .46825 L F
.62164 .3926 m .56308 .41472 L .56312 .41706 L .787 .211 .013 r
F
.62158 .39062 m .56308 .41472 L .62164 .3926 L F
.30609 .45306 m .24212 .44873 L .30593 .45671 L F
.30609 .45306 m .24236 .44482 L .24212 .44873 L F
.6217 .39458 m .56312 .41706 L .56315 .41939 L F
.62164 .3926 m .56312 .41706 L .6217 .39458 L F
.24401 .41764 m .18323 .40547 L .24378 .4215 L F
.24401 .41764 m .18354 .4014 L .18323 .40547 L F
.62176 .39656 m .56315 .41939 L .56319 .42173 L F
.6217 .39458 m .56315 .41939 L .62176 .39656 L F
.55928 .42569 m .4998 .44695 L .56131 .4284 L .479 .526 .746 r
F
.55928 .42569 m .49851 .44412 L .4998 .44695 L F
.43548 .45645 m .37139 .46248 L .37114 .46537 L F
.43496 .45355 m .37139 .46248 L .43548 .45645 L F
.49723 .44128 m .43548 .45645 L .49851 .44412 L F
.49723 .44128 m .43496 .45355 L .43548 .45645 L F
.37114 .46537 m .30645 .46489 L .30543 .4677 L F
.37139 .46248 m .30645 .46489 L .37114 .46537 L F
.30593 .45671 m .24188 .45265 L .30576 .46037 L .787 .211 .013 r
F
.30593 .45671 m .24212 .44873 L .24188 .45265 L F
.24378 .4215 m .18293 .40956 L .24354 .42537 L F
.24378 .4215 m .18323 .40547 L .18293 .40956 L F
.18598 .36908 m .12977 .34965 L .18568 .37309 L F
.18598 .36908 m .13015 .34547 L .12977 .34965 L F
.62182 .39854 m .56319 .42173 L .56323 .42407 L F
.62176 .39656 m .56319 .42173 L .62182 .39854 L F
.67467 .34535 m .62094 .36898 L .621 .37094 L F
.67474 .34697 m .621 .37094 L .62105 .3729 L F
.67467 .34535 m .621 .37094 L .67474 .34697 L F
.62188 .40053 m .56323 .42407 L .56326 .42641 L F
.62182 .39854 m .56323 .42407 L .62188 .40053 L F
.30576 .46037 m .24164 .45657 L .30559 .46403 L F
.30576 .46037 m .24188 .45265 L .24164 .45657 L F
.55724 .42297 m .49851 .44412 L .55928 .42569 L .479 .526 .746 r
F
.55724 .42297 m .49723 .44128 L .49851 .44412 L F
.24354 .42537 m .18262 .41365 L .24331 .42925 L .787 .211 .013 r
F
.24354 .42537 m .18293 .40956 L .18262 .41365 L F
.43496 .45355 m .37164 .45959 L .37139 .46248 L .479 .526 .746 r
F
.43443 .45065 m .37164 .45959 L .43496 .45355 L F
.5 Mabswid
[ ] 0 setdash
.44312 .41763 m .44247 .44837 L .44255 .44902 L p 0 1 0 r
F P
0 g
s
.44312 .41763 m .44255 .44902 L .44255 .44885 L 0 1 0 r
F
.44312 .41763 m .44255 .44904 L .44255 .44887 L F
.44312 .41763 m .44255 .44905 L .44255 .44889 L F
.44312 .41763 m .44255 .44906 L .44256 .44891 L F
.44312 .41763 m .44255 .44908 L .44255 .44903 L F
.44312 .41763 m .44255 .44908 L .44331 .42083 L F
.44247 .44837 m .44312 .41763 L .39282 .42113 L p F P
0 g
s
.48282 .40951 m .44349 .41801 L .44343 .4201 L .479 .526 .746 r
F
.44471 .41998 m .44343 .4201 L .44342 .42033 L F
.48282 .40951 m .44343 .4201 L .44471 .41998 L F
.46271 .41826 m .4434 .42117 L .44333 .42353 L F
.48415 .41244 m .45222 .41928 L .46271 .41826 L F
.45222 .41928 m .4434 .42117 L .46271 .41826 L F
.48547 .41536 m .44331 .42431 L .44323 .42671 L F
.48679 .41827 m .44321 .42744 L .44314 .42987 L F
.48811 .42118 m .44312 .43056 L .44305 .43303 L F
.49594 .43843 m .45787 .44787 L .49723 .44128 L F
.45787 .44787 m .44248 .45169 L .4659 .44723 L F
.45787 .44787 m .4659 .44723 L .49723 .44128 L F
.44247 .44837 m .39281 .45188 L p .39434 .4529 L 0 1 0 r
F P
0 g
s
.44248 .45169 m .43496 .45355 L .44247 .45207 L .479 .526 .746 r
F
.44248 .45169 m .44247 .45207 L .49723 .44128 L F
.45787 .44787 m .43443 .45065 L .43496 .45355 L F
.39434 .4529 m .39436 .45291 L .44255 .44908 L 0 1 0 r
F
.40216 .45231 m .39293 .45365 L .43429 .44984 L .479 .526 .746 r
F
.39293 .45365 m .3719 .45668 L .39293 .45438 L F
.39293 .45365 m .39293 .45438 L .43429 .44984 L F
.39282 .42113 m .39281 .45188 L .44247 .44837 L p 0 1 0 r
F P
0 g
s
.39281 .45188 m .39282 .42113 L p .39315 .42642 L 0 1 0 r
F P
0 g
s
.39293 .45365 m .37207 .45468 L .3719 .45668 L .479 .526 .746 r
F
.40216 .45231 m .39294 .45304 L .39293 .45365 L F
.39294 .45304 m .37207 .45468 L .39293 .45365 L F
.43429 .44984 m .3719 .45668 L .43443 .45065 L F
.43443 .45065 m .3719 .45668 L .37164 .45959 L F
.39281 .45188 m .39719 .49184 L .44737 .48823 L p 0 1 0 r
F P
0 g
s
.43338 .44481 m .39296 .45073 L .43391 .44773 L .479 .526 .746 r
F
.39315 .42642 m .39315 .4265 L .39301 .44424 L 0 1 0 r
F
.39315 .42642 m .39301 .44424 L .39301 .44435 L F
.39315 .42642 m .393 .44551 L .393 .44561 L F
.39315 .42642 m .39299 .44675 L .39299 .44685 L F
.39315 .42642 m .39298 .44797 L .39298 .44806 L F
.39315 .42642 m .39297 .44916 L .39297 .44924 L F
.39315 .42642 m .39296 .45033 L .39296 .45041 L F
.39315 .42642 m .39295 .45147 L .39295 .45154 L F
.39315 .42642 m .39294 .45259 L .39294 .45262 L F
.42966 .42411 m .39319 .42811 L .39317 .43004 L .479 .526 .746 r
F
.43019 .42709 m .39316 .43109 L .39314 .43302 L F
.43073 .43006 m .39313 .43407 L .39311 .43599 L F
.43126 .43303 m .3931 .43703 L .39308 .43896 L F
.43179 .43599 m .39307 .43999 L .39305 .44191 L F
.43233 .43894 m .39304 .44294 L .39302 .44486 L F
.43285 .44188 m .39301 .44588 L .39299 .4478 L F
.43338 .44481 m .39298 .44881 L .39296 .45073 L F
.39296 .45073 m .39295 .45174 L .43391 .44773 L F
.39315 .4265 m .39316 .42658 L .39296 .45116 L 0 1 0 r
F
.43285 .44188 m .39299 .4478 L .43338 .44481 L .479 .526 .746 r
F
.39299 .4478 m .39298 .44881 L .43338 .44481 L F
.43233 .43894 m .39302 .44486 L .43285 .44188 L F
.39316 .42658 m .39316 .42666 L .39298 .44929 L 0 1 0 r
F
.39316 .42666 m .393 .44739 L .39298 .44929 L F
.39316 .42658 m .39298 .44929 L .39296 .45116 L F
.39315 .4265 m .39296 .45116 L .39294 .45302 L F
.39294 .45302 m .39281 .45188 L p .39315 .42642 L F P
0 g
s
.39302 .44486 m .37266 .44793 L .39301 .44588 L .479 .526 .746 r
F
.39302 .44486 m .39301 .44588 L .43285 .44188 L F
.43179 .43599 m .39305 .44191 L .43233 .43894 L F
.39316 .42666 m .39317 .42675 L .393 .44739 L 0 1 0 r
F
.39317 .42675 m .39302 .44547 L .393 .44739 L F
.39305 .44191 m .37292 .44499 L .39304 .44294 L .479 .526 .746 r
F
.39305 .44191 m .39304 .44294 L .43233 .43894 L F
.43126 .43303 m .39308 .43896 L .43179 .43599 L F
.39317 .42675 m .39317 .42683 L .39302 .44547 L 0 1 0 r
F
.39317 .42683 m .39304 .44353 L .39302 .44547 L F
.39308 .43896 m .37318 .44205 L .39307 .43999 L .479 .526 .746 r
F
.39308 .43896 m .39307 .43999 L .43179 .43599 L F
.43073 .43006 m .39311 .43599 L .43126 .43303 L F
.39317 .42683 m .39318 .42692 L .39304 .44353 L 0 1 0 r
F
.39318 .42692 m .39307 .44157 L .39304 .44353 L F
.39311 .43599 m .37343 .43909 L .3931 .43703 L .479 .526 .746 r
F
.39311 .43599 m .3931 .43703 L .43126 .43303 L F
.43019 .42709 m .39314 .43302 L .43073 .43006 L F
.39318 .42692 m .39318 .42702 L .39307 .44157 L 0 1 0 r
F
.39318 .42702 m .39309 .43959 L .39307 .44157 L F
.39314 .43302 m .37369 .43613 L .39313 .43407 L .479 .526 .746 r
F
.39314 .43302 m .39313 .43407 L .43073 .43006 L F
.42966 .42411 m .39317 .43004 L .43019 .42709 L F
.39318 .42702 m .39319 .42711 L .39309 .43959 L 0 1 0 r
F
.39319 .42711 m .39311 .43759 L .39309 .43959 L F
.39317 .43004 m .37395 .43316 L .39316 .43109 L .479 .526 .746 r
F
.39317 .43004 m .39316 .43109 L .43019 .42709 L F
.44343 .4201 m .44312 .41763 L p .44327 .42011 L 0 1 0 r
F P
0 g
s
.39436 .45291 m .42738 .45038 L .44255 .44908 L 0 1 0 r
F
.42702 .45041 m .43997 .44936 L .44255 .44908 L F
.43935 .44941 m .43429 .44984 L .43443 .45065 L .479 .526 .746 r
F
.43935 .44941 m .43443 .45065 L .44151 .44924 L F
.39473 .45316 m .44151 .44924 L .42702 .45041 L 0 1 0 r
F
.44151 .44924 m .44256 .44915 L .42702 .45041 L F
.44255 .44908 m .44247 .44837 L p .39434 .4529 L F P
0 g
s
.44255 .44908 m .44255 .44909 L p .44331 .42083 L 0 1 0 r
F P
0 g
s
.44255 .44909 m .44256 .4491 L p .44257 .44861 L 0 1 0 r
F P
0 g
s
.44331 .42083 m .44255 .44909 L .44257 .44861 L 0 1 0 r
F
.44331 .42083 m .44256 .4491 L .44257 .44865 L F
.44331 .42083 m .44256 .44912 L .44257 .44869 L F
.44331 .42083 m .44256 .44913 L .44257 .44872 L F
.48942 .42407 m .44303 .43366 L .44295 .43617 L .479 .526 .746 r
F
.49073 .42696 m .44294 .43676 L .44286 .4393 L F
.49204 .42984 m .44284 .43984 L .44276 .44241 L F
.49334 .43271 m .44275 .44292 L .44267 .44552 L F
.44331 .42083 m .44256 .44914 L .44258 .44861 L 0 1 0 r
F
.49334 .43271 m .44267 .44552 L .49464 .43557 L .479 .526 .746 r
F
.44332 .42093 m .44258 .44861 L .44266 .44598 L 0 1 0 r
F
.44331 .42083 m .44258 .44861 L .44332 .42093 L F
.44267 .44552 m .43391 .44773 L .44266 .44598 L .479 .526 .746 r
F
.44267 .44552 m .44266 .44598 L .49464 .43557 L F
.49204 .42984 m .44276 .44241 L .49334 .43271 L F
.44332 .42103 m .44266 .44598 L .44274 .4434 L 0 1 0 r
F
.44332 .42103 m .44274 .4434 L .44333 .42113 L F
.44332 .42093 m .44266 .44598 L .44332 .42103 L F
.44276 .44241 m .43338 .44481 L .44275 .44292 L .479 .526 .746 r
F
.44276 .44241 m .44275 .44292 L .49334 .43271 L F
.49073 .42696 m .44286 .4393 L .49204 .42984 L F
.44333 .42113 m .44274 .4434 L .44282 .44086 L 0 1 0 r
F
.44333 .42113 m .44282 .44086 L .44334 .42123 L F
.44286 .4393 m .43285 .44188 L .44284 .43984 L .479 .526 .746 r
F
.44286 .4393 m .44284 .43984 L .49204 .42984 L F
.48942 .42407 m .44295 .43617 L .49073 .42696 L F
.44334 .42123 m .44282 .44086 L .44289 .43836 L 0 1 0 r
F
.44334 .42123 m .44289 .43836 L .44334 .42134 L F
.44295 .43617 m .43233 .43894 L .44294 .43676 L .479 .526 .746 r
F
.44295 .43617 m .44294 .43676 L .49073 .42696 L F
.48811 .42118 m .44305 .43303 L .48942 .42407 L F
.44334 .42134 m .44289 .43836 L .44297 .43591 L 0 1 0 r
F
.44334 .42134 m .44297 .43591 L .44335 .42145 L F
.44305 .43303 m .43179 .43599 L .44303 .43366 L .479 .526 .746 r
F
.44305 .43303 m .44303 .43366 L .48942 .42407 L F
.48679 .41827 m .44314 .42987 L .48811 .42118 L F
.44335 .42145 m .44297 .43591 L .44304 .4335 L 0 1 0 r
F
.44335 .42145 m .44304 .4335 L .44336 .42157 L F
.44314 .42987 m .43126 .43303 L .44312 .43056 L .479 .526 .746 r
F
.44314 .42987 m .44312 .43056 L .48811 .42118 L F
.48547 .41536 m .44323 .42671 L .48679 .41827 L F
.44336 .42157 m .44304 .4335 L .44312 .43113 L 0 1 0 r
F
.44336 .42157 m .44312 .43113 L .44336 .42169 L F
.44323 .42671 m .43073 .43006 L .44321 .42744 L .479 .526 .746 r
F
.44323 .42671 m .44321 .42744 L .48679 .41827 L F
.48415 .41244 m .44333 .42353 L .48547 .41536 L F
.44336 .42169 m .44312 .43113 L .44319 .4288 L 0 1 0 r
F
.44336 .42169 m .44319 .4288 L .44337 .42181 L F
.44333 .42353 m .43019 .42709 L .44331 .42431 L .479 .526 .746 r
F
.44333 .42353 m .44331 .42431 L .48547 .41536 L F
.44337 .42181 m .44319 .4288 L .44339 .42219 L 0 1 0 r
F
.49464 .43557 m .44258 .44861 L .49594 .43843 L .479 .526 .746 r
F
.44258 .44861 m .44257 .44879 L .49594 .43843 L F
.49464 .43557 m .44266 .44598 L .4426 .44788 L F
.49464 .43557 m .43429 .44984 L .43935 .44941 L F
.44257 .44879 m .44257 .44903 L .49594 .43843 L F
.49594 .43843 m .44257 .44903 L .45787 .44787 L F
.44256 .44915 m .44256 .44914 L p .43997 .44936 L 0 1 0 r
F P
0 g
s
.44256 .44914 m .44255 .44908 L p .43997 .44936 L 0 1 0 r
F P
0 g
s
.44255 .44908 m .44255 .44908 L p .44255 .44903 L 0 1 0 r
F P
0 g
s
.44257 .44903 m .44151 .44924 L .44256 .44915 L .479 .526 .746 r
F
.44257 .44903 m .44256 .44915 L .45787 .44787 L F
.44339 .42219 m .44258 .44861 L .44258 .44862 L 0 1 0 r
F
.44151 .44924 m .43443 .45065 L .44255 .44968 L .479 .526 .746 r
F
.44256 .44915 m .44255 .44968 L .45787 .44787 L F
.44151 .44924 m .44255 .44968 L .44256 .44915 L F
.44256 .44916 m .44737 .48823 L p .44258 .44862 L 0 1 0 r
F P
0 g
s
.44258 .44861 m .44257 .44903 L .44258 .44862 L 0 1 0 r
F
.44257 .44903 m .44256 .44916 L .44258 .44862 L F
.4434 .42222 m .44258 .44862 L .44737 .48823 L F
.44339 .42219 m .44258 .44862 L .4434 .42222 L F
.44256 .44914 m .44256 .44916 L p .44258 .44861 L F P
0 g
s
.43935 .44941 m .44151 .44924 L .44257 .44903 L .479 .526 .746 r
F
.44256 .4491 m .44256 .44912 L p .44257 .44865 L 0 1 0 r
F P
0 g
s
.44256 .44912 m .44256 .44913 L p .44257 .44869 L 0 1 0 r
F P
0 g
s
.44256 .44913 m .44256 .44914 L p .44257 .44872 L 0 1 0 r
F P
0 g
s
.44255 .44902 m .44255 .44904 L p .44255 .44885 L 0 1 0 r
F P
0 g
s
.44255 .44904 m .44255 .44905 L p .44255 .44887 L 0 1 0 r
F P
0 g
s
.44255 .44905 m .44255 .44906 L p .44255 .44889 L 0 1 0 r
F P
0 g
s
.44255 .44906 m .44255 .44908 L p .44256 .44891 L 0 1 0 r
F P
0 g
s
.43935 .44941 m .44257 .44903 L .44257 .44879 L .479 .526 .746 r
F
.44258 .44861 m .43935 .44941 L .44257 .44879 L F
.44295 .43617 m .43179 .43599 L .43233 .43894 L F
.44303 .43366 m .43179 .43599 L .44295 .43617 L F
.44286 .4393 m .43233 .43894 L .43285 .44188 L F
.44294 .43676 m .43233 .43894 L .44286 .4393 L F
.44276 .44241 m .43285 .44188 L .43338 .44481 L F
.44284 .43984 m .43285 .44188 L .44276 .44241 L F
.44267 .44552 m .43338 .44481 L .43391 .44773 L F
.44275 .44292 m .43338 .44481 L .44267 .44552 L F
.4426 .44788 m .43391 .44773 L .43429 .44984 L F
.44266 .44598 m .43391 .44773 L .4426 .44788 L F
.48282 .40951 m .44342 .42033 L .48415 .41244 L F
.44327 .42011 m .44338 .42193 L .44343 .4201 L 0 1 0 r
F
.44342 .42033 m .42966 .42411 L .4434 .42117 L .479 .526 .746 r
F
.44342 .42033 m .4434 .42117 L .48415 .41244 L F
.44343 .4201 m .44737 .48823 L .44343 .4201 L 0 1 0 r
F
.44338 .42193 m .44737 .48823 L .44343 .4201 L F
.44737 .48823 m .44809 .45768 L .44343 .4201 L p F P
0 g
s
.3932 .42705 m .39319 .42811 L .42966 .42411 L .479 .526 .746 r
F
.40216 .45231 m .39473 .45316 L .42738 .45038 L 0 1 0 r
F
.39436 .45291 m .39438 .45293 L .40216 .45231 L F
.39438 .45293 m .39473 .45316 L .40216 .45231 L F
.39295 .45154 m .39295 .45147 L .39294 .45259 L F
.39294 .45304 m .39294 .45302 L p .39322 .42763 L F P
0 g
s
.43391 .44773 m .37215 .45377 L .37207 .45468 L .479 .526 .746 r
F
.39294 .45262 m .39294 .45259 L .39294 .45302 L 0 1 0 r
F
.43391 .44773 m .37207 .45468 L .40216 .45231 L .479 .526 .746 r
F
.44737 .48823 m .44256 .44915 L p .39473 .45316 L 0 1 0 r
F P
0 g
s
.39726 .46128 m .39719 .49184 L p .3932 .42721 L 0 1 0 r
F P
0 g
s
.39282 .42113 m .44343 .4201 L .43084 .42134 L 0 1 0 r
F
.39282 .42113 m .43084 .42134 L .42907 .42151 L F
.39282 .42113 m .42919 .42151 L .39763 .42431 L F
.39282 .42113 m .44312 .41763 L .44343 .4201 L p F P
0 g
s
.39322 .42477 m .39282 .42113 L p .3977 .42436 L 0 1 0 r
F P
0 g
s
.42394 .42197 m .39322 .42522 L .3932 .42705 L .479 .526 .746 r
F
.39282 .42113 m .39322 .42477 L p .3932 .42721 L 0 1 0 r
F P
0 g
s
.39322 .42477 m .39322 .42511 L .3932 .42721 L 0 1 0 r
F
.41 .42325 m .37447 .4272 L .42394 .42197 L .479 .526 .746 r
F
.42394 .42197 m .3932 .42705 L .42919 .42151 L F
.39763 .42431 m .42919 .42151 L .3977 .42436 L 0 1 0 r
F
.39323 .42405 m .39322 .42477 L .42912 .42112 L .479 .526 .746 r
F
.39322 .42477 m .39322 .42511 L .41 .42325 L F
.39322 .42477 m .41 .42325 L .42912 .42112 L F
.3977 .42436 m .42919 .42151 L .39803 .42458 L 0 1 0 r
F
.42919 .42151 m .3932 .42705 L .42966 .42411 L .479 .526 .746 r
F
.43391 .44773 m .40216 .45231 L .43429 .44984 L F
.44809 .45768 m .39726 .46128 L .39322 .42477 L p 0 1 0 r
F P
0 g
s
.3977 .42436 m .44809 .45768 L .39322 .42477 L 0 1 0 r
F
.39322 .42477 m .37447 .4272 L .39322 .42511 L .479 .526 .746 r
F
.39323 .42405 m .38398 .4256 L .39322 .42477 L F
.38398 .4256 m .37447 .4272 L .39322 .42477 L F
.42858 .41812 m .39323 .42405 L .42912 .42112 L F
.39322 .42477 m .39322 .42478 L p .39322 .42511 L 0 1 0 r
F P
0 g
s
.39322 .42478 m .39726 .46128 L p .3932 .42721 L 0 1 0 r
F P
0 g
s
.3932 .42705 m .37447 .4272 L .37421 .43019 L .479 .526 .746 r
F
.39322 .42522 m .37447 .4272 L .3932 .42705 L F
.42912 .42112 m .41 .42325 L .42394 .42197 L F
.42907 .42151 m .43084 .42134 L .42919 .42151 L 0 1 0 r
F
.42912 .42112 m .42394 .42197 L .42919 .42151 L .479 .526 .746 r
F
.39319 .42711 m .3932 .42721 L .39311 .43759 L 0 1 0 r
F
.3932 .42721 m .39313 .43557 L .39311 .43759 L F
.3932 .42705 m .37421 .43019 L .39319 .42811 L .479 .526 .746 r
F
.3932 .42721 m .39322 .42763 L .39313 .43557 L 0 1 0 r
F
.39298 .44806 m .39298 .44797 L .39297 .44916 L F
.39299 .4478 m .37241 .45085 L .39298 .44881 L .479 .526 .746 r
F
.39317 .43004 m .37421 .43019 L .37395 .43316 L F
.39319 .42811 m .37421 .43019 L .39317 .43004 L F
.39301 .44435 m .39301 .44424 L .393 .44551 L 0 1 0 r
F
.393 .44561 m .393 .44551 L .39299 .44675 L F
.39314 .43302 m .37395 .43316 L .37369 .43613 L .479 .526 .746 r
F
.39316 .43109 m .37395 .43316 L .39314 .43302 L F
.39311 .43599 m .37369 .43613 L .37343 .43909 L F
.39313 .43407 m .37369 .43613 L .39311 .43599 L F
.39299 .44685 m .39299 .44675 L .39298 .44797 L 0 1 0 r
F
.39308 .43896 m .37343 .43909 L .37318 .44205 L .479 .526 .746 r
F
.3931 .43703 m .37343 .43909 L .39308 .43896 L F
.39305 .44191 m .37318 .44205 L .37292 .44499 L F
.39307 .43999 m .37318 .44205 L .39305 .44191 L F
.39297 .44924 m .39297 .44916 L .39296 .45033 L 0 1 0 r
F
.39296 .45041 m .39296 .45033 L .39295 .45147 L F
.39302 .44486 m .37292 .44499 L .37266 .44793 L .479 .526 .746 r
F
.39304 .44294 m .37292 .44499 L .39302 .44486 L F
.39299 .4478 m .37266 .44793 L .37241 .45085 L F
.39301 .44588 m .37266 .44793 L .39299 .4478 L F
.39296 .45073 m .37241 .45085 L .37215 .45377 L F
.39298 .44881 m .37241 .45085 L .39296 .45073 L F
.39296 .45073 m .37215 .45377 L .39295 .45174 L F
.39719 .49184 m .39294 .45304 L p .39322 .42763 L 0 1 0 r
F P
0 g
s
.44342 .42033 m .42912 .42112 L .42966 .42411 L .479 .526 .746 r
F
.44333 .42353 m .42966 .42411 L .43019 .42709 L F
.4434 .42117 m .42966 .42411 L .44333 .42353 L F
.44323 .42671 m .43019 .42709 L .43073 .43006 L F
.44331 .42431 m .43019 .42709 L .44323 .42671 L F
.44314 .42987 m .43073 .43006 L .43126 .43303 L F
.44321 .42744 m .43073 .43006 L .44314 .42987 L F
.44305 .43303 m .43126 .43303 L .43179 .43599 L F
.44312 .43056 m .43126 .43303 L .44305 .43303 L F
.39803 .42458 m .42919 .42151 L .44809 .45768 L 0 1 0 r
F
.44349 .41801 m .42912 .42112 L .44342 .42033 L .479 .526 .746 r
F
.44343 .4201 m .44343 .42013 L p .42919 .42151 L 0 1 0 r
F P
0 g
s
.44343 .42013 m .44809 .45768 L p .42919 .42151 L 0 1 0 r
F P
0 g
s
.37139 .46248 m .30748 .46207 L .30645 .46489 L .479 .526 .746 r
F
.37164 .45959 m .30748 .46207 L .37139 .46248 L F
.18568 .37309 m .1294 .35384 L .18538 .37711 L .787 .211 .013 r
F
.18568 .37309 m .12977 .34965 L .1294 .35384 L F
.67481 .34859 m .62105 .3729 L .62111 .37486 L F
.67474 .34697 m .62105 .3729 L .67481 .34859 L F
.62194 .40252 m .56326 .42641 L .5633 .42876 L F
.62188 .40053 m .56326 .42641 L .62194 .40252 L F
.30559 .46403 m .24141 .46051 L .30543 .4677 L F
.30559 .46403 m .24164 .45657 L .24141 .46051 L F
.67488 .35021 m .62111 .37486 L .62117 .37682 L F
.67481 .34859 m .62111 .37486 L .67488 .35021 L F
.622 .40451 m .5633 .42876 L .56334 .4311 L F
.62194 .40252 m .5633 .42876 L .622 .40451 L F
.24331 .42925 m .18231 .41775 L .24307 .43313 L F
.24331 .42925 m .18262 .41365 L .18231 .41775 L F
.67495 .35183 m .62117 .37682 L .62123 .37879 L F
.67488 .35021 m .62117 .37682 L .67495 .35183 L F
.18538 .37711 m .12902 .35803 L .18507 .38114 L F
.18538 .37711 m .1294 .35384 L .12902 .35803 L F
.5552 .42025 m .49723 .44128 L .55724 .42297 L .479 .526 .746 r
F
.5552 .42025 m .49594 .43843 L .49723 .44128 L F
.622 .40451 m .56334 .4311 L .62206 .4065 L .787 .211 .013 r
F
.61931 .40398 m .56334 .4311 L .62206 .4065 L .479 .526 .746 r
F
.61931 .40398 m .56131 .4284 L .56334 .4311 L F
.30645 .46489 m .24141 .46051 L .30543 .4677 L F
.37164 .45959 m .3085 .45924 L .30748 .46207 L F
.3719 .45668 m .3085 .45924 L .37164 .45959 L F
.67502 .35346 m .62123 .37879 L .62129 .38075 L .787 .211 .013 r
F
.67495 .35183 m .62123 .37879 L .67502 .35346 L F
.24307 .43313 m .182 .42186 L .24283 .43702 L F
.24307 .43313 m .18231 .41775 L .182 .42186 L F
.67509 .35508 m .62129 .38075 L .62135 .38272 L F
.67502 .35346 m .62129 .38075 L .67509 .35508 L F
.18507 .38114 m .12865 .36223 L .18477 .38517 L F
.18507 .38114 m .12902 .35803 L .12865 .36223 L F
.67516 .35671 m .62135 .38272 L .62141 .38469 L F
.67509 .35508 m .62135 .38272 L .67516 .35671 L F
.61656 .40146 m .56131 .4284 L .61931 .40398 L .479 .526 .746 r
F
.61656 .40146 m .55928 .42569 L .56131 .4284 L F
.55316 .41752 m .49594 .43843 L .5552 .42025 L F
.55316 .41752 m .49464 .43557 L .49594 .43843 L F
.24283 .43702 m .18168 .42598 L .2426 .44091 L .787 .211 .013 r
F
.24283 .43702 m .182 .42186 L .18168 .42598 L F
.30645 .46489 m .24319 .45782 L .24141 .46051 L .479 .526 .746 r
F
.30748 .46207 m .24319 .45782 L .30645 .46489 L F
.3719 .45668 m .30954 .4564 L .3085 .45924 L F
.37215 .45377 m .30954 .4564 L .3719 .45668 L F
.67523 .35834 m .62141 .38469 L .62147 .38667 L .787 .211 .013 r
F
.67516 .35671 m .62141 .38469 L .67523 .35834 L F
.18477 .38517 m .12827 .36644 L .18446 .38922 L F
.18477 .38517 m .12865 .36223 L .12827 .36644 L F
.6753 .35996 m .62147 .38667 L .62153 .38864 L F
.67523 .35834 m .62147 .38667 L .6753 .35996 L F
.2426 .44091 m .18137 .4301 L .24236 .44482 L F
.2426 .44091 m .18168 .42598 L .18137 .4301 L F
.67537 .36159 m .62153 .38864 L .62158 .39062 L F
.6753 .35996 m .62153 .38864 L .67537 .36159 L F
.61381 .39893 m .55928 .42569 L .61656 .40146 L .479 .526 .746 r
F
.61381 .39893 m .55724 .42297 L .55928 .42569 L F
.18446 .38922 m .12789 .37066 L .18416 .39327 L .787 .211 .013 r
F
.18446 .38922 m .12827 .36644 L .12789 .37066 L F
.5511 .41478 m .49464 .43557 L .55316 .41752 L .479 .526 .746 r
F
.5511 .41478 m .49334 .43271 L .49464 .43557 L F
.30748 .46207 m .24498 .45513 L .24319 .45782 L F
.3085 .45924 m .24498 .45513 L .30748 .46207 L F
.37215 .45377 m .31057 .45356 L .30954 .4564 L F
.37241 .45085 m .31057 .45356 L .37215 .45377 L F
.67545 .36323 m .62158 .39062 L .62164 .3926 L .787 .211 .013 r
F
.67537 .36159 m .62158 .39062 L .67545 .36323 L F
.24236 .44482 m .18106 .43423 L .24212 .44873 L F
.24236 .44482 m .18137 .4301 L .18106 .43423 L F
.67552 .36486 m .62164 .3926 L .6217 .39458 L F
.67545 .36323 m .62164 .3926 L .67552 .36486 L F
.18416 .39327 m .12751 .37489 L .18385 .39733 L F
.18416 .39327 m .12789 .37066 L .12751 .37489 L F
.61104 .39639 m .55724 .42297 L .61381 .39893 L .479 .526 .746 r
F
.61104 .39639 m .5552 .42025 L .55724 .42297 L F
.67559 .36649 m .6217 .39458 L .62176 .39656 L .787 .211 .013 r
F
.67552 .36486 m .6217 .39458 L .67559 .36649 L F
.54905 .41203 m .49334 .43271 L .5511 .41478 L .479 .526 .746 r
F
.54905 .41203 m .49204 .42984 L .49334 .43271 L F
.24212 .44873 m .18075 .43837 L .24188 .45265 L .787 .211 .013 r
F
.24212 .44873 m .18106 .43423 L .18075 .43837 L F
.3085 .45924 m .24678 .45243 L .24498 .45513 L .479 .526 .746 r
F
.30954 .4564 m .24678 .45243 L .3085 .45924 L F
.37241 .45085 m .31161 .45071 L .31057 .45356 L F
.37266 .44793 m .31161 .45071 L .37241 .45085 L F
.67566 .36813 m .62176 .39656 L .62182 .39854 L .787 .211 .013 r
F
.67559 .36649 m .62176 .39656 L .67566 .36813 L F
.18385 .39733 m .12713 .37913 L .18354 .4014 L F
.18385 .39733 m .12751 .37489 L .12713 .37913 L F
.67573 .36976 m .62182 .39854 L .62188 .40053 L F
.67566 .36813 m .62182 .39854 L .67573 .36976 L F
.24188 .45265 m .18043 .44252 L .24164 .45657 L F
.24188 .45265 m .18075 .43837 L .18043 .44252 L F
.60827 .39385 m .5552 .42025 L .61104 .39639 L .479 .526 .746 r
F
.60827 .39385 m .55316 .41752 L .5552 .42025 L F
.6758 .3714 m .62188 .40053 L .62194 .40252 L .787 .211 .013 r
F
.67573 .36976 m .62188 .40053 L .6758 .3714 L F
.54698 .40928 m .49204 .42984 L .54905 .41203 L .479 .526 .746 r
F
.54698 .40928 m .49073 .42696 L .49204 .42984 L F
.18354 .4014 m .12675 .38337 L .18323 .40547 L .787 .211 .013 r
F
.18354 .4014 m .12713 .37913 L .12675 .38337 L F
.30954 .4564 m .24858 .44973 L .24678 .45243 L .479 .526 .746 r
F
.31057 .45356 m .24858 .44973 L .30954 .4564 L F
.37266 .44793 m .31265 .44785 L .31161 .45071 L F
.37292 .44499 m .31265 .44785 L .37266 .44793 L F
.67587 .37304 m .62194 .40252 L .622 .40451 L .787 .211 .013 r
F
.6758 .3714 m .62194 .40252 L .67587 .37304 L F
.24164 .45657 m .18012 .44668 L .24141 .46051 L F
.24164 .45657 m .18043 .44252 L .18012 .44668 L F
.67594 .37468 m .622 .40451 L .62206 .4065 L F
.67587 .37304 m .622 .40451 L .67594 .37468 L F
.60549 .39131 m .55316 .41752 L .60827 .39385 L .479 .526 .746 r
F
.60549 .39131 m .5511 .41478 L .55316 .41752 L F
.18323 .40547 m .12637 .38762 L .18293 .40956 L .787 .211 .013 r
F
.18323 .40547 m .12675 .38337 L .12637 .38762 L F
.54491 .40652 m .49073 .42696 L .54698 .40928 L .479 .526 .746 r
F
.54491 .40652 m .48942 .42407 L .49073 .42696 L F
.67594 .37468 m .62206 .4065 L .67601 .37632 L .787 .211 .013 r
F
.67258 .37406 m .62206 .4065 L .67601 .37632 L .479 .526 .746 r
F
.67258 .37406 m .61931 .40398 L .62206 .4065 L F
.31057 .45356 m .25039 .44701 L .24858 .44973 L F
.31161 .45071 m .25039 .44701 L .31057 .45356 L F
.24319 .45782 m .18012 .44668 L .24141 .46051 L F
.37292 .44499 m .31369 .44498 L .31265 .44785 L F
.37318 .44205 m .31369 .44498 L .37292 .44499 L F
.37766 .34817 m .32808 .34699 L .37756 .35149 L .787 .211 .013 r
F
.37766 .34817 m .32823 .34339 L .32808 .34699 L F
.42739 .34816 m .37766 .34817 L .37756 .35149 L F
.42739 .34816 m .37756 .35149 L .42734 .35117 L F
.4764 .34335 m .42739 .34816 L .42734 .35117 L F
.18293 .40956 m .12599 .39189 L .18262 .41365 L F
.18293 .40956 m .12637 .38762 L .12599 .39189 L F
.60271 .38875 m .5511 .41478 L .60549 .39131 L .479 .526 .746 r
F
.60271 .38875 m .54905 .41203 L .5511 .41478 L F
.66915 .37179 m .61931 .40398 L .67258 .37406 L F
.66915 .37179 m .61656 .40146 L .61931 .40398 L F
.42734 .35117 m .37747 .35481 L .42729 .35418 L .787 .211 .013 r
F
.42734 .35117 m .37756 .35149 L .37747 .35481 L F
.47638 .34603 m .42734 .35117 L .42729 .35418 L F
.4764 .34335 m .42734 .35117 L .47638 .34603 L F
.54284 .40375 m .48942 .42407 L .54491 .40652 L .479 .526 .746 r
F
.54284 .40375 m .48811 .42118 L .48942 .42407 L F
.37756 .35149 m .32793 .3506 L .37747 .35481 L .787 .211 .013 r
F
.37756 .35149 m .32808 .34699 L .32793 .3506 L F
.24319 .45782 m .18265 .44419 L .18012 .44668 L .479 .526 .746 r
F
.24498 .45513 m .18265 .44419 L .24319 .45782 L F
.31161 .45071 m .2522 .44429 L .25039 .44701 L F
.31265 .44785 m .2522 .44429 L .31161 .45071 L F
.18262 .41365 m .12561 .39616 L .18231 .41775 L .787 .211 .013 r
F
.18262 .41365 m .12599 .39189 L .12561 .39616 L F
.37318 .44205 m .31474 .44211 L .31369 .44498 L .479 .526 .746 r
F
.37343 .43909 m .31474 .44211 L .37318 .44205 L F
.13015 .34547 m .07922 .3208 L .12977 .34965 L .787 .211 .013 r
F
.13015 .34547 m .07966 .31651 L .07922 .3208 L F
.72259 .31636 m .67467 .34535 L .67474 .34697 L F
.42729 .35418 m .37737 .35814 L .42724 .35719 L F
.42729 .35418 m .37747 .35481 L .37737 .35814 L F
.47637 .3487 m .42729 .35418 L .42724 .35719 L F
.47638 .34603 m .42729 .35418 L .47637 .3487 L F
.37747 .35481 m .32778 .35421 L .37737 .35814 L F
.37747 .35481 m .32793 .3506 L .32778 .35421 L F
.59992 .38619 m .54905 .41203 L .60271 .38875 L .479 .526 .746 r
F
.59992 .38619 m .54698 .40928 L .54905 .41203 L F
.72266 .31765 m .67474 .34697 L .67481 .34859 L .787 .211 .013 r
F
.72259 .31636 m .67474 .34697 L .72266 .31765 L F
.66571 .36952 m .61656 .40146 L .66915 .37179 L .479 .526 .746 r
F
.66571 .36952 m .61381 .39893 L .61656 .40146 L F
.18231 .41775 m .12522 .40044 L .182 .42186 L .787 .211 .013 r
F
.18231 .41775 m .12561 .39616 L .12522 .40044 L F
.72273 .31894 m .67481 .34859 L .67488 .35021 L F
.72266 .31765 m .67481 .34859 L .72273 .31894 L F
.24498 .45513 m .18519 .44169 L .18265 .44419 L .479 .526 .746 r
F
.24678 .45243 m .18519 .44169 L .24498 .45513 L F
.54076 .40098 m .48811 .42118 L .54284 .40375 L F
.54076 .40098 m .48679 .41827 L .48811 .42118 L F
.42724 .35719 m .37727 .36147 L .42719 .36021 L .787 .211 .013 r
F
.42724 .35719 m .37737 .35814 L .37727 .36147 L F
.47635 .35138 m .42724 .35719 L .42719 .36021 L F
.47637 .3487 m .42724 .35719 L .47635 .35138 L F
.32823 .34339 m .27993 .33772 L .32808 .34699 L F
.32823 .34339 m .28014 .33387 L .27993 .33772 L F
.52364 .33382 m .4764 .34335 L .47638 .34603 L F
.12977 .34965 m .07878 .3251 L .1294 .35384 L F
.12977 .34965 m .07922 .3208 L .07878 .3251 L F
.31265 .44785 m .25401 .44157 L .2522 .44429 L .479 .526 .746 r
F
.31369 .44498 m .25401 .44157 L .31265 .44785 L F
.37737 .35814 m .32763 .35783 L .37727 .36147 L .787 .211 .013 r
F
.37737 .35814 m .32778 .35421 L .32763 .35783 L F
.7228 .32024 m .67488 .35021 L .67495 .35183 L F
.72273 .31894 m .67488 .35021 L .7228 .32024 L F
.37343 .43909 m .31578 .43922 L .31474 .44211 L .479 .526 .746 r
F
.37369 .43613 m .31578 .43922 L .37343 .43909 L F
.52366 .33615 m .47638 .34603 L .47637 .3487 L .787 .211 .013 r
F
.52364 .33382 m .47638 .34603 L .52366 .33615 L F
.72287 .32153 m .67495 .35183 L .67502 .35346 L F
.7228 .32024 m .67495 .35183 L .72287 .32153 L F
.42719 .36021 m .37717 .36481 L .42713 .36323 L F
.42719 .36021 m .37727 .36147 L .37717 .36481 L F
.47634 .35407 m .42719 .36021 L .42713 .36323 L F
.47635 .35138 m .42719 .36021 L .47634 .35407 L F
.59712 .38363 m .54698 .40928 L .59992 .38619 L .479 .526 .746 r
F
.59712 .38363 m .54491 .40652 L .54698 .40928 L F
.66226 .36724 m .61381 .39893 L .66571 .36952 L F
.66226 .36724 m .61104 .39639 L .61381 .39893 L F
.182 .42186 m .12484 .40473 L .18168 .42598 L .787 .211 .013 r
F
.182 .42186 m .12522 .40044 L .12484 .40473 L F
.32808 .34699 m .27973 .34158 L .32793 .3506 L F
.32808 .34699 m .27993 .33772 L .27973 .34158 L F
.44737 .48823 m .39719 .49184 L .39726 .46128 L p 0 1 0 r
F P
0 g
s
.39726 .46128 m .44809 .45768 L .44737 .48823 L p 0 1 0 r
F P
0 g
s
.37727 .36147 m .32748 .36146 L .37717 .36481 L .787 .211 .013 r
F
.37727 .36147 m .32763 .35783 L .32748 .36146 L F
.72295 .32283 m .67502 .35346 L .67509 .35508 L F
.72287 .32153 m .67502 .35346 L .72295 .32283 L F
.1294 .35384 m .07833 .3294 L .12902 .35803 L F
.1294 .35384 m .07878 .3251 L .07833 .3294 L F
.24678 .45243 m .18774 .43918 L .18519 .44169 L .479 .526 .746 r
F
.24858 .44973 m .18774 .43918 L .24678 .45243 L F
.52367 .33848 m .47637 .3487 L .47635 .35138 L .787 .211 .013 r
F
.52366 .33615 m .47637 .3487 L .52367 .33848 L F
.53868 .3982 m .48679 .41827 L .54076 .40098 L .479 .526 .746 r
F
.53868 .3982 m .48547 .41536 L .48679 .41827 L F
.31369 .44498 m .25583 .43883 L .25401 .44157 L F
.31474 .44211 m .25583 .43883 L .31369 .44498 L F
.72302 .32412 m .67509 .35508 L .67516 .35671 L .787 .211 .013 r
F
.72295 .32283 m .67509 .35508 L .72302 .32412 L F
.42713 .36323 m .37708 .36816 L .42708 .36626 L F
.42713 .36323 m .37717 .36481 L .37708 .36816 L F
.47633 .35676 m .42713 .36323 L .42708 .36626 L F
.47634 .35407 m .42713 .36323 L .47633 .35676 L F
.32793 .3506 m .27952 .34544 L .32778 .35421 L F
.32793 .3506 m .27973 .34158 L .27952 .34544 L F
.37369 .43613 m .31684 .43633 L .31578 .43922 L .479 .526 .746 r
F
.37395 .43316 m .31684 .43633 L .37369 .43613 L F
.18168 .42598 m .12445 .40903 L .18137 .4301 L .787 .211 .013 r
F
.18168 .42598 m .12484 .40473 L .12445 .40903 L F
.37717 .36481 m .32733 .36509 L .37708 .36816 L F
.37717 .36481 m .32748 .36146 L .32733 .36509 L F
.72309 .32542 m .67516 .35671 L .67523 .35834 L F
.72302 .32412 m .67516 .35671 L .72309 .32542 L F
.52369 .34081 m .47635 .35138 L .47634 .35407 L F
.52367 .33848 m .47635 .35138 L .52369 .34081 L F
.65881 .36495 m .61104 .39639 L .66226 .36724 L .479 .526 .746 r
F
.65881 .36495 m .60827 .39385 L .61104 .39639 L F
.59432 .38106 m .54491 .40652 L .59712 .38363 L F
.59432 .38106 m .54284 .40375 L .54491 .40652 L F
.12902 .35803 m .07789 .33372 L .12865 .36223 L .787 .211 .013 r
F
.12902 .35803 m .07833 .3294 L .07789 .33372 L F
.42708 .36626 m .37698 .37151 L .42703 .3693 L F
.42708 .36626 m .37708 .36816 L .37698 .37151 L F
.47631 .35945 m .42708 .36626 L .42703 .3693 L F
.47633 .35676 m .42708 .36626 L .47631 .35945 L F
.72316 .32671 m .67523 .35834 L .6753 .35996 L F
.72309 .32542 m .67523 .35834 L .72316 .32671 L F
.24858 .44973 m .19029 .43667 L .18774 .43918 L .479 .526 .746 r
F
.25039 .44701 m .19029 .43667 L .24858 .44973 L F
.5237 .34315 m .47634 .35407 L .47633 .35676 L .787 .211 .013 r
F
.52369 .34081 m .47634 .35407 L .5237 .34315 L F
.32778 .35421 m .27931 .34931 L .32763 .35783 L F
.32778 .35421 m .27952 .34544 L .27931 .34931 L F
.72323 .32801 m .6753 .35996 L .67537 .36159 L F
.72316 .32671 m .6753 .35996 L .72323 .32801 L F
.37708 .36816 m .32718 .36873 L .37698 .37151 L F
.37708 .36816 m .32733 .36509 L .32718 .36873 L F
.53659 .39541 m .48547 .41536 L .53868 .3982 L .479 .526 .746 r
F
.53659 .39541 m .48415 .41244 L .48547 .41536 L F
.18137 .4301 m .12407 .41333 L .18106 .43423 L .787 .211 .013 r
F
.18137 .4301 m .12445 .40903 L .12407 .41333 L F
.31474 .44211 m .25766 .43609 L .25583 .43883 L .479 .526 .746 r
F
.31578 .43922 m .25766 .43609 L .31474 .44211 L F
.42703 .3693 m .37688 .37486 L .42698 .37233 L .787 .211 .013 r
F
.42703 .3693 m .37698 .37151 L .37688 .37486 L F
.4763 .36214 m .42703 .3693 L .42698 .37233 L F
.47631 .35945 m .42703 .3693 L .4763 .36214 L F
.7233 .32931 m .67537 .36159 L .67545 .36323 L F
.72323 .32801 m .67537 .36159 L .7233 .32931 L F
.12865 .36223 m .07745 .33805 L .12827 .36644 L F
.12865 .36223 m .07789 .33372 L .07745 .33805 L F
.65534 .36266 m .60827 .39385 L .65881 .36495 L .479 .526 .746 r
F
.65534 .36266 m .60549 .39131 L .60827 .39385 L F
.37395 .43316 m .31789 .43343 L .31684 .43633 L F
.37421 .43019 m .31789 .43343 L .37395 .43316 L F
.52372 .34549 m .47633 .35676 L .47631 .35945 L .787 .211 .013 r
F
.5237 .34315 m .47633 .35676 L .52372 .34549 L F
.59151 .37848 m .54284 .40375 L .59432 .38106 L .479 .526 .746 r
F
.59151 .37848 m .54076 .40098 L .54284 .40375 L F
.72338 .33061 m .67545 .36323 L .67552 .36486 L .787 .211 .013 r
F
.7233 .32931 m .67545 .36323 L .72338 .33061 L F
.37698 .37151 m .32703 .37237 L .37688 .37486 L F
.37698 .37151 m .32718 .36873 L .32703 .37237 L F
.32763 .35783 m .27911 .35319 L .32748 .36146 L F
.32763 .35783 m .27931 .34931 L .27911 .35319 L F
.42698 .37233 m .37678 .37823 L .42693 .37537 L F
.42698 .37233 m .37688 .37486 L .37678 .37823 L F
.47628 .36484 m .42698 .37233 L .42693 .37537 L F
.4763 .36214 m .42698 .37233 L .47628 .36484 L F
.18106 .43423 m .12368 .41765 L .18075 .43837 L F
.18106 .43423 m .12407 .41333 L .12368 .41765 L F
.72345 .33191 m .67552 .36486 L .67559 .36649 L F
.72338 .33061 m .67552 .36486 L .72345 .33191 L F
.25039 .44701 m .19285 .43415 L .19029 .43667 L .479 .526 .746 r
F
.2522 .44429 m .19285 .43415 L .25039 .44701 L F
.52373 .34783 m .47631 .35945 L .4763 .36214 L .787 .211 .013 r
F
.52372 .34549 m .47631 .35945 L .52373 .34783 L F
.53449 .39261 m .48415 .41244 L .53659 .39541 L .479 .526 .746 r
F
.53449 .39261 m .48282 .40951 L .48415 .41244 L F
.12827 .36644 m .077 .34238 L .12789 .37066 L .787 .211 .013 r
F
.12827 .36644 m .07745 .33805 L .077 .34238 L F
.31578 .43922 m .25949 .43334 L .25766 .43609 L .479 .526 .746 r
F
.31684 .43633 m .25949 .43334 L .31578 .43922 L F
.72352 .33321 m .67559 .36649 L .67566 .36813 L .787 .211 .013 r
F
.72345 .33191 m .67559 .36649 L .72352 .33321 L F
.37688 .37486 m .32688 .37603 L .37678 .37823 L F
.37688 .37486 m .32703 .37237 L .32688 .37603 L F
.28014 .33387 m .23415 .32382 L .27993 .33772 L F
.28014 .33387 m .23441 .31977 L .23415 .32382 L F
.65187 .36037 m .60549 .39131 L .65534 .36266 L .479 .526 .746 r
F
.65187 .36037 m .60271 .38875 L .60549 .39131 L F
.56812 .31969 m .52364 .33382 L .52366 .33615 L .787 .211 .013 r
F
.32748 .36146 m .2789 .35708 L .32733 .36509 L F
.32748 .36146 m .27911 .35319 L .2789 .35708 L F
.42693 .37537 m .37668 .38159 L .42687 .37842 L F
.42693 .37537 m .37678 .37823 L .37668 .38159 L F
.47627 .36754 m .42693 .37537 L .42687 .37842 L F
.47628 .36484 m .42693 .37537 L .47627 .36754 L F
.52375 .35017 m .4763 .36214 L .47628 .36484 L F
.52373 .34783 m .4763 .36214 L .52375 .35017 L F
.48149 .40658 m .42912 .42112 L .48282 .40951 L .479 .526 .746 r
F
.48149 .40658 m .42858 .41812 L .42912 .42112 L F
.72359 .33451 m .67566 .36813 L .67573 .36976 L .787 .211 .013 r
F
.72352 .33321 m .67566 .36813 L .72359 .33451 L F
.37421 .43019 m .31895 .43052 L .31789 .43343 L .479 .526 .746 r
F
.37447 .4272 m .31895 .43052 L .37421 .43019 L F
.58869 .37589 m .54076 .40098 L .59151 .37848 L F
.58869 .37589 m .53868 .3982 L .54076 .40098 L F
.18075 .43837 m .12329 .42197 L .18043 .44252 L .787 .211 .013 r
F
.18075 .43837 m .12368 .41765 L .12329 .42197 L F
.56815 .32167 m .52366 .33615 L .52367 .33848 L F
.56812 .31969 m .52366 .33615 L .56815 .32167 L F
.72366 .33582 m .67573 .36976 L .6758 .3714 L F
.72359 .33451 m .67573 .36976 L .72366 .33582 L F
.37678 .37823 m .32673 .37969 L .37668 .38159 L F
.37678 .37823 m .32688 .37603 L .32673 .37969 L F
.42687 .37842 m .37658 .38496 L .42682 .38147 L F
.42687 .37842 m .37668 .38159 L .37658 .38496 L F
.47626 .37025 m .42687 .37842 L .42682 .38147 L F
.47627 .36754 m .42687 .37842 L .47626 .37025 L F
.2522 .44429 m .19542 .43162 L .19285 .43415 L .479 .526 .746 r
F
.25401 .44157 m .19542 .43162 L .2522 .44429 L F
.12789 .37066 m .07655 .34673 L .12751 .37489 L .787 .211 .013 r
F
.12789 .37066 m .077 .34238 L .07655 .34673 L F
.52376 .35252 m .47628 .36484 L .47627 .36754 L F
.52375 .35017 m .47628 .36484 L .52376 .35252 L F
.32733 .36509 m .27869 .36097 L .32718 .36873 L F
.32733 .36509 m .2789 .35708 L .27869 .36097 L F
.27993 .33772 m .23388 .32789 L .27973 .34158 L F
.27993 .33772 m .23415 .32382 L .23388 .32789 L F
.72374 .33712 m .6758 .3714 L .67587 .37304 L F
.72366 .33582 m .6758 .3714 L .72374 .33712 L F
.53239 .38981 m .48282 .40951 L .53449 .39261 L .479 .526 .746 r
F
.53239 .38981 m .48149 .40658 L .48282 .40951 L F
.56818 .32365 m .52367 .33848 L .52369 .34081 L .787 .211 .013 r
F
.56815 .32167 m .52367 .33848 L .56818 .32365 L F
.6484 .35807 m .60271 .38875 L .65187 .36037 L .479 .526 .746 r
F
.6484 .35807 m .59992 .38619 L .60271 .38875 L F
.31684 .43633 m .26132 .43059 L .25949 .43334 L F
.31789 .43343 m .26132 .43059 L .31684 .43633 L F
.18043 .44252 m .1229 .42631 L .18012 .44668 L .787 .211 .013 r
F
.18043 .44252 m .12329 .42197 L .1229 .42631 L F
.72381 .33842 m .67587 .37304 L .67594 .37468 L F
.72374 .33712 m .67587 .37304 L .72381 .33842 L F
.42682 .38147 m .37649 .38834 L .42677 .38452 L F
.42682 .38147 m .37658 .38496 L .37649 .38834 L F
.47624 .37295 m .42682 .38147 L .42677 .38452 L F
.47626 .37025 m .42682 .38147 L .47624 .37295 L F
.52378 .35487 m .47627 .36754 L .47626 .37025 L F
.52376 .35252 m .47627 .36754 L .52378 .35487 L F
.37668 .38159 m .32658 .38335 L .37658 .38496 L F
.37668 .38159 m .32673 .37969 L .32658 .38335 L F
.58586 .3733 m .53868 .3982 L .58869 .37589 L .479 .526 .746 r
F
.58586 .3733 m .53659 .39541 L .53868 .3982 L F
.42858 .41812 m .37474 .4242 L .37447 .4272 L F
.42804 .41511 m .37474 .4242 L .42858 .41812 L F
.48016 .40363 m .42858 .41812 L .48149 .40658 L F
.48016 .40363 m .42804 .41511 L .42858 .41812 L F
.37447 .4272 m .32001 .42761 L .31895 .43052 L F
.37474 .4242 m .32001 .42761 L .37447 .4272 L F
.56822 .32564 m .52369 .34081 L .5237 .34315 L .787 .211 .013 r
F
.56818 .32365 m .52369 .34081 L .56822 .32564 L F
.32718 .36873 m .27849 .36487 L .32703 .37237 L F
.32718 .36873 m .27869 .36097 L .27849 .36487 L F
.12751 .37489 m .07611 .35108 L .12713 .37913 L F
.12751 .37489 m .07655 .34673 L .07611 .35108 L F
.72388 .33973 m .67594 .37468 L .67601 .37632 L F
.72381 .33842 m .67594 .37468 L .72388 .33973 L F
.27973 .34158 m .23362 .33196 L .27952 .34544 L F
.27973 .34158 m .23388 .32789 L .23362 .33196 L F
.25401 .44157 m .19799 .42909 L .19542 .43162 L .479 .526 .746 r
F
.25583 .43883 m .19799 .42909 L .25401 .44157 L F
.52379 .35722 m .47626 .37025 L .47624 .37295 L .787 .211 .013 r
F
.52378 .35487 m .47626 .37025 L .52379 .35722 L F
.72388 .33973 m .67601 .37632 L .72395 .34104 L F
.71989 .33909 m .67601 .37632 L .72395 .34104 L .479 .526 .746 r
F
.71989 .33909 m .67258 .37406 L .67601 .37632 L F
.42677 .38452 m .37639 .39172 L .42672 .38758 L .787 .211 .013 r
F
.42677 .38452 m .37649 .38834 L .37639 .39172 L F
.47623 .37567 m .42677 .38452 L .42672 .38758 L F
.47624 .37295 m .42677 .38452 L .47623 .37567 L F
.56825 .32762 m .5237 .34315 L .52372 .34549 L F
.56822 .32564 m .5237 .34315 L .56825 .32762 L F
.37658 .38496 m .32643 .38702 L .37649 .38834 L F
.37658 .38496 m .32658 .38335 L .32643 .38702 L F
.18265 .44419 m .1229 .42631 L .18012 .44668 L .479 .526 .746 r
F
.64491 .35577 m .59992 .38619 L .6484 .35807 L F
.64491 .35577 m .59712 .38363 L .59992 .38619 L F
.53028 .38699 m .48149 .40658 L .53239 .38981 L F
.53028 .38699 m .48016 .40363 L .48149 .40658 L F
.31789 .43343 m .26316 .42782 L .26132 .43059 L F
.31895 .43052 m .26316 .42782 L .31789 .43343 L F
.32703 .37237 m .27828 .36878 L .32688 .37603 L .787 .211 .013 r
F
.32703 .37237 m .27849 .36487 L .27828 .36878 L F
.27952 .34544 m .23336 .33604 L .27931 .34931 L F
.27952 .34544 m .23362 .33196 L .23336 .33604 L F
.12713 .37913 m .07566 .35545 L .12675 .38337 L F
.12713 .37913 m .07611 .35108 L .07566 .35545 L F
.52381 .35958 m .47624 .37295 L .47623 .37567 L F
.52379 .35722 m .47624 .37295 L .52381 .35958 L F
.56829 .32961 m .52372 .34549 L .52373 .34783 L F
.56825 .32762 m .52372 .34549 L .56829 .32961 L F
.58303 .3707 m .53659 .39541 L .58586 .3733 L .479 .526 .746 r
F
.58303 .3707 m .53449 .39261 L .53659 .39541 L F
.42672 .38758 m .37629 .39511 L .42666 .39065 L .787 .211 .013 r
F
.42672 .38758 m .37639 .39172 L .37629 .39511 L F
.47621 .37838 m .42672 .38758 L .42666 .39065 L F
.47623 .37567 m .42672 .38758 L .47621 .37838 L F
.42804 .41511 m .375 .4212 L .37474 .4242 L .479 .526 .746 r
F
.42749 .4121 m .375 .4212 L .42804 .41511 L F
.47882 .40068 m .42804 .41511 L .48016 .40363 L F
.47882 .40068 m .42749 .4121 L .42804 .41511 L F
.37474 .4242 m .32107 .42469 L .32001 .42761 L F
.375 .4212 m .32107 .42469 L .37474 .4242 L F
.37649 .38834 m .32627 .3907 L .37639 .39172 L .787 .211 .013 r
F
.37649 .38834 m .32643 .38702 L .32627 .3907 L F
.71583 .33715 m .67258 .37406 L .71989 .33909 L .479 .526 .746 r
F
.71583 .33715 m .66915 .37179 L .67258 .37406 L F
.25583 .43883 m .20057 .42656 L .19799 .42909 L F
.25766 .43609 m .20057 .42656 L .25583 .43883 L F
.56832 .3316 m .52373 .34783 L .52375 .35017 L .787 .211 .013 r
F
.56829 .32961 m .52373 .34783 L .56832 .3316 L F
.52382 .36193 m .47623 .37567 L .47621 .37838 L F
.52381 .35958 m .47623 .37567 L .52382 .36193 L F
.32688 .37603 m .27807 .3727 L .32673 .37969 L F
.32688 .37603 m .27828 .36878 L .27807 .3727 L F
.18265 .44419 m .12616 .42407 L .1229 .42631 L .479 .526 .746 r
F
.18519 .44169 m .12616 .42407 L .18265 .44419 L F
.64142 .35346 m .59712 .38363 L .64491 .35577 L F
.64142 .35346 m .59432 .38106 L .59712 .38363 L F
.42666 .39065 m .37619 .39851 L .42661 .39372 L .787 .211 .013 r
F
.42666 .39065 m .37629 .39511 L .37619 .39851 L F
.4762 .3811 m .42666 .39065 L .42661 .39372 L F
.47621 .37838 m .42666 .39065 L .4762 .3811 L F
.27931 .34931 m .23309 .34013 L .27911 .35319 L F
.27931 .34931 m .23336 .33604 L .23309 .34013 L F
.12675 .38337 m .07521 .35982 L .12637 .38762 L F
.12675 .38337 m .07566 .35545 L .07521 .35982 L F
.52817 .38418 m .48016 .40363 L .53028 .38699 L .479 .526 .746 r
F
.52817 .38418 m .47882 .40068 L .48016 .40363 L F
.37639 .39172 m .32612 .39439 L .37629 .39511 L .787 .211 .013 r
F
.37639 .39172 m .32627 .3907 L .32612 .39439 L F
.56836 .33359 m .52375 .35017 L .52376 .35252 L F
.56832 .3316 m .52375 .35017 L .56836 .33359 L F
.31895 .43052 m .26501 .42505 L .26316 .42782 L .479 .526 .746 r
F
.32001 .42761 m .26501 .42505 L .31895 .43052 L F
.52384 .36429 m .47621 .37838 L .4762 .3811 L .787 .211 .013 r
F
.52382 .36193 m .47621 .37838 L .52384 .36429 L F
.58019 .3681 m .53449 .39261 L .58303 .3707 L .479 .526 .746 r
F
.58019 .3681 m .53239 .38981 L .53449 .39261 L F
.71175 .33519 m .66915 .37179 L .71583 .33715 L F
.71175 .33519 m .66571 .36952 L .66915 .37179 L F
.32673 .37969 m .27786 .37662 L .32658 .38335 L .787 .211 .013 r
F
.32673 .37969 m .27807 .3727 L .27786 .37662 L F
.42661 .39372 m .37609 .40191 L .42656 .39679 L F
.42661 .39372 m .37619 .39851 L .37609 .40191 L F
.47619 .38383 m .42661 .39372 L .42656 .39679 L F
.4762 .3811 m .42661 .39372 L .47619 .38383 L F
.42749 .4121 m .37526 .41819 L .375 .4212 L .479 .526 .746 r
F
.42695 .40907 m .37526 .41819 L .42749 .4121 L F
.47747 .39772 m .42749 .4121 L .47882 .40068 L F
.47747 .39772 m .42695 .40907 L .42749 .4121 L F
.375 .4212 m .32214 .42175 L .32107 .42469 L F
.37526 .41819 m .32214 .42175 L .375 .4212 L F
.56839 .33558 m .52376 .35252 L .52378 .35487 L .787 .211 .013 r
F
.56836 .33359 m .52376 .35252 L .56839 .33558 L F
.27911 .35319 m .23283 .34423 L .2789 .35708 L F
.27911 .35319 m .23309 .34013 L .23283 .34423 L F
.25766 .43609 m .20315 .42401 L .20057 .42656 L .479 .526 .746 r
F
.25949 .43334 m .20315 .42401 L .25766 .43609 L F
.18519 .44169 m .12942 .42182 L .12616 .42407 L F
.18774 .43918 m .12942 .42182 L .18519 .44169 L F
.37629 .39511 m .32597 .39808 L .37619 .39851 L .787 .211 .013 r
F
.37629 .39511 m .32612 .39439 L .32597 .39808 L F
.52385 .36666 m .4762 .3811 L .47619 .38383 L F
.52384 .36429 m .4762 .3811 L .52385 .36666 L F
.63792 .35115 m .59432 .38106 L .64142 .35346 L .479 .526 .746 r
F
.63792 .35115 m .59151 .37848 L .59432 .38106 L F
.12637 .38762 m .07476 .3642 L .12599 .39189 L .787 .211 .013 r
F
.12637 .38762 m .07521 .35982 L .07476 .3642 L F
.56842 .33757 m .52378 .35487 L .52379 .35722 L F
.56839 .33558 m .52378 .35487 L .56842 .33757 L F
.42656 .39679 m .37599 .40531 L .42651 .39987 L F
.42656 .39679 m .37609 .40191 L .37599 .40531 L F
.47617 .38655 m .42656 .39679 L .42651 .39987 L F
.47619 .38383 m .42656 .39679 L .47617 .38655 L F
.52605 .38135 m .47882 .40068 L .52817 .38418 L .479 .526 .746 r
F
.52605 .38135 m .47747 .39772 L .47882 .40068 L F
.32658 .38335 m .27765 .38055 L .32643 .38702 L .787 .211 .013 r
F
.32658 .38335 m .27786 .37662 L .27765 .38055 L F
.70767 .33324 m .66571 .36952 L .71175 .33519 L .479 .526 .746 r
F
.70767 .33324 m .66226 .36724 L .66571 .36952 L F
.32001 .42761 m .26686 .42227 L .26501 .42505 L F
.32107 .42469 m .26686 .42227 L .32001 .42761 L F
.52387 .36902 m .47619 .38383 L .47617 .38655 L .787 .211 .013 r
F
.52385 .36666 m .47619 .38383 L .52387 .36902 L F
.57735 .36549 m .53239 .38981 L .58019 .3681 L .479 .526 .746 r
F
.57735 .36549 m .53028 .38699 L .53239 .38981 L F
.37619 .39851 m .32582 .40177 L .37609 .40191 L .787 .211 .013 r
F
.37619 .39851 m .32597 .39808 L .32582 .40177 L F
.2789 .35708 m .23256 .34833 L .27869 .36097 L F
.2789 .35708 m .23283 .34423 L .23256 .34833 L F
.56846 .33957 m .52379 .35722 L .52381 .35958 L F
.56842 .33757 m .52379 .35722 L .56846 .33957 L F
.12599 .39189 m .07431 .36859 L .12561 .39616 L F
.12599 .39189 m .07476 .3642 L .07431 .36859 L F
.42651 .39987 m .37589 .40872 L .42645 .40295 L F
.42651 .39987 m .37599 .40531 L .37589 .40872 L F
.47616 .38928 m .42651 .39987 L .42645 .40295 L F
.47617 .38655 m .42651 .39987 L .47616 .38928 L F
.18774 .43918 m .13269 .41957 L .12942 .42182 L .479 .526 .746 r
F
.19029 .43667 m .13269 .41957 L .18774 .43918 L F
.42695 .40907 m .37553 .41517 L .37526 .41819 L F
.4264 .40604 m .37553 .41517 L .42695 .40907 L F
.47613 .39475 m .42695 .40907 L .47747 .39772 L F
.47613 .39475 m .4264 .40604 L .42695 .40907 L F
.37526 .41819 m .32321 .41881 L .32214 .42175 L F
.37553 .41517 m .32321 .41881 L .37526 .41819 L F
.63441 .34883 m .59151 .37848 L .63792 .35115 L F
.63441 .34883 m .58869 .37589 L .59151 .37848 L F
.25949 .43334 m .20574 .42147 L .20315 .42401 L F
.26132 .43059 m .20574 .42147 L .25949 .43334 L F
.52388 .37139 m .47617 .38655 L .47616 .38928 L .787 .211 .013 r
F
.52387 .36902 m .47617 .38655 L .52388 .37139 L F
.32643 .38702 m .27744 .38449 L .32627 .3907 L F
.32643 .38702 m .27765 .38055 L .27744 .38449 L F
.56849 .34157 m .52381 .35958 L .52382 .36193 L F
.56846 .33957 m .52381 .35958 L .56849 .34157 L F
.37609 .40191 m .32566 .40548 L .37599 .40531 L F
.37609 .40191 m .32582 .40177 L .32566 .40548 L F
.23441 .31977 m .19177 .30551 L .23415 .32382 L F
.23441 .31977 m .19209 .30129 L .19177 .30551 L F
.60879 .3012 m .56812 .31969 L .56815 .32167 L F
.70359 .33128 m .66226 .36724 L .70767 .33324 L .479 .526 .746 r
F
.70359 .33128 m .65881 .36495 L .66226 .36724 L F
.27869 .36097 m .2323 .35245 L .27849 .36487 L .787 .211 .013 r
F
.27869 .36097 m .23256 .34833 L .2323 .35245 L F
.42645 .40295 m .37579 .41214 L .4264 .40604 L F
.42645 .40295 m .37589 .40872 L .37579 .41214 L F
.47614 .39202 m .42645 .40295 L .4264 .40604 L F
.47616 .38928 m .42645 .40295 L .47614 .39202 L F
.52393 .37852 m .47747 .39772 L .52605 .38135 L .479 .526 .746 r
F
.52393 .37852 m .47613 .39475 L .47747 .39772 L F
.5239 .37376 m .47616 .38928 L .47614 .39202 L .787 .211 .013 r
F
.52388 .37139 m .47616 .38928 L .5239 .37376 L F
.32107 .42469 m .26871 .41949 L .26686 .42227 L .479 .526 .746 r
F
.32214 .42175 m .26871 .41949 L .32107 .42469 L F
.56853 .34357 m .52382 .36193 L .52384 .36429 L .787 .211 .013 r
F
.56849 .34157 m .52382 .36193 L .56853 .34357 L F
.5745 .36288 m .53028 .38699 L .57735 .36549 L .479 .526 .746 r
F
.5745 .36288 m .52817 .38418 L .53028 .38699 L F
.12561 .39616 m .07386 .37299 L .12522 .40044 L .787 .211 .013 r
F
.12561 .39616 m .07431 .36859 L .07386 .37299 L F
.60884 .30283 m .56815 .32167 L .56818 .32365 L F
.60879 .3012 m .56815 .32167 L .60884 .30283 L F
.32627 .3907 m .27723 .38843 L .32612 .39439 L F
.32627 .3907 m .27744 .38449 L .27723 .38843 L F
.19029 .43667 m .13596 .41732 L .13269 .41957 L .479 .526 .746 r
F
.19285 .43415 m .13596 .41732 L .19029 .43667 L F
.6309 .34651 m .58869 .37589 L .63441 .34883 L F
.6309 .34651 m .58586 .3733 L .58869 .37589 L F
.37599 .40531 m .32551 .40919 L .37589 .40872 L .787 .211 .013 r
F
.37599 .40531 m .32566 .40548 L .32551 .40919 L F
.26132 .43059 m .20834 .41891 L .20574 .42147 L .479 .526 .746 r
F
.26316 .42782 m .20834 .41891 L .26132 .43059 L F
.47614 .39202 m .4264 .40604 L .47613 .39475 L .787 .211 .013 r
F
.4264 .40604 m .37579 .41214 L .37553 .41517 L .479 .526 .746 r
F
.23415 .32382 m .19145 .30973 L .23388 .32789 L .787 .211 .013 r
F
.23415 .32382 m .19177 .30551 L .19145 .30973 L F
.52391 .37614 m .47614 .39202 L .47613 .39475 L F
.5239 .37376 m .47614 .39202 L .52391 .37614 L F
.37553 .41517 m .32428 .41586 L .32321 .41881 L .479 .526 .746 r
F
.37579 .41214 m .32428 .41586 L .37553 .41517 L F
.60888 .30447 m .56818 .32365 L .56822 .32564 L .787 .211 .013 r
F
.60884 .30283 m .56818 .32365 L .60888 .30447 L F
.56856 .34557 m .52384 .36429 L .52385 .36666 L F
.56853 .34357 m .52384 .36429 L .56856 .34557 L F
.69949 .32932 m .65881 .36495 L .70359 .33128 L .479 .526 .746 r
F
.69949 .32932 m .65534 .36266 L .65881 .36495 L F
.27849 .36487 m .23203 .35657 L .27828 .36878 L .787 .211 .013 r
F
.27849 .36487 m .2323 .35245 L .23203 .35657 L F
.07966 .31651 m .03532 .28694 L .07922 .3208 L F
.07966 .31651 m .03582 .28259 L .03532 .28694 L F
.60893 .3061 m .56822 .32564 L .56825 .32762 L F
.60888 .30447 m .56822 .32564 L .60893 .3061 L F
.12522 .40044 m .07341 .3774 L .12484 .40473 L F
.12522 .40044 m .07386 .37299 L .07341 .3774 L F
.32612 .39439 m .27702 .39239 L .32597 .39808 L F
.32612 .39439 m .27723 .38843 L .27702 .39239 L F
.76341 .28242 m .72259 .31636 L .72266 .31765 L F
.5686 .34757 m .52385 .36666 L .52387 .36902 L F
.56856 .34557 m .52385 .36666 L .5686 .34757 L F
.37589 .40872 m .32536 .41291 L .37579 .41214 L F
.37589 .40872 m .32551 .40919 L .32536 .41291 L F
.52391 .37614 m .47613 .39475 L .52393 .37852 L F
.32214 .42175 m .27057 .4167 L .26871 .41949 L .479 .526 .746 r
F
.32321 .41881 m .27057 .4167 L .32214 .42175 L F
.57164 .36025 m .52817 .38418 L .5745 .36288 L F
.57164 .36025 m .52605 .38135 L .52817 .38418 L F
.76347 .2834 m .72266 .31765 L .72273 .31894 L .787 .211 .013 r
F
.76341 .28242 m .72266 .31765 L .76347 .2834 L F
.19285 .43415 m .13924 .41506 L .13596 .41732 L .479 .526 .746 r
F
.19542 .43162 m .13924 .41506 L .19285 .43415 L F
.60897 .30774 m .56825 .32762 L .56829 .32961 L .787 .211 .013 r
F
.60893 .3061 m .56825 .32762 L .60897 .30774 L F
.23388 .32789 m .19113 .31397 L .23362 .33196 L F
.23388 .32789 m .19145 .30973 L .19113 .31397 L F
.62738 .34418 m .58586 .3733 L .6309 .34651 L .479 .526 .746 r
F
.62738 .34418 m .58303 .3707 L .58586 .3733 L F
.27828 .36878 m .23176 .3607 L .27807 .3727 L .787 .211 .013 r
F
.27828 .36878 m .23203 .35657 L .23176 .3607 L F
.56863 .34958 m .52387 .36902 L .52388 .37139 L F
.5686 .34757 m .52387 .36902 L .56863 .34958 L F
.69539 .32736 m .65534 .36266 L .69949 .32932 L .479 .526 .746 r
F
.69539 .32736 m .65187 .36037 L .65534 .36266 L F
.76354 .28439 m .72273 .31894 L .7228 .32024 L .787 .211 .013 r
F
.76347 .2834 m .72273 .31894 L .76354 .28439 L F
.26316 .42782 m .21094 .41635 L .20834 .41891 L .479 .526 .746 r
F
.26501 .42505 m .21094 .41635 L .26316 .42782 L F
.32597 .39808 m .27681 .39635 L .32582 .40177 L .787 .211 .013 r
F
.32597 .39808 m .27702 .39239 L .27681 .39635 L F
.37579 .41214 m .32536 .41291 L .32428 .41586 L .479 .526 .746 r
F
.60902 .30938 m .56829 .32961 L .56832 .3316 L .787 .211 .013 r
F
.60897 .30774 m .56829 .32961 L .60902 .30938 L F
.7636 .28538 m .7228 .32024 L .72287 .32153 L F
.76354 .28439 m .7228 .32024 L .7636 .28538 L F
.07922 .3208 m .03483 .2913 L .07878 .3251 L F
.07922 .3208 m .03532 .28694 L .03483 .2913 L F
.12484 .40473 m .07295 .38182 L .12445 .40903 L F
.12484 .40473 m .07341 .3774 L .07295 .38182 L F
.56867 .35159 m .52388 .37139 L .5239 .37376 L F
.56863 .34958 m .52388 .37139 L .56867 .35159 L F
.76367 .28636 m .72287 .32153 L .72295 .32283 L F
.7636 .28538 m .72287 .32153 L .76367 .28636 L F
.60906 .31102 m .56832 .3316 L .56836 .33359 L F
.60902 .30938 m .56832 .3316 L .60906 .31102 L F
.23362 .33196 m .19081 .31821 L .23336 .33604 L F
.23362 .33196 m .19113 .31397 L .19081 .31821 L F
.27807 .3727 m .2315 .36483 L .27786 .37662 L F
.27807 .3727 m .23176 .3607 L .2315 .36483 L F
.56877 .35762 m .52605 .38135 L .57164 .36025 L .479 .526 .746 r
F
.56877 .35762 m .52393 .37852 L .52605 .38135 L F
.76373 .28735 m .72295 .32283 L .72302 .32412 L .787 .211 .013 r
F
.76367 .28636 m .72295 .32283 L .76373 .28735 L F
.19542 .43162 m .14253 .4128 L .13924 .41506 L .479 .526 .746 r
F
.19799 .42909 m .14253 .4128 L .19542 .43162 L F
.32321 .41881 m .27243 .4139 L .27057 .4167 L F
.32428 .41586 m .27243 .4139 L .32321 .41881 L F
.62385 .34185 m .58303 .3707 L .62738 .34418 L F
.62385 .34185 m .58019 .3681 L .58303 .3707 L F
.69128 .32539 m .65187 .36037 L .69539 .32736 L F
.69128 .32539 m .6484 .35807 L .65187 .36037 L F
.5687 .3536 m .5239 .37376 L .52391 .37614 L .787 .211 .013 r
F
.56867 .35159 m .5239 .37376 L .5687 .3536 L F
.32582 .40177 m .2766 .40031 L .32566 .40548 L F
.32582 .40177 m .27681 .39635 L .2766 .40031 L F
.60911 .31266 m .56836 .33359 L .56839 .33558 L F
.60906 .31102 m .56836 .33359 L .60911 .31266 L F
.7638 .28833 m .72302 .32412 L .72309 .32542 L F
.76373 .28735 m .72302 .32412 L .7638 .28833 L F
.26501 .42505 m .21355 .41378 L .21094 .41635 L .479 .526 .746 r
F
.26686 .42227 m .21355 .41378 L .26501 .42505 L F
.07878 .3251 m .03433 .29566 L .07833 .3294 L .787 .211 .013 r
F
.07878 .3251 m .03483 .2913 L .03433 .29566 L F
.12445 .40903 m .0725 .38625 L .12407 .41333 L F
.12445 .40903 m .07295 .38182 L .0725 .38625 L F
.76386 .28932 m .72309 .32542 L .72316 .32671 L F
.7638 .28833 m .72309 .32542 L .76386 .28932 L F
.56874 .35561 m .52391 .37614 L .52393 .37852 L F
.5687 .3536 m .52391 .37614 L .56874 .35561 L F
.60915 .3143 m .56839 .33558 L .56842 .33757 L F
.60911 .31266 m .56839 .33558 L .60915 .3143 L F
.27786 .37662 m .23123 .36898 L .27765 .38055 L F
.27786 .37662 m .2315 .36483 L .23123 .36898 L F
.23336 .33604 m .19049 .32246 L .23309 .34013 L F
.23336 .33604 m .19081 .31821 L .19049 .32246 L F
.76393 .29031 m .72316 .32671 L .72323 .32801 L F
.76386 .28932 m .72316 .32671 L .76393 .29031 L F
.32566 .40548 m .27639 .40429 L .32551 .40919 L F
.32566 .40548 m .2766 .40031 L .27639 .40429 L F
.68716 .32342 m .6484 .35807 L .69128 .32539 L .479 .526 .746 r
F
.68716 .32342 m .64491 .35577 L .6484 .35807 L F
.19799 .42909 m .14583 .41053 L .14253 .4128 L F
.20057 .42656 m .14583 .41053 L .19799 .42909 L F
.76399 .2913 m .72323 .32801 L .7233 .32931 L .787 .211 .013 r
F
.76393 .29031 m .72323 .32801 L .76399 .2913 L F
.6092 .31595 m .56842 .33757 L .56846 .33957 L F
.60915 .3143 m .56842 .33757 L .6092 .31595 L F
.62031 .33951 m .58019 .3681 L .62385 .34185 L .479 .526 .746 r
F
.62031 .33951 m .57735 .36549 L .58019 .3681 L F
.56874 .35561 m .52393 .37852 L .56877 .35762 L .787 .211 .013 r
F
.32428 .41586 m .2743 .41109 L .27243 .4139 L .479 .526 .746 r
F
.32536 .41291 m .2743 .41109 L .32428 .41586 L F
.12407 .41333 m .07204 .39069 L .12368 .41765 L .787 .211 .013 r
F
.12407 .41333 m .0725 .38625 L .07204 .39069 L F
.07833 .3294 m .03382 .30004 L .07789 .33372 L F
.07833 .3294 m .03433 .29566 L .03382 .30004 L F
.76406 .29229 m .7233 .32931 L .72338 .33061 L F
.76399 .2913 m .7233 .32931 L .76406 .29229 L F
.60924 .31759 m .56846 .33957 L .56849 .34157 L F
.6092 .31595 m .56846 .33957 L .60924 .31759 L F
.27765 .38055 m .23096 .37314 L .27744 .38449 L F
.27765 .38055 m .23123 .36898 L .23096 .37314 L F
.26686 .42227 m .21616 .41121 L .21355 .41378 L .479 .526 .746 r
F
.26871 .41949 m .21616 .41121 L .26686 .42227 L F
.23309 .34013 m .19017 .32672 L .23283 .34423 L .787 .211 .013 r
F
.23309 .34013 m .19049 .32246 L .19017 .32672 L F
.76412 .29328 m .72338 .33061 L .72345 .33191 L F
.76406 .29229 m .72338 .33061 L .76412 .29328 L F
.32551 .40919 m .27618 .40827 L .32536 .41291 L F
.32551 .40919 m .27639 .40429 L .27618 .40827 L F
.76419 .29427 m .72345 .33191 L .72352 .33321 L F
.76412 .29328 m .72345 .33191 L .76419 .29427 L F
.68304 .32144 m .64491 .35577 L .68716 .32342 L .479 .526 .746 r
F
.68304 .32144 m .64142 .35346 L .64491 .35577 L F
.60929 .31924 m .56849 .34157 L .56853 .34357 L .787 .211 .013 r
F
.60924 .31759 m .56849 .34157 L .60929 .31924 L F
.20057 .42656 m .14913 .40825 L .14583 .41053 L .479 .526 .746 r
F
.20315 .42401 m .14913 .40825 L .20057 .42656 L F
.61676 .33717 m .57735 .36549 L .62031 .33951 L F
.61676 .33717 m .5745 .36288 L .57735 .36549 L F
.12368 .41765 m .07159 .39514 L .12329 .42197 L .787 .211 .013 r
F
.12368 .41765 m .07204 .39069 L .07159 .39514 L F
.76425 .29526 m .72352 .33321 L .72359 .33451 L F
.76419 .29427 m .72352 .33321 L .76425 .29526 L F
.07789 .33372 m .03332 .30443 L .07745 .33805 L F
.07789 .33372 m .03382 .30004 L .03332 .30443 L F
.27744 .38449 m .23069 .3773 L .27723 .38843 L F
.27744 .38449 m .23096 .37314 L .23069 .3773 L F
.60933 .32089 m .56853 .34357 L .56856 .34557 L F
.60929 .31924 m .56853 .34357 L .60933 .32089 L F
.23283 .34423 m .18985 .33099 L .23256 .34833 L F
.23283 .34423 m .19017 .32672 L .18985 .33099 L F
.76432 .29625 m .72359 .33451 L .72366 .33582 L F
.76425 .29526 m .72359 .33451 L .76432 .29625 L F
.32536 .41291 m .27618 .40827 L .2743 .41109 L .479 .526 .746 r
F
.26871 .41949 m .21879 .40863 L .21616 .41121 L F
.27057 .4167 m .21879 .40863 L .26871 .41949 L F
.76438 .29724 m .72366 .33582 L .72374 .33712 L .787 .211 .013 r
F
.76432 .29625 m .72366 .33582 L .76438 .29724 L F
.60938 .32254 m .56856 .34557 L .5686 .34757 L F
.60933 .32089 m .56856 .34557 L .60938 .32254 L F
.67891 .31946 m .64142 .35346 L .68304 .32144 L .479 .526 .746 r
F
.67891 .31946 m .63792 .35115 L .64142 .35346 L F
.76445 .29823 m .72374 .33712 L .72381 .33842 L .787 .211 .013 r
F
.76438 .29724 m .72374 .33712 L .76445 .29823 L F
.12329 .42197 m .07113 .39959 L .1229 .42631 L F
.12329 .42197 m .07159 .39514 L .07113 .39959 L F
.07745 .33805 m .03282 .30883 L .077 .34238 L F
.07745 .33805 m .03332 .30443 L .03282 .30883 L F
.27723 .38843 m .23042 .38147 L .27702 .39239 L F
.27723 .38843 m .23069 .3773 L .23042 .38147 L F
.20315 .42401 m .15244 .40598 L .14913 .40825 L .479 .526 .746 r
F
.20574 .42147 m .15244 .40598 L .20315 .42401 L F
.60942 .32419 m .5686 .34757 L .56863 .34958 L .787 .211 .013 r
F
.60938 .32254 m .5686 .34757 L .60942 .32419 L F
.61321 .33482 m .5745 .36288 L .61676 .33717 L .479 .526 .746 r
F
.61321 .33482 m .57164 .36025 L .5745 .36288 L F
.76451 .29922 m .72381 .33842 L .72388 .33973 L .787 .211 .013 r
F
.76445 .29823 m .72381 .33842 L .76451 .29922 L F
.23256 .34833 m .18953 .33526 L .2323 .35245 L F
.23256 .34833 m .18985 .33099 L .18953 .33526 L F
.76458 .30022 m .72388 .33973 L .72395 .34104 L F
.76451 .29922 m .72388 .33973 L .76458 .30022 L F
.60947 .32584 m .56863 .34958 L .56867 .35159 L F
.60942 .32419 m .56863 .34958 L .60947 .32584 L F
.67477 .31748 m .63792 .35115 L .67891 .31946 L .479 .526 .746 r
F
.67477 .31748 m .63441 .34883 L .63792 .35115 L F
.27057 .4167 m .22141 .40604 L .21879 .40863 L F
.27243 .4139 m .22141 .40604 L .27057 .4167 L F
.76458 .30022 m .72395 .34104 L .76464 .30121 L .787 .211 .013 r
F
.76002 .29965 m .72395 .34104 L .76464 .30121 L .479 .526 .746 r
F
.76002 .29965 m .71989 .33909 L .72395 .34104 L F
.12616 .42407 m .07113 .39959 L .1229 .42631 L F
.27702 .39239 m .23015 .38565 L .27681 .39635 L .787 .211 .013 r
F
.27702 .39239 m .23042 .38147 L .23015 .38565 L F
.077 .34238 m .03232 .31323 L .07655 .34673 L F
.077 .34238 m .03282 .30883 L .03232 .31323 L F
.60951 .32749 m .56867 .35159 L .5687 .3536 L F
.60947 .32584 m .56867 .35159 L .60951 .32749 L F
.2323 .35245 m .1892 .33955 L .23203 .35657 L F
.2323 .35245 m .18953 .33526 L .1892 .33955 L F
.20574 .42147 m .15576 .40369 L .15244 .40598 L .479 .526 .746 r
F
.20834 .41891 m .15576 .40369 L .20574 .42147 L F
.60965 .33246 m .57164 .36025 L .61321 .33482 L F
.60965 .33246 m .56877 .35762 L .57164 .36025 L F
.60956 .32915 m .5687 .3536 L .56874 .35561 L .787 .211 .013 r
F
.60951 .32749 m .5687 .3536 L .60956 .32915 L F
.19209 .30129 m .15383 .28307 L .19177 .30551 L F
.19209 .30129 m .1542 .27874 L .15383 .28307 L F
.64467 .27863 m .60879 .3012 L .60884 .30283 L F
.75538 .2981 m .71989 .33909 L .76002 .29965 L .479 .526 .746 r
F
.75538 .2981 m .71583 .33715 L .71989 .33909 L F
.67062 .31549 m .63441 .34883 L .67477 .31748 L F
.67062 .31549 m .6309 .34651 L .63441 .34883 L F
.27681 .39635 m .22988 .38984 L .2766 .40031 L .787 .211 .013 r
F
.27681 .39635 m .23015 .38565 L .22988 .38984 L F
.6096 .33081 m .56874 .35561 L .56877 .35762 L F
.60956 .32915 m .56874 .35561 L .6096 .33081 L F
.12616 .42407 m .07506 .39767 L .07113 .39959 L .479 .526 .746 r
F
.12942 .42182 m .07506 .39767 L .12616 .42407 L F
.64472 .27993 m .60884 .30283 L .60888 .30447 L .787 .211 .013 r
F
.64467 .27863 m .60884 .30283 L .64472 .27993 L F
.07655 .34673 m .03181 .31765 L .07611 .35108 L F
.07655 .34673 m .03232 .31323 L .03181 .31765 L F
.27243 .4139 m .22405 .40345 L .22141 .40604 L .479 .526 .746 r
F
.2743 .41109 m .22405 .40345 L .27243 .4139 L F
.23203 .35657 m .18888 .34385 L .23176 .3607 L .787 .211 .013 r
F
.23203 .35657 m .1892 .33955 L .18888 .34385 L F
.64477 .28123 m .60888 .30447 L .60893 .3061 L F
.64472 .27993 m .60888 .30447 L .64477 .28123 L F
.20834 .41891 m .15908 .4014 L .15576 .40369 L .479 .526 .746 r
F
.21094 .41635 m .15908 .4014 L .20834 .41891 L F
.6096 .33081 m .56877 .35762 L .60965 .33246 L .787 .211 .013 r
F
.75074 .29654 m .71583 .33715 L .75538 .2981 L .479 .526 .746 r
F
.75074 .29654 m .71175 .33519 L .71583 .33715 L F
.19177 .30551 m .15346 .2874 L .19145 .30973 L .787 .211 .013 r
F
.19177 .30551 m .15383 .28307 L .15346 .2874 L F
.64482 .28254 m .60893 .3061 L .60897 .30774 L F
.64477 .28123 m .60893 .3061 L .64482 .28254 L F
.66647 .3135 m .6309 .34651 L .67062 .31549 L .479 .526 .746 r
F
.66647 .3135 m .62738 .34418 L .6309 .34651 L F
.2766 .40031 m .22961 .39404 L .27639 .40429 L .787 .211 .013 r
F
.2766 .40031 m .22988 .38984 L .22961 .39404 L F
.12942 .42182 m .079 .39575 L .07506 .39767 L .479 .526 .746 r
F
.13269 .41957 m .079 .39575 L .12942 .42182 L F
.07611 .35108 m .0313 .32207 L .07566 .35545 L .787 .211 .013 r
F
.07611 .35108 m .03181 .31765 L .0313 .32207 L F
.23176 .3607 m .18856 .34815 L .2315 .36483 L F
.23176 .3607 m .18888 .34385 L .18856 .34815 L F
.64486 .28384 m .60897 .30774 L .60902 .30938 L F
.64482 .28254 m .60897 .30774 L .64486 .28384 L F
.2743 .41109 m .22669 .40085 L .22405 .40345 L .479 .526 .746 r
F
.27618 .40827 m .22669 .40085 L .2743 .41109 L F
.7461 .29498 m .71175 .33519 L .75074 .29654 L F
.7461 .29498 m .70767 .33324 L .71175 .33519 L F
.64491 .28515 m .60902 .30938 L .60906 .31102 L .787 .211 .013 r
F
.64486 .28384 m .60902 .30938 L .64491 .28515 L F
.19145 .30973 m .15309 .29174 L .19113 .31397 L F
.19145 .30973 m .15346 .2874 L .15309 .29174 L F
.21094 .41635 m .16241 .39911 L .15908 .4014 L .479 .526 .746 r
F
.21355 .41378 m .16241 .39911 L .21094 .41635 L F
.27639 .40429 m .22934 .39824 L .27618 .40827 L .787 .211 .013 r
F
.27639 .40429 m .22961 .39404 L .22934 .39824 L F
.6623 .31151 m .62738 .34418 L .66647 .3135 L .479 .526 .746 r
F
.6623 .31151 m .62385 .34185 L .62738 .34418 L F
.64496 .28645 m .60906 .31102 L .60911 .31266 L .787 .211 .013 r
F
.64491 .28515 m .60906 .31102 L .64496 .28645 L F
.13269 .41957 m .08294 .39382 L .079 .39575 L .479 .526 .746 r
F
.13596 .41732 m .08294 .39382 L .13269 .41957 L F
.2315 .36483 m .18823 .35247 L .23123 .36898 L .787 .211 .013 r
F
.2315 .36483 m .18856 .34815 L .18823 .35247 L F
.07566 .35545 m .0308 .32651 L .07521 .35982 L F
.07566 .35545 m .0313 .32207 L .0308 .32651 L F
.74145 .29341 m .70767 .33324 L .7461 .29498 L .479 .526 .746 r
F
.74145 .29341 m .70359 .33128 L .70767 .33324 L F
.64501 .28776 m .60911 .31266 L .60915 .3143 L .787 .211 .013 r
F
.64496 .28645 m .60911 .31266 L .64501 .28776 L F
.19113 .31397 m .15272 .29609 L .19081 .31821 L F
.19113 .31397 m .15309 .29174 L .15272 .29609 L F
.27618 .40827 m .22934 .39824 L .22669 .40085 L .479 .526 .746 r
F
.64505 .28906 m .60915 .3143 L .6092 .31595 L .787 .211 .013 r
F
.64501 .28776 m .60915 .3143 L .64505 .28906 L F
.21355 .41378 m .16575 .39681 L .16241 .39911 L .479 .526 .746 r
F
.21616 .41121 m .16575 .39681 L .21355 .41378 L F
.65813 .30951 m .62385 .34185 L .6623 .31151 L F
.65813 .30951 m .62031 .33951 L .62385 .34185 L F
.23123 .36898 m .18791 .35679 L .23096 .37314 L .787 .211 .013 r
F
.23123 .36898 m .18823 .35247 L .18791 .35679 L F
.13596 .41732 m .0869 .39189 L .08294 .39382 L .479 .526 .746 r
F
.13924 .41506 m .0869 .39189 L .13596 .41732 L F
.6451 .29037 m .6092 .31595 L .60924 .31759 L .787 .211 .013 r
F
.64505 .28906 m .6092 .31595 L .6451 .29037 L F
.07521 .35982 m .03029 .33095 L .07476 .3642 L F
.07521 .35982 m .0308 .32651 L .03029 .33095 L F
.73679 .29185 m .70359 .33128 L .74145 .29341 L .479 .526 .746 r
F
.73679 .29185 m .69949 .32932 L .70359 .33128 L F
.64515 .29168 m .60924 .31759 L .60929 .31924 L .787 .211 .013 r
F
.6451 .29037 m .60924 .31759 L .64515 .29168 L F
.19081 .31821 m .15235 .30045 L .19049 .32246 L F
.19081 .31821 m .15272 .29609 L .15235 .30045 L F
.6452 .29299 m .60929 .31924 L .60933 .32089 L F
.64515 .29168 m .60929 .31924 L .6452 .29299 L F
.65396 .30751 m .62031 .33951 L .65813 .30951 L .479 .526 .746 r
F
.65396 .30751 m .61676 .33717 L .62031 .33951 L F
.21616 .41121 m .1691 .39451 L .16575 .39681 L F
.21879 .40863 m .1691 .39451 L .21616 .41121 L F
.73212 .29028 m .69949 .32932 L .73679 .29185 L F
.73212 .29028 m .69539 .32736 L .69949 .32932 L F
.23096 .37314 m .18758 .36112 L .23069 .3773 L .787 .211 .013 r
F
.23096 .37314 m .18791 .35679 L .18758 .36112 L F
.13924 .41506 m .09086 .38996 L .0869 .39189 L .479 .526 .746 r
F
.14253 .4128 m .09086 .38996 L .13924 .41506 L F
.07476 .3642 m .02978 .33541 L .07431 .36859 L .787 .211 .013 r
F
.07476 .3642 m .03029 .33095 L .02978 .33541 L F
.64525 .2943 m .60933 .32089 L .60938 .32254 L F
.6452 .29299 m .60933 .32089 L .64525 .2943 L F
.19049 .32246 m .15198 .30482 L .19017 .32672 L F
.19049 .32246 m .15235 .30045 L .15198 .30482 L F
.64529 .29561 m .60938 .32254 L .60942 .32419 L F
.64525 .2943 m .60938 .32254 L .64529 .29561 L F
.72745 .28871 m .69539 .32736 L .73212 .29028 L .479 .526 .746 r
F
.72745 .28871 m .69128 .32539 L .69539 .32736 L F
.64977 .30551 m .61676 .33717 L .65396 .30751 L F
.64977 .30551 m .61321 .33482 L .61676 .33717 L F
.23069 .3773 m .18725 .36546 L .23042 .38147 L .787 .211 .013 r
F
.23069 .3773 m .18758 .36112 L .18725 .36546 L F
.64534 .29693 m .60942 .32419 L .60947 .32584 L F
.64529 .29561 m .60942 .32419 L .64534 .29693 L F
.21879 .40863 m .17245 .3922 L .1691 .39451 L .479 .526 .746 r
F
.22141 .40604 m .17245 .3922 L .21879 .40863 L F
.14253 .4128 m .09482 .38802 L .09086 .38996 L F
.14583 .41053 m .09482 .38802 L .14253 .4128 L F
.07431 .36859 m .02927 .33987 L .07386 .37299 L .787 .211 .013 r
F
.07431 .36859 m .02978 .33541 L .02927 .33987 L F
.64539 .29824 m .60947 .32584 L .60951 .32749 L F
.64534 .29693 m .60947 .32584 L .64539 .29824 L F
.19017 .32672 m .1516 .3092 L .18985 .33099 L F
.19017 .32672 m .15198 .30482 L .1516 .3092 L F
.72277 .28714 m .69128 .32539 L .72745 .28871 L .479 .526 .746 r
F
.72277 .28714 m .68716 .32342 L .69128 .32539 L F
.64544 .29955 m .60951 .32749 L .60956 .32915 L .787 .211 .013 r
F
.64539 .29824 m .60951 .32749 L .64544 .29955 L F
.64558 .3035 m .61321 .33482 L .64977 .30551 L .479 .526 .746 r
F
.64558 .3035 m .60965 .33246 L .61321 .33482 L F
.23042 .38147 m .18692 .36981 L .23015 .38565 L .787 .211 .013 r
F
.23042 .38147 m .18725 .36546 L .18692 .36981 L F
.07386 .37299 m .02876 .34435 L .07341 .3774 L F
.07386 .37299 m .02927 .33987 L .02876 .34435 L F
.14583 .41053 m .0988 .38608 L .09482 .38802 L .479 .526 .746 r
F
.14913 .40825 m .0988 .38608 L .14583 .41053 L F
.64548 .30087 m .60956 .32915 L .6096 .33081 L .787 .211 .013 r
F
.64544 .29955 m .60956 .32915 L .64548 .30087 L F
.22141 .40604 m .17581 .38989 L .17245 .3922 L .479 .526 .746 r
F
.22405 .40345 m .17581 .38989 L .22141 .40604 L F
.71809 .28556 m .68716 .32342 L .72277 .28714 L F
.71809 .28556 m .68304 .32144 L .68716 .32342 L F
.18985 .33099 m .15123 .31359 L .18953 .33526 L .787 .211 .013 r
F
.18985 .33099 m .1516 .3092 L .15123 .31359 L F
.64553 .30218 m .6096 .33081 L .60965 .33246 L F
.64548 .30087 m .6096 .33081 L .64553 .30218 L F
.23015 .38565 m .1866 .37417 L .22988 .38984 L F
.23015 .38565 m .18692 .36981 L .1866 .37417 L F
.64553 .30218 m .60965 .33246 L .64558 .3035 L F
.07341 .3774 m .02824 .34883 L .07295 .38182 L F
.07341 .3774 m .02876 .34435 L .02824 .34883 L F
.14913 .40825 m .10278 .38413 L .0988 .38608 L .479 .526 .746 r
F
.15244 .40598 m .10278 .38413 L .14913 .40825 L F
.71339 .28399 m .68304 .32144 L .71809 .28556 L F
.71339 .28399 m .67891 .31946 L .68304 .32144 L F
.22405 .40345 m .17918 .38757 L .17581 .38989 L F
.22669 .40085 m .17918 .38757 L .22405 .40345 L F
.18953 .33526 m .15086 .31799 L .1892 .33955 L .787 .211 .013 r
F
.18953 .33526 m .15123 .31359 L .15086 .31799 L F
.07295 .38182 m .02773 .35333 L .0725 .38625 L F
.07295 .38182 m .02824 .34883 L .02773 .35333 L F
.0725 .38625 m .02722 .35783 L .07204 .39069 L F
.0725 .38625 m .02773 .35333 L .02722 .35783 L F
.07204 .39069 m .0267 .36234 L .07159 .39514 L F
.07204 .39069 m .02722 .35783 L .0267 .36234 L F
.07159 .39514 m .0267 .36234 L .02618 .36687 L F
.03582 .28259 m .1138 .33732 L .02618 .36687 L F
.03582 .28259 m .12175 .25252 L .1138 .33732 L F
.79586 .24407 m .76341 .28242 L .76347 .2834 L F
.22988 .38984 m .18627 .37854 L .22961 .39404 L F
.22988 .38984 m .1866 .37417 L .18627 .37854 L F
.79591 .24478 m .76347 .2834 L .76354 .28439 L F
.79586 .24407 m .76347 .2834 L .79591 .24478 L F
.79597 .24549 m .76354 .28439 L .7636 .28538 L F
.79591 .24478 m .76354 .28439 L .79597 .24549 L F
.15244 .40598 m .10677 .38218 L .10278 .38413 L .479 .526 .746 r
F
.15576 .40369 m .10677 .38218 L .15244 .40598 L F
.7087 .28241 m .67891 .31946 L .71339 .28399 L F
.7087 .28241 m .67477 .31748 L .67891 .31946 L F
.79602 .24619 m .7636 .28538 L .76367 .28636 L .787 .211 .013 r
F
.79597 .24549 m .7636 .28538 L .79602 .24619 L F
.1892 .33955 m .15048 .3224 L .18888 .34385 L F
.1892 .33955 m .15086 .31799 L .15048 .3224 L F
.22669 .40085 m .18255 .38525 L .17918 .38757 L .479 .526 .746 r
F
.22934 .39824 m .18255 .38525 L .22669 .40085 L F
.79607 .2469 m .76367 .28636 L .76373 .28735 L .787 .211 .013 r
F
.79602 .24619 m .76367 .28636 L .79607 .2469 L F
.22961 .39404 m .18594 .38292 L .22934 .39824 L F
.22961 .39404 m .18627 .37854 L .18594 .38292 L F
.79612 .24761 m .76373 .28735 L .7638 .28833 L F
.79607 .2469 m .76373 .28735 L .79612 .24761 L F
.79618 .24832 m .7638 .28833 L .76386 .28932 L F
.79612 .24761 m .7638 .28833 L .79618 .24832 L F
.70399 .28083 m .67477 .31748 L .7087 .28241 L .479 .526 .746 r
F
.70399 .28083 m .67062 .31549 L .67477 .31748 L F
.15576 .40369 m .11077 .38023 L .10677 .38218 L F
.15908 .4014 m .11077 .38023 L .15576 .40369 L F
.1542 .27874 m .12134 .25689 L .15383 .28307 L .787 .211 .013 r
F
.1542 .27874 m .12175 .25252 L .12134 .25689 L F
.67478 .25239 m .64467 .27863 L .64472 .27993 L F
.79623 .24903 m .76386 .28932 L .76393 .29031 L F
.79618 .24832 m .76386 .28932 L .79623 .24903 L F
.18888 .34385 m .1501 .32682 L .18856 .34815 L F
.18888 .34385 m .15048 .3224 L .1501 .32682 L F
.79628 .24973 m .76393 .29031 L .76399 .2913 L F
.79623 .24903 m .76393 .29031 L .79628 .24973 L F
.67483 .25338 m .64472 .27993 L .64477 .28123 L F
.67478 .25239 m .64472 .27993 L .67483 .25338 L F
.79634 .25044 m .76399 .2913 L .76406 .29229 L F
.79628 .24973 m .76399 .2913 L .79634 .25044 L F
.22934 .39824 m .18594 .38292 L .18255 .38525 L .479 .526 .746 r
F
.67487 .25437 m .64477 .28123 L .64482 .28254 L .787 .211 .013 r
F
.67483 .25338 m .64477 .28123 L .67487 .25437 L F
.69928 .27924 m .67062 .31549 L .70399 .28083 L .479 .526 .746 r
F
.69928 .27924 m .66647 .3135 L .67062 .31549 L F
.79639 .25115 m .76406 .29229 L .76412 .29328 L .787 .211 .013 r
F
.79634 .25044 m .76406 .29229 L .79639 .25115 L F
.67492 .25536 m .64482 .28254 L .64486 .28384 L F
.67487 .25437 m .64482 .28254 L .67492 .25536 L F
.79644 .25186 m .76412 .29328 L .76419 .29427 L F
.79639 .25115 m .76412 .29328 L .79644 .25186 L F
.15383 .28307 m .12093 .26128 L .15346 .2874 L F
.15383 .28307 m .12134 .25689 L .12093 .26128 L F
.15908 .4014 m .11477 .37828 L .11077 .38023 L .479 .526 .746 r
F
.16241 .39911 m .11477 .37828 L .15908 .4014 L F
.79649 .25257 m .76419 .29427 L .76425 .29526 L .787 .211 .013 r
F
.79644 .25186 m .76419 .29427 L .79649 .25257 L F
.67496 .25635 m .64486 .28384 L .64491 .28515 L F
.67492 .25536 m .64486 .28384 L .67496 .25635 L F
.18856 .34815 m .14973 .33124 L .18823 .35247 L F
.18856 .34815 m .1501 .32682 L .14973 .33124 L F
.79655 .25328 m .76425 .29526 L .76432 .29625 L F
.79649 .25257 m .76425 .29526 L .79655 .25328 L F
.69456 .27766 m .66647 .3135 L .69928 .27924 L .479 .526 .746 r
F
.69456 .27766 m .6623 .31151 L .66647 .3135 L F
.675 .25735 m .64491 .28515 L .64496 .28645 L .787 .211 .013 r
F
.67496 .25635 m .64491 .28515 L .675 .25735 L F
.7966 .25399 m .76432 .29625 L .76438 .29724 L F
.79655 .25328 m .76432 .29625 L .7966 .25399 L F
.67505 .25834 m .64496 .28645 L .64501 .28776 L F
.675 .25735 m .64496 .28645 L .67505 .25834 L F
.79665 .2547 m .76438 .29724 L .76445 .29823 L F
.7966 .25399 m .76438 .29724 L .79665 .2547 L F
.07159 .39514 m .02618 .36687 L .07113 .39959 L F
.15346 .2874 m .12052 .26567 L .15309 .29174 L F
.15346 .2874 m .12093 .26128 L .12052 .26567 L F
.16241 .39911 m .11878 .37632 L .11477 .37828 L .479 .526 .746 r
F
.16575 .39681 m .11878 .37632 L .16241 .39911 L F
.79671 .25541 m .76445 .29823 L .76451 .29922 L .787 .211 .013 r
F
.79665 .2547 m .76445 .29823 L .79671 .25541 L F
.67509 .25933 m .64501 .28776 L .64505 .28906 L F
.67505 .25834 m .64501 .28776 L .67509 .25933 L F
.18823 .35247 m .14935 .33568 L .18791 .35679 L F
.18823 .35247 m .14973 .33124 L .14935 .33568 L F
.79676 .25612 m .76451 .29922 L .76458 .30022 L F
.79671 .25541 m .76451 .29922 L .79676 .25612 L F
.68984 .27607 m .6623 .31151 L .69456 .27766 L .479 .526 .746 r
F
.68984 .27607 m .65813 .30951 L .6623 .31151 L F
.67514 .26033 m .64505 .28906 L .6451 .29037 L .787 .211 .013 r
F
.67509 .25933 m .64505 .28906 L .67514 .26033 L F
.79681 .25683 m .76458 .30022 L .76464 .30121 L F
.79676 .25612 m .76458 .30022 L .79681 .25683 L F
.67518 .26132 m .6451 .29037 L .64515 .29168 L F
.67514 .26033 m .6451 .29037 L .67518 .26132 L F
.79681 .25683 m .76464 .30121 L .79686 .25754 L F
.79175 .25644 m .76464 .30121 L .79686 .25754 L .479 .526 .746 r
F
.79175 .25644 m .76002 .29965 L .76464 .30121 L F
.07506 .39767 m .02618 .36687 L .07113 .39959 L F
.15309 .29174 m .12011 .27008 L .15272 .29609 L .787 .211 .013 r
F
.15309 .29174 m .12052 .26567 L .12011 .27008 L F
.16575 .39681 m .1228 .37435 L .11878 .37632 L .479 .526 .746 r
F
.1691 .39451 m .1228 .37435 L .16575 .39681 L F
.67522 .26232 m .64515 .29168 L .6452 .29299 L .787 .211 .013 r
F
.67518 .26132 m .64515 .29168 L .67522 .26232 L F
.18791 .35679 m .14897 .34013 L .18758 .36112 L F
.18791 .35679 m .14935 .33568 L .14897 .34013 L F
.6851 .27448 m .65813 .30951 L .68984 .27607 L .479 .526 .746 r
F
.6851 .27448 m .65396 .30751 L .65813 .30951 L F
.67527 .26331 m .6452 .29299 L .64525 .2943 L .787 .211 .013 r
F
.67522 .26232 m .6452 .29299 L .67527 .26331 L F
.78664 .25534 m .76002 .29965 L .79175 .25644 L .479 .526 .746 r
F
.78664 .25534 m .75538 .2981 L .76002 .29965 L F
.67531 .26431 m .64525 .2943 L .64529 .29561 L .787 .211 .013 r
F
.67527 .26331 m .64525 .2943 L .67531 .26431 L F
.07506 .39767 m .03073 .36533 L .02618 .36687 L .479 .526 .746 r
F
.079 .39575 m .03073 .36533 L .07506 .39767 L F
.67536 .2653 m .64529 .29561 L .64534 .29693 L .787 .211 .013 r
F
.67531 .26431 m .64529 .29561 L .67536 .2653 L F
.15272 .29609 m .11969 .27449 L .15235 .30045 L F
.15272 .29609 m .12011 .27008 L .11969 .27449 L F
.1691 .39451 m .12683 .37239 L .1228 .37435 L .479 .526 .746 r
F
.17245 .3922 m .12683 .37239 L .1691 .39451 L F
.68037 .27289 m .65396 .30751 L .6851 .27448 L F
.68037 .27289 m .64977 .30551 L .65396 .30751 L F
.78151 .25424 m .75538 .2981 L .78664 .25534 L F
.78151 .25424 m .75074 .29654 L .75538 .2981 L F
.18758 .36112 m .14859 .34458 L .18725 .36546 L .787 .211 .013 r
F
.18758 .36112 m .14897 .34013 L .14859 .34458 L F
.6754 .2663 m .64534 .29693 L .64539 .29824 L F
.67536 .2653 m .64534 .29693 L .6754 .2663 L F
.67544 .2673 m .64539 .29824 L .64544 .29955 L F
.6754 .2663 m .64539 .29824 L .67544 .2673 L F
.079 .39575 m .03529 .36379 L .03073 .36533 L .479 .526 .746 r
F
.08294 .39382 m .03529 .36379 L .079 .39575 L F
.77639 .25314 m .75074 .29654 L .78151 .25424 L F
.77639 .25314 m .7461 .29498 L .75074 .29654 L F
.67549 .26829 m .64544 .29955 L .64548 .30087 L .787 .211 .013 r
F
.67544 .2673 m .64544 .29955 L .67549 .26829 L F
.67562 .27129 m .64977 .30551 L .68037 .27289 L .479 .526 .746 r
F
.67562 .27129 m .64558 .3035 L .64977 .30551 L F
.15235 .30045 m .11928 .27892 L .15198 .30482 L .787 .211 .013 r
F
.15235 .30045 m .11969 .27449 L .11928 .27892 L F
.17245 .3922 m .13086 .37042 L .12683 .37239 L .479 .526 .746 r
F
.17581 .38989 m .13086 .37042 L .17245 .3922 L F
.67553 .26929 m .64548 .30087 L .64553 .30218 L .787 .211 .013 r
F
.67549 .26829 m .64548 .30087 L .67553 .26929 L F
.18725 .36546 m .14821 .34905 L .18692 .36981 L F
.18725 .36546 m .14859 .34458 L .14821 .34905 L F
.77126 .25204 m .7461 .29498 L .77639 .25314 L .479 .526 .746 r
F
.77126 .25204 m .74145 .29341 L .7461 .29498 L F
.67558 .27029 m .64553 .30218 L .64558 .3035 L .787 .211 .013 r
F
.67553 .26929 m .64553 .30218 L .67558 .27029 L F
.08294 .39382 m .03986 .36225 L .03529 .36379 L .479 .526 .746 r
F
.0869 .39189 m .03986 .36225 L .08294 .39382 L F
.67558 .27029 m .64558 .3035 L .67562 .27129 L .787 .211 .013 r
F
.15198 .30482 m .11886 .28335 L .1516 .3092 L F
.15198 .30482 m .11928 .27892 L .11886 .28335 L F
.76612 .25094 m .74145 .29341 L .77126 .25204 L .479 .526 .746 r
F
.76612 .25094 m .73679 .29185 L .74145 .29341 L F
.17581 .38989 m .1349 .36845 L .13086 .37042 L F
.17918 .38757 m .1349 .36845 L .17581 .38989 L F
.18692 .36981 m .14783 .35352 L .1866 .37417 L .787 .211 .013 r
F
.18692 .36981 m .14821 .34905 L .14783 .35352 L F
.0869 .39189 m .04443 .36071 L .03986 .36225 L .479 .526 .746 r
F
.09086 .38996 m .04443 .36071 L .0869 .39189 L F
.76098 .24983 m .73679 .29185 L .76612 .25094 L F
.76098 .24983 m .73212 .29028 L .73679 .29185 L F
.1516 .3092 m .11844 .28779 L .15123 .31359 L .787 .211 .013 r
F
.1516 .3092 m .11886 .28335 L .11844 .28779 L F
.17918 .38757 m .13895 .36647 L .1349 .36845 L .479 .526 .746 r
F
.18255 .38525 m .13895 .36647 L .17918 .38757 L F
.1866 .37417 m .14745 .35801 L .18627 .37854 L .787 .211 .013 r
F
.1866 .37417 m .14783 .35352 L .14745 .35801 L F
.09086 .38996 m .04901 .35917 L .04443 .36071 L .479 .526 .746 r
F
.09482 .38802 m .04901 .35917 L .09086 .38996 L F
.75583 .24873 m .73212 .29028 L .76098 .24983 L F
.75583 .24873 m .72745 .28871 L .73212 .29028 L F
.15123 .31359 m .11803 .29225 L .15086 .31799 L .787 .211 .013 r
F
.15123 .31359 m .11844 .28779 L .11803 .29225 L F
.09482 .38802 m .05359 .35762 L .04901 .35917 L .479 .526 .746 r
F
.0988 .38608 m .05359 .35762 L .09482 .38802 L F
.75068 .24762 m .72745 .28871 L .75583 .24873 L F
.75068 .24762 m .72277 .28714 L .72745 .28871 L F
.18255 .38525 m .143 .36449 L .13895 .36647 L F
.18594 .38292 m .143 .36449 L .18255 .38525 L F
.18627 .37854 m .14707 .3625 L .18594 .38292 L .787 .211 .013 r
F
.18627 .37854 m .14745 .35801 L .14707 .3625 L F
.74552 .24651 m .72277 .28714 L .75068 .24762 L .479 .526 .746 r
F
.74552 .24651 m .71809 .28556 L .72277 .28714 L F
.0988 .38608 m .05818 .35607 L .05359 .35762 L F
.10278 .38413 m .05818 .35607 L .0988 .38608 L F
.15086 .31799 m .11761 .29671 L .15048 .3224 L .787 .211 .013 r
F
.15086 .31799 m .11803 .29225 L .11761 .29671 L F
.18594 .38292 m .14707 .3625 L .143 .36449 L .479 .526 .746 r
F
.74036 .2454 m .71809 .28556 L .74552 .24651 L F
.74036 .2454 m .71339 .28399 L .71809 .28556 L F
.10278 .38413 m .06278 .35452 L .05818 .35607 L F
.10677 .38218 m .06278 .35452 L .10278 .38413 L F
.73519 .24429 m .71339 .28399 L .74036 .2454 L F
.73519 .24429 m .7087 .28241 L .71339 .28399 L F
.15048 .3224 m .11719 .30118 L .1501 .32682 L .787 .211 .013 r
F
.15048 .3224 m .11761 .29671 L .11719 .30118 L F
.10677 .38218 m .06739 .35297 L .06278 .35452 L .479 .526 .746 r
F
.11077 .38023 m .06739 .35297 L .10677 .38218 L F
.73002 .24318 m .7087 .28241 L .73519 .24429 L F
.73002 .24318 m .70399 .28083 L .7087 .28241 L F
.6982 .22297 m .67478 .25239 L .67483 .25338 L .787 .211 .013 r
F
.1501 .32682 m .11677 .30566 L .14973 .33124 L F
.1501 .32682 m .11719 .30118 L .11677 .30566 L F
.69824 .22368 m .67483 .25338 L .67487 .25437 L F
.6982 .22297 m .67483 .25338 L .69824 .22368 L F
.72484 .24207 m .70399 .28083 L .73002 .24318 L .479 .526 .746 r
F
.72484 .24207 m .69928 .27924 L .70399 .28083 L F
.69827 .22439 m .67487 .25437 L .67492 .25536 L .787 .211 .013 r
F
.69824 .22368 m .67487 .25437 L .69827 .22439 L F
.11077 .38023 m .072 .35142 L .06739 .35297 L .479 .526 .746 r
F
.11477 .37828 m .072 .35142 L .11077 .38023 L F
.69831 .2251 m .67492 .25536 L .67496 .25635 L .787 .211 .013 r
F
.69827 .22439 m .67492 .25536 L .69831 .2251 L F
.69834 .22581 m .67496 .25635 L .675 .25735 L F
.69831 .2251 m .67496 .25635 L .69834 .22581 L F
.71966 .24096 m .69928 .27924 L .72484 .24207 L .479 .526 .746 r
F
.71966 .24096 m .69456 .27766 L .69928 .27924 L F
.14973 .33124 m .11635 .31016 L .14935 .33568 L .787 .211 .013 r
F
.14973 .33124 m .11677 .30566 L .11635 .31016 L F
.69838 .22652 m .675 .25735 L .67505 .25834 L F
.69834 .22581 m .675 .25735 L .69838 .22652 L F
.11477 .37828 m .07661 .34986 L .072 .35142 L .479 .526 .746 r
F
.11878 .37632 m .07661 .34986 L .11477 .37828 L F
.69841 .22723 m .67505 .25834 L .67509 .25933 L .787 .211 .013 r
F
.69838 .22652 m .67505 .25834 L .69841 .22723 L F
.69845 .22794 m .67509 .25933 L .67514 .26033 L F
.69841 .22723 m .67509 .25933 L .69845 .22794 L F
.71447 .23984 m .69456 .27766 L .71966 .24096 L .479 .526 .746 r
F
.71447 .23984 m .68984 .27607 L .69456 .27766 L F
.69849 .22866 m .67514 .26033 L .67518 .26132 L .787 .211 .013 r
F
.69845 .22794 m .67514 .26033 L .69849 .22866 L F
.69852 .22937 m .67518 .26132 L .67522 .26232 L F
.69849 .22866 m .67518 .26132 L .69852 .22937 L F
.14935 .33568 m .11592 .31466 L .14897 .34013 L F
.14935 .33568 m .11635 .31016 L .11592 .31466 L F
.11878 .37632 m .08124 .3483 L .07661 .34986 L .479 .526 .746 r
F
.1228 .37435 m .08124 .3483 L .11878 .37632 L F
.69856 .23008 m .67522 .26232 L .67527 .26331 L .787 .211 .013 r
F
.69852 .22937 m .67522 .26232 L .69856 .23008 L F
.70928 .23873 m .68984 .27607 L .71447 .23984 L .479 .526 .746 r
F
.70928 .23873 m .6851 .27448 L .68984 .27607 L F
.69859 .23079 m .67527 .26331 L .67531 .26431 L .787 .211 .013 r
F
.69856 .23008 m .67527 .26331 L .69859 .23079 L F
.69863 .2315 m .67531 .26431 L .67536 .2653 L F
.69859 .23079 m .67531 .26431 L .69863 .2315 L F
.69867 .23221 m .67536 .2653 L .6754 .2663 L F
.69863 .2315 m .67536 .2653 L .69867 .23221 L F
.70408 .23761 m .6851 .27448 L .70928 .23873 L .479 .526 .746 r
F
.70408 .23761 m .68037 .27289 L .6851 .27448 L F
.1228 .37435 m .08587 .34674 L .08124 .3483 L F
.12683 .37239 m .08587 .34674 L .1228 .37435 L F
.14897 .34013 m .1155 .31917 L .14859 .34458 L .787 .211 .013 r
F
.14897 .34013 m .11592 .31466 L .1155 .31917 L F
.6987 .23293 m .6754 .2663 L .67544 .2673 L F
.69867 .23221 m .6754 .2663 L .6987 .23293 L F
.81873 .20202 m .79586 .24407 L .79591 .24478 L F
.69874 .23364 m .67544 .2673 L .67549 .26829 L F
.6987 .23293 m .67544 .2673 L .69874 .23364 L F
.81877 .20249 m .79591 .24478 L .79597 .24549 L F
.81873 .20202 m .79591 .24478 L .81877 .20249 L F
.69877 .23435 m .67549 .26829 L .67553 .26929 L F
.69874 .23364 m .67549 .26829 L .69877 .23435 L F
.69888 .23649 m .68037 .27289 L .70408 .23761 L .479 .526 .746 r
F
.69888 .23649 m .67562 .27129 L .68037 .27289 L F
.81881 .20296 m .79597 .24549 L .79602 .24619 L .787 .211 .013 r
F
.81877 .20249 m .79597 .24549 L .81881 .20296 L F
.81884 .20342 m .79602 .24619 L .79607 .2469 L F
.81881 .20296 m .79602 .24619 L .81884 .20342 L F
.69881 .23507 m .67553 .26929 L .67558 .27029 L F
.69877 .23435 m .67553 .26929 L .69881 .23507 L F
.12683 .37239 m .09051 .34517 L .08587 .34674 L .479 .526 .746 r
F
.13086 .37042 m .09051 .34517 L .12683 .37239 L F
.81888 .20389 m .79607 .2469 L .79612 .24761 L .787 .211 .013 r
F
.81884 .20342 m .79607 .2469 L .81888 .20389 L F
.69885 .23578 m .67558 .27029 L .67562 .27129 L F
.69881 .23507 m .67558 .27029 L .69885 .23578 L F
.14859 .34458 m .11508 .32369 L .14821 .34905 L F
.14859 .34458 m .1155 .31917 L .11508 .32369 L F
.81892 .20435 m .79612 .24761 L .79618 .24832 L F
.81888 .20389 m .79612 .24761 L .81892 .20435 L F
.69885 .23578 m .67562 .27129 L .69888 .23649 L F
.81896 .20482 m .79618 .24832 L .79623 .24903 L F
.81892 .20435 m .79618 .24832 L .81896 .20482 L F
.81899 .20528 m .79623 .24903 L .79628 .24973 L F
.81896 .20482 m .79623 .24903 L .81899 .20528 L F
.81903 .20575 m .79628 .24973 L .79634 .25044 L F
.81899 .20528 m .79628 .24973 L .81903 .20575 L F
.13086 .37042 m .09515 .34361 L .09051 .34517 L .479 .526 .746 r
F
.1349 .36845 m .09515 .34361 L .13086 .37042 L F
.81907 .20622 m .79634 .25044 L .79639 .25115 L .787 .211 .013 r
F
.81903 .20575 m .79634 .25044 L .81907 .20622 L F
.81911 .20668 m .79639 .25115 L .79644 .25186 L F
.81907 .20622 m .79639 .25115 L .81911 .20668 L F
.14821 .34905 m .11465 .32822 L .14783 .35352 L F
.14821 .34905 m .11508 .32369 L .11465 .32822 L F
.81915 .20715 m .79644 .25186 L .79649 .25257 L F
.81911 .20668 m .79644 .25186 L .81915 .20715 L F
.81918 .20761 m .79649 .25257 L .79655 .25328 L F
.81915 .20715 m .79649 .25257 L .81918 .20761 L F
.81922 .20808 m .79655 .25328 L .7966 .25399 L F
.81918 .20761 m .79655 .25328 L .81922 .20808 L F
.1349 .36845 m .0998 .34204 L .09515 .34361 L .479 .526 .746 r
F
.13895 .36647 m .0998 .34204 L .1349 .36845 L F
.81926 .20855 m .7966 .25399 L .79665 .2547 L .787 .211 .013 r
F
.81922 .20808 m .7966 .25399 L .81926 .20855 L F
.8193 .20901 m .79665 .2547 L .79671 .25541 L F
.81926 .20855 m .79665 .2547 L .8193 .20901 L F
.81934 .20948 m .79671 .25541 L .79676 .25612 L F
.8193 .20901 m .79671 .25541 L .81934 .20948 L F
.14783 .35352 m .11423 .33277 L .14745 .35801 L F
.14783 .35352 m .11465 .32822 L .11423 .33277 L F
.81937 .20995 m .79676 .25612 L .79681 .25683 L F
.81934 .20948 m .79676 .25612 L .81937 .20995 L F
.81941 .21042 m .79681 .25683 L .79686 .25754 L F
.81937 .20995 m .79681 .25683 L .81941 .21042 L F
.13895 .36647 m .10446 .34047 L .0998 .34204 L .479 .526 .746 r
F
.143 .36449 m .10446 .34047 L .13895 .36647 L F
.81941 .21042 m .79686 .25754 L .81945 .21088 L .787 .211 .013 r
F
.81395 .21031 m .79686 .25754 L .81945 .21088 L .479 .526 .746 r
F
.81395 .21031 m .79175 .25644 L .79686 .25754 L F
.80845 .20973 m .79175 .25644 L .81395 .21031 L F
.80845 .20973 m .78664 .25534 L .79175 .25644 L F
.14745 .35801 m .1138 .33732 L .14707 .3625 L .787 .211 .013 r
F
.14745 .35801 m .11423 .33277 L .1138 .33732 L F
.143 .36449 m .10913 .33889 L .10446 .34047 L .479 .526 .746 r
F
.14707 .3625 m .10913 .33889 L .143 .36449 L F
.80295 .20915 m .78664 .25534 L .80845 .20973 L F
.80295 .20915 m .78151 .25424 L .78664 .25534 L F
.79745 .20857 m .78151 .25424 L .80295 .20915 L F
.79745 .20857 m .77639 .25314 L .78151 .25424 L F
.14707 .3625 m .1138 .33732 L .10913 .33889 L F
.79194 .20799 m .77639 .25314 L .79745 .20857 L F
.79194 .20799 m .77126 .25204 L .77639 .25314 L F
.78643 .20742 m .77126 .25204 L .79194 .20799 L F
.78643 .20742 m .76612 .25094 L .77126 .25204 L F
.78092 .20684 m .76612 .25094 L .78643 .20742 L F
.78092 .20684 m .76098 .24983 L .76612 .25094 L F
.77541 .20626 m .76098 .24983 L .78092 .20684 L F
.77541 .20626 m .75583 .24873 L .76098 .24983 L F
.76989 .20568 m .75583 .24873 L .77541 .20626 L F
.76989 .20568 m .75068 .24762 L .75583 .24873 L F
.76437 .2051 m .75068 .24762 L .76989 .20568 L F
.76437 .2051 m .74552 .24651 L .75068 .24762 L F
.75884 .20452 m .74552 .24651 L .76437 .2051 L F
.75884 .20452 m .74036 .2454 L .74552 .24651 L F
.75332 .20394 m .74036 .2454 L .75884 .20452 L F
.75332 .20394 m .73519 .24429 L .74036 .2454 L F
.74779 .20336 m .73519 .24429 L .75332 .20394 L F
.74779 .20336 m .73002 .24318 L .73519 .24429 L F
.71407 .19099 m .6982 .22297 L .69824 .22368 L .787 .211 .013 r
F
.7141 .19146 m .69824 .22368 L .69827 .22439 L F
.71407 .19099 m .69824 .22368 L .7141 .19146 L F
.71412 .19192 m .69827 .22439 L .69831 .2251 L F
.7141 .19146 m .69827 .22439 L .71412 .19192 L F
.74226 .20278 m .73002 .24318 L .74779 .20336 L .479 .526 .746 r
F
.74226 .20278 m .72484 .24207 L .73002 .24318 L F
.71415 .19239 m .69831 .2251 L .69834 .22581 L .787 .211 .013 r
F
.71412 .19192 m .69831 .2251 L .71415 .19239 L F
.71417 .19286 m .69834 .22581 L .69838 .22652 L F
.71415 .19239 m .69834 .22581 L .71417 .19286 L F
.7142 .19332 m .69838 .22652 L .69841 .22723 L F
.71417 .19286 m .69838 .22652 L .7142 .19332 L F
.73672 .20219 m .72484 .24207 L .74226 .20278 L .479 .526 .746 r
F
.73672 .20219 m .71966 .24096 L .72484 .24207 L F
.71422 .19379 m .69841 .22723 L .69845 .22794 L .787 .211 .013 r
F
.7142 .19332 m .69841 .22723 L .71422 .19379 L F
.71425 .19426 m .69845 .22794 L .69849 .22866 L F
.71422 .19379 m .69845 .22794 L .71425 .19426 L F
.71428 .19472 m .69849 .22866 L .69852 .22937 L F
.71425 .19426 m .69849 .22866 L .71428 .19472 L F
.73119 .20161 m .71966 .24096 L .73672 .20219 L .479 .526 .746 r
F
.73119 .20161 m .71447 .23984 L .71966 .24096 L F
.7143 .19519 m .69852 .22937 L .69856 .23008 L .787 .211 .013 r
F
.71428 .19472 m .69852 .22937 L .7143 .19519 L F
.71433 .19566 m .69856 .23008 L .69859 .23079 L F
.7143 .19519 m .69856 .23008 L .71433 .19566 L F
.72565 .20103 m .71447 .23984 L .73119 .20161 L .479 .526 .746 r
F
.72565 .20103 m .70928 .23873 L .71447 .23984 L F
.71435 .19612 m .69859 .23079 L .69863 .2315 L .787 .211 .013 r
F
.71433 .19566 m .69859 .23079 L .71435 .19612 L F
.71438 .19659 m .69863 .2315 L .69867 .23221 L F
.71435 .19612 m .69863 .2315 L .71438 .19659 L F
.7144 .19706 m .69867 .23221 L .6987 .23293 L F
.71438 .19659 m .69867 .23221 L .7144 .19706 L F
.7201 .20045 m .70928 .23873 L .72565 .20103 L .479 .526 .746 r
F
.7201 .20045 m .70408 .23761 L .70928 .23873 L F
.71443 .19753 m .6987 .23293 L .69874 .23364 L .787 .211 .013 r
F
.7144 .19706 m .6987 .23293 L .71443 .19753 L F
.71446 .19799 m .69874 .23364 L .69877 .23435 L F
.71443 .19753 m .69874 .23364 L .71446 .19799 L F
.71448 .19846 m .69877 .23435 L .69881 .23507 L F
.71446 .19799 m .69877 .23435 L .71448 .19846 L F
.71456 .19987 m .70408 .23761 L .7201 .20045 L .479 .526 .746 r
F
.71456 .19987 m .69888 .23649 L .70408 .23761 L F
.71451 .19893 m .69881 .23507 L .69885 .23578 L .787 .211 .013 r
F
.71448 .19846 m .69881 .23507 L .71451 .19893 L F
.71453 .1994 m .69885 .23578 L .69888 .23649 L F
.71451 .19893 m .69885 .23578 L .71453 .1994 L F
.71453 .1994 m .69888 .23649 L .71456 .19987 L F
.83089 .15714 m .81873 .20202 L .81877 .20249 L F
.83091 .15741 m .81877 .20249 L .81881 .20296 L F
.83089 .15714 m .81877 .20249 L .83091 .15741 L F
.83094 .15768 m .81881 .20296 L .81884 .20342 L F
.83091 .15741 m .81881 .20296 L .83094 .15768 L F
.83096 .15795 m .81884 .20342 L .81888 .20389 L F
.83094 .15768 m .81884 .20342 L .83096 .15795 L F
.83098 .15822 m .81888 .20389 L .81892 .20435 L F
.83096 .15795 m .81888 .20389 L .83098 .15822 L F
.831 .15848 m .81892 .20435 L .81896 .20482 L F
.83098 .15822 m .81892 .20435 L .831 .15848 L F
.83103 .15875 m .81896 .20482 L .81899 .20528 L F
.831 .15848 m .81896 .20482 L .83103 .15875 L F
.83105 .15902 m .81899 .20528 L .81903 .20575 L F
.83103 .15875 m .81899 .20528 L .83105 .15902 L F
.83107 .15929 m .81903 .20575 L .81907 .20622 L F
.83105 .15902 m .81903 .20575 L .83107 .15929 L F
.8311 .15956 m .81907 .20622 L .81911 .20668 L F
.83107 .15929 m .81907 .20622 L .8311 .15956 L F
.83112 .15983 m .81911 .20668 L .81915 .20715 L F
.8311 .15956 m .81911 .20668 L .83112 .15983 L F
.83114 .16009 m .81915 .20715 L .81918 .20761 L F
.83112 .15983 m .81915 .20715 L .83114 .16009 L F
.83116 .16036 m .81918 .20761 L .81922 .20808 L F
.83114 .16009 m .81918 .20761 L .83116 .16036 L F
.83119 .16063 m .81922 .20808 L .81926 .20855 L F
.83116 .16036 m .81922 .20808 L .83119 .16063 L F
.83121 .1609 m .81926 .20855 L .8193 .20901 L F
.83119 .16063 m .81926 .20855 L .83121 .1609 L F
.83123 .16117 m .8193 .20901 L .81934 .20948 L F
.83121 .1609 m .8193 .20901 L .83123 .16117 L F
.83126 .16144 m .81934 .20948 L .81937 .20995 L F
.83123 .16117 m .81934 .20948 L .83126 .16144 L F
.83128 .16171 m .81937 .20995 L .81941 .21042 L F
.83126 .16144 m .81937 .20995 L .83128 .16171 L F
.8313 .16197 m .81941 .21042 L .81945 .21088 L F
.83128 .16171 m .81941 .21042 L .8313 .16197 L F
.8313 .16197 m .81945 .21088 L .83132 .16224 L F
.82557 .16224 m .81945 .21088 L .83132 .16224 L .479 .526 .746 r
F
.82557 .16224 m .81395 .21031 L .81945 .21088 L F
.81981 .16225 m .81395 .21031 L .82557 .16224 L F
.81981 .16225 m .80845 .20973 L .81395 .21031 L F
.81406 .16225 m .80845 .20973 L .81981 .16225 L F
.81406 .16225 m .80295 .20915 L .80845 .20973 L F
.8083 .16225 m .80295 .20915 L .81406 .16225 L F
.8083 .16225 m .79745 .20857 L .80295 .20915 L F
.80254 .16225 m .79745 .20857 L .8083 .16225 L F
.80254 .16225 m .79194 .20799 L .79745 .20857 L F
.79679 .16225 m .79194 .20799 L .80254 .16225 L F
.79679 .16225 m .78643 .20742 L .79194 .20799 L F
.79103 .16225 m .78643 .20742 L .79679 .16225 L F
.79103 .16225 m .78092 .20684 L .78643 .20742 L F
.78528 .16225 m .78092 .20684 L .79103 .16225 L F
.78528 .16225 m .77541 .20626 L .78092 .20684 L F
.77952 .16225 m .77541 .20626 L .78528 .16225 L F
.77952 .16225 m .76989 .20568 L .77541 .20626 L F
.77376 .16226 m .76989 .20568 L .77952 .16225 L F
.77376 .16226 m .76437 .2051 L .76989 .20568 L F
.76801 .16226 m .76437 .2051 L .77376 .16226 L F
.76801 .16226 m .75884 .20452 L .76437 .2051 L F
.72167 .15717 m .71407 .19099 L .7141 .19146 L .787 .211 .013 r
F
.72168 .15744 m .7141 .19146 L .71412 .19192 L F
.72167 .15717 m .7141 .19146 L .72168 .15744 L F
.76225 .16226 m .75884 .20452 L .76801 .16226 L .479 .526 .746 r
F
.76225 .16226 m .75332 .20394 L .75884 .20452 L F
.7217 .15771 m .71412 .19192 L .71415 .19239 L .787 .211 .013 r
F
.72168 .15744 m .71412 .19192 L .7217 .15771 L F
.72171 .15798 m .71415 .19239 L .71417 .19286 L F
.7217 .15771 m .71415 .19239 L .72171 .15798 L F
.72173 .15824 m .71417 .19286 L .7142 .19332 L F
.72171 .15798 m .71417 .19286 L .72173 .15824 L F
.7565 .16226 m .75332 .20394 L .76225 .16226 L .479 .526 .746 r
F
.7565 .16226 m .74779 .20336 L .75332 .20394 L F
.72175 .15851 m .7142 .19332 L .71422 .19379 L .787 .211 .013 r
F
.72173 .15824 m .7142 .19332 L .72175 .15851 L F
.72176 .15878 m .71422 .19379 L .71425 .19426 L F
.72175 .15851 m .71422 .19379 L .72176 .15878 L F
.75074 .16226 m .74779 .20336 L .7565 .16226 L .479 .526 .746 r
F
.75074 .16226 m .74226 .20278 L .74779 .20336 L F
.72178 .15905 m .71425 .19426 L .71428 .19472 L .787 .211 .013 r
F
.72176 .15878 m .71425 .19426 L .72178 .15905 L F
.72179 .15932 m .71428 .19472 L .7143 .19519 L F
.72178 .15905 m .71428 .19472 L .72179 .15932 L F
.74498 .16226 m .74226 .20278 L .75074 .16226 L .479 .526 .746 r
F
.74498 .16226 m .73672 .20219 L .74226 .20278 L F
.72181 .15958 m .7143 .19519 L .71433 .19566 L .787 .211 .013 r
F
.72179 .15932 m .7143 .19519 L .72181 .15958 L F
.72182 .15985 m .71433 .19566 L .71435 .19612 L F
.72181 .15958 m .71433 .19566 L .72182 .15985 L F
.73923 .16226 m .73672 .20219 L .74498 .16226 L .479 .526 .746 r
F
.73923 .16226 m .73119 .20161 L .73672 .20219 L F
.72184 .16012 m .71435 .19612 L .71438 .19659 L .787 .211 .013 r
F
.72182 .15985 m .71435 .19612 L .72184 .16012 L F
.72185 .16039 m .71438 .19659 L .7144 .19706 L F
.72184 .16012 m .71438 .19659 L .72185 .16039 L F
.73347 .16227 m .73119 .20161 L .73923 .16226 L .479 .526 .746 r
F
.73347 .16227 m .72565 .20103 L .73119 .20161 L F
.72187 .16066 m .7144 .19706 L .71443 .19753 L .787 .211 .013 r
F
.72185 .16039 m .7144 .19706 L .72187 .16066 L F
.72188 .16093 m .71443 .19753 L .71446 .19799 L F
.72187 .16066 m .71443 .19753 L .72188 .16093 L F
.72772 .16227 m .72565 .20103 L .73347 .16227 L .479 .526 .746 r
F
.72772 .16227 m .7201 .20045 L .72565 .20103 L F
.7219 .16119 m .71446 .19799 L .71448 .19846 L .787 .211 .013 r
F
.72188 .16093 m .71446 .19799 L .7219 .16119 L F
.72191 .16146 m .71448 .19846 L .71451 .19893 L F
.7219 .16119 m .71448 .19846 L .72191 .16146 L F
.72196 .16227 m .7201 .20045 L .72772 .16227 L .479 .526 .746 r
F
.72196 .16227 m .71456 .19987 L .7201 .20045 L F
.72193 .16173 m .71451 .19893 L .71453 .1994 L .787 .211 .013 r
F
.72191 .16146 m .71451 .19893 L .72193 .16173 L F
.72194 .162 m .71453 .1994 L .71456 .19987 L F
.72193 .16173 m .71453 .1994 L .72194 .162 L F
.72194 .162 m .71456 .19987 L .72196 .16227 L F
.72042 .12235 m .72167 .15717 L .72168 .15744 L F
.83138 .11049 m .83089 .15714 L .83091 .15741 L F
.72043 .12247 m .72168 .15744 L .7217 .15771 L F
.72042 .12235 m .72168 .15744 L .72043 .12247 L F
.83139 .11061 m .83091 .15741 L .83094 .15768 L F
.83138 .11049 m .83091 .15741 L .83139 .11061 L F
.72043 .1226 m .7217 .15771 L .72171 .15798 L F
.72043 .12247 m .7217 .15771 L .72043 .1226 L F
.8314 .11073 m .83094 .15768 L .83096 .15795 L F
.83139 .11061 m .83094 .15768 L .8314 .11073 L F
.72044 .12272 m .72171 .15798 L .72173 .15824 L F
.72043 .1226 m .72171 .15798 L .72044 .12272 L F
.83141 .11086 m .83096 .15795 L .83098 .15822 L F
.8314 .11073 m .83096 .15795 L .83141 .11086 L F
.72045 .12284 m .72173 .15824 L .72175 .15851 L F
.72044 .12272 m .72173 .15824 L .72045 .12284 L F
.83142 .11098 m .83098 .15822 L .831 .15848 L F
.83141 .11086 m .83098 .15822 L .83142 .11098 L F
.72045 .12296 m .72175 .15851 L .72176 .15878 L F
.72045 .12284 m .72175 .15851 L .72045 .12296 L F
.83143 .1111 m .831 .15848 L .83103 .15875 L F
.83142 .11098 m .831 .15848 L .83143 .1111 L F
.72046 .12308 m .72176 .15878 L .72178 .15905 L F
.72045 .12296 m .72176 .15878 L .72046 .12308 L F
.83144 .11122 m .83103 .15875 L .83105 .15902 L F
.83143 .1111 m .83103 .15875 L .83144 .11122 L F
.72047 .1232 m .72178 .15905 L .72179 .15932 L F
.72046 .12308 m .72178 .15905 L .72047 .1232 L F
.83145 .11134 m .83105 .15902 L .83107 .15929 L F
.83144 .11122 m .83105 .15902 L .83145 .11134 L F
.72048 .12332 m .72179 .15932 L .72181 .15958 L F
.72047 .1232 m .72179 .15932 L .72048 .12332 L F
.83146 .11146 m .83107 .15929 L .8311 .15956 L F
.83145 .11134 m .83107 .15929 L .83146 .11146 L F
.72048 .12344 m .72181 .15958 L .72182 .15985 L F
.72048 .12332 m .72181 .15958 L .72048 .12344 L F
.83147 .11158 m .8311 .15956 L .83112 .15983 L F
.83146 .11146 m .8311 .15956 L .83147 .11158 L F
.72049 .12357 m .72182 .15985 L .72184 .16012 L F
.72048 .12344 m .72182 .15985 L .72049 .12357 L F
.83148 .11171 m .83112 .15983 L .83114 .16009 L F
.83147 .11158 m .83112 .15983 L .83148 .11171 L F
.7205 .12369 m .72184 .16012 L .72185 .16039 L F
.72049 .12357 m .72184 .16012 L .7205 .12369 L F
.83149 .11183 m .83114 .16009 L .83116 .16036 L F
.83148 .11171 m .83114 .16009 L .83149 .11183 L F
.7205 .12381 m .72185 .16039 L .72187 .16066 L F
.7205 .12369 m .72185 .16039 L .7205 .12381 L F
.8315 .11195 m .83116 .16036 L .83119 .16063 L F
.83149 .11183 m .83116 .16036 L .8315 .11195 L F
.72051 .12393 m .72187 .16066 L .72188 .16093 L F
.7205 .12381 m .72187 .16066 L .72051 .12393 L F
.83151 .11207 m .83119 .16063 L .83121 .1609 L F
.8315 .11195 m .83119 .16063 L .83151 .11207 L F
.72052 .12405 m .72188 .16093 L .7219 .16119 L F
.72051 .12393 m .72188 .16093 L .72052 .12405 L F
.83152 .11219 m .83121 .1609 L .83123 .16117 L F
.83151 .11207 m .83121 .1609 L .83152 .11219 L F
.72052 .12417 m .7219 .16119 L .72191 .16146 L F
.72052 .12405 m .7219 .16119 L .72052 .12417 L F
.83154 .11231 m .83123 .16117 L .83126 .16144 L F
.83152 .11219 m .83123 .16117 L .83154 .11231 L F
.72053 .12429 m .72191 .16146 L .72193 .16173 L F
.72052 .12417 m .72191 .16146 L .72053 .12429 L F
.83155 .11243 m .83126 .16144 L .83128 .16171 L F
.83154 .11231 m .83126 .16144 L .83155 .11243 L F
.72054 .12441 m .72193 .16173 L .72194 .162 L F
.72053 .12429 m .72193 .16173 L .72054 .12441 L F
.83156 .11256 m .83128 .16171 L .8313 .16197 L F
.83155 .11243 m .83128 .16171 L .83156 .11256 L F
.72054 .12454 m .72194 .162 L .72196 .16227 L F
.72054 .12441 m .72194 .162 L .72054 .12454 L F
.83157 .11268 m .8313 .16197 L .83132 .16224 L F
.83156 .11256 m .8313 .16197 L .83157 .11268 L F
.72055 .12466 m .72196 .16227 L .72772 .16227 L .479 .526 .746 r
F
.72001 .11008 m .72055 .12466 L .72637 .12404 L F
.70997 .08749 m .72042 .12235 L .72043 .12247 L .787 .211 .013 r
F
.70997 .08752 m .72043 .12247 L .72043 .1226 L F
.70997 .08749 m .72043 .12247 L .70997 .08752 L F
.70997 .08755 m .72043 .1226 L .72044 .12272 L F
.70997 .08752 m .72043 .1226 L .70997 .08755 L F
.70997 .08758 m .72044 .12272 L .72045 .12284 L F
.70997 .08755 m .72044 .12272 L .70997 .08758 L F
.70997 .08761 m .72045 .12284 L .72045 .12296 L F
.70997 .08758 m .72045 .12284 L .70997 .08761 L F
.70998 .08764 m .72045 .12296 L .72046 .12308 L F
.70997 .08761 m .72045 .12296 L .70998 .08764 L F
.70998 .08767 m .72046 .12308 L .72047 .1232 L F
.70998 .08764 m .72046 .12308 L .70998 .08767 L F
.70998 .0877 m .72047 .1232 L .72048 .12332 L F
.70998 .08767 m .72047 .1232 L .70998 .0877 L F
.70998 .08773 m .72048 .12332 L .72048 .12344 L F
.70998 .0877 m .72048 .12332 L .70998 .08773 L F
.70998 .08776 m .72048 .12344 L .72049 .12357 L F
.70998 .08773 m .72048 .12344 L .70998 .08776 L F
.70998 .08779 m .72049 .12357 L .7205 .12369 L F
.70998 .08776 m .72049 .12357 L .70998 .08779 L F
.70999 .08783 m .7205 .12369 L .7205 .12381 L F
.70998 .08779 m .7205 .12369 L .70999 .08783 L F
.70999 .08786 m .7205 .12381 L .72051 .12393 L F
.70999 .08783 m .7205 .12381 L .70999 .08786 L F
.70999 .08789 m .72051 .12393 L .72052 .12405 L F
.70999 .08786 m .72051 .12393 L .70999 .08789 L F
.70999 .08792 m .72052 .12405 L .72052 .12417 L F
.70999 .08789 m .72052 .12405 L .70999 .08792 L F
.70999 .08795 m .72052 .12417 L .72053 .12429 L F
.70999 .08792 m .72052 .12417 L .70999 .08795 L F
.70999 .08798 m .72053 .12429 L .72054 .12441 L F
.70999 .08795 m .72053 .12429 L .70999 .08798 L F
.71 .08801 m .72054 .12441 L .72054 .12454 L F
.70999 .08798 m .72054 .12441 L .71 .08801 L F
.71 .08804 m .72054 .12454 L .72055 .12466 L F
.71 .08801 m .72054 .12454 L .71 .08804 L F
.71 .08804 m .71028 .089 L .71 .08807 L F
.71028 .089 m .72055 .12466 L .71 .08807 L F
.69022 .05361 m .70997 .08749 L .70997 .08752 L F
.69022 .05361 m .70997 .08752 L .70997 .08755 L F
.69022 .05361 m .70997 .08755 L .70997 .08758 L F
.69022 .05361 m .70997 .08758 L .70997 .08761 L F
.69022 .05361 m .70997 .08761 L .70998 .08764 L F
.69022 .05361 m .70998 .08764 L .70998 .08767 L F
.69022 .05361 m .70998 .08767 L .70998 .0877 L F
.69022 .05361 m .70998 .0877 L .70998 .08773 L F
.69022 .05361 m .70998 .08773 L .70998 .08776 L F
.69022 .05361 m .70998 .08776 L .70998 .08779 L F
.69022 .05361 m .70998 .08779 L .70999 .08783 L F
.69022 .05361 m .70999 .08783 L .70999 .08786 L F
.69022 .05361 m .70999 .08786 L .70999 .08789 L F
.69022 .05361 m .70999 .08789 L .70999 .08792 L F
.69022 .05361 m .70999 .08792 L .70999 .08795 L F
.69022 .05361 m .70999 .08795 L .70999 .08798 L F
.69022 .05361 m .70999 .08798 L .71 .08801 L F
.69022 .05361 m .71 .08801 L .71 .08804 L F
.69022 .05361 m .71 .08804 L .71 .08807 L F
.70581 .07392 m .71 .08807 L .71571 .08681 L .479 .526 .746 r
F
.69022 .05361 m .71 .08807 L .70581 .07392 L F
.71 .08807 m .72055 .12466 L .72001 .11008 L F
.72054 .12454 m .72069 .12834 L .72055 .12466 L .787 .211 .013 r
F
.72069 .12834 m .72196 .16227 L .72055 .12466 L F
.72637 .12404 m .72772 .16227 L .73347 .16227 L .479 .526 .746 r
F
.72055 .12466 m .72772 .16227 L .72637 .12404 L F
.73219 .12341 m .73347 .16227 L .73923 .16226 L F
.72637 .12404 m .73347 .16227 L .73219 .12341 L F
.73801 .12279 m .73923 .16226 L .74498 .16226 L F
.73219 .12341 m .73923 .16226 L .73801 .12279 L F
.74383 .12217 m .74498 .16226 L .75074 .16226 L F
.73801 .12279 m .74498 .16226 L .74383 .12217 L F
.74966 .12155 m .75074 .16226 L .7565 .16226 L F
.74383 .12217 m .75074 .16226 L .74966 .12155 L F
.75549 .12092 m .7565 .16226 L .76225 .16226 L F
.74966 .12155 m .7565 .16226 L .75549 .12092 L F
.76133 .1203 m .76225 .16226 L .76801 .16226 L F
.75549 .12092 m .76225 .16226 L .76133 .1203 L F
.76717 .11968 m .76801 .16226 L .77376 .16226 L F
.76133 .1203 m .76801 .16226 L .76717 .11968 L F
.77301 .11905 m .77376 .16226 L .77952 .16225 L F
.76717 .11968 m .77376 .16226 L .77301 .11905 L F
.77885 .11843 m .77952 .16225 L .78528 .16225 L F
.77301 .11905 m .77952 .16225 L .77885 .11843 L F
.7847 .11781 m .78528 .16225 L .79103 .16225 L F
.77885 .11843 m .78528 .16225 L .7847 .11781 L F
.79055 .11718 m .79103 .16225 L .79679 .16225 L F
.7847 .11781 m .79103 .16225 L .79055 .11718 L F
.7964 .11656 m .79679 .16225 L .80254 .16225 L F
.79055 .11718 m .79679 .16225 L .7964 .11656 L F
.80225 .11593 m .80254 .16225 L .8083 .16225 L F
.7964 .11656 m .80254 .16225 L .80225 .11593 L F
.80811 .1153 m .8083 .16225 L .81406 .16225 L F
.80225 .11593 m .8083 .16225 L .80811 .1153 L F
.81397 .11468 m .81406 .16225 L .81981 .16225 L F
.80811 .1153 m .81406 .16225 L .81397 .11468 L F
.81984 .11405 m .81981 .16225 L .82557 .16224 L F
.81397 .11468 m .81981 .16225 L .81984 .11405 L F
.82571 .11343 m .82557 .16224 L .83132 .16224 L F
.81984 .11405 m .82557 .16224 L .82571 .11343 L F
.83157 .11268 m .83132 .16224 L .83158 .1128 L .787 .211 .013 r
F
.82571 .11343 m .83132 .16224 L .83158 .1128 L .479 .526 .746 r
F
.71571 .08681 m .72637 .12404 L .73219 .12341 L F
.71 .08807 m .72637 .12404 L .71571 .08681 L F
.72143 .08555 m .73219 .12341 L .73801 .12279 L F
.71571 .08681 m .73219 .12341 L .72143 .08555 L F
.72715 .08428 m .73801 .12279 L .74383 .12217 L F
.72143 .08555 m .73801 .12279 L .72715 .08428 L F
.73288 .08302 m .74383 .12217 L .74966 .12155 L F
.72715 .08428 m .74383 .12217 L .73288 .08302 L F
.73861 .08175 m .74966 .12155 L .75549 .12092 L F
.73288 .08302 m .74966 .12155 L .73861 .08175 L F
.74435 .08049 m .75549 .12092 L .76133 .1203 L F
.73861 .08175 m .75549 .12092 L .74435 .08049 L F
.7501 .07922 m .76133 .1203 L .76717 .11968 L F
.74435 .08049 m .76133 .1203 L .7501 .07922 L F
.75585 .07795 m .76717 .11968 L .77301 .11905 L F
.7501 .07922 m .76717 .11968 L .75585 .07795 L F
.76161 .07668 m .77301 .11905 L .77885 .11843 L F
.75585 .07795 m .77301 .11905 L .76161 .07668 L F
.76738 .0754 m .77885 .11843 L .7847 .11781 L F
.76161 .07668 m .77885 .11843 L .76738 .0754 L F
.77315 .07413 m .7847 .11781 L .79055 .11718 L F
.76738 .0754 m .7847 .11781 L .77315 .07413 L F
.77892 .07286 m .79055 .11718 L .7964 .11656 L F
.77315 .07413 m .79055 .11718 L .77892 .07286 L F
.78471 .07158 m .7964 .11656 L .80225 .11593 L F
.77892 .07286 m .7964 .11656 L .78471 .07158 L F
.79049 .0703 m .80225 .11593 L .80811 .1153 L F
.78471 .07158 m .80225 .11593 L .79049 .0703 L F
.79629 .06902 m .80811 .1153 L .81397 .11468 L F
.79049 .0703 m .80811 .1153 L .79629 .06902 L F
.80209 .06774 m .81397 .11468 L .81984 .11405 L F
.79629 .06902 m .81397 .11468 L .80209 .06774 L F
.81948 .06331 m .83138 .11049 L .83139 .11061 L .787 .211 .013 r
F
.81948 .06334 m .83139 .11061 L .8314 .11073 L F
.81948 .06331 m .83139 .11061 L .81948 .06334 L F
.81949 .06337 m .8314 .11073 L .83141 .11086 L F
.81948 .06334 m .8314 .11073 L .81949 .06337 L F
.8079 .06646 m .81984 .11405 L .82571 .11343 L .479 .526 .746 r
F
.80209 .06774 m .81984 .11405 L .8079 .06646 L F
.81949 .0634 m .83141 .11086 L .83142 .11098 L .787 .211 .013 r
F
.81949 .06337 m .83141 .11086 L .81949 .0634 L F
.81949 .06343 m .83142 .11098 L .83143 .1111 L F
.81949 .0634 m .83142 .11098 L .81949 .06343 L F
.81949 .06346 m .83143 .1111 L .83144 .11122 L F
.81949 .06343 m .83143 .1111 L .81949 .06346 L F
.8195 .06349 m .83144 .11122 L .83145 .11134 L F
.81949 .06346 m .83144 .11122 L .8195 .06349 L F
.8195 .06352 m .83145 .11134 L .83146 .11146 L F
.8195 .06349 m .83145 .11134 L .8195 .06352 L F
.8195 .06355 m .83146 .11146 L .83147 .11158 L F
.8195 .06352 m .83146 .11146 L .8195 .06355 L F
.8195 .06358 m .83147 .11158 L .83148 .11171 L F
.8195 .06355 m .83147 .11158 L .8195 .06358 L F
.81951 .06361 m .83148 .11171 L .83149 .11183 L F
.8195 .06358 m .83148 .11171 L .81951 .06361 L F
.81371 .06518 m .82571 .11343 L .83158 .1128 L .479 .526 .746 r
F
.8079 .06646 m .82571 .11343 L .81371 .06518 L F
.81951 .06365 m .83149 .11183 L .8315 .11195 L .787 .211 .013 r
F
.81951 .06361 m .83149 .11183 L .81951 .06365 L F
.81951 .06368 m .8315 .11195 L .83151 .11207 L F
.81951 .06365 m .8315 .11195 L .81951 .06368 L F
.81951 .06371 m .83151 .11207 L .83152 .11219 L F
.81951 .06368 m .83151 .11207 L .81951 .06371 L F
.81952 .06374 m .83152 .11219 L .83154 .11231 L F
.81951 .06371 m .83152 .11219 L .81952 .06374 L F
.81952 .06377 m .83154 .11231 L .83155 .11243 L F
.81952 .06374 m .83154 .11231 L .81952 .06377 L F
.81952 .0638 m .83155 .11243 L .83156 .11256 L F
.81952 .06377 m .83155 .11243 L .81952 .0638 L F
.81952 .06383 m .83156 .11256 L .83157 .11268 L F
.81952 .0638 m .83156 .11256 L .81952 .06383 L F
.81953 .06386 m .83157 .11268 L .83158 .1128 L F
.81952 .06383 m .83157 .11268 L .81953 .06386 L F
.81371 .06518 m .83158 .1128 L .81953 .06389 L .479 .526 .746 r
F
.81953 .06386 m .83158 .1128 L .81953 .06389 L .787 .211 .013 r
F
.69565 .05171 m .71571 .08681 L .72143 .08555 L .479 .526 .746 r
F
.69022 .05361 m .71571 .08681 L .69565 .05171 L F
.70108 .0498 m .72143 .08555 L .72715 .08428 L F
.69565 .05171 m .72143 .08555 L .70108 .0498 L F
.70653 .0479 m .72715 .08428 L .73288 .08302 L F
.70108 .0498 m .72715 .08428 L .70653 .0479 L F
.71198 .04599 m .73288 .08302 L .73861 .08175 L F
.70653 .0479 m .73288 .08302 L .71198 .04599 L F
.71745 .04408 m .73861 .08175 L .74435 .08049 L F
.71198 .04599 m .73861 .08175 L .71745 .04408 L F
.72292 .04216 m .74435 .08049 L .7501 .07922 L F
.71745 .04408 m .74435 .08049 L .72292 .04216 L F
.7284 .04025 m .7501 .07922 L .75585 .07795 L F
.72292 .04216 m .7501 .07922 L .7284 .04025 L F
.73389 .03833 m .75585 .07795 L .76161 .07668 L F
.7284 .04025 m .75585 .07795 L .73389 .03833 L F
.73938 .0364 m .76161 .07668 L .76738 .0754 L F
.73389 .03833 m .76161 .07668 L .73938 .0364 L F
.74489 .03448 m .76738 .0754 L .77315 .07413 L F
.73938 .0364 m .76738 .0754 L .74489 .03448 L F
.7504 .03255 m .77315 .07413 L .77892 .07286 L F
.74489 .03448 m .77315 .07413 L .7504 .03255 L F
.75592 .03062 m .77892 .07286 L .78471 .07158 L F
.7504 .03255 m .77892 .07286 L .75592 .03062 L F
.76146 .02868 m .78471 .07158 L .79049 .0703 L F
.75592 .03062 m .78471 .07158 L .76146 .02868 L F
.767 .02674 m .79049 .0703 L .79629 .06902 L F
.76146 .02868 m .79049 .0703 L .767 .02674 L F
.77254 .0248 m .79629 .06902 L .80209 .06774 L F
.767 .02674 m .79629 .06902 L .77254 .0248 L F
.7781 .02286 m .80209 .06774 L .8079 .06646 L F
.77254 .0248 m .80209 .06774 L .7781 .02286 L F
.78367 .02091 m .8079 .06646 L .81371 .06518 L F
.7781 .02286 m .8079 .06646 L .78367 .02091 L F
.78924 .01896 m .81371 .06518 L .81953 .06389 L F
.78367 .02091 m .81371 .06518 L .78924 .01896 L F
.79482 .017 m .81948 .06331 L .81948 .06334 L .787 .211 .013 r
F
.79482 .017 m .81948 .06334 L .81949 .06337 L F
.79482 .017 m .81949 .06337 L .81949 .0634 L F
.79482 .017 m .81949 .0634 L .81949 .06343 L F
.79482 .017 m .81949 .06343 L .81949 .06346 L F
.79482 .017 m .81949 .06346 L .8195 .06349 L F
.79482 .017 m .8195 .06349 L .8195 .06352 L F
.79482 .017 m .8195 .06352 L .8195 .06355 L F
.79482 .017 m .8195 .06355 L .8195 .06358 L F
.79482 .017 m .8195 .06358 L .81951 .06361 L F
.79482 .017 m .81951 .06361 L .81951 .06365 L F
.79482 .017 m .81951 .06365 L .81951 .06368 L F
.79482 .017 m .81951 .06368 L .81951 .06371 L F
.79482 .017 m .81951 .06371 L .81952 .06374 L F
.79482 .017 m .81952 .06374 L .81952 .06377 L F
.79482 .017 m .81952 .06377 L .81952 .0638 L F
.79482 .017 m .81952 .0638 L .81952 .06383 L F
.79482 .017 m .81952 .06383 L .81953 .06386 L F
.79482 .017 m .81953 .06386 L .81953 .06389 L F
.78924 .01896 m .81953 .06389 L .79482 .017 L .479 .526 .746 r
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{295.625, 175.5},
  ImageMargins->{{176.312, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000[a000`40O003h00OogoL:7oL003oOm`X
Om`00?mog2Qog000ogoL:7oL003oOm`XOm`00?mog2Qog000jGoL00<n5goLOm`0>goL003VOm`5?QLl
Om`00>9og0Tn5caog000ggoL3ChG>goL003NOm`>?QLkOm`00=Yog1<n5cYog000egoL5ShG>WoL003D
Om`J?QLiOm`00=9og1`n5cUog000cgoL83hG>7oL003<Om`S?QLhOm`00<]og2Dn5cMog000c7oL93hG
=goL003=Om`T?QLfOm`00<eog2@n5cIog000cWoL8chG=WoL003>Om`T?QLeOm`00=1og28n5cEog000
d7oL8ShG=GoL003@Om`R?QLeOm`00=5og24n5cEog000dGoL8ShG=7oL003AOm`R?QLdOm`00=9og24n
5cAog000dWoL8ChG=7oL003BOm`Q?QLdOm`00==og24n5c=og000dgoL8ChG<goL003COm`Q?QLcOm`0
0==og24n5c=og000e7oL83hG<goL003DOm`P?QLcOm`00=Aog20n5c=og000e7oL83hG<goL003DOm`P
?QLcOm`00=Aog20n5c=og000e7oL83hG<goL003DOm`P?QLcOm`00=Aog20n5c=og000e7oL83hG<goL
003DOm`P?QLcOm`00=Aog20n5c=og000e7oL83hG<goL003DOm`P?QLcOm`00==og003I<0n5chG01hn
5c=og000dgoL00=T`3hG?QL07ShG<goL003COm`00fC0?QLn5`0M?QLdOm`00==og20n5cAog000dgoL
83hG=7oL003BOm`00fC0?QLn5`0N?QLdOm`00=9og003I<0n5chG01hn5cAog000dWoL00=T`3hG?QL0
7ChG=GoL003BOm`P?QLeOm`00=5og003I<0n5chG01hn5cEog000dGoL00=T`3hG?QL07ShG=GoL003@
Om`2I<0P?QLeOm`00=1og003I<0n5chG01hn5cIog000cgoL0VC083hG=WoL003?Om`00fC0?QLn5`0O
?QLfOm`00<iog09T`20n5cMog000cWoL00=T`3hG?QL07chG=goL003=Om`2I<0P?QLhOm`00<eog09T
`20n5cQog000c7oL0VC083hG>GoL003;Om`3I<0P?QLiOm`00<Yog0=T`20n5cYog000bGoL16C083hG
>WoL0038Om`4I<0P?QLkOm`00<Mog0AT`24n5c]og0008WoL0fC0X7oL1VC083hG?7oL000OOm`7I<2N
Om`6I<0Q?QLlOm`001aog0]T`9aog0MT`20n5ceog0006GoL3fC0VWoL1fC08ChG?GoL000FOm`DI<2G
Om`7I<0Q?QLnOm`001Aog1MT`9Eog0QT`20n5cmog0004GoL6fC0TgoL26C08ChG?goL000>Om`DI<00
0goLI<1T`008I<2AOm`8I<0Q?QM0Om`000]og1MT`003OmaT`6C000YT`8eog0UT`24n5d5og0002WoL
66C000=og6C0I<002fC0RgoL2FC08ChG@WoL000:Om`HI<000goLI<1T`00=I<27Om`:I<0R?QM2Om`0
00Yog2YT`8Aog0YT`28n5d=og0002WoL:fC0PWoL2VC08ShGA7oL000:Om`]I<1nOm`;I<0S?QM4Om`0
00Uog2mT`7aog0]T`2<n5dEog0002GoL<FC0N7oL2fC08chGAgoL0009Om`dI<1bOm`=I<0S?QM8Om`0
00Uog3MT`6eog0iT`2<n5dUog0002GoL>FC0JGoL3fC08chGBWoL0009Om`lI<1SOm`@I<0T?QM;Om`0
00Uog1QT`003OmaT`6C002AT`5eog19T`2@n5daog0002GoL@VC0EgoL56C093hGCGoL0008Oma6I<1A
Om`FI<0T?QM>Om`000Qog4UT`4]og1QT`2@n5dmog00027oLCFC0@goL6VC09ChGD7oL0008Om`II<02
?QLgI<0iOm`MI<0V?QMAOm`000Qog1IT`0Hn5c]T`2mog25T`2Dn5e=og00027oL4fC02ShG@6C08goL
9FC09ShGE7oL0008Om`@I<0>?QM6I<0EOm`ZI<0W?QMEOm`000Qog0aT`1@n5h9T`2Ln5eIog00027oL
2VC05chGOfC09chGF7oL0007Om`8I<0K?QMlI<0X?QMIOm`000Mog0ET`1ln5gUT`2Tn5eYog0001goL
0fC08chGMFC0:ChGG7oL0009Om`V?QM`I<0[?QMMOm`000Yog2Ln5faT`2`n5eiog00037oL9ShGJFC0
;ChGGgoL000=Om`W?QMUI<0]?QMQOm`000iog2Pn5f1T`2hn5f=og00047oL:ChGFVC0<3hGI7oL000A
Om`[?QMDI<0a?QMVOm`001=og2`n5diT`38n5fQog00057oL;ShGB6C0<chGJWoL000EOm`a?QM0I<0e
?QM/Om`001Mog3@n5cQT`3Ln5feog0006GoL=chG;fC0>ChGKgoL000KOm`k?QLPI<10?QMaOm`001eo
g40n5`YT`4`n5gAog0007WoLTchGMWoL000POmaR?QL00`00?QLn5`0Y?QMiOm`0029og5Pn5`P3h003
000n5chG02Hn5gaog00097oLCchG00<000?P0n0030?P00<003hG?QL093hGOWoL000VOma=?QL00`00
0n03h00<0n000`00?QLn5`0Q?QN1Om`002Uog4Xn5`030003h0?P00d3h003000n5chG01dn5hAog000
;7oLAchG00<3h0000n003@?P00<003hG?QL06ShGQgoL000_Oma4?QL00`?P0003h00=0n000`00?QLn
5`0F?QN;Om`0039og44n5`030n0000?P00d3h003000n5chG018n5hmog000=GoL?ShG00<3h0000n00
3@?P00<003hG?QL03chGTWoL000hOm`k?QL2000?0n000`00?QMT`00:?QNFOm`003eog3Hn5`030003
h00000h3h003000n5chG00Dn5i]og000@GoL<ShG00<000?P00001`?P20000ShGX7oL0016Om`]?QL0
0`000n00000700070n000`00Omaog02POm`004eog2Ln5`8000h3h003001og7oL0:1og000EWoL73hG
0WoL0P003P?P00<007oLOm`0X7oL001dOm`2000>0n000`00Omaog02POm`007Aog08000d3h003001o
g7oL0:5og000M7oL0P003@?P00<007oLOm`0XGoL001dOm`2000=0n000`00Omaog02QOm`007Eog003
0003h0?P00/3h003001og7oL0:5og000MGoL00<000?P0n0010?P2000XgoL001eOm`7002[Om`00?mo
g2Qog000ogoL:7oL003oOm`XOm`00?mog2Qog000ogoL:7oL003oOm`XOm`00?mog2Qog000ogoL:7oL
003oOm`XOm`00?mog2Qog000ogoL:7oL003oOm`XOm`00?mog2Qog000ogoL:7oL003oOm`XOm`00?mo
g2Qog000ogoL:7oL003oOm`XOm`00?mog2Qog000ogoL:7oL003oOm`XOm`00?mog2Qog000ogoL:7oL
003oOm`XOm`00?mog2Qog000ogoL:7oL003oOm`XOm`00?mog2Qog000ogoL:7oL0000\
\>"],
  ImageRangeCache->{{{0, 294.625}, {174.5, 0}} -> {0.00435825, 0.176904, \
0.00338012, 0.00338012}}],

Cell["Box on a circular inclined plane.", "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49829
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 -0.250854 1 [
[ 0 0 0 0 ]
[ 1 .49829 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49829 L
0 .49829 L
closepath
clip
newpath
.97548 .01222 m .96899 .09048 L .96899 .09048 L .787 .211 .013 r
F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.97548 .01222 m .96899 .09048 L .96899 .09048 L F
.96922 .01222 m .96899 .09048 L .97548 .01222 L .479 .526 .746 r
F
.96922 .01222 m .96282 .08945 L .96899 .09048 L F
.96296 .01222 m .96282 .08945 L .96922 .01222 L F
.96296 .01222 m .95665 .08842 L .96282 .08945 L F
.95671 .01222 m .95665 .08842 L .96296 .01222 L F
.95671 .01222 m .95048 .08739 L .95665 .08842 L F
.95045 .01222 m .95048 .08739 L .95671 .01222 L F
.95045 .01222 m .94431 .08636 L .95048 .08739 L F
.94419 .01222 m .94431 .08636 L .95045 .01222 L F
.94419 .01222 m .93814 .08533 L .94431 .08636 L F
.93794 .01222 m .93814 .08533 L .94419 .01222 L F
.93794 .01222 m .93197 .0843 L .93814 .08533 L F
.93168 .01222 m .93197 .0843 L .93794 .01222 L F
.93168 .01222 m .9258 .08327 L .93197 .0843 L F
.92543 .01222 m .9258 .08327 L .93168 .01222 L F
.92543 .01222 m .91963 .08224 L .9258 .08327 L F
.91917 .01222 m .91963 .08224 L .92543 .01222 L F
.91917 .01222 m .91346 .08121 L .91963 .08224 L F
.91291 .01222 m .91346 .08121 L .91917 .01222 L F
.91291 .01222 m .90729 .08018 L .91346 .08121 L F
.90666 .01222 m .90729 .08018 L .91291 .01222 L F
.90666 .01222 m .90111 .07915 L .90729 .08018 L F
.9004 .01222 m .90111 .07915 L .90666 .01222 L F
.9004 .01222 m .89494 .07812 L .90111 .07915 L F
.89414 .01222 m .89494 .07812 L .9004 .01222 L F
.89414 .01222 m .88877 .07709 L .89494 .07812 L F
.88789 .01222 m .88877 .07709 L .89414 .01222 L F
.88789 .01222 m .8826 .07606 L .88877 .07709 L F
.88163 .01222 m .8826 .07606 L .88789 .01222 L F
.88163 .01222 m .87643 .07503 L .8826 .07606 L F
.87538 .01222 m .87643 .07503 L .88163 .01222 L F
.87538 .01222 m .87026 .074 L .87643 .07503 L F
.86912 .01222 m .87026 .074 L .87538 .01222 L F
.86912 .01222 m .86409 .07297 L .87026 .074 L F
.86286 .01222 m .86409 .07297 L .86912 .01222 L F
.86286 .01222 m .85792 .07194 L .86409 .07297 L F
.85661 .01222 m .85792 .07194 L .86286 .01222 L F
.85661 .01222 m .85175 .07091 L .85792 .07194 L F
.02452 .01222 m .14297 .01194 L .02396 .01194 L .787 .211 .013 r
F
.02452 .01222 m .14339 .01222 L .14297 .01194 L F
.85661 .01222 m .85175 .07091 L .85175 .07091 L F
.85661 .01222 m .85175 .07091 L .85175 .07091 L F
.85661 .01222 m .85175 .07091 L .85175 .07091 L F
.85661 .01222 m .85175 .07091 L .85175 .07091 L F
.85661 .01222 m .85175 .07091 L .85175 .07091 L F
.85661 .01222 m .85175 .07091 L .85175 .07091 L F
.85661 .01222 m .85175 .07091 L .85175 .07091 L F
.85661 .01222 m .85174 .07091 L .85175 .07091 L F
.85661 .01222 m .85174 .07091 L .85174 .07091 L F
.85661 .01222 m .85174 .07092 L .85174 .07091 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.14826 .07092 m .14337 .01221 L .14823 .0709 L F
.14826 .07092 m .14339 .01222 L .14337 .01221 L F
.16271 .12801 m .14823 .0709 L .16269 .128 L F
.16271 .12801 m .14826 .07092 L .14823 .0709 L F
.18637 .18195 m .16269 .128 L .18636 .18194 L F
.18637 .18195 m .16271 .12801 L .16269 .128 L F
.21859 .23125 m .18636 .18194 L .21857 .23125 L F
.21859 .23125 m .18637 .18195 L .18636 .18194 L F
.25848 .27458 m .21857 .23125 L .25846 .27459 L F
.25848 .27458 m .21859 .23125 L .21857 .23125 L F
.30495 .31076 m .25846 .27459 L .30495 .31076 L F
.30495 .31076 m .25848 .27458 L .25846 .27459 L F
.35675 .33879 m .30495 .31076 L .35675 .3388 L F
.35675 .33879 m .30495 .31076 L .30495 .31076 L F
0 g
.5 Mabswid
[ ] 0 setdash
.32061 .32294 m
.32223 .32012 L
s
.32224 .32011 m
.5 .01222 L
s
.41246 .35792 m .35675 .3388 L .41245 .35792 L .787 .211 .013 r
F
.41246 .35792 m .35675 .33879 L .35675 .3388 L F
.47055 .36761 m .41245 .35792 L .47055 .36761 L F
.47055 .36761 m .41246 .35792 L .41245 .35792 L F
.52945 .36761 m .47055 .36761 L .52945 .36761 L F
.52945 .36761 m .47055 .36761 L .47055 .36761 L F
.58754 .35792 m .52945 .36761 L .58754 .35792 L F
.58754 .35792 m .52945 .36761 L .52945 .36761 L F
.64325 .33879 m .58754 .35792 L .64325 .33879 L F
.64325 .33879 m .58754 .35792 L .58754 .35792 L F
.69505 .31076 m .64325 .33879 L .69505 .31076 L F
.69505 .31076 m .64325 .33879 L .64325 .33879 L F
.74152 .27458 m .69505 .31076 L .74153 .27458 L F
.74152 .27458 m .69505 .31076 L .69505 .31076 L F
.78141 .23125 m .74153 .27458 L .78141 .23125 L F
.78141 .23125 m .74152 .27458 L .74153 .27458 L F
.81363 .18195 m .78141 .23125 L .81363 .18195 L F
.81363 .18195 m .78141 .23125 L .78141 .23125 L F
.83729 .12801 m .81363 .18195 L .83729 .12801 L F
.83729 .12801 m .81363 .18195 L .81363 .18195 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.85661 .01222 m .85174 .07092 L .85174 .07092 L F
.03101 .09048 m .02449 .01221 L .03098 .09047 L F
.03101 .09048 m .02452 .01222 L .02449 .01221 L F
.05029 .16661 m .03098 .09047 L .05026 .1666 L F
.05029 .16661 m .03101 .09048 L .03098 .09047 L F
.08183 .23852 m .05026 .1666 L .08181 .23852 L F
.08183 .23852 m .05029 .16661 L .05026 .1666 L F
.12478 .30426 m .08181 .23852 L .12476 .30427 L F
.12478 .30426 m .08183 .23852 L .08181 .23852 L F
.17797 .36204 m .12476 .30427 L .17795 .36205 L F
.17797 .36204 m .12478 .30426 L .12476 .30427 L F
.23994 .41027 m .17795 .36205 L .23993 .41028 L F
.23994 .41027 m .17797 .36204 L .17795 .36205 L F
.309 .44765 m .23993 .41028 L .309 .44766 L F
.309 .44765 m .23994 .41027 L .23993 .41028 L F
0 g
.26226 .42399 m
.26298 .42275 L
s
.26298 .42274 m
.32061 .32294 L
s
.38328 .47315 m .309 .44766 L .38327 .47316 L .787 .211 .013 r
F
.38328 .47315 m .309 .44765 L .309 .44766 L F
.46074 .48607 m .38327 .47316 L .46073 .48608 L F
.46074 .48607 m .38328 .47315 L .38327 .47316 L F
.53926 .48607 m .46073 .48608 L .53927 .48608 L F
.53926 .48607 m .46074 .48607 L .46073 .48608 L F
.61672 .47315 m .53927 .48608 L .61673 .47315 L F
.61672 .47315 m .53926 .48607 L .53927 .48608 L F
.691 .44765 m .61673 .47315 L .691 .44765 L F
.691 .44765 m .61672 .47315 L .61673 .47315 L F
.76006 .41027 m .691 .44765 L .76006 .41027 L F
.76006 .41027 m .691 .44765 L .691 .44765 L F
.82203 .36204 m .76006 .41027 L .82203 .36204 L F
.82203 .36204 m .76006 .41027 L .76006 .41027 L F
.87522 .30426 m .82203 .36204 L .87522 .30426 L F
.87522 .30426 m .82203 .36204 L .82203 .36204 L F
.91817 .23852 m .87522 .30426 L .91817 .23852 L F
.91817 .23852 m .87522 .30426 L .87522 .30426 L F
.94971 .16661 m .91817 .23852 L .94971 .16661 L F
.94971 .16661 m .91817 .23852 L .91817 .23852 L F
.96899 .09048 m .94971 .16661 L .96899 .09048 L F
.96899 .09048 m .94971 .16661 L .94971 .16661 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94971 .16661 L .96899 .09048 L F
.96899 .09048 m .94971 .16661 L .94971 .16661 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94971 .16661 L .94972 .16661 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.83729 .12801 m .81363 .18195 L .83729 .12801 L F
.83729 .12801 m .81363 .18195 L .81363 .18195 L F
.94971 .16661 m .91817 .23852 L .94971 .16661 L F
.94971 .16661 m .91817 .23852 L .91817 .23852 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.83729 .12801 m .81363 .18195 L .83729 .12801 L F
.83729 .12801 m .81363 .18195 L .81363 .18195 L F
.94971 .16661 m .91817 .23852 L .94972 .16661 L F
.94971 .16661 m .91817 .23852 L .91817 .23852 L F
.85174 .07092 m .83729 .12801 L .85174 .07092 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.81363 .18195 m .78142 .23125 L .81363 .18195 L F
.81363 .18195 m .78141 .23125 L .78142 .23125 L F
.91817 .23852 m .87522 .30426 L .91817 .23852 L F
.91817 .23852 m .87522 .30426 L .87522 .30426 L F
.85174 .07092 m .83729 .12801 L .85174 .07091 L F
.85174 .07092 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.85174 .07091 m .83729 .12801 L .85174 .07091 L F
.85174 .07091 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.85174 .07091 m .83729 .12801 L .85175 .07091 L F
.85174 .07091 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.83729 .12801 m .81363 .18195 L .83729 .12801 L F
.83729 .12801 m .81363 .18195 L .81363 .18195 L F
.94972 .16661 m .91817 .23852 L .94972 .16661 L F
.94972 .16661 m .91817 .23852 L .91817 .23852 L F
.85175 .07091 m .83729 .12801 L .85175 .07091 L F
.85175 .07091 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .16661 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .16661 L F
.85175 .07091 m .83729 .12801 L .85175 .07091 L F
.85175 .07091 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .1666 L .96899 .09048 L F
.96899 .09048 m .94972 .16661 L .94972 .1666 L F
.85175 .07091 m .83729 .12801 L .85175 .07091 L F
.85175 .07091 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94972 .1666 L .96899 .09048 L F
.96899 .09048 m .94972 .1666 L .94972 .1666 L F
.85175 .07091 m .83729 .12801 L .85175 .07091 L F
.85175 .07091 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94973 .1666 L .96899 .09048 L F
.96899 .09048 m .94972 .1666 L .94973 .1666 L F
.78141 .23125 m .74153 .27458 L .78142 .23125 L F
.78141 .23125 m .74153 .27458 L .74153 .27458 L F
.87522 .30426 m .82204 .36204 L .87522 .30426 L F
.87522 .30426 m .82203 .36204 L .82204 .36204 L F
.83729 .12801 m .81363 .18195 L .83729 .12801 L F
.83729 .12801 m .81363 .18195 L .81363 .18195 L F
.94972 .16661 m .91818 .23852 L .94972 .16661 L F
.94972 .16661 m .91817 .23852 L .91818 .23852 L F
.85175 .07091 m .83729 .12801 L .85175 .07091 L F
.85175 .07091 m .83729 .12801 L .83729 .12801 L F
.96899 .09048 m .94973 .1666 L .96899 .09048 L F
.96899 .09048 m .94973 .1666 L .94973 .1666 L F
.85175 .07091 m .8373 .12801 L .85175 .07091 L F
.85175 .07091 m .83729 .12801 L .8373 .12801 L F
.96899 .09048 m .94973 .1666 L .96899 .09048 L F
.96899 .09048 m .94973 .1666 L .94973 .1666 L F
.81363 .18195 m .78142 .23125 L .81363 .18195 L F
.81363 .18195 m .78142 .23125 L .78142 .23125 L F
.91817 .23852 m .87522 .30426 L .91817 .23852 L F
.91817 .23852 m .87522 .30426 L .87522 .30426 L F
.85175 .07091 m .8373 .12801 L .85175 .07091 L F
.85175 .07091 m .8373 .12801 L .8373 .12801 L F
.96899 .09048 m .94973 .1666 L .96899 .09048 L F
.96899 .09048 m .94973 .1666 L .94973 .1666 L F
.96282 .08945 m .94973 .1666 L .96899 .09048 L .479 .526 .746 r
F
.96282 .08945 m .94381 .16457 L .94973 .1666 L F
.95665 .08842 m .94381 .16457 L .96282 .08945 L F
.95665 .08842 m .93789 .16254 L .94381 .16457 L F
.95048 .08739 m .93789 .16254 L .95665 .08842 L F
.95048 .08739 m .93198 .16051 L .93789 .16254 L F
.94431 .08636 m .93198 .16051 L .95048 .08739 L F
.94431 .08636 m .92606 .15848 L .93198 .16051 L F
.93814 .08533 m .92606 .15848 L .94431 .08636 L F
.93814 .08533 m .92014 .15645 L .92606 .15848 L F
.93197 .0843 m .92014 .15645 L .93814 .08533 L F
.93197 .0843 m .91422 .15442 L .92014 .15645 L F
.9258 .08327 m .91422 .15442 L .93197 .0843 L F
.9258 .08327 m .90831 .15238 L .91422 .15442 L F
.91963 .08224 m .90831 .15238 L .9258 .08327 L F
.91963 .08224 m .90239 .15035 L .90831 .15238 L F
.91346 .08121 m .90239 .15035 L .91963 .08224 L F
.91346 .08121 m .89647 .14832 L .90239 .15035 L F
.90729 .08018 m .89647 .14832 L .91346 .08121 L F
.90729 .08018 m .89055 .14629 L .89647 .14832 L F
.90111 .07915 m .89055 .14629 L .90729 .08018 L F
.90111 .07915 m .88464 .14426 L .89055 .14629 L F
.89494 .07812 m .88464 .14426 L .90111 .07915 L F
.89494 .07812 m .87872 .14223 L .88464 .14426 L F
.88877 .07709 m .87872 .14223 L .89494 .07812 L F
.88877 .07709 m .8728 .1402 L .87872 .14223 L F
.8826 .07606 m .8728 .1402 L .88877 .07709 L F
.8826 .07606 m .86688 .13816 L .8728 .1402 L F
.87643 .07503 m .86688 .13816 L .8826 .07606 L F
.87643 .07503 m .86097 .13613 L .86688 .13816 L F
.87026 .074 m .86097 .13613 L .87643 .07503 L F
.87026 .074 m .85505 .1341 L .86097 .13613 L F
.86409 .07297 m .85505 .1341 L .87026 .074 L F
.86409 .07297 m .84913 .13207 L .85505 .1341 L F
.85792 .07194 m .84913 .13207 L .86409 .07297 L F
.85792 .07194 m .84321 .13004 L .84913 .13207 L F
.85175 .07091 m .84321 .13004 L .85792 .07194 L F
.85175 .07091 m .8373 .12801 L .84321 .13004 L F
.83729 .12801 m .81363 .18194 L .83729 .12801 L .787 .211 .013 r
F
.83729 .12801 m .81363 .18195 L .81363 .18194 L F
.94972 .16661 m .91818 .23852 L .94972 .16661 L F
.94972 .16661 m .91818 .23852 L .91818 .23852 L F
.74153 .27458 m .69505 .31076 L .74153 .27458 L F
.74153 .27458 m .69505 .31076 L .69505 .31076 L F
.82203 .36204 m .76007 .41028 L .82204 .36204 L F
.82203 .36204 m .76006 .41027 L .76007 .41028 L F
.83729 .12801 m .81363 .18194 L .83729 .12801 L F
.83729 .12801 m .81363 .18194 L .81363 .18194 L F
.94972 .16661 m .91818 .23852 L .94972 .16661 L F
.94972 .16661 m .91818 .23852 L .91818 .23852 L F
.81363 .18195 m .78142 .23125 L .81363 .18195 L F
.81363 .18195 m .78142 .23125 L .78142 .23125 L F
.91817 .23852 m .87523 .30426 L .91817 .23852 L F
.91817 .23852 m .87522 .30426 L .87523 .30426 L F
.83729 .12801 m .81364 .18194 L .83729 .12801 L F
.83729 .12801 m .81363 .18194 L .81364 .18194 L F
.94972 .16661 m .91818 .23852 L .94972 .16661 L F
.94972 .16661 m .91818 .23852 L .91818 .23852 L F
.78142 .23125 m .74153 .27459 L .78142 .23125 L F
.78142 .23125 m .74153 .27458 L .74153 .27459 L F
.87522 .30426 m .82204 .36204 L .87522 .30426 L F
.87522 .30426 m .82204 .36204 L .82204 .36204 L F
.83729 .12801 m .81364 .18194 L .83729 .12801 L F
.83729 .12801 m .81364 .18194 L .81364 .18194 L F
.94972 .16661 m .91818 .23852 L .94972 .16661 L F
.94972 .16661 m .91818 .23852 L .91818 .23852 L F
.69505 .31076 m .64325 .33879 L .69505 .31076 L F
.69505 .31076 m .64325 .33879 L .64325 .33879 L F
.76006 .41027 m .691 .44766 L .76007 .41028 L F
.76006 .41027 m .691 .44765 L .691 .44766 L F
.81363 .18195 m .78142 .23125 L .81363 .18195 L F
.81363 .18195 m .78142 .23125 L .78142 .23125 L F
.91817 .23852 m .87523 .30427 L .91818 .23852 L F
.91817 .23852 m .87523 .30426 L .87523 .30427 L F
.83729 .12801 m .81364 .18194 L .83729 .12801 L F
.83729 .12801 m .81364 .18194 L .81364 .18194 L F
.94972 .16661 m .91818 .23852 L .94972 .16661 L F
.94972 .16661 m .91818 .23852 L .91818 .23852 L F
.83729 .12801 m .81364 .18194 L .83729 .12801 L F
.83729 .12801 m .81364 .18194 L .81364 .18194 L F
.94972 .16661 m .91819 .23852 L .94972 .16661 L F
.94972 .16661 m .91818 .23852 L .91819 .23852 L F
.83729 .12801 m .81364 .18194 L .83729 .12801 L F
.83729 .12801 m .81364 .18194 L .81364 .18194 L F
.94972 .16661 m .91819 .23852 L .94972 .16661 L F
.94972 .16661 m .91819 .23852 L .91819 .23852 L F
.64325 .33879 m .58755 .35792 L .64325 .33879 L F
.64325 .33879 m .58754 .35792 L .58755 .35792 L F
.691 .44765 m .61673 .47316 L .691 .44766 L F
.691 .44765 m .61673 .47315 L .61673 .47316 L F
.81363 .18195 m .78142 .23125 L .81363 .18194 L F
.81363 .18195 m .78142 .23125 L .78142 .23125 L F
.91818 .23852 m .87523 .30427 L .91818 .23852 L F
.91818 .23852 m .87523 .30427 L .87523 .30427 L F
.78142 .23125 m .74153 .27459 L .78142 .23125 L F
.78142 .23125 m .74153 .27459 L .74153 .27459 L F
.87522 .30426 m .82204 .36204 L .87523 .30426 L F
.87522 .30426 m .82204 .36204 L .82204 .36204 L F
.74153 .27458 m .69505 .31076 L .74153 .27459 L F
.74153 .27458 m .69505 .31076 L .69505 .31076 L F
.82204 .36204 m .76007 .41028 L .82204 .36204 L F
.82204 .36204 m .76007 .41028 L .76007 .41028 L F
.83729 .12801 m .81364 .18194 L .83729 .12801 L F
.83729 .12801 m .81364 .18194 L .81364 .18194 L F
.94972 .16661 m .91819 .23852 L .94972 .16661 L F
.94972 .16661 m .91819 .23852 L .91819 .23852 L F
.83729 .12801 m .81364 .18194 L .83729 .12801 L F
.83729 .12801 m .81364 .18194 L .81364 .18194 L F
.94972 .16661 m .91819 .23852 L .94972 .1666 L F
.94972 .16661 m .91819 .23852 L .91819 .23852 L F
.81363 .18194 m .78143 .23125 L .81363 .18194 L F
.81363 .18194 m .78142 .23125 L .78143 .23125 L F
.91818 .23852 m .87523 .30427 L .91818 .23852 L F
.91818 .23852 m .87523 .30427 L .87523 .30427 L F
.58754 .35792 m .52945 .36762 L .58755 .35792 L F
.58754 .35792 m .52945 .36761 L .52945 .36762 L F
.61673 .47315 m .53927 .48609 L .61673 .47316 L F
.61673 .47315 m .53927 .48608 L .53927 .48609 L F
.83729 .12801 m .81364 .18194 L .83729 .12801 L F
.83729 .12801 m .81364 .18194 L .81364 .18194 L F
.94972 .1666 m .91819 .23852 L .94972 .1666 L F
.94972 .1666 m .91819 .23852 L .91819 .23852 L F
.83729 .12801 m .81365 .18194 L .83729 .12801 L F
.83729 .12801 m .81364 .18194 L .81365 .18194 L F
.94972 .1666 m .91819 .23852 L .94973 .1666 L F
.94972 .1666 m .91819 .23852 L .91819 .23852 L F
.78142 .23125 m .74154 .27459 L .78142 .23125 L F
.78142 .23125 m .74153 .27459 L .74154 .27459 L F
.87523 .30426 m .82205 .36204 L .87523 .30427 L F
.87523 .30426 m .82204 .36204 L .82205 .36204 L F
.81363 .18194 m .78143 .23125 L .81364 .18194 L F
.81363 .18194 m .78143 .23125 L .78143 .23125 L F
.91818 .23852 m .87524 .30427 L .91818 .23852 L F
.91818 .23852 m .87523 .30427 L .87524 .30427 L F
.83729 .12801 m .81365 .18194 L .83729 .12801 L F
.83729 .12801 m .81365 .18194 L .81365 .18194 L F
.94973 .1666 m .9182 .23852 L .94973 .1666 L F
.94973 .1666 m .91819 .23852 L .9182 .23852 L F
.69505 .31076 m .64326 .3388 L .69505 .31076 L F
.69505 .31076 m .64325 .33879 L .64326 .3388 L F
.76007 .41028 m .69101 .44766 L .76007 .41028 L F
.76007 .41028 m .691 .44766 L .69101 .44766 L F
.52945 .36761 m .47055 .36762 L .52945 .36762 L F
.52945 .36761 m .47055 .36761 L .47055 .36762 L F
.53927 .48608 m .46073 .48609 L .53927 .48609 L F
.53927 .48608 m .46073 .48608 L .46073 .48609 L F
.83729 .12801 m .81365 .18194 L .8373 .12801 L F
.83729 .12801 m .81365 .18194 L .81365 .18194 L F
.94973 .1666 m .9182 .23852 L .94973 .1666 L F
.94973 .1666 m .9182 .23852 L .9182 .23852 L F
.81364 .18194 m .78143 .23125 L .81364 .18194 L F
.81364 .18194 m .78143 .23125 L .78143 .23125 L F
.91818 .23852 m .87524 .30427 L .91818 .23852 L F
.91818 .23852 m .87524 .30427 L .87524 .30427 L F
.74153 .27459 m .69506 .31076 L .74153 .27459 L F
.74153 .27459 m .69505 .31076 L .69506 .31076 L F
.82204 .36204 m .76008 .41028 L .82204 .36204 L F
.82204 .36204 m .76007 .41028 L .76008 .41028 L F
.8373 .12801 m .81365 .18194 L .8373 .12801 L F
.8373 .12801 m .81365 .18194 L .81365 .18194 L F
.94973 .1666 m .9182 .23852 L .94973 .1666 L F
.94973 .1666 m .9182 .23852 L .9182 .23852 L F
.94381 .16457 m .9182 .23852 L .94973 .1666 L .479 .526 .746 r
F
.94381 .16457 m .9127 .23554 L .9182 .23852 L F
.93789 .16254 m .9127 .23554 L .94381 .16457 L F
.93789 .16254 m .90719 .23257 L .9127 .23554 L F
.93198 .16051 m .90719 .23257 L .93789 .16254 L F
.93198 .16051 m .90169 .22959 L .90719 .23257 L F
.92606 .15848 m .90169 .22959 L .93198 .16051 L F
.92606 .15848 m .89619 .22661 L .90169 .22959 L F
.92014 .15645 m .89619 .22661 L .92606 .15848 L F
.92014 .15645 m .89069 .22363 L .89619 .22661 L F
.91422 .15442 m .89069 .22363 L .92014 .15645 L F
.91422 .15442 m .88518 .22065 L .89069 .22363 L F
.90831 .15238 m .88518 .22065 L .91422 .15442 L F
.90831 .15238 m .87968 .21768 L .88518 .22065 L F
.90239 .15035 m .87968 .21768 L .90831 .15238 L F
.90239 .15035 m .87418 .2147 L .87968 .21768 L F
.89647 .14832 m .87418 .2147 L .90239 .15035 L F
.89647 .14832 m .86868 .21172 L .87418 .2147 L F
.89055 .14629 m .86868 .21172 L .89647 .14832 L F
.89055 .14629 m .86317 .20874 L .86868 .21172 L F
.88464 .14426 m .86317 .20874 L .89055 .14629 L F
.88464 .14426 m .85767 .20576 L .86317 .20874 L F
.87872 .14223 m .85767 .20576 L .88464 .14426 L F
.87872 .14223 m .85217 .20279 L .85767 .20576 L F
.8728 .1402 m .85217 .20279 L .87872 .14223 L F
.8728 .1402 m .84666 .19981 L .85217 .20279 L F
.86688 .13816 m .84666 .19981 L .8728 .1402 L F
.86688 .13816 m .84116 .19683 L .84666 .19981 L F
.86097 .13613 m .84116 .19683 L .86688 .13816 L F
.86097 .13613 m .83566 .19385 L .84116 .19683 L F
.85505 .1341 m .83566 .19385 L .86097 .13613 L F
.85505 .1341 m .83016 .19088 L .83566 .19385 L F
.84913 .13207 m .83016 .19088 L .85505 .1341 L F
.84913 .13207 m .82465 .1879 L .83016 .19088 L F
.84321 .13004 m .82465 .1879 L .84913 .13207 L F
.84321 .13004 m .81915 .18492 L .82465 .1879 L F
.8373 .12801 m .81915 .18492 L .84321 .13004 L F
.8373 .12801 m .81365 .18194 L .81915 .18492 L F
.78142 .23125 m .74154 .27459 L .78142 .23125 L .787 .211 .013 r
F
.78142 .23125 m .74154 .27459 L .74154 .27459 L F
.87523 .30427 m .82205 .36205 L .87523 .30427 L F
.87523 .30427 m .82205 .36204 L .82205 .36205 L F
.47055 .36761 m .41245 .35792 L .47055 .36762 L F
.47055 .36761 m .41245 .35792 L .41245 .35792 L F
.46073 .48608 m .38327 .47316 L .46073 .48609 L F
.46073 .48608 m .38327 .47316 L .38327 .47316 L F
.81364 .18194 m .78143 .23125 L .81364 .18194 L F
.81364 .18194 m .78143 .23125 L .78143 .23125 L F
.91818 .23852 m .87524 .30427 L .91818 .23852 L F
.91818 .23852 m .87524 .30427 L .87524 .30427 L F
.64325 .33879 m .58755 .35792 L .64326 .3388 L F
.64325 .33879 m .58755 .35792 L .58755 .35792 L F
.691 .44766 m .61673 .47316 L .69101 .44766 L F
.691 .44766 m .61673 .47316 L .61673 .47316 L F
.81364 .18194 m .78143 .23125 L .81364 .18194 L F
.81364 .18194 m .78143 .23125 L .78143 .23125 L F
.91818 .23852 m .87524 .30427 L .91819 .23852 L F
.91818 .23852 m .87524 .30427 L .87524 .30427 L F
.41245 .35792 m .35674 .3388 L .41245 .35792 L F
.41245 .35792 m .35675 .3388 L .35674 .3388 L F
.38327 .47316 m .30899 .44767 L .38327 .47316 L F
.38327 .47316 m .309 .44766 L .30899 .44767 L F
.78142 .23125 m .74154 .27459 L .78143 .23125 L F
.78142 .23125 m .74154 .27459 L .74154 .27459 L F
.87523 .30427 m .82205 .36205 L .87523 .30427 L F
.87523 .30427 m .82205 .36205 L .82205 .36205 L F
.74153 .27459 m .69506 .31076 L .74154 .27459 L F
.74153 .27459 m .69506 .31076 L .69506 .31076 L F
.82204 .36204 m .76008 .41028 L .82205 .36204 L F
.82204 .36204 m .76008 .41028 L .76008 .41028 L F
.81364 .18194 m .78144 .23125 L .81364 .18194 L F
.81364 .18194 m .78143 .23125 L .78144 .23125 L F
.91819 .23852 m .87525 .30427 L .91819 .23852 L F
.91819 .23852 m .87524 .30427 L .87525 .30427 L F
.69505 .31076 m .64326 .3388 L .69506 .31076 L F
.69505 .31076 m .64326 .3388 L .64326 .3388 L F
.76007 .41028 m .69101 .44766 L .76008 .41028 L F
.76007 .41028 m .69101 .44766 L .69101 .44766 L F
.35675 .3388 m .30494 .31077 L .35674 .3388 L F
.35675 .3388 m .30495 .31076 L .30494 .31077 L F
.309 .44766 m .23991 .41029 L .30899 .44767 L F
.309 .44766 m .23993 .41028 L .23991 .41029 L F
.81364 .18194 m .78144 .23125 L .81364 .18194 L F
.81364 .18194 m .78144 .23125 L .78144 .23125 L F
.91819 .23852 m .87525 .30427 L .91819 .23852 L F
.91819 .23852 m .87525 .30427 L .87525 .30427 L F
.78143 .23125 m .74154 .27459 L .78143 .23125 L F
.78143 .23125 m .74154 .27459 L .74154 .27459 L F
.87523 .30427 m .82206 .36205 L .87524 .30427 L F
.87523 .30427 m .82205 .36205 L .82206 .36205 L F
.58755 .35792 m .52945 .36762 L .58755 .35792 L F
.58755 .35792 m .52945 .36762 L .52945 .36762 L F
.61673 .47316 m .53927 .48609 L .61673 .47316 L F
.61673 .47316 m .53927 .48609 L .53927 .48609 L F
.30495 .31076 m .25845 .27459 L .30494 .31077 L F
.30495 .31076 m .25846 .27459 L .25845 .27459 L F
.23993 .41028 m .17794 .36205 L .23991 .41029 L F
.23993 .41028 m .17795 .36205 L .17794 .36205 L F
.81364 .18194 m .78144 .23125 L .81364 .18194 L F
.81364 .18194 m .78144 .23125 L .78144 .23125 L F
.91819 .23852 m .87525 .30427 L .91819 .23852 L F
.91819 .23852 m .87525 .30427 L .87525 .30427 L F
.74154 .27459 m .69506 .31076 L .74154 .27459 L F
.74154 .27459 m .69506 .31076 L .69506 .31076 L F
.82205 .36204 m .76008 .41029 L .82205 .36205 L F
.82205 .36204 m .76008 .41028 L .76008 .41029 L F
.25846 .27459 m .21856 .23125 L .25845 .27459 L F
.25846 .27459 m .21857 .23125 L .21856 .23125 L F
.17795 .36205 m .12474 .30427 L .17794 .36205 L F
.17795 .36205 m .12476 .30427 L .12474 .30427 L F
.78143 .23125 m .74155 .27459 L .78143 .23125 L F
.78143 .23125 m .74154 .27459 L .74155 .27459 L F
.87524 .30427 m .82206 .36205 L .87524 .30427 L F
.87524 .30427 m .82206 .36205 L .82206 .36205 L F
.81364 .18194 m .78144 .23125 L .81364 .18194 L F
.81364 .18194 m .78144 .23125 L .78144 .23125 L F
.91819 .23852 m .87525 .30427 L .91819 .23852 L F
.91819 .23852 m .87525 .30427 L .87525 .30427 L F
.21857 .23125 m .18634 .18194 L .21856 .23125 L F
.21857 .23125 m .18636 .18194 L .18634 .18194 L F
.12476 .30427 m .08178 .23852 L .12474 .30427 L F
.12476 .30427 m .08181 .23852 L .08178 .23852 L F
.64326 .3388 m .58755 .35793 L .64326 .3388 L F
.64326 .3388 m .58755 .35792 L .58755 .35793 L F
.69101 .44766 m .61673 .47317 L .69101 .44766 L F
.69101 .44766 m .61673 .47316 L .61673 .47317 L F
.81364 .18194 m .78144 .23125 L .81365 .18194 L F
.81364 .18194 m .78144 .23125 L .78144 .23125 L F
.91819 .23852 m .87526 .30427 L .91819 .23852 L F
.91819 .23852 m .87525 .30427 L .87526 .30427 L F
.69506 .31076 m .64326 .3388 L .69506 .31076 L F
.69506 .31076 m .64326 .3388 L .64326 .3388 L F
.76008 .41028 m .69101 .44767 L .76008 .41028 L F
.76008 .41028 m .69101 .44766 L .69101 .44767 L F
.52945 .36762 m .47055 .36762 L .52945 .36762 L F
.52945 .36762 m .47055 .36762 L .47055 .36762 L F
.53927 .48609 m .46073 .4861 L .53927 .48609 L F
.53927 .48609 m .46073 .48609 L .46073 .4861 L F
.18636 .18194 m .16267 .128 L .18634 .18194 L F
.18636 .18194 m .16269 .128 L .16267 .128 L F
.08181 .23852 m .05023 .1666 L .08178 .23852 L F
.08181 .23852 m .05026 .1666 L .05023 .1666 L F
.78143 .23125 m .74155 .27459 L .78143 .23125 L F
.78143 .23125 m .74155 .27459 L .74155 .27459 L F
.87524 .30427 m .82206 .36205 L .87524 .30427 L F
.87524 .30427 m .82206 .36205 L .82206 .36205 L F
.81365 .18194 m .78144 .23125 L .81365 .18194 L F
.81365 .18194 m .78144 .23125 L .78144 .23125 L F
.91819 .23852 m .87526 .30427 L .9182 .23852 L F
.91819 .23852 m .87526 .30427 L .87526 .30427 L F
.74154 .27459 m .69506 .31077 L .74154 .27459 L F
.74154 .27459 m .69506 .31076 L .69506 .31077 L F
.82205 .36205 m .76009 .41029 L .82205 .36205 L F
.82205 .36205 m .76008 .41029 L .76009 .41029 L F
.16269 .128 m .14821 .07089 L .16267 .128 L F
.16269 .128 m .14823 .0709 L .14821 .07089 L F
.05026 .1666 m .03095 .09046 L .05023 .1666 L F
.05026 .1666 m .03098 .09047 L .03095 .09046 L F
.14823 .0709 m .14335 .01219 L .14821 .07089 L F
.14823 .0709 m .14337 .01221 L .14335 .01219 L F
.03098 .09047 m .02446 .01219 L .03095 .09046 L F
.03098 .09047 m .02449 .01221 L .02446 .01219 L F
.81365 .18194 m .78145 .23125 L .81365 .18194 L F
.81365 .18194 m .78144 .23125 L .78145 .23125 L F
.9182 .23852 m .87526 .30427 L .9182 .23852 L F
.9182 .23852 m .87526 .30427 L .87526 .30427 L F
.78143 .23125 m .74155 .27459 L .78143 .23125 L F
.78143 .23125 m .74155 .27459 L .74155 .27459 L F
.87524 .30427 m .82207 .36205 L .87524 .30427 L F
.87524 .30427 m .82206 .36205 L .82207 .36205 L F
.47055 .36762 m .41245 .35793 L .47055 .36762 L F
.47055 .36762 m .41245 .35792 L .41245 .35793 L F
.46073 .48609 m .38326 .47317 L .46073 .4861 L F
.46073 .48609 m .38327 .47316 L .38326 .47317 L F
.81365 .18194 m .78145 .23125 L .81365 .18194 L F
.81365 .18194 m .78145 .23125 L .78145 .23125 L F
.9182 .23852 m .87526 .30427 L .9182 .23852 L F
.9182 .23852 m .87526 .30427 L .87526 .30427 L F
.74154 .27459 m .69507 .31077 L .74154 .27459 L F
.74154 .27459 m .69506 .31077 L .69507 .31077 L F
.82205 .36205 m .76009 .41029 L .82206 .36205 L F
.82205 .36205 m .76009 .41029 L .76009 .41029 L F
.58755 .35792 m .52945 .36762 L .58755 .35793 L F
.58755 .35792 m .52945 .36762 L .52945 .36762 L F
.61673 .47316 m .53927 .4861 L .61673 .47317 L F
.61673 .47316 m .53927 .48609 L .53927 .4861 L F
.69506 .31076 m .64326 .3388 L .69506 .31076 L F
.69506 .31076 m .64326 .3388 L .64326 .3388 L F
.76008 .41028 m .69102 .44767 L .76008 .41029 L F
.76008 .41028 m .69101 .44767 L .69102 .44767 L F
.9127 .23554 m .87526 .30427 L .9182 .23852 L .479 .526 .746 r
F
.9127 .23554 m .87033 .30043 L .87526 .30427 L F
.90719 .23257 m .87033 .30043 L .9127 .23554 L F
.90719 .23257 m .86539 .29658 L .87033 .30043 L F
.90169 .22959 m .86539 .29658 L .90719 .23257 L F
.90169 .22959 m .86045 .29274 L .86539 .29658 L F
.89619 .22661 m .86045 .29274 L .90169 .22959 L F
.89619 .22661 m .85551 .2889 L .86045 .29274 L F
.89069 .22363 m .85551 .2889 L .89619 .22661 L F
.89069 .22363 m .85058 .28505 L .85551 .2889 L F
.88518 .22065 m .85058 .28505 L .89069 .22363 L F
.88518 .22065 m .84564 .28121 L .85058 .28505 L F
.87968 .21768 m .84564 .28121 L .88518 .22065 L F
.87968 .21768 m .8407 .27737 L .84564 .28121 L F
.87418 .2147 m .8407 .27737 L .87968 .21768 L F
.87418 .2147 m .83576 .27353 L .8407 .27737 L F
.86868 .21172 m .83576 .27353 L .87418 .2147 L F
.86868 .21172 m .83083 .26968 L .83576 .27353 L F
.86317 .20874 m .83083 .26968 L .86868 .21172 L F
.86317 .20874 m .82589 .26584 L .83083 .26968 L F
.85767 .20576 m .82589 .26584 L .86317 .20874 L F
.85767 .20576 m .82095 .262 L .82589 .26584 L F
.85217 .20279 m .82095 .262 L .85767 .20576 L F
.85217 .20279 m .81601 .25815 L .82095 .262 L F
.84666 .19981 m .81601 .25815 L .85217 .20279 L F
.84666 .19981 m .81107 .25431 L .81601 .25815 L F
.84116 .19683 m .81107 .25431 L .84666 .19981 L F
.84116 .19683 m .80614 .25047 L .81107 .25431 L F
.83566 .19385 m .80614 .25047 L .84116 .19683 L F
.83566 .19385 m .8012 .24662 L .80614 .25047 L F
.83016 .19088 m .8012 .24662 L .83566 .19385 L F
.83016 .19088 m .79626 .24278 L .8012 .24662 L F
.82465 .1879 m .79626 .24278 L .83016 .19088 L F
.82465 .1879 m .79132 .23894 L .79626 .24278 L F
.81915 .18492 m .79132 .23894 L .82465 .1879 L F
.81915 .18492 m .78639 .23509 L .79132 .23894 L F
.81365 .18194 m .78639 .23509 L .81915 .18492 L F
.81365 .18194 m .78145 .23125 L .78639 .23509 L F
.78143 .23125 m .74155 .27459 L .78144 .23125 L .787 .211 .013 r
F
.78143 .23125 m .74155 .27459 L .74155 .27459 L F
.87524 .30427 m .82207 .36205 L .87525 .30427 L F
.87524 .30427 m .82207 .36205 L .82207 .36205 L F
.64326 .3388 m .58755 .35793 L .64326 .3388 L F
.64326 .3388 m .58755 .35793 L .58755 .35793 L F
.69101 .44766 m .61674 .47317 L .69101 .44767 L F
.69101 .44766 m .61673 .47317 L .61674 .47317 L F
.41245 .35792 m .35673 .3388 L .41245 .35793 L F
.41245 .35792 m .35674 .3388 L .35673 .3388 L F
.38327 .47316 m .30898 .44767 L .38326 .47317 L F
.38327 .47316 m .30899 .44767 L .30898 .44767 L F
.78144 .23125 m .74156 .27459 L .78144 .23125 L F
.78144 .23125 m .74155 .27459 L .74156 .27459 L F
.87525 .30427 m .82207 .36205 L .87525 .30427 L F
.87525 .30427 m .82207 .36205 L .82207 .36205 L F
.74154 .27459 m .69507 .31077 L .74155 .27459 L F
.74154 .27459 m .69507 .31077 L .69507 .31077 L F
.82206 .36205 m .76009 .41029 L .82206 .36205 L F
.82206 .36205 m .76009 .41029 L .76009 .41029 L F
.69506 .31076 m .64327 .3388 L .69506 .31077 L F
.69506 .31076 m .64326 .3388 L .64327 .3388 L F
.76008 .41029 m .69102 .44767 L .76009 .41029 L F
.76008 .41029 m .69102 .44767 L .69102 .44767 L F
.78144 .23125 m .74156 .27459 L .78144 .23125 L F
.78144 .23125 m .74156 .27459 L .74156 .27459 L F
.87525 .30427 m .82208 .36206 L .87525 .30427 L F
.87525 .30427 m .82207 .36205 L .82208 .36206 L F
.52945 .36762 m .47055 .36763 L .52945 .36762 L F
.52945 .36762 m .47055 .36762 L .47055 .36763 L F
.53927 .48609 m .46073 .4861 L .53927 .4861 L F
.53927 .48609 m .46073 .4861 L .46073 .4861 L F
.35674 .3388 m .30493 .31077 L .35673 .3388 L F
.35674 .3388 m .30494 .31077 L .30493 .31077 L F
.30899 .44767 m .2399 .4103 L .30898 .44767 L F
.30899 .44767 m .23991 .41029 L .2399 .4103 L F
.74155 .27459 m .69507 .31077 L .74155 .27459 L F
.74155 .27459 m .69507 .31077 L .69507 .31077 L F
.82206 .36205 m .7601 .4103 L .82206 .36205 L F
.82206 .36205 m .76009 .41029 L .7601 .4103 L F
.78144 .23125 m .74156 .27459 L .78144 .23125 L F
.78144 .23125 m .74156 .27459 L .74156 .27459 L F
.87525 .30427 m .82208 .36206 L .87525 .30427 L F
.87525 .30427 m .82208 .36206 L .82208 .36206 L F
.64326 .3388 m .58755 .35793 L .64326 .3388 L F
.64326 .3388 m .58755 .35793 L .58755 .35793 L F
.69101 .44767 m .61674 .47318 L .69102 .44767 L F
.69101 .44767 m .61674 .47317 L .61674 .47318 L F
.58755 .35793 m .52945 .36763 L .58755 .35793 L F
.58755 .35793 m .52945 .36762 L .52945 .36763 L F
.61673 .47317 m .53927 .48611 L .61674 .47317 L F
.61673 .47317 m .53927 .4861 L .53927 .48611 L F
.30494 .31077 m .25844 .27459 L .30493 .31077 L F
.30494 .31077 m .25845 .27459 L .25844 .27459 L F
.23991 .41029 m .17792 .36206 L .2399 .4103 L F
.23991 .41029 m .17794 .36205 L .17792 .36206 L F
.78144 .23125 m .74156 .27459 L .78144 .23125 L F
.78144 .23125 m .74156 .27459 L .74156 .27459 L F
.87525 .30427 m .82208 .36206 L .87526 .30427 L F
.87525 .30427 m .82208 .36206 L .82208 .36206 L F
.69506 .31077 m .64327 .3388 L .69507 .31077 L F
.69506 .31077 m .64327 .3388 L .64327 .3388 L F
.76009 .41029 m .69103 .44768 L .76009 .41029 L F
.76009 .41029 m .69102 .44767 L .69103 .44768 L F
.74155 .27459 m .69508 .31077 L .74155 .27459 L F
.74155 .27459 m .69507 .31077 L .69508 .31077 L F
.82206 .36205 m .7601 .4103 L .82207 .36205 L F
.82206 .36205 m .7601 .4103 L .7601 .4103 L F
.47055 .36762 m .41244 .35793 L .47055 .36763 L F
.47055 .36762 m .41245 .35793 L .41244 .35793 L F
.46073 .4861 m .38326 .47318 L .46073 .4861 L F
.46073 .4861 m .38326 .47317 L .38326 .47318 L F
.25845 .27459 m .21854 .23125 L .25844 .27459 L F
.25845 .27459 m .21856 .23125 L .21854 .23125 L F
.17794 .36205 m .12472 .30427 L .17792 .36206 L F
.17794 .36205 m .12474 .30427 L .12472 .30427 L F
.78144 .23125 m .74156 .27459 L .78144 .23125 L F
.78144 .23125 m .74156 .27459 L .74156 .27459 L F
.87526 .30427 m .82209 .36206 L .87526 .30427 L F
.87526 .30427 m .82208 .36206 L .82209 .36206 L F
.74155 .27459 m .69508 .31077 L .74155 .27459 L F
.74155 .27459 m .69508 .31077 L .69508 .31077 L F
.82207 .36205 m .7601 .4103 L .82207 .36205 L F
.82207 .36205 m .7601 .4103 L .7601 .4103 L F
.21856 .23125 m .18632 .18193 L .21854 .23125 L F
.21856 .23125 m .18634 .18194 L .18632 .18193 L F
.12474 .30427 m .08176 .23852 L .12472 .30427 L F
.12474 .30427 m .08178 .23852 L .08176 .23852 L F
.78144 .23125 m .74157 .27459 L .78145 .23125 L F
.78144 .23125 m .74156 .27459 L .74157 .27459 L F
.87526 .30427 m .82209 .36206 L .87526 .30427 L F
.87526 .30427 m .82209 .36206 L .82209 .36206 L F
.64326 .3388 m .58756 .35793 L .64327 .3388 L F
.64326 .3388 m .58755 .35793 L .58756 .35793 L F
.69102 .44767 m .61674 .47318 L .69102 .44767 L F
.69102 .44767 m .61674 .47318 L .61674 .47318 L F
.69507 .31077 m .64327 .33881 L .69507 .31077 L F
.69507 .31077 m .64327 .3388 L .64327 .33881 L F
.76009 .41029 m .69103 .44768 L .76009 .41029 L F
.76009 .41029 m .69103 .44768 L .69103 .44768 L F
.52945 .36762 m .47055 .36763 L .52945 .36763 L F
.52945 .36762 m .47055 .36763 L .47055 .36763 L F
.53927 .4861 m .46073 .48611 L .53927 .48611 L F
.53927 .4861 m .46073 .4861 L .46073 .48611 L F
.41245 .35793 m .35673 .33881 L .41244 .35793 L F
.41245 .35793 m .35673 .3388 L .35673 .33881 L F
.38326 .47317 m .30897 .44768 L .38326 .47318 L F
.38326 .47317 m .30898 .44767 L .30897 .44768 L F
.18634 .18194 m .16265 .12799 L .18632 .18193 L F
.18634 .18194 m .16267 .128 L .16265 .12799 L F
.08178 .23852 m .0502 .16659 L .08176 .23852 L F
.08178 .23852 m .05023 .1666 L .0502 .16659 L F
.58755 .35793 m .52945 .36763 L .58755 .35793 L F
.58755 .35793 m .52945 .36763 L .52945 .36763 L F
.61674 .47317 m .53927 .48611 L .61674 .47318 L F
.61674 .47317 m .53927 .48611 L .53927 .48611 L F
.78145 .23125 m .74157 .27459 L .78145 .23125 L F
.78145 .23125 m .74157 .27459 L .74157 .27459 L F
.87526 .30427 m .82209 .36206 L .87526 .30427 L F
.87526 .30427 m .82209 .36206 L .82209 .36206 L F
.74155 .27459 m .69508 .31077 L .74156 .27459 L F
.74155 .27459 m .69508 .31077 L .69508 .31077 L F
.82207 .36205 m .76011 .4103 L .82207 .36205 L F
.82207 .36205 m .7601 .4103 L .76011 .4103 L F
.16267 .128 m .14819 .07088 L .16265 .12799 L F
.16267 .128 m .14821 .07089 L .14819 .07088 L F
.05023 .1666 m .03092 .09045 L .0502 .16659 L F
.05023 .1666 m .03095 .09046 L .03092 .09045 L F
.14821 .07089 m .14333 .01218 L .14819 .07088 L F
.14821 .07089 m .14335 .01219 L .14333 .01218 L F
.03095 .09046 m .02443 .01218 L .03092 .09045 L F
.03095 .09046 m .02446 .01219 L .02443 .01218 L F
.87033 .30043 m .82209 .36206 L .87526 .30427 L .479 .526 .746 r
F
.87033 .30043 m .81785 .35746 L .82209 .36206 L F
.86539 .29658 m .81785 .35746 L .87033 .30043 L F
.86539 .29658 m .81362 .35285 L .81785 .35746 L F
.86045 .29274 m .81362 .35285 L .86539 .29658 L F
.86045 .29274 m .80938 .34825 L .81362 .35285 L F
.85551 .2889 m .80938 .34825 L .86045 .29274 L F
.85551 .2889 m .80514 .34365 L .80938 .34825 L F
.85058 .28505 m .80514 .34365 L .85551 .2889 L F
.85058 .28505 m .8009 .33904 L .80514 .34365 L F
.84564 .28121 m .8009 .33904 L .85058 .28505 L F
.84564 .28121 m .79666 .33444 L .8009 .33904 L F
.8407 .27737 m .79666 .33444 L .84564 .28121 L F
.8407 .27737 m .79243 .32983 L .79666 .33444 L F
.83576 .27353 m .79243 .32983 L .8407 .27737 L F
.83576 .27353 m .78819 .32523 L .79243 .32983 L F
.83083 .26968 m .78819 .32523 L .83576 .27353 L F
.83083 .26968 m .78395 .32063 L .78819 .32523 L F
.82589 .26584 m .78395 .32063 L .83083 .26968 L F
.82589 .26584 m .77971 .31602 L .78395 .32063 L F
.82095 .262 m .77971 .31602 L .82589 .26584 L F
.82095 .262 m .77547 .31142 L .77971 .31602 L F
.81601 .25815 m .77547 .31142 L .82095 .262 L F
.81601 .25815 m .77124 .30682 L .77547 .31142 L F
.81107 .25431 m .77124 .30682 L .81601 .25815 L F
.81107 .25431 m .767 .30221 L .77124 .30682 L F
.80614 .25047 m .767 .30221 L .81107 .25431 L F
.80614 .25047 m .76276 .29761 L .767 .30221 L F
.8012 .24662 m .76276 .29761 L .80614 .25047 L F
.8012 .24662 m .75852 .293 L .76276 .29761 L F
.79626 .24278 m .75852 .293 L .8012 .24662 L F
.79626 .24278 m .75428 .2884 L .75852 .293 L F
.79132 .23894 m .75428 .2884 L .79626 .24278 L F
.79132 .23894 m .75005 .2838 L .75428 .2884 L F
.78639 .23509 m .75005 .2838 L .79132 .23894 L F
.78639 .23509 m .74581 .27919 L .75005 .2838 L F
.78145 .23125 m .74581 .27919 L .78639 .23509 L F
.78145 .23125 m .74157 .27459 L .74581 .27919 L F
.69507 .31077 m .64327 .33881 L .69507 .31077 L .787 .211 .013 r
F
.69507 .31077 m .64327 .33881 L .64327 .33881 L F
.76009 .41029 m .69103 .44769 L .7601 .4103 L F
.76009 .41029 m .69103 .44768 L .69103 .44769 L F
.64327 .3388 m .58756 .35794 L .64327 .3388 L F
.64327 .3388 m .58756 .35793 L .58756 .35794 L F
.69102 .44767 m .61674 .47319 L .69103 .44768 L F
.69102 .44767 m .61674 .47318 L .61674 .47319 L F
.74156 .27459 m .69508 .31077 L .74156 .27459 L F
.74156 .27459 m .69508 .31077 L .69508 .31077 L F
.82207 .36205 m .76011 .4103 L .82208 .36206 L F
.82207 .36205 m .76011 .4103 L .76011 .4103 L F
.35673 .3388 m .30492 .31077 L .35673 .33881 L F
.35673 .3388 m .30493 .31077 L .30492 .31077 L F
.30898 .44767 m .23989 .4103 L .30897 .44768 L F
.30898 .44767 m .2399 .4103 L .23989 .4103 L F
.47055 .36763 m .41244 .35794 L .47055 .36763 L F
.47055 .36763 m .41244 .35793 L .41244 .35794 L F
.46073 .4861 m .38325 .47319 L .46073 .48611 L F
.46073 .4861 m .38326 .47318 L .38325 .47319 L F
.74156 .27459 m .69509 .31077 L .74156 .27459 L F
.74156 .27459 m .69508 .31077 L .69509 .31077 L F
.82208 .36206 m .76012 .41031 L .82208 .36206 L F
.82208 .36206 m .76011 .4103 L .76012 .41031 L F
.58755 .35793 m .52945 .36763 L .58756 .35793 L F
.58755 .35793 m .52945 .36763 L .52945 .36763 L F
.61674 .47318 m .53927 .48612 L .61674 .47318 L F
.61674 .47318 m .53927 .48611 L .53927 .48612 L F
.69507 .31077 m .64328 .33881 L .69508 .31077 L F
.69507 .31077 m .64327 .33881 L .64328 .33881 L F
.7601 .4103 m .69104 .44769 L .7601 .4103 L F
.7601 .4103 m .69103 .44769 L .69104 .44769 L F
.52945 .36763 m .47055 .36763 L .52945 .36763 L F
.52945 .36763 m .47055 .36763 L .47055 .36763 L F
.53927 .48611 m .46073 .48612 L .53927 .48611 L F
.53927 .48611 m .46073 .48611 L .46073 .48612 L F
.30493 .31077 m .25843 .27459 L .30492 .31077 L F
.30493 .31077 m .25844 .27459 L .25843 .27459 L F
.2399 .4103 m .1779 .36206 L .23989 .4103 L F
.2399 .4103 m .17792 .36206 L .1779 .36206 L F
.64327 .3388 m .58756 .35794 L .64327 .33881 L F
.64327 .3388 m .58756 .35794 L .58756 .35794 L F
.69103 .44768 m .61675 .47319 L .69103 .44768 L F
.69103 .44768 m .61674 .47319 L .61675 .47319 L F
.74156 .27459 m .69509 .31077 L .74156 .27459 L F
.74156 .27459 m .69509 .31077 L .69509 .31077 L F
.82208 .36206 m .76012 .41031 L .82208 .36206 L F
.82208 .36206 m .76012 .41031 L .76012 .41031 L F
.41244 .35793 m .35672 .33881 L .41244 .35794 L F
.41244 .35793 m .35673 .33881 L .35672 .33881 L F
.38326 .47318 m .30896 .44769 L .38325 .47319 L F
.38326 .47318 m .30897 .44768 L .30896 .44769 L F
.69508 .31077 m .64328 .33881 L .69508 .31077 L F
.69508 .31077 m .64328 .33881 L .64328 .33881 L F
.7601 .4103 m .69104 .44769 L .7601 .4103 L F
.7601 .4103 m .69104 .44769 L .69104 .44769 L F
.25844 .27459 m .21852 .23125 L .25843 .27459 L F
.25844 .27459 m .21854 .23125 L .21852 .23125 L F
.17792 .36206 m .1247 .30428 L .1779 .36206 L F
.17792 .36206 m .12472 .30427 L .1247 .30428 L F
.74156 .27459 m .69509 .31077 L .74156 .27459 L F
.74156 .27459 m .69509 .31077 L .69509 .31077 L F
.82208 .36206 m .76012 .41031 L .82209 .36206 L F
.82208 .36206 m .76012 .41031 L .76012 .41031 L F
.58756 .35793 m .52946 .36764 L .58756 .35794 L F
.58756 .35793 m .52945 .36763 L .52946 .36764 L F
.61674 .47318 m .53927 .48613 L .61674 .47319 L F
.61674 .47318 m .53927 .48612 L .53927 .48613 L F
.21854 .23125 m .1863 .18193 L .21852 .23125 L F
.21854 .23125 m .18632 .18193 L .1863 .18193 L F
.12472 .30427 m .08173 .23852 L .1247 .30428 L F
.12472 .30427 m .08176 .23852 L .08173 .23852 L F
.64327 .33881 m .58756 .35794 L .64327 .33881 L F
.64327 .33881 m .58756 .35794 L .58756 .35794 L F
.69103 .44768 m .61675 .4732 L .69103 .44769 L F
.69103 .44768 m .61675 .47319 L .61675 .4732 L F
.47055 .36763 m .41244 .35794 L .47055 .36763 L F
.47055 .36763 m .41244 .35794 L .41244 .35794 L F
.46073 .48611 m .38325 .4732 L .46073 .48612 L F
.46073 .48611 m .38325 .47319 L .38325 .4732 L F
.69508 .31077 m .64328 .33881 L .69508 .31077 L F
.69508 .31077 m .64328 .33881 L .64328 .33881 L F
.7601 .4103 m .69104 .4477 L .76011 .4103 L F
.7601 .4103 m .69104 .44769 L .69104 .4477 L F
.74156 .27459 m .6951 .31078 L .74157 .27459 L F
.74156 .27459 m .69509 .31077 L .6951 .31078 L F
.82209 .36206 m .76013 .41031 L .82209 .36206 L F
.82209 .36206 m .76012 .41031 L .76013 .41031 L F
.52945 .36763 m .47054 .36764 L .52945 .36763 L F
.52945 .36763 m .47055 .36763 L .47054 .36764 L F
.53927 .48611 m .46073 .48613 L .53927 .48612 L F
.53927 .48611 m .46073 .48612 L .46073 .48613 L F
.35673 .33881 m .30491 .31077 L .35672 .33881 L F
.35673 .33881 m .30492 .31077 L .30491 .31077 L F
.30897 .44768 m .23988 .41031 L .30896 .44769 L F
.30897 .44768 m .23989 .4103 L .23988 .41031 L F
.18632 .18193 m .16263 .12798 L .1863 .18193 L F
.18632 .18193 m .16265 .12799 L .16263 .12798 L F
.08176 .23852 m .05018 .16659 L .08173 .23852 L F
.08176 .23852 m .0502 .16659 L .05018 .16659 L F
.74157 .27459 m .6951 .31078 L .74157 .27459 L F
.74157 .27459 m .6951 .31078 L .6951 .31078 L F
.82209 .36206 m .76013 .41032 L .82209 .36206 L F
.82209 .36206 m .76013 .41031 L .76013 .41032 L F
.16265 .12799 m .14817 .07087 L .16263 .12798 L F
.16265 .12799 m .14819 .07088 L .14817 .07087 L F
.0502 .16659 m .03089 .09044 L .05018 .16659 L F
.0502 .16659 m .03092 .09045 L .03089 .09044 L F
.69508 .31077 m .64328 .33881 L .69508 .31077 L F
.69508 .31077 m .64328 .33881 L .64328 .33881 L F
.76011 .4103 m .69105 .4477 L .76011 .4103 L F
.76011 .4103 m .69104 .4477 L .69105 .4477 L F
.14819 .07088 m .1433 .01216 L .14817 .07087 L F
.14819 .07088 m .14333 .01218 L .1433 .01216 L F
.03092 .09045 m .0244 .01216 L .03089 .09044 L F
.03092 .09045 m .02443 .01218 L .0244 .01216 L F
.64327 .33881 m .58756 .35794 L .64328 .33881 L F
.64327 .33881 m .58756 .35794 L .58756 .35794 L F
.69103 .44769 m .61675 .4732 L .69104 .44769 L F
.69103 .44769 m .61675 .4732 L .61675 .4732 L F
.58756 .35794 m .52946 .36764 L .58756 .35794 L F
.58756 .35794 m .52946 .36764 L .52946 .36764 L F
.61674 .47319 m .53927 .48613 L .61675 .47319 L F
.61674 .47319 m .53927 .48613 L .53927 .48613 L F
.81785 .35746 m .76013 .41032 L .82209 .36206 L .479 .526 .746 r
F
.81785 .35746 m .75671 .40508 L .76013 .41032 L F
.81362 .35285 m .75671 .40508 L .81785 .35746 L F
.81362 .35285 m .75329 .39984 L .75671 .40508 L F
.80938 .34825 m .75329 .39984 L .81362 .35285 L F
.80938 .34825 m .74986 .3946 L .75329 .39984 L F
.80514 .34365 m .74986 .3946 L .80938 .34825 L F
.80514 .34365 m .74644 .38936 L .74986 .3946 L F
.8009 .33904 m .74644 .38936 L .80514 .34365 L F
.8009 .33904 m .74302 .38412 L .74644 .38936 L F
.79666 .33444 m .74302 .38412 L .8009 .33904 L F
.79666 .33444 m .73959 .37888 L .74302 .38412 L F
.79243 .32983 m .73959 .37888 L .79666 .33444 L F
.79243 .32983 m .73617 .37364 L .73959 .37888 L F
.78819 .32523 m .73617 .37364 L .79243 .32983 L F
.78819 .32523 m .73275 .3684 L .73617 .37364 L F
.78395 .32063 m .73275 .3684 L .78819 .32523 L F
.78395 .32063 m .72933 .36317 L .73275 .3684 L F
.77971 .31602 m .72933 .36317 L .78395 .32063 L F
.77971 .31602 m .7259 .35793 L .72933 .36317 L F
.77547 .31142 m .7259 .35793 L .77971 .31602 L F
.77547 .31142 m .72248 .35269 L .7259 .35793 L F
.77124 .30682 m .72248 .35269 L .77547 .31142 L F
.77124 .30682 m .71906 .34745 L .72248 .35269 L F
.767 .30221 m .71906 .34745 L .77124 .30682 L F
.767 .30221 m .71563 .34221 L .71906 .34745 L F
.76276 .29761 m .71563 .34221 L .767 .30221 L F
.76276 .29761 m .71221 .33697 L .71563 .34221 L F
.75852 .293 m .71221 .33697 L .76276 .29761 L F
.75852 .293 m .70879 .33173 L .71221 .33697 L F
.75428 .2884 m .70879 .33173 L .75852 .293 L F
.75428 .2884 m .70537 .32649 L .70879 .33173 L F
.75005 .2838 m .70537 .32649 L .75428 .2884 L F
.75005 .2838 m .70194 .32125 L .70537 .32649 L F
.74581 .27919 m .70194 .32125 L .75005 .2838 L F
.74581 .27919 m .69852 .31602 L .70194 .32125 L F
.74157 .27459 m .69852 .31602 L .74581 .27919 L F
.74157 .27459 m .6951 .31078 L .69852 .31602 L F
.30492 .31077 m .25841 .27459 L .30491 .31077 L .787 .211 .013 r
F
.30492 .31077 m .25843 .27459 L .25841 .27459 L F
.23989 .4103 m .17788 .36207 L .23988 .41031 L F
.23989 .4103 m .1779 .36206 L .17788 .36207 L F
.41244 .35794 m .35671 .33881 L .41244 .35794 L F
.41244 .35794 m .35672 .33881 L .35671 .33881 L F
.38325 .47319 m .30895 .4477 L .38325 .4732 L F
.38325 .47319 m .30896 .44769 L .30895 .4477 L F
.69508 .31077 m .64329 .33882 L .69509 .31077 L F
.69508 .31077 m .64328 .33881 L .64329 .33882 L F
.76011 .4103 m .69105 .4477 L .76012 .41031 L F
.76011 .4103 m .69105 .4477 L .69105 .4477 L F
.52945 .36763 m .47054 .36764 L .52946 .36764 L F
.52945 .36763 m .47054 .36764 L .47054 .36764 L F
.53927 .48612 m .46072 .48614 L .53927 .48613 L F
.53927 .48612 m .46073 .48613 L .46072 .48614 L F
.47055 .36763 m .41243 .35794 L .47054 .36764 L F
.47055 .36763 m .41244 .35794 L .41243 .35794 L F
.46073 .48612 m .38325 .47321 L .46073 .48613 L F
.46073 .48612 m .38325 .4732 L .38325 .47321 L F
.64328 .33881 m .58757 .35795 L .64328 .33881 L F
.64328 .33881 m .58756 .35794 L .58757 .35795 L F
.69104 .44769 m .61676 .47321 L .69104 .44769 L F
.69104 .44769 m .61675 .4732 L .61676 .47321 L F
.25843 .27459 m .21851 .23125 L .25841 .27459 L F
.25843 .27459 m .21852 .23125 L .21851 .23125 L F
.1779 .36206 m .12468 .30428 L .17788 .36207 L F
.1779 .36206 m .1247 .30428 L .12468 .30428 L F
.58756 .35794 m .52946 .36764 L .58756 .35794 L F
.58756 .35794 m .52946 .36764 L .52946 .36764 L F
.61675 .47319 m .53928 .48614 L .61675 .4732 L F
.61675 .47319 m .53927 .48613 L .53928 .48614 L F
.69509 .31077 m .64329 .33882 L .69509 .31077 L F
.69509 .31077 m .64329 .33882 L .64329 .33882 L F
.76012 .41031 m .69105 .44771 L .76012 .41031 L F
.76012 .41031 m .69105 .4477 L .69105 .44771 L F
.35672 .33881 m .3049 .31078 L .35671 .33881 L F
.35672 .33881 m .30491 .31077 L .3049 .31078 L F
.30896 .44769 m .23986 .41032 L .30895 .4477 L F
.30896 .44769 m .23988 .41031 L .23986 .41032 L F
.21852 .23125 m .18628 .18193 L .21851 .23125 L F
.21852 .23125 m .1863 .18193 L .18628 .18193 L F
.1247 .30428 m .08171 .23852 L .12468 .30428 L F
.1247 .30428 m .08173 .23852 L .08171 .23852 L F
.64328 .33881 m .58757 .35795 L .64328 .33881 L F
.64328 .33881 m .58757 .35795 L .58757 .35795 L F
.69104 .44769 m .61676 .47322 L .69104 .4477 L F
.69104 .44769 m .61676 .47321 L .61676 .47322 L F
.69509 .31077 m .64329 .33882 L .69509 .31077 L F
.69509 .31077 m .64329 .33882 L .64329 .33882 L F
.76012 .41031 m .69106 .44771 L .76012 .41031 L F
.76012 .41031 m .69105 .44771 L .69106 .44771 L F
.52946 .36764 m .47054 .36765 L .52946 .36764 L F
.52946 .36764 m .47054 .36764 L .47054 .36765 L F
.53927 .48613 m .46072 .48614 L .53927 .48613 L F
.53927 .48613 m .46072 .48614 L .46072 .48614 L F
.41244 .35794 m .35671 .33882 L .41243 .35794 L F
.41244 .35794 m .35671 .33881 L .35671 .33882 L F
.38325 .4732 m .30894 .44771 L .38325 .47321 L F
.38325 .4732 m .30895 .4477 L .30894 .44771 L F
.1863 .18193 m .16261 .12797 L .18628 .18193 L F
.1863 .18193 m .16263 .12798 L .16261 .12797 L F
.08173 .23852 m .05015 .16658 L .08171 .23852 L F
.08173 .23852 m .05018 .16659 L .05015 .16658 L F
.58756 .35794 m .52946 .36765 L .58756 .35794 L F
.58756 .35794 m .52946 .36764 L .52946 .36765 L F
.61675 .4732 m .53928 .48615 L .61675 .4732 L F
.61675 .4732 m .53928 .48614 L .53928 .48615 L F
.47054 .36764 m .41243 .35795 L .47054 .36764 L F
.47054 .36764 m .41243 .35794 L .41243 .35795 L F
.46073 .48613 m .38324 .47322 L .46072 .48614 L F
.46073 .48613 m .38325 .47321 L .38324 .47322 L F
.69509 .31077 m .6433 .33882 L .6951 .31078 L F
.69509 .31077 m .64329 .33882 L .6433 .33882 L F
.76012 .41031 m .69106 .44772 L .76013 .41031 L F
.76012 .41031 m .69106 .44771 L .69106 .44772 L F
.30491 .31077 m .2584 .27459 L .3049 .31078 L F
.30491 .31077 m .25841 .27459 L .2584 .27459 L F
.23988 .41031 m .17787 .36207 L .23986 .41032 L F
.23988 .41031 m .17788 .36207 L .17787 .36207 L F
.64328 .33881 m .58757 .35795 L .64328 .33881 L F
.64328 .33881 m .58757 .35795 L .58757 .35795 L F
.69104 .4477 m .61676 .47322 L .69105 .4477 L F
.69104 .4477 m .61676 .47322 L .61676 .47322 L F
.16263 .12798 m .14815 .07086 L .16261 .12797 L F
.16263 .12798 m .14817 .07087 L .14815 .07086 L F
.05018 .16659 m .03086 .09043 L .05015 .16658 L F
.05018 .16659 m .03089 .09044 L .03086 .09043 L F
.14817 .07087 m .14328 .01215 L .14815 .07086 L F
.14817 .07087 m .1433 .01216 L .14328 .01215 L F
.03089 .09044 m .02438 .01215 L .03086 .09043 L F
.03089 .09044 m .0244 .01216 L .02438 .01215 L F
.6951 .31078 m .6433 .33882 L .6951 .31078 L F
.6951 .31078 m .6433 .33882 L .6433 .33882 L F
.76013 .41031 m .69106 .44772 L .76013 .41032 L F
.76013 .41031 m .69106 .44772 L .69106 .44772 L F
.52946 .36764 m .47054 .36765 L .52946 .36764 L F
.52946 .36764 m .47054 .36765 L .47054 .36765 L F
.53927 .48613 m .46072 .48615 L .53928 .48614 L F
.53927 .48613 m .46072 .48614 L .46072 .48615 L F
.58756 .35794 m .52946 .36765 L .58757 .35795 L F
.58756 .35794 m .52946 .36765 L .52946 .36765 L F
.61675 .4732 m .53928 .48615 L .61676 .47321 L F
.61675 .4732 m .53928 .48615 L .53928 .48615 L F
.64328 .33881 m .58757 .35795 L .64329 .33882 L F
.64328 .33881 m .58757 .35795 L .58757 .35795 L F
.69105 .4477 m .61676 .47323 L .69105 .4477 L F
.69105 .4477 m .61676 .47322 L .61676 .47323 L F
.25841 .27459 m .21849 .23125 L .2584 .27459 L F
.25841 .27459 m .21851 .23125 L .21849 .23125 L F
.17788 .36207 m .12466 .30428 L .17787 .36207 L F
.17788 .36207 m .12468 .30428 L .12466 .30428 L F
.35671 .33881 m .30489 .31078 L .35671 .33882 L F
.35671 .33881 m .3049 .31078 L .30489 .31078 L F
.30895 .4477 m .23985 .41033 L .30894 .44771 L F
.30895 .4477 m .23986 .41032 L .23985 .41033 L F
.75671 .40508 m .69106 .44772 L .76013 .41032 L .479 .526 .746 r
F
.75671 .40508 m .68855 .44199 L .69106 .44772 L F
.75329 .39984 m .68855 .44199 L .75671 .40508 L F
.75329 .39984 m .68604 .43626 L .68855 .44199 L F
.74986 .3946 m .68604 .43626 L .75329 .39984 L F
.74986 .3946 m .68352 .43052 L .68604 .43626 L F
.74644 .38936 m .68352 .43052 L .74986 .3946 L F
.74644 .38936 m .68101 .42479 L .68352 .43052 L F
.74302 .38412 m .68101 .42479 L .74644 .38936 L F
.74302 .38412 m .67849 .41906 L .68101 .42479 L F
.73959 .37888 m .67849 .41906 L .74302 .38412 L F
.73959 .37888 m .67598 .41333 L .67849 .41906 L F
.73617 .37364 m .67598 .41333 L .73959 .37888 L F
.73617 .37364 m .67347 .4076 L .67598 .41333 L F
.73275 .3684 m .67347 .4076 L .73617 .37364 L F
.73275 .3684 m .67095 .40187 L .67347 .4076 L F
.72933 .36317 m .67095 .40187 L .73275 .3684 L F
.72933 .36317 m .66844 .39614 L .67095 .40187 L F
.7259 .35793 m .66844 .39614 L .72933 .36317 L F
.7259 .35793 m .66592 .39041 L .66844 .39614 L F
.72248 .35269 m .66592 .39041 L .7259 .35793 L F
.72248 .35269 m .66341 .38467 L .66592 .39041 L F
.71906 .34745 m .66341 .38467 L .72248 .35269 L F
.71906 .34745 m .6609 .37894 L .66341 .38467 L F
.71563 .34221 m .6609 .37894 L .71906 .34745 L F
.71563 .34221 m .65838 .37321 L .6609 .37894 L F
.71221 .33697 m .65838 .37321 L .71563 .34221 L F
.71221 .33697 m .65587 .36748 L .65838 .37321 L F
.70879 .33173 m .65587 .36748 L .71221 .33697 L F
.70879 .33173 m .65335 .36175 L .65587 .36748 L F
.70537 .32649 m .65335 .36175 L .70879 .33173 L F
.70537 .32649 m .65084 .35602 L .65335 .36175 L F
.70194 .32125 m .65084 .35602 L .70537 .32649 L F
.70194 .32125 m .64833 .35029 L .65084 .35602 L F
.69852 .31602 m .64833 .35029 L .70194 .32125 L F
.69852 .31602 m .64581 .34455 L .64833 .35029 L F
.6951 .31078 m .64581 .34455 L .69852 .31602 L F
.6951 .31078 m .6433 .33882 L .64581 .34455 L F
.47054 .36764 m .41243 .35795 L .47054 .36765 L .787 .211 .013 r
F
.47054 .36764 m .41243 .35795 L .41243 .35795 L F
.46072 .48614 m .38324 .47323 L .46072 .48614 L F
.46072 .48614 m .38324 .47322 L .38324 .47323 L F
.41243 .35794 m .3567 .33882 L .41243 .35795 L F
.41243 .35794 m .35671 .33882 L .3567 .33882 L F
.38325 .47321 m .30894 .44772 L .38324 .47322 L F
.38325 .47321 m .30894 .44771 L .30894 .44772 L F
.21851 .23125 m .18626 .18192 L .21849 .23125 L F
.21851 .23125 m .18628 .18193 L .18626 .18192 L F
.12468 .30428 m .08168 .23852 L .12466 .30428 L F
.12468 .30428 m .08171 .23852 L .08168 .23852 L F
.64329 .33882 m .58757 .35796 L .64329 .33882 L F
.64329 .33882 m .58757 .35795 L .58757 .35796 L F
.69105 .4477 m .61677 .47323 L .69105 .44771 L F
.69105 .4477 m .61676 .47323 L .61677 .47323 L F
.58757 .35795 m .52946 .36765 L .58757 .35795 L F
.58757 .35795 m .52946 .36765 L .52946 .36765 L F
.61676 .47321 m .53928 .48616 L .61676 .47322 L F
.61676 .47321 m .53928 .48615 L .53928 .48616 L F
.52946 .36764 m .47054 .36765 L .52946 .36765 L F
.52946 .36764 m .47054 .36765 L .47054 .36765 L F
.53928 .48614 m .46072 .48616 L .53928 .48615 L F
.53928 .48614 m .46072 .48615 L .46072 .48616 L F
.3049 .31078 m .25839 .27459 L .30489 .31078 L F
.3049 .31078 m .2584 .27459 L .25839 .27459 L F
.23986 .41032 m .17785 .36208 L .23985 .41033 L F
.23986 .41032 m .17787 .36207 L .17785 .36208 L F
.18628 .18193 m .16259 .12797 L .18626 .18192 L F
.18628 .18193 m .16261 .12797 L .16259 .12797 L F
.08171 .23852 m .05012 .16658 L .08168 .23852 L F
.08171 .23852 m .05015 .16658 L .05012 .16658 L F
.64329 .33882 m .58758 .35796 L .64329 .33882 L F
.64329 .33882 m .58757 .35796 L .58758 .35796 L F
.69105 .44771 m .61677 .47324 L .69106 .44771 L F
.69105 .44771 m .61677 .47323 L .61677 .47324 L F
.16261 .12797 m .14813 .07085 L .16259 .12797 L F
.16261 .12797 m .14815 .07086 L .14813 .07085 L F
.05015 .16658 m .03083 .09042 L .05012 .16658 L F
.05015 .16658 m .03086 .09043 L .03083 .09042 L F
.47054 .36765 m .41242 .35796 L .47054 .36765 L F
.47054 .36765 m .41243 .35795 L .41242 .35796 L F
.46072 .48614 m .38323 .47323 L .46072 .48615 L F
.46072 .48614 m .38324 .47323 L .38323 .47323 L F
.58757 .35795 m .52946 .36766 L .58757 .35795 L F
.58757 .35795 m .52946 .36765 L .52946 .36766 L F
.61676 .47322 m .53928 .48617 L .61676 .47322 L F
.61676 .47322 m .53928 .48616 L .53928 .48617 L F
.35671 .33882 m .30488 .31078 L .3567 .33882 L F
.35671 .33882 m .30489 .31078 L .30488 .31078 L F
.30894 .44771 m .23984 .41034 L .30894 .44772 L F
.30894 .44771 m .23985 .41033 L .23984 .41034 L F
.14815 .07086 m .14326 .01213 L .14813 .07085 L F
.14815 .07086 m .14328 .01215 L .14326 .01213 L F
.03086 .09043 m .02435 .01213 L .03083 .09042 L F
.03086 .09043 m .02438 .01215 L .02435 .01213 L F
.41243 .35795 m .3567 .33883 L .41243 .35795 L F
.41243 .35795 m .3567 .33882 L .3567 .33883 L F
.38324 .47322 m .30893 .44773 L .38324 .47323 L F
.38324 .47322 m .30894 .44772 L .30893 .44773 L F
.2584 .27459 m .21848 .23125 L .25839 .27459 L F
.2584 .27459 m .21849 .23125 L .21848 .23125 L F
.17787 .36207 m .12464 .30429 L .17785 .36208 L F
.17787 .36207 m .12466 .30428 L .12464 .30429 L F
.52946 .36765 m .47054 .36766 L .52946 .36765 L F
.52946 .36765 m .47054 .36765 L .47054 .36766 L F
.53928 .48615 m .46072 .48617 L .53928 .48615 L F
.53928 .48615 m .46072 .48616 L .46072 .48617 L F
.64329 .33882 m .58758 .35796 L .6433 .33882 L F
.64329 .33882 m .58758 .35796 L .58758 .35796 L F
.69106 .44771 m .61677 .47324 L .69106 .44772 L F
.69106 .44771 m .61677 .47324 L .61677 .47324 L F
.58757 .35795 m .52946 .36766 L .58757 .35795 L F
.58757 .35795 m .52946 .36766 L .52946 .36766 L F
.61676 .47322 m .53928 .48617 L .61676 .47323 L F
.61676 .47322 m .53928 .48617 L .53928 .48617 L F
.21849 .23125 m .18624 .18192 L .21848 .23125 L F
.21849 .23125 m .18626 .18192 L .18624 .18192 L F
.12466 .30428 m .08166 .23852 L .12464 .30429 L F
.12466 .30428 m .08168 .23852 L .08166 .23852 L F
.6433 .33882 m .58758 .35796 L .6433 .33882 L F
.6433 .33882 m .58758 .35796 L .58758 .35796 L F
.69106 .44772 m .61677 .47325 L .69106 .44772 L F
.69106 .44772 m .61677 .47324 L .61677 .47325 L F
.47054 .36765 m .41242 .35796 L .47054 .36765 L F
.47054 .36765 m .41242 .35796 L .41242 .35796 L F
.46072 .48615 m .38323 .47324 L .46072 .48616 L F
.46072 .48615 m .38323 .47323 L .38323 .47324 L F
.30489 .31078 m .25838 .2746 L .30488 .31078 L F
.30489 .31078 m .25839 .27459 L .25838 .2746 L F
.23985 .41033 m .17783 .36209 L .23984 .41034 L F
.23985 .41033 m .17785 .36208 L .17783 .36209 L F
.52946 .36765 m .47054 .36766 L .52946 .36765 L F
.52946 .36765 m .47054 .36766 L .47054 .36766 L F
.53928 .48615 m .46072 .48618 L .53928 .48616 L F
.53928 .48615 m .46072 .48617 L .46072 .48618 L F
.41243 .35795 m .35669 .33883 L .41242 .35796 L F
.41243 .35795 m .3567 .33883 L .35669 .33883 L F
.38324 .47323 m .30892 .44774 L .38323 .47323 L F
.38324 .47323 m .30893 .44773 L .30892 .44774 L F
.3567 .33882 m .30487 .31079 L .3567 .33883 L F
.3567 .33882 m .30488 .31078 L .30487 .31079 L F
.30894 .44772 m .23983 .41034 L .30893 .44773 L F
.30894 .44772 m .23984 .41034 L .23983 .41034 L F
.18626 .18192 m .16257 .12796 L .18624 .18192 L F
.18626 .18192 m .16259 .12797 L .16257 .12796 L F
.08168 .23852 m .05009 .16657 L .08166 .23852 L F
.08168 .23852 m .05012 .16658 L .05009 .16657 L F
.58757 .35795 m .52946 .36766 L .58757 .35796 L F
.58757 .35795 m .52946 .36766 L .52946 .36766 L F
.61676 .47323 m .53928 .48618 L .61677 .47323 L F
.61676 .47323 m .53928 .48617 L .53928 .48618 L F
.68855 .44199 m .61677 .47325 L .69106 .44772 L .479 .526 .746 r
F
.68855 .44199 m .61524 .46718 L .61677 .47325 L F
.68604 .43626 m .61524 .46718 L .68855 .44199 L F
.68604 .43626 m .6137 .46111 L .61524 .46718 L F
.68352 .43052 m .6137 .46111 L .68604 .43626 L F
.68352 .43052 m .61217 .45504 L .6137 .46111 L F
.68101 .42479 m .61217 .45504 L .68352 .43052 L F
.68101 .42479 m .61063 .44898 L .61217 .45504 L F
.67849 .41906 m .61063 .44898 L .68101 .42479 L F
.67849 .41906 m .60909 .44291 L .61063 .44898 L F
.67598 .41333 m .60909 .44291 L .67849 .41906 L F
.67598 .41333 m .60756 .43684 L .60909 .44291 L F
.67347 .4076 m .60756 .43684 L .67598 .41333 L F
.67347 .4076 m .60602 .43077 L .60756 .43684 L F
.67095 .40187 m .60602 .43077 L .67347 .4076 L F
.67095 .40187 m .60448 .42471 L .60602 .43077 L F
.66844 .39614 m .60448 .42471 L .67095 .40187 L F
.66844 .39614 m .60295 .41864 L .60448 .42471 L F
.66592 .39041 m .60295 .41864 L .66844 .39614 L F
.66592 .39041 m .60141 .41257 L .60295 .41864 L F
.66341 .38467 m .60141 .41257 L .66592 .39041 L F
.66341 .38467 m .59987 .4065 L .60141 .41257 L F
.6609 .37894 m .59987 .4065 L .66341 .38467 L F
.6609 .37894 m .59834 .40044 L .59987 .4065 L F
.65838 .37321 m .59834 .40044 L .6609 .37894 L F
.65838 .37321 m .5968 .39437 L .59834 .40044 L F
.65587 .36748 m .5968 .39437 L .65838 .37321 L F
.65587 .36748 m .59526 .3883 L .5968 .39437 L F
.65335 .36175 m .59526 .3883 L .65587 .36748 L F
.65335 .36175 m .59373 .38223 L .59526 .3883 L F
.65084 .35602 m .59373 .38223 L .65335 .36175 L F
.65084 .35602 m .59219 .37617 L .59373 .38223 L F
.64833 .35029 m .59219 .37617 L .65084 .35602 L F
.64833 .35029 m .59065 .3701 L .59219 .37617 L F
.64581 .34455 m .59065 .3701 L .64833 .35029 L F
.64581 .34455 m .58912 .36403 L .59065 .3701 L F
.6433 .33882 m .58912 .36403 L .64581 .34455 L F
.6433 .33882 m .58758 .35796 L .58912 .36403 L F
.16259 .12797 m .1481 .07084 L .16257 .12796 L .787 .211 .013 r
F
.16259 .12797 m .14813 .07085 L .1481 .07084 L F
.05012 .16658 m .0308 .09041 L .05009 .16657 L F
.05012 .16658 m .03083 .09042 L .0308 .09041 L F
.25839 .27459 m .21846 .23124 L .25838 .2746 L F
.25839 .27459 m .21848 .23125 L .21846 .23124 L F
.17785 .36208 m .12461 .30429 L .17783 .36209 L F
.17785 .36208 m .12464 .30429 L .12461 .30429 L F
.47054 .36765 m .41242 .35797 L .47054 .36766 L F
.47054 .36765 m .41242 .35796 L .41242 .35797 L F
.46072 .48616 m .38322 .47325 L .46072 .48617 L F
.46072 .48616 m .38323 .47324 L .38322 .47325 L F
.14813 .07085 m .14324 .01212 L .1481 .07084 L F
.14813 .07085 m .14326 .01213 L .14324 .01212 L F
.03083 .09042 m .02432 .01212 L .0308 .09041 L F
.03083 .09042 m .02435 .01213 L .02432 .01212 L F
.52946 .36765 m .47054 .36767 L .52946 .36766 L F
.52946 .36765 m .47054 .36766 L .47054 .36767 L F
.53928 .48616 m .46072 .48618 L .53928 .48617 L F
.53928 .48616 m .46072 .48618 L .46072 .48618 L F
.58757 .35796 m .52946 .36767 L .58758 .35796 L F
.58757 .35796 m .52946 .36766 L .52946 .36767 L F
.61677 .47323 m .53928 .48619 L .61677 .47324 L F
.61677 .47323 m .53928 .48618 L .53928 .48619 L F
.30488 .31078 m .25836 .2746 L .30487 .31079 L F
.30488 .31078 m .25838 .2746 L .25836 .2746 L F
.23984 .41034 m .17782 .36209 L .23983 .41034 L F
.23984 .41034 m .17783 .36209 L .17782 .36209 L F
.41242 .35796 m .35668 .33883 L .41242 .35796 L F
.41242 .35796 m .35669 .33883 L .35668 .33883 L F
.38323 .47323 m .30891 .44774 L .38323 .47324 L F
.38323 .47323 m .30892 .44774 L .30891 .44774 L F
.21848 .23125 m .18623 .18191 L .21846 .23124 L F
.21848 .23125 m .18624 .18192 L .18623 .18191 L F
.12464 .30429 m .08163 .23852 L .12461 .30429 L F
.12464 .30429 m .08166 .23852 L .08163 .23852 L F
.3567 .33883 m .30486 .31079 L .35669 .33883 L F
.3567 .33883 m .30487 .31079 L .30486 .31079 L F
.30893 .44773 m .23981 .41035 L .30892 .44774 L F
.30893 .44773 m .23983 .41034 L .23981 .41035 L F
.58758 .35796 m .52946 .36767 L .58758 .35796 L F
.58758 .35796 m .52946 .36767 L .52946 .36767 L F
.61677 .47324 m .53928 .48619 L .61677 .47324 L F
.61677 .47324 m .53928 .48619 L .53928 .48619 L F
.52946 .36766 m .47054 .36767 L .52946 .36766 L F
.52946 .36766 m .47054 .36767 L .47054 .36767 L F
.53928 .48617 m .46072 .48619 L .53928 .48617 L F
.53928 .48617 m .46072 .48618 L .46072 .48619 L F
.47054 .36766 m .41241 .35797 L .47054 .36766 L F
.47054 .36766 m .41242 .35797 L .41241 .35797 L F
.46072 .48617 m .38322 .47326 L .46072 .48618 L F
.46072 .48617 m .38322 .47325 L .38322 .47326 L F
.18624 .18192 m .16255 .12795 L .18623 .18191 L F
.18624 .18192 m .16257 .12796 L .16255 .12795 L F
.08166 .23852 m .05007 .16657 L .08163 .23852 L F
.08166 .23852 m .05009 .16657 L .05007 .16657 L F
.25838 .2746 m .21845 .23124 L .25836 .2746 L F
.25838 .2746 m .21846 .23124 L .21845 .23124 L F
.17783 .36209 m .12459 .30429 L .17782 .36209 L F
.17783 .36209 m .12461 .30429 L .12459 .30429 L F
.58758 .35796 m .52946 .36767 L .58758 .35796 L F
.58758 .35796 m .52946 .36767 L .52946 .36767 L F
.61677 .47324 m .53929 .4862 L .61677 .47325 L F
.61677 .47324 m .53928 .48619 L .53929 .4862 L F
.16257 .12796 m .14808 .07083 L .16255 .12795 L F
.16257 .12796 m .1481 .07084 L .14808 .07083 L F
.05009 .16657 m .03078 .0904 L .05007 .16657 L F
.05009 .16657 m .0308 .09041 L .03078 .0904 L F
.41242 .35796 m .35668 .33884 L .41242 .35797 L F
.41242 .35796 m .35668 .33883 L .35668 .33884 L F
.38323 .47324 m .3089 .44775 L .38322 .47325 L F
.38323 .47324 m .30891 .44774 L .3089 .44775 L F
.52946 .36766 m .47054 .36767 L .52946 .36766 L F
.52946 .36766 m .47054 .36767 L .47054 .36767 L F
.53928 .48617 m .46071 .4862 L .53928 .48618 L F
.53928 .48617 m .46072 .48619 L .46071 .4862 L F
.1481 .07084 m .14321 .0121 L .14808 .07083 L F
.1481 .07084 m .14324 .01212 L .14321 .0121 L F
.0308 .09041 m .02429 .0121 L .03078 .0904 L F
.0308 .09041 m .02432 .01212 L .02429 .0121 L F
.30487 .31079 m .25835 .2746 L .30486 .31079 L F
.30487 .31079 m .25836 .2746 L .25835 .2746 L F
.23983 .41034 m .1778 .3621 L .23981 .41035 L F
.23983 .41034 m .17782 .36209 L .1778 .3621 L F
.35669 .33883 m .30485 .31079 L .35668 .33883 L F
.35669 .33883 m .30486 .31079 L .30485 .31079 L F
.30892 .44774 m .2398 .41036 L .30891 .44774 L F
.30892 .44774 m .23981 .41035 L .2398 .41036 L F
.47054 .36766 m .41241 .35797 L .47054 .36767 L F
.47054 .36766 m .41241 .35797 L .41241 .35797 L F
.46072 .48618 m .38321 .47327 L .46072 .48618 L F
.46072 .48618 m .38322 .47326 L .38321 .47327 L F
.21846 .23124 m .18621 .18191 L .21845 .23124 L F
.21846 .23124 m .18623 .18191 L .18621 .18191 L F
.12461 .30429 m .08161 .23852 L .12459 .30429 L F
.12461 .30429 m .08163 .23852 L .08161 .23852 L F
.61524 .46718 m .53929 .4862 L .61677 .47325 L .479 .526 .746 r
F
.61524 .46718 m .53877 .47996 L .53929 .4862 L F
.6137 .46111 m .53877 .47996 L .61524 .46718 L F
.6137 .46111 m .53825 .47372 L .53877 .47996 L F
.61217 .45504 m .53825 .47372 L .6137 .46111 L F
.61217 .45504 m .53774 .46749 L .53825 .47372 L F
.61063 .44898 m .53774 .46749 L .61217 .45504 L F
.61063 .44898 m .53722 .46125 L .53774 .46749 L F
.60909 .44291 m .53722 .46125 L .61063 .44898 L F
.60909 .44291 m .5367 .45501 L .53722 .46125 L F
.60756 .43684 m .5367 .45501 L .60909 .44291 L F
.60756 .43684 m .53618 .44877 L .5367 .45501 L F
.60602 .43077 m .53618 .44877 L .60756 .43684 L F
.60602 .43077 m .53567 .44253 L .53618 .44877 L F
.60448 .42471 m .53567 .44253 L .60602 .43077 L F
.60448 .42471 m .53515 .4363 L .53567 .44253 L F
.60295 .41864 m .53515 .4363 L .60448 .42471 L F
.60295 .41864 m .53463 .43006 L .53515 .4363 L F
.60141 .41257 m .53463 .43006 L .60295 .41864 L F
.60141 .41257 m .53412 .42382 L .53463 .43006 L F
.59987 .4065 m .53412 .42382 L .60141 .41257 L F
.59987 .4065 m .5336 .41758 L .53412 .42382 L F
.59834 .40044 m .5336 .41758 L .59987 .4065 L F
.59834 .40044 m .53308 .41134 L .5336 .41758 L F
.5968 .39437 m .53308 .41134 L .59834 .40044 L F
.5968 .39437 m .53257 .4051 L .53308 .41134 L F
.59526 .3883 m .53257 .4051 L .5968 .39437 L F
.59526 .3883 m .53205 .39887 L .53257 .4051 L F
.59373 .38223 m .53205 .39887 L .59526 .3883 L F
.59373 .38223 m .53153 .39263 L .53205 .39887 L F
.59219 .37617 m .53153 .39263 L .59373 .38223 L F
.59219 .37617 m .53102 .38639 L .53153 .39263 L F
.59065 .3701 m .53102 .38639 L .59219 .37617 L F
.59065 .3701 m .5305 .38015 L .53102 .38639 L F
.58912 .36403 m .5305 .38015 L .59065 .3701 L F
.58912 .36403 m .52998 .37391 L .5305 .38015 L F
.58758 .35796 m .52998 .37391 L .58912 .36403 L F
.58758 .35796 m .52946 .36767 L .52998 .37391 L F
.52946 .36766 m .47053 .36768 L .52946 .36767 L .787 .211 .013 r
F
.52946 .36766 m .47054 .36767 L .47053 .36768 L F
.53928 .48618 m .46071 .48621 L .53928 .48619 L F
.53928 .48618 m .46071 .4862 L .46071 .48621 L F
.41242 .35797 m .35667 .33884 L .41241 .35797 L F
.41242 .35797 m .35668 .33884 L .35667 .33884 L F
.38322 .47325 m .30889 .44776 L .38322 .47326 L F
.38322 .47325 m .3089 .44775 L .30889 .44776 L F
.18623 .18191 m .16253 .12794 L .18621 .18191 L F
.18623 .18191 m .16255 .12795 L .16253 .12794 L F
.08163 .23852 m .05004 .16656 L .08161 .23852 L F
.08163 .23852 m .05007 .16657 L .05004 .16656 L F
.25836 .2746 m .21843 .23124 L .25835 .2746 L F
.25836 .2746 m .21845 .23124 L .21843 .23124 L F
.17782 .36209 m .12457 .30429 L .1778 .3621 L F
.17782 .36209 m .12459 .30429 L .12457 .30429 L F
.47054 .36767 m .41241 .35798 L .47054 .36767 L F
.47054 .36767 m .41241 .35797 L .41241 .35798 L F
.46072 .48618 m .38321 .47328 L .46072 .48619 L F
.46072 .48618 m .38321 .47327 L .38321 .47328 L F
.35668 .33883 m .30484 .3108 L .35668 .33884 L F
.35668 .33883 m .30485 .31079 L .30484 .3108 L F
.30891 .44774 m .23979 .41037 L .3089 .44775 L F
.30891 .44774 m .2398 .41036 L .23979 .41037 L F
.30486 .31079 m .25834 .2746 L .30485 .31079 L F
.30486 .31079 m .25835 .2746 L .25834 .2746 L F
.23981 .41035 m .17778 .3621 L .2398 .41036 L F
.23981 .41035 m .1778 .3621 L .17778 .3621 L F
.16255 .12795 m .14806 .07082 L .16253 .12794 L F
.16255 .12795 m .14808 .07083 L .14806 .07082 L F
.05007 .16657 m .03075 .09039 L .05004 .16656 L F
.05007 .16657 m .03078 .0904 L .03075 .09039 L F
.52946 .36767 m .47053 .36768 L .52946 .36767 L F
.52946 .36767 m .47053 .36768 L .47053 .36768 L F
.53928 .48619 m .46071 .48622 L .53928 .48619 L F
.53928 .48619 m .46071 .48621 L .46071 .48622 L F
.14808 .07083 m .14319 .01209 L .14806 .07082 L F
.14808 .07083 m .14321 .0121 L .14319 .01209 L F
.03078 .0904 m .02426 .01209 L .03075 .09039 L F
.03078 .0904 m .02429 .0121 L .02426 .01209 L F
.21845 .23124 m .18619 .18191 L .21843 .23124 L F
.21845 .23124 m .18621 .18191 L .18619 .18191 L F
.12459 .30429 m .08159 .23852 L .12457 .30429 L F
.12459 .30429 m .08161 .23852 L .08159 .23852 L F
.41241 .35797 m .35666 .33885 L .41241 .35797 L F
.41241 .35797 m .35667 .33884 L .35666 .33885 L F
.38322 .47326 m .30889 .44777 L .38321 .47327 L F
.38322 .47326 m .30889 .44776 L .30889 .44777 L F
.47054 .36767 m .4124 .35798 L .47054 .36767 L F
.47054 .36767 m .41241 .35798 L .4124 .35798 L F
.46072 .48619 m .3832 .47329 L .46071 .4862 L F
.46072 .48619 m .38321 .47328 L .3832 .47329 L F
.52946 .36767 m .47053 .36769 L .52946 .36767 L F
.52946 .36767 m .47053 .36768 L .47053 .36769 L F
.53928 .48619 m .46071 .48622 L .53929 .4862 L F
.53928 .48619 m .46071 .48622 L .46071 .48622 L F
.25835 .2746 m .21841 .23124 L .25834 .2746 L F
.25835 .2746 m .21843 .23124 L .21841 .23124 L F
.1778 .3621 m .12455 .3043 L .17778 .3621 L F
.1778 .3621 m .12457 .30429 L .12455 .3043 L F
.35668 .33884 m .30483 .3108 L .35667 .33884 L F
.35668 .33884 m .30484 .3108 L .30483 .3108 L F
.3089 .44775 m .23978 .41037 L .30889 .44776 L F
.3089 .44775 m .23979 .41037 L .23978 .41037 L F
.18621 .18191 m .16251 .12794 L .18619 .18191 L F
.18621 .18191 m .16253 .12794 L .16251 .12794 L F
.08161 .23852 m .05001 .16656 L .08159 .23852 L F
.08161 .23852 m .05004 .16656 L .05001 .16656 L F
.30485 .31079 m .25832 .2746 L .30484 .3108 L F
.30485 .31079 m .25834 .2746 L .25832 .2746 L F
.2398 .41036 m .17777 .36211 L .23979 .41037 L F
.2398 .41036 m .17778 .3621 L .17777 .36211 L F
.47054 .36767 m .4124 .35799 L .47053 .36768 L F
.47054 .36767 m .4124 .35798 L .4124 .35799 L F
.46071 .4862 m .3832 .4733 L .46071 .48621 L F
.46071 .4862 m .3832 .47329 L .3832 .4733 L F
.53877 .47996 m .46071 .48622 L .53929 .4862 L .479 .526 .746 r
F
.46071 .48621 m .3832 .4733 L .46071 .48622 L .787 .211 .013 r
F
.46071 .48621 m .3832 .4733 L .3832 .4733 L F
.46071 .48622 m .38319 .47331 L .46071 .48622 L F
.46071 .48622 m .3832 .4733 L .38319 .47331 L F
.53877 .47996 m .46123 .47999 L .46071 .48622 L .479 .526 .746 r
F
.53825 .47372 m .46123 .47999 L .53877 .47996 L F
.53825 .47372 m .46174 .47375 L .46123 .47999 L F
.53774 .46749 m .46174 .47375 L .53825 .47372 L F
.53774 .46749 m .46226 .46751 L .46174 .47375 L F
.53722 .46125 m .46226 .46751 L .53774 .46749 L F
.53722 .46125 m .46278 .46127 L .46226 .46751 L F
.5367 .45501 m .46278 .46127 L .53722 .46125 L F
.5367 .45501 m .4633 .45503 L .46278 .46127 L F
.53618 .44877 m .4633 .45503 L .5367 .45501 L F
.53618 .44877 m .46381 .44879 L .4633 .45503 L F
.53567 .44253 m .46381 .44879 L .53618 .44877 L F
.53567 .44253 m .46433 .44255 L .46381 .44879 L F
.53515 .4363 m .46433 .44255 L .53567 .44253 L F
.53515 .4363 m .46485 .43631 L .46433 .44255 L F
.53463 .43006 m .46485 .43631 L .53515 .4363 L F
.53463 .43006 m .46536 .43007 L .46485 .43631 L F
.53412 .42382 m .46536 .43007 L .53463 .43006 L F
.53412 .42382 m .46588 .42384 L .46536 .43007 L F
.5336 .41758 m .46588 .42384 L .53412 .42382 L F
.5336 .41758 m .4664 .4176 L .46588 .42384 L F
.53308 .41134 m .4664 .4176 L .5336 .41758 L F
.53308 .41134 m .46691 .41136 L .4664 .4176 L F
.53257 .4051 m .46691 .41136 L .53308 .41134 L F
.53257 .4051 m .46743 .40512 L .46691 .41136 L F
.53205 .39887 m .46743 .40512 L .53257 .4051 L F
.53205 .39887 m .46795 .39888 L .46743 .40512 L F
.53153 .39263 m .46795 .39888 L .53205 .39887 L F
.53153 .39263 m .46846 .39264 L .46795 .39888 L F
.53102 .38639 m .46846 .39264 L .53153 .39263 L F
.53102 .38639 m .46898 .3864 L .46846 .39264 L F
.5305 .38015 m .46898 .3864 L .53102 .38639 L F
.5305 .38015 m .4695 .38016 L .46898 .3864 L F
.52998 .37391 m .4695 .38016 L .5305 .38015 L F
.52998 .37391 m .47002 .37392 L .4695 .38016 L F
.52946 .36767 m .47002 .37392 L .52998 .37391 L F
.52946 .36767 m .47053 .36769 L .47002 .37392 L F
.41241 .35797 m .35666 .33885 L .41241 .35798 L .787 .211 .013 r
F
.41241 .35797 m .35666 .33885 L .35666 .33885 L F
.38321 .47327 m .30888 .44778 L .38321 .47328 L F
.38321 .47327 m .30889 .44777 L .30888 .44778 L F
.16253 .12794 m .14804 .0708 L .16251 .12794 L F
.16253 .12794 m .14806 .07082 L .14804 .0708 L F
.05004 .16656 m .03072 .09038 L .05001 .16656 L F
.05004 .16656 m .03075 .09039 L .03072 .09038 L F
.14806 .07082 m .14317 .01207 L .14804 .0708 L F
.14806 .07082 m .14319 .01209 L .14317 .01207 L F
.03075 .09039 m .02423 .01207 L .03072 .09038 L F
.03075 .09039 m .02426 .01209 L .02423 .01207 L F
.21843 .23124 m .18617 .1819 L .21841 .23124 L F
.21843 .23124 m .18619 .18191 L .18617 .1819 L F
.12457 .30429 m .08156 .23851 L .12455 .3043 L F
.12457 .30429 m .08159 .23852 L .08156 .23851 L F
.35667 .33884 m .30482 .3108 L .35666 .33885 L F
.35667 .33884 m .30483 .3108 L .30482 .3108 L F
.30889 .44776 m .23976 .41038 L .30889 .44777 L F
.30889 .44776 m .23978 .41037 L .23976 .41038 L F
.47053 .36768 m .4124 .35799 L .47053 .36768 L F
.47053 .36768 m .4124 .35799 L .4124 .35799 L F
.25834 .2746 m .2184 .23124 L .25832 .2746 L F
.25834 .2746 m .21841 .23124 L .2184 .23124 L F
.17778 .3621 m .12453 .3043 L .17777 .36211 L F
.17778 .3621 m .12455 .3043 L .12453 .3043 L F
.30484 .3108 m .25831 .2746 L .30483 .3108 L F
.30484 .3108 m .25832 .2746 L .25831 .2746 L F
.23979 .41037 m .17775 .36212 L .23978 .41037 L F
.23979 .41037 m .17777 .36211 L .17775 .36212 L F
.41241 .35798 m .35665 .33885 L .4124 .35798 L F
.41241 .35798 m .35666 .33885 L .35665 .33885 L F
.38321 .47328 m .30887 .44779 L .3832 .47329 L F
.38321 .47328 m .30888 .44778 L .30887 .44779 L F
.18619 .18191 m .16249 .12793 L .18617 .1819 L F
.18619 .18191 m .16251 .12794 L .16249 .12793 L F
.08159 .23852 m .04999 .16655 L .08156 .23851 L F
.08159 .23852 m .05001 .16656 L .04999 .16655 L F
.16251 .12794 m .14802 .07079 L .16249 .12793 L F
.16251 .12794 m .14804 .0708 L .14802 .07079 L F
.05001 .16656 m .03069 .09037 L .04999 .16655 L F
.05001 .16656 m .03072 .09038 L .03069 .09037 L F
.47053 .36768 m .41239 .358 L .47053 .36769 L F
.47053 .36768 m .4124 .35799 L .41239 .358 L F
.35666 .33885 m .30481 .3108 L .35666 .33885 L F
.35666 .33885 m .30482 .3108 L .30481 .3108 L F
.30889 .44777 m .23975 .41039 L .30888 .44778 L F
.30889 .44777 m .23976 .41038 L .23975 .41039 L F
.21841 .23124 m .18615 .1819 L .2184 .23124 L F
.21841 .23124 m .18617 .1819 L .18615 .1819 L F
.12455 .3043 m .08154 .23851 L .12453 .3043 L F
.12455 .3043 m .08156 .23851 L .08154 .23851 L F
.14804 .0708 m .14315 .01206 L .14802 .07079 L F
.14804 .0708 m .14317 .01207 L .14315 .01206 L F
.03072 .09038 m .0242 .01206 L .03069 .09037 L F
.03072 .09038 m .02423 .01207 L .0242 .01206 L F
.4124 .35798 m .35665 .33886 L .4124 .35799 L F
.4124 .35798 m .35665 .33885 L .35665 .33886 L F
.3832 .47329 m .30886 .4478 L .3832 .4733 L F
.3832 .47329 m .30887 .44779 L .30886 .4478 L F
.30483 .3108 m .2583 .2746 L .30482 .3108 L F
.30483 .3108 m .25831 .2746 L .2583 .2746 L F
.23978 .41037 m .17773 .36212 L .23976 .41038 L F
.23978 .41037 m .17775 .36212 L .17773 .36212 L F
.25832 .2746 m .21838 .23124 L .25831 .2746 L F
.25832 .2746 m .2184 .23124 L .21838 .23124 L F
.17777 .36211 m .12451 .3043 L .17775 .36212 L F
.17777 .36211 m .12453 .3043 L .12451 .3043 L F
.46123 .47999 m .38319 .47331 L .46071 .48622 L .479 .526 .746 r
F
.3832 .4733 m .30885 .44781 L .3832 .4733 L .787 .211 .013 r
F
.3832 .4733 m .30886 .4478 L .30885 .44781 L F
.3832 .4733 m .30884 .44781 L .38319 .47331 L F
.3832 .4733 m .30885 .44781 L .30884 .44781 L F
.46123 .47999 m .38473 .46724 L .38319 .47331 L .479 .526 .746 r
F
.46174 .47375 m .38473 .46724 L .46123 .47999 L F
.46174 .47375 m .38626 .46117 L .38473 .46724 L F
.46226 .46751 m .38626 .46117 L .46174 .47375 L F
.46226 .46751 m .3878 .4551 L .38626 .46117 L F
.46278 .46127 m .3878 .4551 L .46226 .46751 L F
.46278 .46127 m .38934 .44904 L .3878 .4551 L F
.4633 .45503 m .38934 .44904 L .46278 .46127 L F
.4633 .45503 m .39088 .44297 L .38934 .44904 L F
.46381 .44879 m .39088 .44297 L .4633 .45503 L F
.46381 .44879 m .39241 .4369 L .39088 .44297 L F
.46433 .44255 m .39241 .4369 L .46381 .44879 L F
.46433 .44255 m .39395 .43083 L .39241 .4369 L F
.46485 .43631 m .39395 .43083 L .46433 .44255 L F
.46485 .43631 m .39549 .42476 L .39395 .43083 L F
.46536 .43007 m .39549 .42476 L .46485 .43631 L F
.46536 .43007 m .39702 .41869 L .39549 .42476 L F
.46588 .42384 m .39702 .41869 L .46536 .43007 L F
.46588 .42384 m .39856 .41262 L .39702 .41869 L F
.4664 .4176 m .39856 .41262 L .46588 .42384 L F
.4664 .4176 m .4001 .40655 L .39856 .41262 L F
.46691 .41136 m .4001 .40655 L .4664 .4176 L F
.46691 .41136 m .40163 .40048 L .4001 .40655 L F
.46743 .40512 m .40163 .40048 L .46691 .41136 L F
.46743 .40512 m .40317 .39441 L .40163 .40048 L F
.46795 .39888 m .40317 .39441 L .46743 .40512 L F
.46795 .39888 m .40471 .38834 L .40317 .39441 L F
.46846 .39264 m .40471 .38834 L .46795 .39888 L F
.46846 .39264 m .40625 .38227 L .40471 .38834 L F
.46898 .3864 m .40625 .38227 L .46846 .39264 L F
.46898 .3864 m .40778 .3762 L .40625 .38227 L F
.4695 .38016 m .40778 .3762 L .46898 .3864 L F
.4695 .38016 m .40932 .37013 L .40778 .3762 L F
.47002 .37392 m .40932 .37013 L .4695 .38016 L F
.47002 .37392 m .41086 .36406 L .40932 .37013 L F
.47053 .36769 m .41086 .36406 L .47002 .37392 L F
.47053 .36769 m .41239 .358 L .41086 .36406 L F
.18617 .1819 m .16247 .12792 L .18615 .1819 L .787 .211 .013 r
F
.18617 .1819 m .16249 .12793 L .16247 .12792 L F
.08156 .23851 m .04996 .16655 L .08154 .23851 L F
.08156 .23851 m .04999 .16655 L .04996 .16655 L F
.35666 .33885 m .3048 .31081 L .35665 .33885 L F
.35666 .33885 m .30481 .3108 L .3048 .31081 L F
.30888 .44778 m .23974 .4104 L .30887 .44779 L F
.30888 .44778 m .23975 .41039 L .23974 .4104 L F
.4124 .35799 m .35664 .33886 L .4124 .35799 L F
.4124 .35799 m .35665 .33886 L .35664 .33886 L F
.16249 .12793 m .14799 .07078 L .16247 .12792 L F
.16249 .12793 m .14802 .07079 L .14799 .07078 L F
.04999 .16655 m .03066 .09036 L .04996 .16655 L F
.04999 .16655 m .03069 .09037 L .03066 .09036 L F
.2184 .23124 m .18613 .18189 L .21838 .23124 L F
.2184 .23124 m .18615 .1819 L .18613 .18189 L F
.12453 .3043 m .08151 .23851 L .12451 .3043 L F
.12453 .3043 m .08154 .23851 L .08151 .23851 L F
.30482 .3108 m .25829 .2746 L .30481 .3108 L F
.30482 .3108 m .2583 .2746 L .25829 .2746 L F
.23976 .41038 m .17772 .36213 L .23975 .41039 L F
.23976 .41038 m .17773 .36212 L .17772 .36213 L F
.25831 .2746 m .21837 .23124 L .2583 .2746 L F
.25831 .2746 m .21838 .23124 L .21837 .23124 L F
.17775 .36212 m .12449 .30431 L .17773 .36212 L F
.17775 .36212 m .12451 .3043 L .12449 .30431 L F
.14802 .07079 m .14312 .01204 L .14799 .07078 L F
.14802 .07079 m .14315 .01206 L .14312 .01204 L F
.03069 .09037 m .02417 .01204 L .03066 .09036 L F
.03069 .09037 m .0242 .01206 L .02417 .01204 L F
.4124 .35799 m .35663 .33887 L .41239 .358 L F
.4124 .35799 m .35664 .33886 L .35663 .33887 L F
.35665 .33885 m .30479 .31081 L .35665 .33886 L F
.35665 .33885 m .3048 .31081 L .30479 .31081 L F
.30887 .44779 m .23973 .41041 L .30886 .4478 L F
.30887 .44779 m .23974 .4104 L .23973 .41041 L F
.18615 .1819 m .16245 .12791 L .18613 .18189 L F
.18615 .1819 m .16247 .12792 L .16245 .12791 L F
.08154 .23851 m .04993 .16654 L .08151 .23851 L F
.08154 .23851 m .04996 .16655 L .04993 .16654 L F
.30481 .3108 m .25827 .27461 L .3048 .31081 L F
.30481 .3108 m .25829 .2746 L .25827 .27461 L F
.23975 .41039 m .1777 .36213 L .23974 .4104 L F
.23975 .41039 m .17772 .36213 L .1777 .36213 L F
.21838 .23124 m .18611 .18189 L .21837 .23124 L F
.21838 .23124 m .18613 .18189 L .18611 .18189 L F
.12451 .3043 m .08149 .23851 L .12449 .30431 L F
.12451 .3043 m .08151 .23851 L .08149 .23851 L F
.16247 .12792 m .14797 .07077 L .16245 .12791 L F
.16247 .12792 m .14799 .07078 L .14797 .07077 L F
.04996 .16655 m .03063 .09035 L .04993 .16654 L F
.04996 .16655 m .03066 .09036 L .03063 .09035 L F
.2583 .2746 m .21835 .23124 L .25829 .2746 L F
.2583 .2746 m .21837 .23124 L .21835 .23124 L F
.17773 .36212 m .12447 .30431 L .17772 .36213 L F
.17773 .36212 m .12449 .30431 L .12447 .30431 L F
.38473 .46724 m .30884 .44781 L .38319 .47331 L .479 .526 .746 r
F
.30886 .4478 m .23971 .41041 L .30885 .44781 L .787 .211 .013 r
F
.30886 .4478 m .23973 .41041 L .23971 .41041 L F
.30885 .44781 m .2397 .41042 L .30884 .44781 L F
.30885 .44781 m .23971 .41041 L .2397 .41042 L F
.38473 .46724 m .31136 .44208 L .30884 .44781 L .479 .526 .746 r
F
.38626 .46117 m .31136 .44208 L .38473 .46724 L F
.38626 .46117 m .31387 .43635 L .31136 .44208 L F
.3878 .4551 m .31387 .43635 L .38626 .46117 L F
.3878 .4551 m .31639 .43061 L .31387 .43635 L F
.38934 .44904 m .31639 .43061 L .3878 .4551 L F
.32796 .42829 m .3577 .37678 L .30668 .34687 L p 0 1 0 r
F P
0 g
s
.3577 .37678 m .32796 .42829 L .32808 .4283 L p 0 1 0 r
F P
0 g
s
.32808 .4283 m .32808 .4283 L p .32826 .42799 L 0 1 0 r
F P
0 g
s
.3577 .37678 m .32808 .4283 L .32826 .42799 L 0 1 0 r
F
.3577 .37678 m .32808 .4283 L .32825 .428 L F
.3577 .37678 m .32808 .4283 L .32825 .42801 L F
.3577 .37678 m .32808 .4283 L .32824 .42802 L F
.3577 .37678 m .32809 .4283 L .32824 .42803 L F
.3577 .37678 m .32809 .4283 L .32824 .42804 L F
.3577 .37678 m .32809 .4283 L .32823 .42805 L F
.3577 .37678 m .32809 .4283 L .32823 .42806 L F
.3577 .37678 m .3281 .4283 L .32823 .42807 L F
.3577 .37678 m .3281 .4283 L .32823 .42808 L F
.40317 .39441 m .3571 .37861 L .35467 .38276 L .479 .526 .746 r
F
.40163 .40048 m .35389 .3841 L .35142 .38834 L F
.4001 .40655 m .35068 .3896 L .34816 .39392 L F
.39856 .41262 m .34748 .3951 L .34491 .39949 L F
.39702 .41869 m .34427 .40059 L .34166 .40506 L F
.39549 .42476 m .34106 .40609 L .33841 .41063 L F
.39395 .43083 m .33785 .41159 L .33516 .4162 L F
.39241 .4369 m .33465 .41708 L .33191 .42177 L F
.39088 .44297 m .33144 .42258 L .32866 .42733 L F
.3577 .37678 m .3281 .4283 L .32823 .42808 L 0 1 0 r
F
.39088 .44297 m .32866 .42733 L .38934 .44904 L .479 .526 .746 r
F
.32866 .42733 m .32823 .42808 L .38934 .44904 L F
.39241 .4369 m .33191 .42177 L .39088 .44297 L F
.35665 .37918 m .32823 .42808 L .33099 .42335 L 0 1 0 r
F
.35665 .37918 m .33099 .42335 L .35662 .37926 L F
.3577 .37678 m .32823 .42808 L .35665 .37918 L F
.30668 .34687 m .27693 .39839 L .32796 .42829 L p F P
0 g
s
.33191 .42177 m .32142 .41914 L .33144 .42258 L .479 .526 .746 r
F
.33191 .42177 m .33144 .42258 L .39088 .44297 L F
.39395 .43083 m .33516 .4162 L .39241 .4369 L F
.35662 .37926 m .33099 .42335 L .33369 .41872 L 0 1 0 r
F
.35662 .37926 m .33369 .41872 L .35659 .37933 L F
.33516 .4162 m .32394 .41341 L .33465 .41708 L .479 .526 .746 r
F
.33516 .4162 m .33465 .41708 L .39241 .4369 L F
.39549 .42476 m .33841 .41063 L .39395 .43083 L F
.35659 .37933 m .33369 .41872 L .33635 .41418 L 0 1 0 r
F
.35659 .37933 m .33635 .41418 L .35656 .37941 L F
.33841 .41063 m .32645 .40768 L .33785 .41159 L .479 .526 .746 r
F
.33841 .41063 m .33785 .41159 L .39395 .43083 L F
.39702 .41869 m .34166 .40506 L .39549 .42476 L F
.35656 .37941 m .33635 .41418 L .33895 .40973 L 0 1 0 r
F
.35656 .37941 m .33895 .40973 L .35652 .37949 L F
.34166 .40506 m .32897 .40194 L .34106 .40609 L .479 .526 .746 r
F
.34166 .40506 m .34106 .40609 L .39549 .42476 L F
.39856 .41262 m .34491 .39949 L .39702 .41869 L F
.35652 .37949 m .33895 .40973 L .3415 .40536 L 0 1 0 r
F
.35652 .37949 m .3415 .40536 L .35649 .37957 L F
.34491 .39949 m .33148 .39621 L .34427 .40059 L .479 .526 .746 r
F
.34491 .39949 m .34427 .40059 L .39702 .41869 L F
.4001 .40655 m .34816 .39392 L .39856 .41262 L F
.35649 .37957 m .3415 .40536 L .34401 .40107 L 0 1 0 r
F
.35649 .37957 m .34401 .40107 L .35645 .37965 L F
.34816 .39392 m .334 .39047 L .34748 .3951 L .479 .526 .746 r
F
.34816 .39392 m .34748 .3951 L .39856 .41262 L F
.40163 .40048 m .35142 .38834 L .4001 .40655 L F
.35645 .37965 m .34401 .40107 L .34647 .39686 L 0 1 0 r
F
.35645 .37965 m .34647 .39686 L .35641 .37974 L F
.35142 .38834 m .33651 .38474 L .35068 .3896 L .479 .526 .746 r
F
.35142 .38834 m .35068 .3896 L .4001 .40655 L F
.40317 .39441 m .35467 .38276 L .40163 .40048 L F
.35641 .37974 m .34647 .39686 L .34888 .39272 L 0 1 0 r
F
.35641 .37974 m .34888 .39272 L .35638 .37983 L F
.35467 .38276 m .33903 .379 L .35389 .3841 L .479 .526 .746 r
F
.35467 .38276 m .35389 .3841 L .40163 .40048 L F
.35638 .37983 m .34888 .39272 L .35624 .38013 L 0 1 0 r
F
.32796 .42829 m .27693 .39839 L p .27859 .39925 L F P
0 g
s
.27859 .39925 m .28498 .40299 L .32796 .42829 L 0 1 0 r
F
.32142 .41914 m .2866 .40394 L .3196 .4233 L .479 .526 .746 r
F
.32866 .42733 m .3248 .42636 L .32823 .42808 L F
.3248 .42636 m .32702 .42766 L .32823 .42808 L F
.32808 .4283 m .32808 .4283 L p .32825 .428 L 0 1 0 r
F P
0 g
s
.32808 .4283 m .32808 .4283 L p .32825 .42801 L 0 1 0 r
F P
0 g
s
.32808 .4283 m .32809 .4283 L p .32824 .42802 L 0 1 0 r
F P
0 g
s
.32809 .4283 m .32809 .4283 L p .32824 .42803 L 0 1 0 r
F P
0 g
s
.32809 .4283 m .32809 .4283 L p .32824 .42804 L 0 1 0 r
F P
0 g
s
.32809 .4283 m .32809 .4283 L p .32823 .42805 L 0 1 0 r
F P
0 g
s
.32809 .4283 m .3281 .4283 L p .32823 .42806 L 0 1 0 r
F P
0 g
s
.3281 .4283 m .3281 .4283 L p .32823 .42807 L 0 1 0 r
F P
0 g
s
.32866 .42733 m .32142 .41914 L .3196 .4233 L .479 .526 .746 r
F
.32866 .42733 m .3196 .4233 L .3248 .42636 L F
.33144 .42258 m .32142 .41914 L .32866 .42733 L F
.3281 .4283 m .3281 .4283 L p .32823 .42808 L 0 1 0 r
F P
0 g
s
.38934 .44904 m .32823 .42808 L .3281 .4283 L .479 .526 .746 r
F
.34385 .43755 m .3281 .4283 L .32541 .43289 L F
.38934 .44904 m .3281 .4283 L .34385 .43755 L F
.3284 .42778 m .33524 .4284 L p .35624 .38013 L 0 1 0 r
F P
0 g
s
.33524 .4284 m .3281 .4283 L p .32702 .42766 L 0 1 0 r
F P
0 g
s
.3248 .42636 m .3248 .42636 L .32702 .42766 L 0 1 0 r
F
.3248 .42636 m .33524 .4284 L .32702 .42766 L F
.32394 .41341 m .27963 .39413 L .32142 .41914 L .479 .526 .746 r
F
.27693 .39839 m .30668 .34687 L p .30497 .35077 L 0 1 0 r
F P
0 g
s
.30497 .35077 m .29473 .3683 L .27693 .39839 L 0 1 0 r
F
.27963 .39413 m .27856 .39597 L .32142 .41914 L .479 .526 .746 r
F
.32394 .41341 m .28172 .39058 L .27963 .39413 L F
.32645 .40768 m .28279 .38874 L .32394 .41341 L F
.28279 .38874 m .28172 .39058 L .32394 .41341 L F
.32645 .40768 m .28488 .38519 L .28279 .38874 L F
.32897 .40194 m .28595 .38335 L .32645 .40768 L F
.28595 .38335 m .28488 .38519 L .32645 .40768 L F
.32897 .40194 m .28804 .37981 L .28595 .38335 L F
.33148 .39621 m .28911 .37796 L .32897 .40194 L F
.28911 .37796 m .28804 .37981 L .32897 .40194 L F
.33148 .39621 m .29119 .37442 L .28911 .37796 L F
.334 .39047 m .29227 .37257 L .33148 .39621 L F
.29227 .37257 m .29119 .37442 L .33148 .39621 L F
.334 .39047 m .29435 .36903 L .29227 .37257 L F
.33651 .38474 m .29543 .36718 L .334 .39047 L F
.29543 .36718 m .29435 .36903 L .334 .39047 L F
.33651 .38474 m .29751 .36365 L .29543 .36718 L F
.33903 .379 m .29859 .36179 L .33651 .38474 L F
.29859 .36179 m .29751 .36365 L .33651 .38474 L F
.33903 .379 m .30067 .35826 L .29859 .36179 L F
.34154 .37327 m .30175 .3564 L .33903 .379 L F
.30175 .3564 m .30067 .35826 L .33903 .379 L F
.30668 .34687 m .3577 .37678 L .35816 .37678 L p 0 1 0 r
F P
0 g
s
.30668 .34687 m .35816 .37678 L .35645 .37578 L 0 1 0 r
F
.35287 .37367 m .34406 .36754 L .34373 .36828 L .479 .526 .746 r
F
.40471 .38834 m .3603 .37311 L .35793 .37718 L F
.30668 .34687 m .35645 .37578 L .3118 .3495 L 0 1 0 r
F
.3603 .37311 m .34406 .36754 L .35287 .37367 L .479 .526 .746 r
F
.3603 .37311 m .35287 .37367 L .35816 .37678 L F
.35645 .37578 m .35818 .37678 L .34373 .36828 L 0 1 0 r
F
.35645 .37578 m .3454 .36927 L .3118 .3495 L F
.3454 .36927 m .33841 .36515 L .3118 .3495 L F
.30497 .35077 m .30475 .35129 L .29473 .3683 L F
.30475 .35129 m .30475 .3513 L .30443 .35183 L F
.30475 .35129 m .30443 .35183 L .29473 .3683 L F
.33841 .36515 m .30687 .34768 L .30491 .35101 L .479 .526 .746 r
F
.34406 .36754 m .32431 .35685 L .33841 .36515 L F
.34406 .36754 m .33841 .36515 L .34373 .36828 L F
.40625 .38227 m .34406 .36754 L .40471 .38834 L F
.40625 .38227 m .34657 .3618 L .34406 .36754 L F
.34657 .3618 m .30808 .34562 L .34406 .36754 L F
.30808 .34562 m .298 .34138 L .30742 .34673 L F
.30808 .34562 m .30742 .34673 L .34406 .36754 L F
.30742 .34673 m .32431 .35685 L .34406 .36754 L F
.298 .34138 m .30734 .34687 L .30742 .34673 L F
.30734 .34687 m .32431 .35685 L .30742 .34673 L F
.34657 .3618 m .29107 .33179 L .28847 .33577 L F
.34657 .3618 m .28847 .33577 L .298 .34138 L F
.365 .37685 m .31394 .34693 L .30734 .34687 L p 0 1 0 r
F P
0 g
s
.30734 .34687 m .30668 .34687 L p .31183 .34952 L 0 1 0 r
F P
0 g
s
.31183 .34952 m .365 .37685 L .30734 .34687 L 0 1 0 r
F
.298 .34138 m .28847 .33577 L .28765 .33703 L .479 .526 .746 r
F
.30668 .34687 m .30734 .34687 L p .30475 .35129 L 0 1 0 r
F P
0 g
s
.30734 .34687 m .30698 .34748 L .30475 .35129 L 0 1 0 r
F
.3118 .3495 m .34373 .36828 L .31187 .34954 L F
.298 .34138 m .28765 .33703 L .30698 .34748 L .479 .526 .746 r
F
.30734 .34687 m .30698 .34748 L .32431 .35685 L F
.298 .34138 m .30698 .34748 L .30734 .34687 L F
.30698 .34749 m .30698 .34749 L .33841 .36515 L F
.32431 .35685 m .30698 .34749 L .33841 .36515 L F
.30698 .34748 m .30687 .34768 L .33841 .36515 L F
.34373 .36828 m .30491 .35101 L .34154 .37327 L F
.3454 .36927 m .34373 .36828 L .33841 .36515 L 0 1 0 r
F
.33841 .36515 m .30491 .35101 L .34373 .36828 L .479 .526 .746 r
F
.30491 .35101 m .30383 .35287 L .34154 .37327 L F
.30734 .34687 m .31394 .34693 L p .30476 .35128 L 0 1 0 r
F P
0 g
s
.30698 .34748 m .30476 .35128 L .30475 .35129 L 0 1 0 r
F
.30734 .34687 m .30476 .35128 L .30698 .34748 L F
.30734 .34687 m .30734 .34687 L p .30698 .34748 L F P
0 g
s
.35818 .37678 m .365 .37685 L p .31187 .34954 L 0 1 0 r
F P
0 g
s
.34373 .36828 m .35818 .37678 L .31187 .34954 L 0 1 0 r
F
.34154 .37327 m .30383 .35287 L .30175 .3564 L .479 .526 .746 r
F
.31394 .34693 m .28418 .39848 L p .30471 .35137 L 0 1 0 r
F P
0 g
s
.30475 .35129 m .30476 .35128 L .30471 .35137 L 0 1 0 r
F
.30476 .35128 m .31394 .34693 L .30471 .35137 L F
.30698 .34748 m .28765 .33703 L .30687 .34768 L .479 .526 .746 r
F
.30491 .35101 m .28765 .33703 L .28422 .34227 L F
.30687 .34768 m .28765 .33703 L .30491 .35101 L F
.40471 .38834 m .35793 .37718 L .40317 .39441 L F
.35793 .37718 m .3571 .37861 L .40317 .39441 L F
.33524 .4284 m .365 .37685 L .35816 .37678 L p 0 1 0 r
F P
0 g
s
.35816 .37678 m .3577 .37678 L p .35634 .37992 L 0 1 0 r
F P
0 g
s
.35634 .37992 m .33524 .4284 L .35816 .37678 L 0 1 0 r
F
.35793 .37718 m .34154 .37327 L .3571 .37861 L .479 .526 .746 r
F
.35816 .37678 m .35287 .37367 L .35793 .37718 L F
.35793 .37718 m .35287 .37367 L .34154 .37327 L F
.35287 .37367 m .34373 .36828 L .34154 .37327 L F
.35816 .37678 m .35818 .37678 L p .35645 .37578 L 0 1 0 r
F P
0 g
s
.30475 .3513 m .30418 .35227 L .29473 .3683 L 0 1 0 r
F
.30473 .35133 m .29924 .36067 L .29473 .3683 L F
.30491 .35101 m .28422 .34227 L .30383 .35287 L .479 .526 .746 r
F
.30475 .3513 m .30473 .35133 L .30418 .35227 L 0 1 0 r
F
.30473 .35133 m .30461 .3516 L .29924 .36067 L F
.30175 .3564 m .28422 .34227 L .2808 .34751 L .479 .526 .746 r
F
.30383 .35287 m .28422 .34227 L .30175 .3564 L F
.30175 .3564 m .2808 .34751 L .30067 .35826 L F
.27711 .39839 m .2771 .39839 L p .29966 .35999 L 0 1 0 r
F P
0 g
s
.30073 .35816 m .2996 .36008 L .29966 .35999 L 0 1 0 r
F
.2996 .36008 m .27711 .39839 L .29966 .35999 L F
.2771 .39839 m .27693 .39839 L p .3 .35939 L F P
0 g
s
.30073 .35816 m .2771 .39839 L .3 .35939 L 0 1 0 r
F
.29859 .36179 m .2808 .34751 L .27737 .35276 L .479 .526 .746 r
F
.30067 .35826 m .2808 .34751 L .29859 .36179 L F
.29859 .36179 m .27737 .35276 L .29751 .36365 L F
.27711 .39839 m .27711 .39839 L p .29667 .36508 L 0 1 0 r
F P
0 g
s
.30144 .35697 m .29645 .36546 L .29667 .36508 L 0 1 0 r
F
.29645 .36546 m .27711 .39839 L .29667 .36508 L F
.30144 .35697 m .27711 .39839 L .30073 .35816 L F
.29543 .36718 m .27737 .35276 L .27395 .358 L .479 .526 .746 r
F
.29751 .36365 m .27737 .35276 L .29543 .36718 L F
.29543 .36718 m .27395 .358 L .29435 .36903 L F
.27712 .39839 m .27711 .39839 L p .29368 .37019 L 0 1 0 r
F P
0 g
s
.30212 .35582 m .29329 .37084 L .29368 .37019 L 0 1 0 r
F
.29329 .37084 m .27712 .39839 L .29368 .37019 L F
.30212 .35582 m .27711 .39839 L .30144 .35697 L F
.29227 .37257 m .27395 .358 L .27052 .36324 L .479 .526 .746 r
F
.29435 .36903 m .27395 .358 L .29227 .37257 L F
.29227 .37257 m .27052 .36324 L .29119 .37442 L F
.27712 .39839 m .27712 .39839 L p .29066 .37533 L 0 1 0 r
F P
0 g
s
.30277 .35471 m .29014 .37623 L .29066 .37533 L 0 1 0 r
F
.29014 .37623 m .27712 .39839 L .29066 .37533 L F
.30277 .35471 m .27712 .39839 L .30212 .35582 L F
.28911 .37796 m .27052 .36324 L .2671 .36848 L .479 .526 .746 r
F
.29119 .37442 m .27052 .36324 L .28911 .37796 L F
.28911 .37796 m .2671 .36848 L .28804 .37981 L F
.27713 .39839 m .27712 .39839 L p .28764 .38048 L 0 1 0 r
F P
0 g
s
.30341 .35364 m .28698 .38161 L .28764 .38048 L 0 1 0 r
F
.28698 .38161 m .27713 .39839 L .28764 .38048 L F
.30341 .35364 m .27712 .39839 L .30277 .35471 L F
.28595 .38335 m .2671 .36848 L .26367 .37372 L .479 .526 .746 r
F
.28804 .37981 m .2671 .36848 L .28595 .38335 L F
.28595 .38335 m .26367 .37372 L .28488 .38519 L F
.27713 .39839 m .27713 .39839 L p .28461 .38565 L 0 1 0 r
F P
0 g
s
.30402 .3526 m .28382 .38699 L .28461 .38565 L 0 1 0 r
F
.28382 .38699 m .27713 .39839 L .28461 .38565 L F
.30402 .3526 m .27713 .39839 L .30341 .35364 L F
.28279 .38874 m .26367 .37372 L .26025 .37897 L .479 .526 .746 r
F
.28488 .38519 m .26367 .37372 L .28279 .38874 L F
.28279 .38874 m .26025 .37897 L .28172 .39058 L F
.27714 .39839 m .27713 .39839 L p .28157 .39084 L 0 1 0 r
F P
0 g
s
.30461 .3516 m .28067 .39238 L .28157 .39084 L 0 1 0 r
F
.28067 .39238 m .27714 .39839 L .28157 .39084 L F
.30461 .3516 m .27713 .39839 L .30402 .3526 L F
.27963 .39413 m .26025 .37897 L .25682 .38421 L .479 .526 .746 r
F
.28172 .39058 m .26025 .37897 L .27963 .39413 L F
.27963 .39413 m .25682 .38421 L .27856 .39597 L F
.32142 .41914 m .27856 .39597 L .27791 .39708 L F
.32142 .41914 m .25576 .38584 L .2866 .40394 L F
.28418 .39848 m .27714 .39839 L p .30461 .3516 L 0 1 0 r
F P
0 g
s
.27791 .39708 m .25682 .38421 L .25576 .38584 L .479 .526 .746 r
F
.27856 .39597 m .25682 .38421 L .27791 .39708 L F
.27859 .39925 m .27862 .39926 L .28498 .40299 L 0 1 0 r
F
.27862 .39926 m .28482 .4029 L .28498 .40299 L F
.27877 .39934 m .32702 .42766 L .32796 .42829 L F
.32823 .42808 m .32702 .42766 L .3281 .4283 L .479 .526 .746 r
F
.3281 .4283 m .3281 .4283 L p .32702 .42766 L 0 1 0 r
F P
0 g
s
.3281 .4283 m .32796 .42829 L p .32702 .42766 L 0 1 0 r
F P
0 g
s
.3281 .4283 m .3189 .42488 L .32541 .43289 L .479 .526 .746 r
F
.32702 .42766 m .3189 .42488 L .3281 .4283 L F
.27693 .39839 m .28418 .39848 L .33524 .4284 L p 0 1 0 r
F P
0 g
s
.2866 .40394 m .25576 .38584 L .2534 .38945 L .479 .526 .746 r
F
.27862 .39926 m .27877 .39934 L .28482 .4029 L 0 1 0 r
F
.27877 .39934 m .27907 .39949 L .3248 .42636 L F
.27907 .39949 m .33524 .4284 L .3248 .42636 L F
.3248 .42636 m .3196 .4233 L .3189 .42488 L .479 .526 .746 r
F
.3196 .4233 m .2534 .38945 L .3189 .42488 L F
.2866 .40394 m .2534 .38945 L .3196 .4233 L F
.3248 .42636 m .3189 .42488 L .32702 .42766 L F
.35467 .38276 m .34154 .37327 L .33903 .379 L F
.3571 .37861 m .34154 .37327 L .35467 .38276 L F
.35142 .38834 m .33903 .379 L .33651 .38474 L F
.35389 .3841 m .33903 .379 L .35142 .38834 L F
.34816 .39392 m .33651 .38474 L .334 .39047 L F
.35068 .3896 m .33651 .38474 L .34816 .39392 L F
.34491 .39949 m .334 .39047 L .33148 .39621 L F
.34748 .3951 m .334 .39047 L .34491 .39949 L F
.34166 .40506 m .33148 .39621 L .32897 .40194 L F
.34427 .40059 m .33148 .39621 L .34166 .40506 L F
.33841 .41063 m .32897 .40194 L .32645 .40768 L F
.34106 .40609 m .32897 .40194 L .33841 .41063 L F
.33516 .4162 m .32645 .40768 L .32394 .41341 L F
.33785 .41159 m .32645 .40768 L .33516 .4162 L F
.33191 .42177 m .32394 .41341 L .32142 .41914 L F
.33465 .41708 m .32394 .41341 L .33191 .42177 L F
.32541 .43289 m .3189 .42488 L .31639 .43061 L F
.40778 .3762 m .34657 .3618 L .40625 .38227 L F
.40778 .3762 m .34909 .35607 L .34657 .3618 L F
.40932 .37013 m .34909 .35607 L .40778 .3762 L F
.40932 .37013 m .3516 .35033 L .34909 .35607 L F
.41086 .36406 m .3516 .35033 L .40932 .37013 L F
.41086 .36406 m .35412 .3446 L .3516 .35033 L F
.41239 .358 m .35412 .3446 L .41086 .36406 L F
.41239 .358 m .35663 .33887 L .35412 .3446 L F
.35665 .33886 m .30478 .31081 L .35664 .33886 L .787 .211 .013 r
F
.35665 .33886 m .30479 .31081 L .30478 .31081 L F
.14799 .07078 m .1431 .01203 L .14797 .07077 L F
.14799 .07078 m .14312 .01204 L .1431 .01203 L F
.03066 .09036 m .02414 .01203 L .03063 .09035 L F
.03066 .09036 m .02417 .01204 L .02414 .01203 L F
.18613 .18189 m .16243 .12791 L .18611 .18189 L F
.18613 .18189 m .16245 .12791 L .16243 .12791 L F
.08151 .23851 m .0499 .16654 L .08149 .23851 L F
.08151 .23851 m .04993 .16654 L .0499 .16654 L F
.3048 .31081 m .25826 .27461 L .30479 .31081 L F
.3048 .31081 m .25827 .27461 L .25826 .27461 L F
.23974 .4104 m .17768 .36214 L .23973 .41041 L F
.23974 .4104 m .1777 .36213 L .17768 .36214 L F
.21837 .23124 m .1861 .18189 L .21835 .23124 L F
.21837 .23124 m .18611 .18189 L .1861 .18189 L F
.12449 .30431 m .08146 .23851 L .12447 .30431 L F
.12449 .30431 m .08149 .23851 L .08146 .23851 L F
.25829 .2746 m .21833 .23124 L .25827 .27461 L F
.25829 .2746 m .21835 .23124 L .21833 .23124 L F
.17772 .36213 m .12445 .30431 L .1777 .36213 L F
.17772 .36213 m .12447 .30431 L .12445 .30431 L F
.35664 .33886 m .30477 .31082 L .35663 .33887 L F
.35664 .33886 m .30478 .31081 L .30477 .31082 L F
.16245 .12791 m .14795 .07076 L .16243 .12791 L F
.16245 .12791 m .14797 .07077 L .14795 .07076 L F
.04993 .16654 m .0306 .09034 L .0499 .16654 L F
.04993 .16654 m .03063 .09035 L .0306 .09034 L F
.14797 .07077 m .14308 .01201 L .14795 .07076 L F
.14797 .07077 m .1431 .01203 L .14308 .01201 L F
.03063 .09035 m .02411 .01201 L .0306 .09034 L F
.03063 .09035 m .02414 .01203 L .02411 .01201 L F
.30479 .31081 m .25825 .27461 L .30478 .31081 L F
.30479 .31081 m .25826 .27461 L .25825 .27461 L F
.23973 .41041 m .17766 .36215 L .23971 .41041 L F
.23973 .41041 m .17768 .36214 L .17766 .36215 L F
.18611 .18189 m .16241 .1279 L .1861 .18189 L F
.18611 .18189 m .16243 .12791 L .16241 .1279 L F
.08149 .23851 m .04988 .16653 L .08146 .23851 L F
.08149 .23851 m .0499 .16654 L .04988 .16653 L F
.31136 .44208 m .2397 .41042 L .30884 .44781 L .479 .526 .746 r
F
.23971 .41041 m .17765 .36215 L .2397 .41042 L .787 .211 .013 r
F
.23971 .41041 m .17766 .36215 L .17765 .36215 L F
.31136 .44208 m .24312 .40518 L .2397 .41042 L .479 .526 .746 r
F
.31387 .43635 m .24312 .40518 L .31136 .44208 L F
.31387 .43635 m .24655 .39994 L .24312 .40518 L F
.31639 .43061 m .24655 .39994 L .31387 .43635 L F
.31639 .43061 m .24997 .39469 L .24655 .39994 L F
.3189 .42488 m .24997 .39469 L .31639 .43061 L F
.3189 .42488 m .2534 .38945 L .24997 .39469 L F
.34909 .35607 m .29107 .33179 L .34657 .3618 L F
.34909 .35607 m .2945 .32654 L .29107 .33179 L F
.3516 .35033 m .2945 .32654 L .34909 .35607 L F
.3516 .35033 m .29792 .3213 L .2945 .32654 L F
.35412 .3446 m .29792 .3213 L .3516 .35033 L F
.35412 .3446 m .30135 .31606 L .29792 .3213 L F
.35663 .33887 m .30135 .31606 L .35412 .3446 L F
.35663 .33887 m .30477 .31082 L .30135 .31606 L F
.25827 .27461 m .21832 .23124 L .25826 .27461 L .787 .211 .013 r
F
.25827 .27461 m .21833 .23124 L .21832 .23124 L F
.1777 .36213 m .12443 .30432 L .17768 .36214 L F
.1777 .36213 m .12445 .30431 L .12443 .30432 L F
.21835 .23124 m .18608 .18188 L .21833 .23124 L F
.21835 .23124 m .1861 .18189 L .18608 .18188 L F
.12447 .30431 m .08144 .23851 L .12445 .30431 L F
.12447 .30431 m .08146 .23851 L .08144 .23851 L F
.16243 .12791 m .14793 .07075 L .16241 .1279 L F
.16243 .12791 m .14795 .07076 L .14793 .07075 L F
.0499 .16654 m .03057 .09033 L .04988 .16653 L F
.0499 .16654 m .0306 .09034 L .03057 .09033 L F
.14795 .07076 m .14306 .012 L .14793 .07075 L F
.14795 .07076 m .14308 .01201 L .14306 .012 L F
.0306 .09034 m .02408 .012 L .03057 .09033 L F
.0306 .09034 m .02411 .01201 L .02408 .012 L F
.30478 .31081 m .25824 .27461 L .30477 .31082 L F
.30478 .31081 m .25825 .27461 L .25824 .27461 L F
.1861 .18189 m .16239 .12789 L .18608 .18188 L F
.1861 .18189 m .16241 .1279 L .16239 .12789 L F
.08146 .23851 m .04985 .16653 L .08144 .23851 L F
.08146 .23851 m .04988 .16653 L .04985 .16653 L F
.25826 .27461 m .2183 .23123 L .25825 .27461 L F
.25826 .27461 m .21832 .23124 L .2183 .23123 L F
.17768 .36214 m .1244 .30432 L .17766 .36215 L F
.17768 .36214 m .12443 .30432 L .1244 .30432 L F
.21833 .23124 m .18606 .18188 L .21832 .23124 L F
.21833 .23124 m .18608 .18188 L .18606 .18188 L F
.12445 .30431 m .08141 .23851 L .12443 .30432 L F
.12445 .30431 m .08144 .23851 L .08141 .23851 L F
.16241 .1279 m .14791 .07074 L .16239 .12789 L F
.16241 .1279 m .14793 .07075 L .14791 .07074 L F
.04988 .16653 m .03054 .09032 L .04985 .16653 L F
.04988 .16653 m .03057 .09033 L .03054 .09032 L F
.24312 .40518 m .17765 .36215 L .2397 .41042 L .479 .526 .746 r
F
.17766 .36215 m .12438 .30432 L .17765 .36215 L .787 .211 .013 r
F
.17766 .36215 m .1244 .30432 L .12438 .30432 L F
.24312 .40518 m .18189 .35754 L .17765 .36215 L .479 .526 .746 r
F
.24655 .39994 m .18189 .35754 L .24312 .40518 L F
.24655 .39994 m .18613 .35294 L .18189 .35754 L F
.24997 .39469 m .18613 .35294 L .24655 .39994 L F
.24997 .39469 m .19037 .34833 L .18613 .35294 L F
.2534 .38945 m .19037 .34833 L .24997 .39469 L F
.2534 .38945 m .19461 .34372 L .19037 .34833 L F
.25682 .38421 m .19461 .34372 L .2534 .38945 L F
.25682 .38421 m .19885 .33911 L .19461 .34372 L F
.26025 .37897 m .19885 .33911 L .25682 .38421 L F
.26025 .37897 m .2031 .33451 L .19885 .33911 L F
.26367 .37372 m .2031 .33451 L .26025 .37897 L F
.26367 .37372 m .20734 .3299 L .2031 .33451 L F
.2671 .36848 m .20734 .3299 L .26367 .37372 L F
.2671 .36848 m .21158 .32529 L .20734 .3299 L F
.27052 .36324 m .21158 .32529 L .2671 .36848 L F
.27052 .36324 m .21582 .32068 L .21158 .32529 L F
.27395 .358 m .21582 .32068 L .27052 .36324 L F
.27395 .358 m .22006 .31608 L .21582 .32068 L F
.27737 .35276 m .22006 .31608 L .27395 .358 L F
.27737 .35276 m .2243 .31147 L .22006 .31608 L F
.2808 .34751 m .2243 .31147 L .27737 .35276 L F
.2808 .34751 m .22855 .30686 L .2243 .31147 L F
.28422 .34227 m .22855 .30686 L .2808 .34751 L F
.28422 .34227 m .23279 .30225 L .22855 .30686 L F
.28765 .33703 m .23279 .30225 L .28422 .34227 L F
.28765 .33703 m .23703 .29765 L .23279 .30225 L F
.29107 .33179 m .23703 .29765 L .28765 .33703 L F
.29107 .33179 m .24127 .29304 L .23703 .29765 L F
.2945 .32654 m .24127 .29304 L .29107 .33179 L F
.2945 .32654 m .24551 .28843 L .24127 .29304 L F
.29792 .3213 m .24551 .28843 L .2945 .32654 L F
.29792 .3213 m .24975 .28382 L .24551 .28843 L F
.30135 .31606 m .24975 .28382 L .29792 .3213 L F
.30135 .31606 m .25399 .27922 L .24975 .28382 L F
.30477 .31082 m .25399 .27922 L .30135 .31606 L F
.30477 .31082 m .25824 .27461 L .25399 .27922 L F
.14793 .07075 m .14304 .01198 L .14791 .07074 L .787 .211 .013 r
F
.14793 .07075 m .14306 .012 L .14304 .01198 L F
.03057 .09033 m .02405 .01198 L .03054 .09032 L F
.03057 .09033 m .02408 .012 L .02405 .01198 L F
.18608 .18188 m .16237 .12788 L .18606 .18188 L F
.18608 .18188 m .16239 .12789 L .16237 .12788 L F
.08144 .23851 m .04982 .16652 L .08141 .23851 L F
.08144 .23851 m .04985 .16653 L .04982 .16652 L F
.25825 .27461 m .21829 .23123 L .25824 .27461 L F
.25825 .27461 m .2183 .23123 L .21829 .23123 L F
.21832 .23124 m .18604 .18188 L .2183 .23123 L F
.21832 .23124 m .18606 .18188 L .18604 .18188 L F
.12443 .30432 m .08139 .23851 L .1244 .30432 L F
.12443 .30432 m .08141 .23851 L .08139 .23851 L F
.16239 .12789 m .14788 .07073 L .16237 .12788 L F
.16239 .12789 m .14791 .07074 L .14788 .07073 L F
.04985 .16653 m .03051 .09031 L .04982 .16652 L F
.04985 .16653 m .03054 .09032 L .03051 .09031 L F
.14791 .07074 m .14301 .01197 L .14788 .07073 L F
.14791 .07074 m .14304 .01198 L .14301 .01197 L F
.03054 .09032 m .02402 .01197 L .03051 .09031 L F
.03054 .09032 m .02405 .01198 L .02402 .01197 L F
.18189 .35754 m .12438 .30432 L .17765 .36215 L .479 .526 .746 r
F
.1244 .30432 m .08136 .23851 L .12438 .30432 L .787 .211 .013 r
F
.1244 .30432 m .08139 .23851 L .08136 .23851 L F
.18189 .35754 m .12933 .30048 L .12438 .30432 L .479 .526 .746 r
F
.18613 .35294 m .12933 .30048 L .18189 .35754 L F
.18613 .35294 m .13427 .29663 L .12933 .30048 L F
.19037 .34833 m .13427 .29663 L .18613 .35294 L F
.19037 .34833 m .13921 .29278 L .13427 .29663 L F
.19461 .34372 m .13921 .29278 L .19037 .34833 L F
.19461 .34372 m .14415 .28894 L .13921 .29278 L F
.19885 .33911 m .14415 .28894 L .19461 .34372 L F
.19885 .33911 m .14909 .28509 L .14415 .28894 L F
.2031 .33451 m .14909 .28509 L .19885 .33911 L F
.2031 .33451 m .15404 .28124 L .14909 .28509 L F
.20734 .3299 m .15404 .28124 L .2031 .33451 L F
.20734 .3299 m .15898 .27739 L .15404 .28124 L F
.21158 .32529 m .15898 .27739 L .20734 .3299 L F
.21158 .32529 m .16392 .27355 L .15898 .27739 L F
.21582 .32068 m .16392 .27355 L .21158 .32529 L F
.21582 .32068 m .16886 .2697 L .16392 .27355 L F
.22006 .31608 m .16886 .2697 L .21582 .32068 L F
.22006 .31608 m .17381 .26585 L .16886 .2697 L F
.2243 .31147 m .17381 .26585 L .22006 .31608 L F
.2243 .31147 m .17875 .26201 L .17381 .26585 L F
.22855 .30686 m .17875 .26201 L .2243 .31147 L F
.22855 .30686 m .18369 .25816 L .17875 .26201 L F
.23279 .30225 m .18369 .25816 L .22855 .30686 L F
.23279 .30225 m .18863 .25431 L .18369 .25816 L F
.23703 .29765 m .18863 .25431 L .23279 .30225 L F
.23703 .29765 m .19358 .25047 L .18863 .25431 L F
.24127 .29304 m .19358 .25047 L .23703 .29765 L F
.24127 .29304 m .19852 .24662 L .19358 .25047 L F
.24551 .28843 m .19852 .24662 L .24127 .29304 L F
.24551 .28843 m .20346 .24277 L .19852 .24662 L F
.24975 .28382 m .20346 .24277 L .24551 .28843 L F
.24975 .28382 m .2084 .23893 L .20346 .24277 L F
.25399 .27922 m .2084 .23893 L .24975 .28382 L F
.25399 .27922 m .21334 .23508 L .2084 .23893 L F
.25824 .27461 m .21334 .23508 L .25399 .27922 L F
.25824 .27461 m .21829 .23123 L .21334 .23508 L F
.18606 .18188 m .16234 .12788 L .18604 .18188 L .787 .211 .013 r
F
.18606 .18188 m .16237 .12788 L .16234 .12788 L F
.08141 .23851 m .04979 .16652 L .08139 .23851 L F
.08141 .23851 m .04982 .16652 L .04979 .16652 L F
.2183 .23123 m .18602 .18187 L .21829 .23123 L F
.2183 .23123 m .18604 .18188 L .18602 .18187 L F
.16237 .12788 m .14786 .07072 L .16234 .12788 L F
.16237 .12788 m .14788 .07073 L .14786 .07072 L F
.04982 .16652 m .03048 .0903 L .04979 .16652 L F
.04982 .16652 m .03051 .09031 L .03048 .0903 L F
.14788 .07073 m .14299 .01195 L .14786 .07072 L F
.14788 .07073 m .14301 .01197 L .14299 .01195 L F
.03051 .09031 m .02399 .01195 L .03048 .0903 L F
.03051 .09031 m .02402 .01197 L .02399 .01195 L F
.18604 .18188 m .16232 .12787 L .18602 .18187 L F
.18604 .18188 m .16234 .12788 L .16232 .12787 L F
.08139 .23851 m .04977 .16651 L .08136 .23851 L F
.08139 .23851 m .04979 .16652 L .04977 .16651 L F
.12933 .30048 m .08136 .23851 L .12438 .30432 L .479 .526 .746 r
F
.12933 .30048 m .08687 .23553 L .08136 .23851 L F
.13427 .29663 m .08687 .23553 L .12933 .30048 L F
.13427 .29663 m .09238 .23255 L .08687 .23553 L F
.13921 .29278 m .09238 .23255 L .13427 .29663 L F
.13921 .29278 m .09789 .22957 L .09238 .23255 L F
.14415 .28894 m .09789 .22957 L .13921 .29278 L F
.14415 .28894 m .1034 .22659 L .09789 .22957 L F
.14909 .28509 m .1034 .22659 L .14415 .28894 L F
.14909 .28509 m .10891 .2236 L .1034 .22659 L F
.15404 .28124 m .10891 .2236 L .14909 .28509 L F
.15404 .28124 m .11441 .22062 L .10891 .2236 L F
.15898 .27739 m .11441 .22062 L .15404 .28124 L F
.15898 .27739 m .11992 .21764 L .11441 .22062 L F
.16392 .27355 m .11992 .21764 L .15898 .27739 L F
.16392 .27355 m .12543 .21466 L .11992 .21764 L F
.16886 .2697 m .12543 .21466 L .16392 .27355 L F
.16886 .2697 m .13094 .21168 L .12543 .21466 L F
.17381 .26585 m .13094 .21168 L .16886 .2697 L F
.17381 .26585 m .13645 .2087 L .13094 .21168 L F
.17875 .26201 m .13645 .2087 L .17381 .26585 L F
.17875 .26201 m .14196 .20572 L .13645 .2087 L F
.18369 .25816 m .14196 .20572 L .17875 .26201 L F
.18369 .25816 m .14746 .20274 L .14196 .20572 L F
.18863 .25431 m .14746 .20274 L .18369 .25816 L F
.18863 .25431 m .15297 .19976 L .14746 .20274 L F
.19358 .25047 m .15297 .19976 L .18863 .25431 L F
.19358 .25047 m .15848 .19678 L .15297 .19976 L F
.19852 .24662 m .15848 .19678 L .19358 .25047 L F
.19852 .24662 m .16399 .1938 L .15848 .19678 L F
.20346 .24277 m .16399 .1938 L .19852 .24662 L F
.20346 .24277 m .1695 .19081 L .16399 .1938 L F
.2084 .23893 m .1695 .19081 L .20346 .24277 L F
.2084 .23893 m .17501 .18783 L .1695 .19081 L F
.21334 .23508 m .17501 .18783 L .2084 .23893 L F
.21334 .23508 m .18051 .18485 L .17501 .18783 L F
.21829 .23123 m .18051 .18485 L .21334 .23508 L F
.21829 .23123 m .18602 .18187 L .18051 .18485 L F
.16234 .12788 m .14784 .0707 L .16232 .12787 L .787 .211 .013 r
F
.16234 .12788 m .14786 .07072 L .14784 .0707 L F
.04979 .16652 m .03045 .09029 L .04977 .16651 L F
.04979 .16652 m .03048 .0903 L .03045 .09029 L F
.08687 .23553 m .04977 .16651 L .08136 .23851 L .479 .526 .746 r
F
.08687 .23553 m .05569 .16448 L .04977 .16651 L F
.09238 .23255 m .05569 .16448 L .08687 .23553 L F
.09238 .23255 m .06161 .16244 L .05569 .16448 L F
.09789 .22957 m .06161 .16244 L .09238 .23255 L F
.09789 .22957 m .06754 .16041 L .06161 .16244 L F
.1034 .22659 m .06754 .16041 L .09789 .22957 L F
.1034 .22659 m .07346 .15838 L .06754 .16041 L F
.10891 .2236 m .07346 .15838 L .1034 .22659 L F
.10891 .2236 m .07939 .15634 L .07346 .15838 L F
.11441 .22062 m .07939 .15634 L .10891 .2236 L F
.11441 .22062 m .08531 .15431 L .07939 .15634 L F
.11992 .21764 m .08531 .15431 L .11441 .22062 L F
.11992 .21764 m .09123 .15227 L .08531 .15431 L F
.12543 .21466 m .09123 .15227 L .11992 .21764 L F
.12543 .21466 m .09716 .15024 L .09123 .15227 L F
.13094 .21168 m .09716 .15024 L .12543 .21466 L F
.13094 .21168 m .10308 .14821 L .09716 .15024 L F
.13645 .2087 m .10308 .14821 L .13094 .21168 L F
.13645 .2087 m .10901 .14617 L .10308 .14821 L F
.14196 .20572 m .10901 .14617 L .13645 .2087 L F
.14196 .20572 m .11493 .14414 L .10901 .14617 L F
.14746 .20274 m .11493 .14414 L .14196 .20572 L F
.14746 .20274 m .12086 .14211 L .11493 .14414 L F
.15297 .19976 m .12086 .14211 L .14746 .20274 L F
.15297 .19976 m .12678 .14007 L .12086 .14211 L F
.15848 .19678 m .12678 .14007 L .15297 .19976 L F
.15848 .19678 m .1327 .13804 L .12678 .14007 L F
.16399 .1938 m .1327 .13804 L .15848 .19678 L F
.16399 .1938 m .13863 .136 L .1327 .13804 L F
.1695 .19081 m .13863 .136 L .16399 .1938 L F
.1695 .19081 m .14455 .13397 L .13863 .136 L F
.17501 .18783 m .14455 .13397 L .1695 .19081 L F
.17501 .18783 m .15048 .13194 L .14455 .13397 L F
.18051 .18485 m .15048 .13194 L .17501 .18783 L F
.18051 .18485 m .1564 .1299 L .15048 .13194 L F
.18602 .18187 m .1564 .1299 L .18051 .18485 L F
.18602 .18187 m .16232 .12787 L .1564 .1299 L F
.14786 .07072 m .14297 .01194 L .14784 .0707 L .787 .211 .013 r
F
.14786 .07072 m .14299 .01195 L .14297 .01194 L F
.03048 .0903 m .02396 .01194 L .03045 .09029 L F
.03048 .0903 m .02399 .01195 L .02396 .01194 L F
.05569 .16448 m .03045 .09029 L .04977 .16651 L .479 .526 .746 r
F
.05569 .16448 m .03663 .08926 L .03045 .09029 L F
.06161 .16244 m .03663 .08926 L .05569 .16448 L F
.06161 .16244 m .04281 .08823 L .03663 .08926 L F
.06754 .16041 m .04281 .08823 L .06161 .16244 L F
.06754 .16041 m .04899 .0872 L .04281 .08823 L F
.07346 .15838 m .04899 .0872 L .06754 .16041 L F
.07346 .15838 m .05517 .08617 L .04899 .0872 L F
.07939 .15634 m .05517 .08617 L .07346 .15838 L F
.07939 .15634 m .06135 .08514 L .05517 .08617 L F
.08531 .15431 m .06135 .08514 L .07939 .15634 L F
.08531 .15431 m .06752 .08411 L .06135 .08514 L F
.09123 .15227 m .06752 .08411 L .08531 .15431 L F
.09123 .15227 m .0737 .08308 L .06752 .08411 L F
.09716 .15024 m .0737 .08308 L .09123 .15227 L F
.09716 .15024 m .07988 .08205 L .0737 .08308 L F
.10308 .14821 m .07988 .08205 L .09716 .15024 L F
.10308 .14821 m .08606 .08101 L .07988 .08205 L F
.10901 .14617 m .08606 .08101 L .10308 .14821 L F
.10901 .14617 m .09224 .07998 L .08606 .08101 L F
.11493 .14414 m .09224 .07998 L .10901 .14617 L F
.11493 .14414 m .09841 .07895 L .09224 .07998 L F
.12086 .14211 m .09841 .07895 L .11493 .14414 L F
.12086 .14211 m .10459 .07792 L .09841 .07895 L F
.12678 .14007 m .10459 .07792 L .12086 .14211 L F
.12678 .14007 m .11077 .07689 L .10459 .07792 L F
.1327 .13804 m .11077 .07689 L .12678 .14007 L F
.1327 .13804 m .11695 .07586 L .11077 .07689 L F
.13863 .136 m .11695 .07586 L .1327 .13804 L F
.13863 .136 m .12313 .07483 L .11695 .07586 L F
.14455 .13397 m .12313 .07483 L .13863 .136 L F
.14455 .13397 m .12931 .0738 L .12313 .07483 L F
.15048 .13194 m .12931 .0738 L .14455 .13397 L F
.15048 .13194 m .13548 .07277 L .12931 .0738 L F
.1564 .1299 m .13548 .07277 L .15048 .13194 L F
.1564 .1299 m .14166 .07174 L .13548 .07277 L F
.16232 .12787 m .14166 .07174 L .1564 .1299 L F
.16232 .12787 m .14784 .0707 L .14166 .07174 L F
.03663 .08926 m .02396 .01194 L .03045 .09029 L F
.03663 .08926 m .03022 .01194 L .02396 .01194 L F
.04281 .08823 m .03022 .01194 L .03663 .08926 L F
.04281 .08823 m .03649 .01194 L .03022 .01194 L F
.04899 .0872 m .03649 .01194 L .04281 .08823 L F
.04899 .0872 m .04275 .01194 L .03649 .01194 L F
.05517 .08617 m .04275 .01194 L .04899 .0872 L F
.05517 .08617 m .04901 .01194 L .04275 .01194 L F
.06135 .08514 m .04901 .01194 L .05517 .08617 L F
.06135 .08514 m .05528 .01194 L .04901 .01194 L F
.06752 .08411 m .05528 .01194 L .06135 .08514 L F
.06752 .08411 m .06154 .01194 L .05528 .01194 L F
.0737 .08308 m .06154 .01194 L .06752 .08411 L F
.0737 .08308 m .0678 .01194 L .06154 .01194 L F
.07988 .08205 m .0678 .01194 L .0737 .08308 L F
.07988 .08205 m .07407 .01194 L .0678 .01194 L F
.08606 .08101 m .07407 .01194 L .07988 .08205 L F
.08606 .08101 m .08033 .01194 L .07407 .01194 L F
.09224 .07998 m .08033 .01194 L .08606 .08101 L F
.09224 .07998 m .08659 .01194 L .08033 .01194 L F
.09841 .07895 m .08659 .01194 L .09224 .07998 L F
.09841 .07895 m .09286 .01194 L .08659 .01194 L F
.10459 .07792 m .09286 .01194 L .09841 .07895 L F
.10459 .07792 m .09912 .01194 L .09286 .01194 L F
.11077 .07689 m .09912 .01194 L .10459 .07792 L F
.11077 .07689 m .10539 .01194 L .09912 .01194 L F
.11695 .07586 m .10539 .01194 L .11077 .07689 L F
.11695 .07586 m .11165 .01194 L .10539 .01194 L F
.12313 .07483 m .11165 .01194 L .11695 .07586 L F
.12313 .07483 m .11791 .01194 L .11165 .01194 L F
.12931 .0738 m .11791 .01194 L .12313 .07483 L F
.12931 .0738 m .12418 .01194 L .11791 .01194 L F
.13548 .07277 m .12418 .01194 L .12931 .0738 L F
.13548 .07277 m .13044 .01194 L .12418 .01194 L F
.14166 .07174 m .13044 .01194 L .13548 .07277 L F
.14166 .07174 m .1367 .01194 L .13044 .01194 L F
.14784 .0707 m .1367 .01194 L .14166 .07174 L F
.14784 .0707 m .14297 .01194 L .1367 .01194 L F
.31394 .34693 m .365 .37685 L .33524 .4284 L p 0 1 0 r
F P
0 g
s
.33524 .4284 m .28418 .39848 L .31394 .34693 L p 0 1 0 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 143.5},
  ImageMargins->{{164.312, 0}, {0, 4}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Sa000`40O003h00OogoL8GoL003oOm`Q
Om`00?mog25og000SgoL00<007oLOm`0SWoL0007Om`R?QMVOm`00`00Omaog01SOm`R?QL9Om`000Mo
g28n5fEog003001og7oL06Aog28n5`Uog0001goL8ShGIGoL00<007oLOm`0I7oL8ShG2GoL0007Om`R
?QMTOm`00`00Omaog01UOm`R?QL9Om`000Mog28n5f=og003001og7oL06Iog28n5`Uog0001goL8ShG
HgoL00<007oLOm`0IWoL8ShG2GoL0008Om`Q?QMROm`00`00Omaog01WOm`R?QL9Om`000Qog24n5f9o
g003001og7oL06Mog24n5`Yog00027oL8ShGH7oL00<007oLOm`0J7oL8ChG2WoL0008Om`R?QMPOm`0
0`00Omaog01WOm`R?QL:Om`000Qog28n5emog003001og7oL06Qog28n5`Yog00027oL8ShGGWoL00<0
07oLOm`0JGoL8ShG2WoL0008Om`R?QMNOm`00`00Omaog01YOm`R?QL:Om`000Qog28n5eeog003001o
g7oL06Yog28n5`Yog00027oL8ShGGGoL00<007oLOm`0JWoL8ShG2WoL0008Om`R?QMLOm`00`00Omao
g01[Om`R?QL:Om`000Qog28n5eaog003001og7oL06]og28n5`Yog0002GoL8ChGFgoL00<007oLOm`0
K7oL8ShG2WoL0009Om`Q?QMJOm`00`00Omaog01]Om`Q?QL;Om`000Uog28n5eUog003001og7oL06eo
g24n5`]og0002GoL8ShGF7oL00<007oLOm`0KGoL8ShG2goL0009Om`R?QMHOm`00`00Omaog01]Om`R
?QL;Om`000Uog28n5`03I<1og7oL05Aog003001og7oL06iog28n5`]og0002GoL8chGEWoL00<007oL
Om`0KGoL8chG2goL0009Om`S?QMEOm`00`00Omaog01^Om`S?QL;Om`000Yog28n5`03I<1og7oL055o
g003001og7oL06mog2<n5`]og0002WoL8ShG00=T`7oLOm`0DGoL00<007oLOm`0KWoL8chG37oL000:
Om`R?QL00fC0Omaog01@Om`00`00Omaog01_Om`S?QL<Om`000Yog2<n5e9og003001og7oL06mog2<n
5`aog0002WoL8chG00=T`7oLOm`0CWoL00<007oLOm`0L7oL8chG37oL000;Om`R?QL00fC0Omaog01>
Om`00`00Omaog01_Om`T?QL<Om`000]og28n5`03I<1og7oL04eog003001og7oL071og2<n5`eog000
2goL8chG00=T`7oLOm`0BgoL00<007oLOm`0LGoL8chG3GoL000;Om`S?QL00fC0Omaog01;Om`00`00
Omaog01`Om`T?QL=Om`000aog28n5`03I<1og7oL04Yog003001og7oL075og2@n5`eog00037oL8chG
00=T`7oLOm`0BGoL00<007oLOm`0LGoL8chG3WoL000<Om`S?QL00fC0Omaog018Om`00`00Omaog01a
Om`T?QL>Om`000aog2@n5dYog003001og7oL075og2@n5`iog0003GoL8chG00=T`7oLOm`0AWoL00<0
07oLOm`0LWoL93hG3WoL000=Om`T?QM7Om`00`00Omaog01bOm`T?QL?Om`000eog2@n5`03I<1og7oL
04Aog003001og7oL079og2@n5`mog0003GoL9ChGAGoL00<007oLOm`0LWoL9ChG3goL000=Om`U?QM5
Om`00`00Omaog01bOm`U?QL?Om`000iog2@n5`03I<1og7oL045og003001og7oL07=og2Dn5`mog000
3WoL9ChG@WoL00<007oLOm`0LgoL9ChG47oL000>Om`U?QL00fC0Omaog00oOm`00`00Omaog01cOm`U
?QL@Om`000mog2Dn5d1og003001og7oL07=og2Hn5a1og0003goL9ChG@7oL00<007oLOm`0LgoL9ChG
4GoL000@Om`U?QLnOm`00`00Omaog01dOm`U?QLAOm`0011og2Dn5ciog003001og7oL07=og2Dn5a9o
g00047oL9ShG?7oL00<007oLOm`0M7oL9ChG4WoL000AOm`V?QLjOm`00`00Omaog01dOm`V?QLBOm`0
015og2Hn5`03I<1og7oL03Mog003001og7oL07=og2Hn5a=og0004WoL9ShG>7oL00<007oLOm`0LgoL
9chG4goL000BOm`W?QLgOm`00`00Omaog01cOm`V?QLDOm`001=og2Hn5`03I<1og7oL03=og003001o
g7oL07=og2Ln5aAog0004goL9chG=GoL00<007oLOm`0LWoL9chG5GoL000DOm`V?QL00fC0Omaog00a
Om`00`00Omaog01cOm`W?QLEOm`001Aog2Ln5`03I<1og7oL02mog003001og7oL07=og2Ln5aIog000
5GoL9chG00=T`7oLOm`0;WoL00<007oLOm`0LWoL:3hG5WoL000EOm`W?QL00fC0Omaog00]Om`00`00
Omaog01bOm`X?QLGOm`001Eog2Pn5`03I<1og7oL02aog003001og7oL079og2Pn5aMog0005WoL:3hG
00=T`7oLOm`0:WoL00<007oLOm`0LWoL:ChG5goL000FOm`X?QL00fC0Omaog00ZOm`00`00Omaog01a
Om`Y?QLHOm`001Mog2Pn5`03I<1og7oL02Qog003001og7oL079og2Tn5aQog0005goL:ChG00=T`7oL
Om`09WoL00<007oLOm`0LWoL:ChG6GoL000HOm`Y?QL00fC0Omaog00UOm`00`00Omaog01aOm`Z?QLI
Om`001Uog2Tn5`03I<1og7oL02=og003001og7oL075og2Xn5aYog0006GoL:ShG00=T`7oLOm`08WoL
00<007oLOm`0L7oL:ShG6goL000JOm`Z?QL00fC0Omaog00POm`00`00Omaog01`Om`[?QLKOm`001]o
g2Xn5b9og003001og7oL06mog2/n5aaog0006goL:chG87oL00<007oLOm`0L7oL:ShG7GoL000LOm`[
?QLNOm`00`00Omaog01`Om`[?QLMOm`001eog2/n5aeog003001og7oL06mog2/n5aiog0007WoL:chG
6goL00<007oLOm`0KgoL:chG7goL000NOm`/?QLJOm`00`00Omaog01^Om`[?QLPOm`001mog2dn5aMo
g003001og7oL06eog2dn5b1og00087oL;ChG5WoL00<007oLOm`0K7oL;ChG8GoL000POm`^?QLDOm`0
0`00Omaog01/Om`]?QLROm`0025og2ln5a5og003001og7oL06]og2ln5b9og0008WoL;chG47oL00<0
07oLOm`0JWoL;chG8goL000ROm``?QL>Om`00`00Omaog01ZOm`_?QLTOm`002=og30n5`eog003001o
g7oL06Uog30n5bAog00097oL<ChG2WoL00<007oLOm`0J7oL<ChG9GoL000TOm`b?QL9Om`00`00Omao
g01WOm`a?QLVOm`002Eog38n5`Mog003001og7oL06Mog38n5bIog0009WoL<chG17oL00<007oLOm`0
IWoL<chG9goL000WOm`d?QL2Om`00`00Omaog01TOm`d?QLXOm`002Qog3Dn5fEog3Dn5bUog000:GoL
=ShGHGoL=ShG:WoL000ZOm`f?QMOOm`f?QL[Om`002]og3Ln5e]og3Ln5baog000;7oL>3hGEgoL>3hG
;GoL000/Om`j?QMCOm`i?QL^Om`002eog3`n5deog3`n5biog000;WoL:ShG100043hGAgoL?ShG;goL
000_Om`Y?QL20n000`000n00000B?QM1Oma0?QL`Om`0031og2Ln5`83h0040003h0?P0n02000C?QLk
Oma2?QLaOm`0035og2Hn5`030n0000?P00D3h003000n5chG01<n5cEog4@n5c9og000<WoL93hG0P?P
00<000?P0n001@?P0P0063hG:goLB3hG<goL000cOm`R?QL20n000`000n03h0080n02000L?QLOOma=
?QLdOm`003Eog20n5`83h0030003h0?P00X3h003000n5chG01hn5aEog50n5cIog000=WoL7chG00<3
h0000n003@?P0P00PShG=goL000gOm`M?QL00`?P0003h00@0n000`00?QLn5`1n?QLhOm`003Uog1Xn
5`83h0030003h0?P0103h003000n5goL07/n5cYog000>WoL6ChG00<3h0000n004P?P00<003hG?QL0
0ShG00=og3hG?QL0MChG>goL000lOm`F?QL20n000`000n03h00@0n000`00?QLn5`06?QL00goL?QLn
5`1`?QLmOm`003eog1@n5`83h0030003h0?P0143h003000n5chG00Tn5`03Om`n5chG06`n5ciog000
?WoL4chG00<3h0000n004P?P00<003hG?QL0N3hG?goL0010Om`A?QL00`?P0003h00B0n000`00?QLn
5`1f?QM1Om`0045og0hn5`@00183h003000n5chG07Hn5d9og000@goL3ShG0P?P0P0040?P00<003hG
?QL0M3hGA7oL0014Om`??QL20n000`000n03h00<0n000`00?QLn5`1d?QM5Om`004Eog10n5`030n00
000000/3h003000n5chG07@n5dIog000AgoL43hG00<3h00000002@?P00<003hG?QL0LShGB7oL0019
Om`??QL20n000`000n03h0050n000`00?QLn5`1a?QM:Om`004Yog10n5`030n00000000D3h003000n
5chG070n5d]og000BgoL00<003hG?QL03ShG00<3h00000000P?P00<003hG?QL0KchGCGoL001>Om`?
?QL20n000`000n00001_?QM?Om`0051og10n5`03000n5chG06`n5e5og000DGoLOChGDWoL001COmai
?QMDOm`005Eog7Dn5eIog000EWoLLchGEgoL001HOma_?QMIOm`005]og6Tn5eaog000GWoLHchGGgoL
001QOmaM?QMROm`006Aog5Ln5fEog000IgoLDChGJ7oL001ZOma;?QM[Om`006eog4Dn5fiog000LWoL
>chGLgoL001gOm`a?QMhOm`007eog2Dn5giog000PWoL6chGPgoL003oOm`QOm`00?mog25og000ogoL
8GoL0000\
\>"],
  ImageRangeCache->{{{0, 287}, {142.5, 0}} -> {-0.00179179, 0.250852, \
0.00349681, 0.00349681}}],

Cell["Box on a circular inclined plane, top view", "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "In this example its not quite so  simple a matter to describe the position \
of the block, the orientation of the block, the speed of the block and the \
color of the block as it slides down the plane, although we would probably \
agree that each of these factors was a function of time, ",
  Cell[BoxData[
      \(t\)]],
  ".  Further, if we are to produce animation frames that will play at ",
  Cell[BoxData[
      \(24\)]],
  " frames per second (film) or ",
  Cell[BoxData[
      \(30\)]],
  " frames per second (computer graphics), we will have to be able to \
construct versions of the scene for equally spaced time intervals.  "
}], "Text"],

Cell[TextData[{
  "Borrowing the physics term for abstract motion, we call the control of the \
parameters we need ",
  StyleBox["kinetic",
    FontWeight->"Bold"],
  " control.  The kinetic parameters we have mentioned are position, a three \
dimensional quantity; orientation, basically a bounded two dimensional \
quantity (we'll explain that a little later); velocity, a three dimensional \
vector valued quantity; and color, a bounded three dimensional quantity.  \
There are of course many others but most of what we will have to say in this \
chapter can be illustrated using these parameters.  "
}], "Text"],

Cell[CellGroupData[{

Cell["Key Frames and Interpolation", "Subsection"],

Cell[CellGroupData[{

Cell["Linear Interpolation", "Subsubsection"],

Cell[TextData[{
  "Let's be specific.  For an object in a scene, we will specify a point on \
or in the object (perhaps the center, or center of gravity of the object) and \
we will agree that we have described the position of the object when we have \
given the location in three dimensional space of the specified point.  Look \
at the block sliding down the simple wedge.  If we assume the block in its \
own (model) coordinate system is half of the unit box ( i.e. the block from \
",
  Cell[BoxData[
      \(\((0, 0, 0)\)\)]],
  " to ",
  Cell[BoxData[
      \(\((0.5, 0.5, 0.5)\)\)]],
  "), then a convenient locator point would be the point corresponding to ",
  Cell[BoxData[
      \(\((0, 0, 0)\)\)]],
  StyleBox[" ", "Output",
    FontSize->16],
  "(the red point in the figure above).  If the scene we are animating is to \
take ",
  Cell[BoxData[
      \(5\)]],
  " seconds, then we need a function "
}], "Text"],

Cell[BoxData[
    RowBox[{"\t\t", 
      RowBox[{
        OverscriptBox[
          StyleBox["p",
            FontWeight->"Bold"], "\[RightVector]"], ":", 
        RowBox[{
        Cell["[0, 5]"], "\[RightArrow]", 
          " ", \(\[DoubleStruckCapitalR]\^3\)}]}]}]], "Text"],

Cell[TextData[{
  "with the property that ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["p",
            FontWeight->"Bold"], "\[RightVector]"], \((0)\)}]]],
  "  is the position of the red point at the top of the ramp and ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["p",
            FontWeight->"Bold"], "\[RightVector]"], \((5)\)}]]],
  "  is the position of the point at the bottom of the ramp.  If the ramp's \
dimensions are as given below, then ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["p",
            FontWeight->"Bold"], "\[RightVector]"], \((0)\)}]]],
  " ",
  Cell[BoxData[
      \(\(\(=\)\(\ \)\((0.3, \ 0.25, \ 1.925)\)\)\)]],
  "  (this is an arbitrary choice)  and  ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["p",
            FontWeight->"Bold"], "\[RightVector]"], \((5)\)}]]],
  " \[TildeTilde] ",
  Cell[BoxData[
      \(\((7.51493, \ 0.25, \ 0.121268)\)\)]],
  " (this places the other end of the block at the bottom of the ramp)."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .125
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1 -0.4375 1 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[-0.0125 .00298 -6 -4.5 ]
[-0.0125 .00298 0 4.5 ]
[-0.0125 .03274 -24 -4.5 ]
[-0.0125 .03274 0 4.5 ]
[-0.0125 .0625 -18 -4.5 ]
[-0.0125 .0625 0 4.5 ]
[-0.0125 .09226 -24 -4.5 ]
[-0.0125 .09226 0 4.5 ]
[-0.0125 .12202 -6 -4.5 ]
[-0.0125 .12202 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(6)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(8)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
0 .125 L
s
0 .00298 m
.00625 .00298 L
s
[(0)] -0.0125 .00298 1 0 Mshowa
0 .03274 m
.00625 .03274 L
s
[(0.25)] -0.0125 .03274 1 0 Mshowa
0 .0625 m
.00625 .0625 L
s
[(0.5)] -0.0125 .0625 1 0 Mshowa
0 .09226 m
.00625 .09226 L
s
[(0.75)] -0.0125 .09226 1 0 Mshowa
0 .12202 m
.00625 .12202 L
s
[(1)] -0.0125 .12202 1 0 Mshowa
.125 Mabswid
0 .00893 m
.00375 .00893 L
s
0 .01488 m
.00375 .01488 L
s
0 .02083 m
.00375 .02083 L
s
0 .02679 m
.00375 .02679 L
s
0 .03869 m
.00375 .03869 L
s
0 .04464 m
.00375 .04464 L
s
0 .0506 m
.00375 .0506 L
s
0 .05655 m
.00375 .05655 L
s
0 .06845 m
.00375 .06845 L
s
0 .0744 m
.00375 .0744 L
s
0 .08036 m
.00375 .08036 L
s
0 .08631 m
.00375 .08631 L
s
0 .09821 m
.00375 .09821 L
s
0 .10417 m
.00375 .10417 L
s
0 .11012 m
.00375 .11012 L
s
0 .11607 m
.00375 .11607 L
s
.25 Mabswid
.00125 .00016 m
0 0 L
s
0 0 m
0 .125 L
s
0 .125 m
.00125 .12484 L
s
.00125 .12484 m
.00125 .00016 L
s
.99875 .00016 m
.99875 .12484 L
s
.99875 .12484 m
1 .125 L
s
1 .125 m
1 0 L
s
1 0 m
.99875 .00016 L
s
.00125 .00016 m
0 0 L
s
0 0 m
1 0 L
s
1 0 m
.99875 .00016 L
s
.99875 .00016 m
.00125 .00016 L
s
.00125 .12484 m
.99875 .12484 L
s
.99875 .12484 m
1 .125 L
s
1 .125 m
0 .125 L
s
0 .125 m
.00125 .12484 L
s
0 0 m
1 0 L
1 .125 L
0 .125 L
closepath
clip
newpath
.5 Mabswid
.02384 .12202 m .02497 .12188 L .02497 .00312 L p .942 .769 .304 r
F P
0 g
s
.02497 .00312 m .02384 .00298 L .02384 .12202 L p .942 .769 .304 r
F P
0 g
s
.02497 .12188 m .02384 .12202 L .97503 .12188 L closepath p .042 0 0 r
F P
0 g
s
.97503 .12188 m .97503 .00312 L .02497 .00312 L p .707 .577 .707 r
F P
0 g
s
.02497 .00312 m .02497 .12188 L .97503 .12188 L p .707 .577 .707 r
F P
0 g
s
.02497 .00312 m .97503 .00312 L .02384 .00298 L closepath p .042 .611 .748 r
F P
0 g
s
.02384 .12202 m .02384 .00298 L .97503 .00312 L p .709 .579 .707 r
F P
0 g
s
.97503 .00312 m .97503 .12188 L .02384 .12202 L p .709 .579 .707 r
F P
0 g
s
.25 Mabswid
0 0 m
0 .125 L
s
0 .00298 m
.00625 .00298 L
s
[(0)] -0.0125 .00298 1 0 Mshowa
0 .03274 m
.00625 .03274 L
s
[(0.25)] -0.0125 .03274 1 0 Mshowa
0 .0625 m
.00625 .0625 L
s
[(0.5)] -0.0125 .0625 1 0 Mshowa
0 .09226 m
.00625 .09226 L
s
[(0.75)] -0.0125 .09226 1 0 Mshowa
0 .12202 m
.00625 .12202 L
s
[(1)] -0.0125 .12202 1 0 Mshowa
.125 Mabswid
0 .00893 m
.00375 .00893 L
s
0 .01488 m
.00375 .01488 L
s
0 .02083 m
.00375 .02083 L
s
0 .02679 m
.00375 .02679 L
s
0 .03869 m
.00375 .03869 L
s
0 .04464 m
.00375 .04464 L
s
0 .0506 m
.00375 .0506 L
s
0 .05655 m
.00375 .05655 L
s
0 .06845 m
.00375 .06845 L
s
0 .0744 m
.00375 .0744 L
s
0 .08036 m
.00375 .08036 L
s
0 .08631 m
.00375 .08631 L
s
0 .09821 m
.00375 .09821 L
s
0 .10417 m
.00375 .10417 L
s
0 .11012 m
.00375 .11012 L
s
0 .11607 m
.00375 .11607 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{108.812, Inherited}, {Inherited, Inherited}},
  ImageSize->{259.875, 64.875},
  ImageMargins->{{72.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000430000@1000`40O003h00OogoL17oL003oOm`4
Om`00?mog0Aog000ogoL17oL003oOm`4Om`00?mog0Aog000ogoL17oL003oOm`4Om`00?mog0Aog000
ogoL17oL000OOm`2000cOm`5000dOm`3000dOm`3000dOm`30005Om`001iog004001og7oL000cOm`0
1000Omaog000=GoL00<007oLOm`0<WoL00D007oLOmaog000039og005001og7oLOm`00004Om`001io
g004001og7oL000dOm`00`00Omaog00bOm`5000cOm`01@00Omaog7oL0000<WoL00D007oLOmaog000
00Aog0007WoL00@007oLOm`003Eog003001og7oL035og004001og7oL000dOm`4000dOm`30005Om`0
01iog004001og7oL000bOm`01@00Omaog7oL0000<goL00<007oL0000=7oL00<007oLOm`0=7oL00D0
07oLOmaog00000Aog0007WoL00@007oLOm`0039og005001og7oLOm`0000dOm`2000eOm`00`00Omao
g00cOm`01@00Omaog7oL000017oL000OOm`2000dOm`3000fOm`00`00Omaog00dOm`2000dOm`30005
Om`00?mog0Aog000ogoL17oL000DOm`2003]Om`001=og004001og7oL003/Om`001=og004001og7oL
0003OmcY000001=og004001og7oL0003Om`30003OmcN0004Om`1000001=og004001og7oL0003Om`2
0004Om`00`00FUIJEP3JFUH00`00Omaog002Om`1000001=og004001og7oL0003Om`20004Om`00`00
FUIJEP3JFUH00`00Omaog002Om`1000001Aog08000Aog08000Aog003001JEUYF0=YJEP03001og7oL
009og04000000WoL0P0017oL00@007oLOmaog0D0009og0<000Aog08000Aog003001JEUYF0=YJEP03
001og7oL009og040000000Eog000Omaog00000Qog006001og7oL001og0000goL00@007oLOmaog080
00Aog003001JEUYF0=YJEP03001og7oL009og040000000Eog000Omaog00000Uog003001og7oL00Eo
g004001og7oLOm`20004Om`00`00FUIJEP3JFUH00`00Omaog002Om`100000005Om`007oLOm`0000:
Om`00`00Omaog004Om`01000Omaog7oL0`000goL00<005YFFUH0fUYF00<007oLOm`00WoL0@000000
1GoL001og7oL00001goL00H007oLOmaog000Om`40004Om`20004Om`00`00FUIJEP3JFUH00`00Omao
g002Om`100000005Om`007oLOm`00007Om`01`00Omaog7oL001og00000Mog08000Aog003001JEUYF
0=YJEP03001og7oL009og04000000WoL0P002GoL0`000WoL1@000goL0P0017oL00<005YFFUH0fUYF
00<007oLOm`00WoL0@000008Om`20004Om`00`00Omaog002Om`30004Om`20004Om`00`00FUIJEP3J
FUH00`00Omaog002Om`1000000Mog004001og7oL0007Om`01@00Omaog7oL00000goL0P0017oL00<0
05YFFUH0fUYF00<007oLOm`00WoL0@000007Om`01000Omaog0002goL00@007oLOmaog08000Aog003
001JEUYF0=YJEP03001og7oL009og04000001goL00@007oLOm`000]og004001og7oLOm`30003Om`0
0`00FUIJEP3JFUH00`00Omaog002Om`1000000Mog004001og7oL0007Om`40004Om`20004Om`00`00
FUIJEP3JFUH00`00Omaog002Om`1000000Mog004001og7oL0007Om`00`00Omaog005Om`20004Om`0
0`00FUIJEP3JFUH00`00Omaog002Om`1000000Qog08000Qog0D000=og08000Aog003001JEUYF0=YJ
EP03001og7oL009og04000000WoL0P0017oL00<007oLOm`00goL00<007oLOm`00WoL0`0017oL0P00
17oL00<005YFFUH0fUYF00<007oLOm`00WoL0@0000001GoL001og7oL00002GoL00D007oLOmaog000
00=og004001og7oLOm`20004Om`00`00FUIJEP3JFUH00`00Omaog002Om`100000005Om`007oLOm`0
000:Om`00`00Omaog004Om`01000Omaog7oL0P0017oL00<005YFFUH0fUYF00<007oLOm`00WoL0@00
00001GoL001og7oL00002WoL00<007oLOm`017oL00@007oLOmaog0<000=og003001JEUYF0=YJEP03
001og7oL009og040000000Eog000Omaog00000]og003001og00000<000Aog08000Aog003001JEUYF
0=YJEP03001og7oL009og040000000Eog000Omaog00000Mog007001og7oLOm`007oL00001goL0P00
17oL00<005YFFUH0fUYF00<007oLOm`00WoL0@000002Om`20008Om`500000goL000000030003Om`2
0004Om`00`00FUIJEP3JFUH00`00Omaog002Om`1000001=og0<000Aog08000Aog003001JEUYF0=YJ
EP03001og7oL009og040000057oL00<007oLOm`00goL0P0017oL00<005YFFUH0fUYF00<007oLOm`0
0WoL0@00000DOm`00`00Omaog003Om`30003OmcN0004Om`1000001Aog003001og7oL00=og>T00000
57oL00<007oLOm`0k7oL000COm`2003^Om`001Aog003001og7oL0>aog000ogoL17oL003oOm`4Om`0
0?mog0Aog000ogoL17oL003oOm`4Om`00?mog0Aog000ogoL17oL003oOm`4Om`00?mog0Aog000ogoL
17oL0000\
\>"],
  ImageRangeCache->{{{0, 258.875}, {63.875, 0}} -> {-0.115965, 0.344883, \
0.00431085, 0.00431085}}],

Cell["The simple wedge, top .", "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 -0.375 1 [
[.01172 -0.00317 -6 -5.68125 ]
[.01172 -0.00317 0 3.31875 ]
[.25084 -0.00581 -6 -6.8625 ]
[.25084 -0.00581 0 2.1375 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74916 -0.00581 0 -6.8625 ]
[.74916 -0.00581 6 2.1375 ]
[.98828 -0.00317 0 -5.68125 ]
[.98828 -0.00317 6 3.31875 ]
[-0.0125 .00595 -6 -4.5 ]
[-0.0125 .00595 0 4.5 ]
[-0.0125 .06548 -18 -4.5 ]
[-0.0125 .06548 0 4.5 ]
[-0.0125 .125 -6 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .18452 -18 -4.5 ]
[-0.0125 .18452 0 4.5 ]
[-0.0125 .24405 -6 -4.5 ]
[-0.0125 .24405 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
.02381 0 m
.02985 .00159 L
s
[(0)] .01172 -0.00317 1 .2625 Mshowa
.2619 0 m
.26744 .00291 L
s
[(2)] .25084 -0.00581 1 .525 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.73256 .00291 L
s
[(6)] .74916 -0.00581 -1 .525 Mshowa
.97619 0 m
.97015 .00159 L
s
[(8)] .98828 -0.00317 -1 .2625 Mshowa
.125 Mabswid
.08333 0 m
.08693 .00108 L
s
.14286 0 m
.1464 .00124 L
s
.20238 0 m
.20584 .00145 L
s
.32143 0 m
.3245 .00215 L
s
.38095 0 m
.38354 .00272 L
s
.44048 0 m
.44209 .00339 L
s
.55952 0 m
.55791 .00339 L
s
.61905 0 m
.61646 .00272 L
s
.67857 0 m
.6755 .00215 L
s
.79762 0 m
.79416 .00145 L
s
.85714 0 m
.8536 .00124 L
s
.91667 0 m
.91307 .00108 L
s
.25 Mabswid
0 0 m
0 .25 L
s
0 .00595 m
.00625 .00595 L
s
[(0)] -0.0125 .00595 1 0 Mshowa
0 .06548 m
.00625 .06548 L
s
[(0.5)] -0.0125 .06548 1 0 Mshowa
0 .125 m
.00625 .125 L
s
[(1)] -0.0125 .125 1 0 Mshowa
0 .18452 m
.00625 .18452 L
s
[(1.5)] -0.0125 .18452 1 0 Mshowa
0 .24405 m
.00625 .24405 L
s
[(2)] -0.0125 .24405 1 0 Mshowa
.125 Mabswid
0 .01786 m
.00375 .01786 L
s
0 .02976 m
.00375 .02976 L
s
0 .04167 m
.00375 .04167 L
s
0 .05357 m
.00375 .05357 L
s
0 .07738 m
.00375 .07738 L
s
0 .08929 m
.00375 .08929 L
s
0 .10119 m
.00375 .10119 L
s
0 .1131 m
.00375 .1131 L
s
0 .1369 m
.00375 .1369 L
s
0 .14881 m
.00375 .14881 L
s
0 .16071 m
.00375 .16071 L
s
0 .17262 m
.00375 .17262 L
s
0 .19643 m
.00375 .19643 L
s
0 .20833 m
.00375 .20833 L
s
0 .22024 m
.00375 .22024 L
s
0 .23214 m
.00375 .23214 L
s
.25 Mabswid
0 0 m
0 .25 L
s
0 .25 m
.00062 .24984 L
s
.00062 .24984 m
.00062 .00016 L
s
.00062 .00016 m
0 0 L
s
1 0 m
.99938 .00016 L
s
.99938 .00016 m
.99938 .24984 L
s
.99938 .24984 m
1 .25 L
s
1 .25 m
1 0 L
s
0 0 m
0 .25 L
s
0 .25 m
1 .25 L
s
1 .25 m
1 0 L
s
1 0 m
0 0 L
s
.00062 .00016 m
.99938 .00016 L
s
.99938 .00016 m
.99938 .24984 L
s
.99938 .24984 m
.00062 .24984 L
s
.00062 .24984 m
.00062 .00016 L
s
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
.5 Mabswid
.02439 .2439 m .02439 .0061 L .02382 .00596 L p .942 .769 .304 r
F P
0 g
s
.02382 .00596 m .02382 .24404 L .02439 .2439 L p .942 .769 .304 r
F P
0 g
s
.02439 .0061 m .02439 .2439 L .97561 .0061 L closepath p .707 .577 .707 r
F P
0 g
s
.97561 .0061 m .97618 .00596 L .02382 .00596 L p .084 .642 .786 r
F P
0 g
s
.02382 .00596 m .02439 .0061 L .97561 .0061 L p .084 .642 .786 r
F P
0 g
s
.02439 .2439 m .02382 .24404 L .97618 .00596 L p 0 0 0 r
F P
0 g
s
.97618 .00596 m .97561 .0061 L .02439 .2439 L p 0 0 0 r
F P
0 g
s
.02382 .00596 m .97618 .00596 L .02382 .24404 L closepath p .707 .577 .707 r
F P
0 g
s
.25 Mabswid
0 0 m
0 .25 L
s
0 .25 m
1 .25 L
s
1 .25 m
1 0 L
s
1 0 m
0 0 L
s
0 0 m
1 0 L
s
.02381 0 m
.02985 .00159 L
s
[(0)] .01172 -0.00317 1 .2625 Mshowa
.2619 0 m
.26744 .00291 L
s
[(2)] .25084 -0.00581 1 .525 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.73256 .00291 L
s
[(6)] .74916 -0.00581 -1 .525 Mshowa
.97619 0 m
.97015 .00159 L
s
[(8)] .98828 -0.00317 -1 .2625 Mshowa
.125 Mabswid
.08333 0 m
.08693 .00108 L
s
.14286 0 m
.1464 .00124 L
s
.20238 0 m
.20584 .00145 L
s
.32143 0 m
.3245 .00215 L
s
.38095 0 m
.38354 .00272 L
s
.44048 0 m
.44209 .00339 L
s
.55952 0 m
.55791 .00339 L
s
.61905 0 m
.61646 .00272 L
s
.67857 0 m
.6755 .00215 L
s
.79762 0 m
.79416 .00145 L
s
.85714 0 m
.8536 .00124 L
s
.91667 0 m
.91307 .00108 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellMargins->{{99, Inherited}, {Inherited, Inherited}},
  ImageSize->{294.375, 73.3125},
  ImageMargins->{{68, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004V0000BA000`40O003h00OogoL9goL002JOm`3
0029Om`009]og003001og7oL08Qog000V7oL1@00RGoL002HOm`01000Omaog000RWoL001LOm`5000h
Om`00`00Om`0000iOm`3001>Om`005eog004001og7oL000iOm`2000hOm`01@00Omaog7oL0000CGoL
000WOm`2000eOm`00`00Omaog00jOm`00`00Omaog00fOm`01@00Omaog7oL0000<goL0`005goL000V
Om`01000Omaog000=GoL00<007oLOm`0LWoL1000<goL00D007oLOmaog00001Iog0009WoL00@007oL
Om`0039og005001og7oLOm`0001cOm`00`00Omaog00dOm`01@00Omaog7oL00005WoL000VOm`01000
Omaog000<WoL00D007oLOmaog00007Aog003001og7oL03Aog0<001Mog0008GoL0P000goL00@007oL
Om`003=og0<007Iog08003=og005001og7oLOm`0000FOm`0021og004001og7oL0002Om`00`00Om`0
003W000FOm`0021og004001og7oL0003Om`40003OmcK0003Om`3000GOm`0021og004001og7oL0004
Om`00`00Omaog003Om`00`00FUIJEP3AFUH40007Om`2000GOm`0021og004001og7oL0004Om`00`00
Omaog003Om`00`00FUIJEP3=FUH4000;Om`2000GOm`0021og004001og7oL0004Om`20004Om`00`00
FUIJEP39FUH4000?Om`2000GOm`0025og08000Eog003001og7oL00=og003001JEUYF0<EJEP@001=o
g08001Mog000:7oL00<007oLOm`00goL00<005YFFUH0`EYF10005goL0P005goL000XOm`20004Om`0
0`00FUIJEP2mFUH4000KOm`2000GOm`002Qog003001og7oL00=og003001JEUYF0;UJEP@001mog080
01Mog000:7oL00<007oLOm`00goL00<005YFFUH0]EYF10008goL0P005goL000XOm`20004Om`00`00
FUIJEP2aFUH4000WOm`2000GOm`002Qog003001og7oL00=og003001JEUYF0:eJEP@002]og08001Mo
g000:7oL0P0017oL00<005YFFUH0ZEYF1000;goL0P005goL000EOm`20004Om`00`00Omaog002Om`3
0005Om`00`00Omaog003Om`00`00FUIJEP2UFUH4000cOm`2000GOm`001Aog004001og7oL0007Om`0
1@00Omaog7oL000017oL00<007oLOm`00goL00<005YFFUH0XEYF1000=goL0P005goL000DOm`01000
Omaog0002goL00<007oLOm`00WoL0`000goL00<005YFFUH0WUYF0`00>goL0P005goL000DOm`01000
Omaog0002goL00<007oLOm`00WoL00<007oLOm`00goL00<005YFFUH0VUYF1000?WoL0P005goL000D
Om`01000Omaog0001goL10001GoL00<007oLOm`00goL00<005YFFUH0UUYF1000@WoL0P005goL000D
Om`01000Omaog0001goL00<007oLOm`01WoL0P0017oL00<005YFFUH0TUYF1000AWoL0P005goL000E
Om`20008Om`50004Om`00`00Omaog003Om`00`00FUIJEP2>FUH4001:Om`2000GOm`002Qog003001o
g7oL00=og003001JEUYF08YJEP@004iog08001Mog000:7oL0P0017oL00<005YFFUH0QUYF1000DWoL
0P005goL000XOm`00`00Omaog003Om`00`00FUIJEP22FUH4001FOm`2000GOm`002Qog08000Aog003
001JEUYF07iJEP@005Yog08001Mog000:7oL00<007oLOm`00goL00<005YFFUH0NUYF1000GWoL0P00
5goL000XOm`00`00Omaog003Om`00`00FUIJEP1fFUH4001ROm`2000GOm`0021og0<000Eog08000Ao
g003001JEUYF079JEP@006Iog08001Mog0008GoL00<007oLOm`017oL00<007oLOm`00goL00<005YF
FUH0KUYF1000JWoL0P005goL000QOm`00`00Omaog004Om`00`00Omaog003Om`00`00FUIJEP1ZFUH4
001^Om`2000GOm`0025og003001og7oL00Aog0<000=og003001JEUYF06IJEP@0079og08001Mog000
8GoL00<007oLOm`017oL00<007oLOm`00goL00<005YFFUH0HUYF1000MWoL0P005goL000POm`20006
Om`20004Om`00`00FUIJEP1NFUH4001jOm`2000GOm`0025og003001og7oL00Aog003001og7oL00=o
g003001JEUYF05YJEP@007iog08001Mog000:7oL00<007oLOm`00goL00<005YFFUH0EUYF1000PWoL
0P005goL000XOm`20004Om`00`00FUIJEP1BFUH40026Om`2000GOm`002Qog003001og7oL00=og003
001JEUYF04iJEP@008Yog08001Mog000:7oL00<007oLOm`00goL00<005YFFUH0BUYF1000SWoL0P00
5goL000XOm`20004Om`00`00FUIJEP16FUH4002BOm`2000GOm`002Qog003001og7oL00=og003001J
EUYF049JEP@009Iog08001Mog000:7oL00<007oLOm`00goL00<005YFFUH0?UYF1000VWoL0P005goL
000DOm`30004Om`00`00Omaog002Om`30005Om`20004Om`00`00FUIJEP0jFUH4002NOm`2000GOm`0
01Eog003001og7oL00Mog005001og7oLOm`00004Om`00`00Omaog003Om`00`00FUIJEP0fFUH4002R
Om`2000GOm`001Eog003001og7oL00]og003001og7oL009og0<000=og003001JEUYF03=JEP<00:Io
g08001Mog0005GoL00<007oLOm`02goL00<007oLOm`00WoL00<007oLOm`00goL00<005YFFUH0;eYF
1000ZGoL0P005goL000EOm`00`00Omaog007Om`40005Om`00`00Omaog003Om`00`00FUIJEP0[FUH4
002]Om`2000GOm`001Aog08000Uog003001og7oL00Iog08000Aog003001JEUYF02MJEP@00;5og080
01Mog0005GoL00<007oLOm`01goL1@0017oL00<007oLOm`00goL00<005YFFUH08eYF1000]GoL0P00
5goL000XOm`00`00Omaog003Om`00`00FUIJEP0OFUH4002iOm`2000GOm`002Qog08000Aog003001J
EUYF01]JEP@00;eog08001Mog000:7oL00<007oLOm`00goL00<005YFFUH05eYF1000`GoL0P005goL
000XOm`00`00Omaog003Om`00`00FUIJEP0CFUH40035Om`2000GOm`002Qog08000Aog003001JEUYF
00mJEP@00<Uog08001Mog000:7oL00<007oLOm`00goL00<005YFFUH02eYF1000cGoL0P005goL000O
Om`50004Om`20004Om`00`00FUIJEP07FUH4003AOm`2000GOm`0021og004001og7oL0004Om`00`00
Omaog003Om`00`00FUIJEP03FUH4003EOm`2000GOm`0025og003001og7oL00Aog003001og7oL00=o
g003001JEP0000<00=Uog08001Mog0008WoL00<007oLOm`00goL0`000goL0P00gGoL0P005goL000O
Om`01@00Omaog7oL000017oLi`005goL000OOm`01@00Omaog7oL0000ogoL0goL000POm`3003oOm`4
Om`00?mog2Mog000\
\>"],
  ImageRangeCache->{{{0, 293.375}, {72.3125, 0}} -> {-0.178165, 0.323239, \
0.00436221, 0.00436221}}],

Cell["The simple wedge,  front.", "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The simplest geometric entity in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  " with these properties is the line segment from ",
  Cell[BoxData[
      SubscriptBox[
        OverscriptBox[
          StyleBox["p",
            FontWeight->"Bold"], "\[RightVector]"], "0"]]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\((\(- .3\), \ 0.25, \ 1.925)\)\)\)\)]],
  "   to ",
  Cell[BoxData[
      SubscriptBox[
        OverscriptBox[
          StyleBox["p",
            FontWeight->"Bold"], "\[RightVector]"], "1"]]],
  " ",
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\((7.51493, \ 0.25, \ 0.121268)\)\)\)\)]],
  ".  The  parametric equation of this line segment is"
}], "Text"],

Cell[BoxData[
    RowBox[{"\t\t", 
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox["f",
              FontWeight->"Bold"], "\[RightVector]"], \((u)\)}], " ", "=", 
        " ", 
        RowBox[{
          RowBox[{
            RowBox[{\((1 - u)\), 
              SubscriptBox[
                OverscriptBox[
                  StyleBox["p",
                    FontWeight->"Bold"], "\[RightVector]"], "0"]}], " ", "+", 
            " ", 
            RowBox[{"u", " ", 
              SubscriptBox[
                OverscriptBox[
                  StyleBox["p",
                    FontWeight->"Bold"], "\[RightVector]"], "1"], " ", 
              StyleBox["for",
                FontFamily->"Times"], " ", "0"}]}], " ", "\[LessEqual]", " ", 
          "u", " ", "\[LessEqual]", " ", "1."}]}]}]], "Text"],

Cell[TextData[{
  "Since our time parameter has to range from ",
  Cell[BoxData[
      \(0\)]],
  " to ",
  Cell[BoxData[
      \(5\)]],
  " , we map the interval ",
  Cell[BoxData[
      \(\([0, 5]\) \[RightArrow] \([0, 1]\)\)]],
  "  by multiplying by ",
  Cell[BoxData[
      \(1\/5\)]],
  ".  So our function ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["p",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " is "
}], "Text"],

Cell[BoxData[
    RowBox[{"\t\t", 
      RowBox[{
        StyleBox[
          RowBox[{
            OverscriptBox[
              StyleBox["p",
                FontWeight->"Bold"], "\[RightVector]"], \((t)\)}],
          FontWeight->"Plain"], " ", "=", " ", 
        RowBox[{
          RowBox[{
            OverscriptBox[
              StyleBox["f",
                FontWeight->"Bold"], "\[RightVector]"], 
            StyleBox[\((t\/5)\),
              FontWeight->"Plain"]}], " ", "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\((1 - t\/5)\),
                  FontWeight->"Plain"], 
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["p",
                      FontWeight->"Bold"], "\[RightVector]"], "0"]}], " ", 
              "+", " ", 
              RowBox[{
                StyleBox[\(t\/5\),
                  FontWeight->"Plain"], 
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["p",
                      FontWeight->"Bold"], "\[RightVector]"], "1"], " ", 
                StyleBox["for",
                  FontFamily->"Times",
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox["0",
                  FontWeight->"Plain"]}]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["\[LessEqual]",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["\[LessEqual]",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[
              RowBox[{
                StyleBox["5",
                  FontWeight->"Plain"], "."}]]}]}]}]}]], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "The function we have created is the ",
  StyleBox["linear interpolation",
    FontWeight->"Bold"],
  " of the two points ",
  Cell[BoxData[
      SubscriptBox[
        OverscriptBox[
          StyleBox["p",
            FontFamily->"Courier",
            FontWeight->"Bold"], "\[RightVector]"], "0"]]],
  " and ",
  Cell[BoxData[
      SubscriptBox[
        OverscriptBox[
          StyleBox["p",
            FontFamily->"Courier",
            FontWeight->"Bold"], "\[RightVector]"], "1"]]],
  "scaled to fit our time interval.  "
}], "Text"],

Cell[TextData[{
  StyleBox["Example",
    FontWeight->"Bold"],
  ":  The code contained in this example will animate the block sliding down \
the inclined plane.  The animation consists of 120 frames."
}], "1ColumnBox",
  CellMargins->{{54, 108.562}, {Inherited, Inherited}}],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(wedge\)]],
  " draws the inclined plane."
}], "Text"],

Cell[BoxData[
    \(Clear[wedge]; 
    wedge\  = \ {Polygon[{{0, 0, 0}, {8, 0, 0}, {0, 0, 2}}], 
        Polygon[{{8, 0, 0}, {8, 1, 0}, {0, 1, 2}, {0, 0, 2}}], 
        Polygon[{{0, 0, 0}, {0, 1, 0}, {8, 1, 0}, {8, 0, 0}}], 
        Polygon[{{0, 1, 0}, {0, 1, 2}, {8, 1, 0}}], 
        Polygon[{{0, 0, 0}, {0, 0, 2}, {0, 1, 2}, {0, 1, 0}}]};\)], "Input",
  CellMargins->{{54, 151.188}, {Inherited, Inherited}},
  ShowCellLabel->True],

Cell[TextData[{
  Cell[BoxData[
      \(p0\)]],
  " and ",
  Cell[BoxData[
      \(p1\)]],
  " are the points mentioned above.  The vector ",
  Cell[BoxData[
      \(dir\)]],
  " is the vector of length ",
  Cell[BoxData[
      \(1\/2\)]],
  "that is parallel to the hypotenuse of the inclined plane.  "
}], "Text"],

Cell[BoxData[{
    \(\(p0\  = \ {0.3, \ 0.25, \ 1.925};\)\), "\[IndentingNewLine]", 
    \(\(dir\  = \ \({4, 0, \(-1\)}/Sqrt[17]\)/2;\)\), "\n", 
    \(\(p1\  = \ {8, 0.25, 0} - dir;\)\)}], "Input",
  CellMargins->{{54, 151.188}, {Inherited, Inherited}},
  ShowCellLabel->True],

Cell[TextData[{
  Cell[BoxData[
      \(box3\)]],
  " draws a cube of side length ",
  Cell[BoxData[
      \(1\/2\)]],
  "whose bottom face is parallel to the inclined face of ",
  Cell[BoxData[
      \(wedge\)]],
  ".  The three directions of the edges of the cube are ",
  Cell[BoxData[
      \(dir\)]],
  ", ",
  Cell[BoxData[
      \(perp\  = \ \ {\(-dir\[LeftDoubleBracket]3\[RightDoubleBracket]\), \ 
          0, dir\[LeftDoubleBracket]1\[RightDoubleBracket]}\)]],
  ", and ",
  Cell[BoxData[
      \(half\  = \ {0, \ 0.5, \ 0}\)]],
  ".  The left front bottom vertex of the cube will be located at the point \
specified by the input parameter ",
  Cell[BoxData[
      \(p\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[box3];\)\), "\n", 
    \(box3[p_] := 
      Module[{z, \ orig}, \n\t\tz\  = \ \((8 - t)\)/4; \n\t\torig\  = 
          p; \n\t\tperp\  = \ {\(-dir\[LeftDoubleBracket]3\
\[RightDoubleBracket]\), \ 0, 
            dir\[LeftDoubleBracket]1\[RightDoubleBracket]}; \n\t\thalf\  = \ \
{0, 0.5, 0}; \n\t\tReturn[{Polygon[{orig, \ orig + dir, \ orig + dir + perp, 
                orig + perp}], \n\t\t\t\tPolygon[{orig, \ orig + perp, \ 
                orig + perp + half, 
                orig + half}], \n\t\t\t\tPolygon[{orig + half, \ 
                orig + half + perp, orig + half + perp + dir, 
                orig + half + dir}], \n\t\t\t\tPolygon[{orig + dir, \ 
                orig + dir + half, orig + dir + half + perp, \ 
                orig + dir + perp}], \n\t\t\t\tPolygon[{orig + perp, \ 
                orig + perp + dir, orig + perp + dir + half, \ 
                orig + perp + half}], \n\t\t\t\tPolygon[{orig, \ orig + half, 
                orig + half + dir, orig + dir}]}]]\)}], "Input",
  CellMargins->{{54, 151.188}, {Inherited, Inherited}}],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(p\)]],
  " is the function ",
  Cell[BoxData[
      StyleBox[
        RowBox[{
          OverscriptBox[
            StyleBox["p",
              FontWeight->"Bold"], "\[RightVector]"], \((t)\)}],
        FontWeight->"Plain"]],
    FontWeight->"Bold"],
  " from above."
}], "Text"],

Cell[BoxData[
    \(p[t_]\  := \ \((1 - t/5)\)*p0 + t*p1/5\)], "Input",
  CellMargins->{{54, 151.188}, {Inherited, Inherited}}],

Cell[TextData[{
  "The following frame constructs the ",
  Cell[BoxData[
      \(121\)]],
  " frames of the animation."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\(gr = 
        Table[Show[
            Graphics3D[{wedge, \ box3[p[t]], \ Hue[0], 
                AbsolutePointSize[5], \ 
                Point[p[t]]}], \ \n\t\t\tDisplayFunction \[Rule] Identity, 
            Axes \[Rule] False, PlotRange -> All, \ Boxed -> False], {t, 0, 
            5, 5/120}];\)\)}], "Input",
  CellMargins->{{54, 151.188}, {Inherited, Inherited}}],

Cell[TextData[{
  "This cell calls ",
  Cell[BoxData[
      \(GLShow\)]],
  " to produce the animation.  It may take one or two minutes for ",
  Cell[BoxData[
      \(GLShow\)]],
  " to set up the animation, so be patient.  The speed and smoothness of the \
animation will be affected by the amount of memory you have allocated to the \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel and to GLExplorer, as well as what ever else you are doing or \
trying to do with your computer at the time.  Various aspects of the \
animation can be controlled using GLExplorer's ",
  Cell[BoxData[
      \(Motion\ Palette\)]],
  "; see ",
  Cell[BoxData[
      \(GLExplorer : Reference\ \(\(Manual\)\(:\)\)\)]],
  "\n",
  Cell[BoxData[
      \(Palettes : Motion\ Palette\)]],
  " in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Help Browser.  The ",
  Cell[BoxData[
      \(Motion\ Palette\)]],
  " is activated automatically when ",
  Cell[BoxData[
      \(AnimateFrames\)]],
  " is set to ",
  Cell[BoxData[
      \(True\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(GLShow[gr, ShadeModel \[Rule] Smooth, 
        AnimateFrames \[Rule] True];\)\)], "Input",
  CellMargins->{{54, 151.188}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Problems with Linear Interpolation", "Subsubsection"],

Cell[TextData[{
  "Linearly  interpolating, sometimes called ",
  StyleBox["lerping",
    FontWeight->"Bold"],
  " for short, is simple and easy but very often inappropriate."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0625 0.125 0.0625 0.125 [
[ 0 0 0 0 ]
[ 1 .8125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .8125 L
0 .8125 L
closepath
clip
newpath
1 g
.0625 .0625 m
.0625 .0625 .0625 0 365.73 arc
F
.4375 .6875 m
.4375 .6875 .0625 0 365.73 arc
F
.6875 .0625 m
.6875 .0625 .0625 0 365.73 arc
F
.9375 .3125 m
.9375 .3125 .0625 0 365.73 arc
F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.0625 .0625 .0625 0 365.73 arc
s
newpath
.4375 .6875 .0625 0 365.73 arc
s
newpath
.6875 .0625 .0625 0 365.73 arc
s
newpath
.9375 .3125 .0625 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 234},
  ImageMargins->{{94, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jR000`400?l00000o`00003oo`3ol>HQ
0?o`iP002`3ol>H=00000:H0oo3V3@00001E0?o`iP002P3ol>H00`000000oooo0?ooo`0;0?ooo`@0
0000X@3ol>H00`000000oooo0?ooo`0;0?ooo`@00000D@3ol>H000P0oo3V0P00000B0?ooo`030000
003ol>H0oo3V09`0oo3V0P00000B0?ooo`030000003ol>H0oo3V04h0oo3V00070?o`iP030000003o
ool0oooo01<0oooo00<000000?o`iP3ol>H0VP3ol>H00`000000oooo0?ooo`0C0?ooo`030000003o
l>H0oo3V04d0oo3V00060?o`iP030000003oool0oooo01@0oooo00<000000?o`iP3ol>H0V@3ol>H0
0`000000oooo0?ooo`0E0?ooo`030000003ol>H0oo3V04`0oo3V00050?o`iP030000003oool0oooo
01H0oooo00<000000?o`iP3ol>H0U`3ol>H00`000000oooo0?ooo`0G0?ooo`030000003ol>H0oo3V
04/0oo3V00040?o`iP030000003oool0oooo01P0oooo00<000000?o`iP3ol>H0U@3ol>H00`000000
oooo0?ooo`0I0?ooo`030000003ol>H0oo3V04X0oo3V00030?o`iP030000003oool0oooo01T0oooo
00<000000?o`iP3ol>H0U03ol>H00`000000oooo0?ooo`0J0?ooo`030000003ol>H0oo3V04X0oo3V
00020?o`iP030000003oool0oooo01/0oooo00<000000?o`iP3ol>H0TP3ol>H00`000000oooo0?oo
o`0L0?ooo`030000003ol>H0oo3V04T0oo3V00020?o`iP030000003oool0oooo01`0oooo00<00000
0?o`iP3ol>H0T@3ol>H00`000000oooo0?ooo`0M0?ooo`030000003ol>H0oo3V04P0oo3V00000`3o
l>H000000?ooo`0O0?ooo`030000003ol>H0oo3V0900oo3V00<000000?ooo`3oool07@3oool00`00
0000oo3V0?o`iP180?o`iP0000<0oo3V0000003oool07`3oool00`000000oo3V0?o`iP2?0?o`iP03
0000003oool0oooo01h0oooo00<000000?o`iP3ol>H0B03ol>H000030?o`iP000000oooo0200oooo
00<000000?o`iP3ol>H0SP3ol>H00`000000oooo0?ooo`0O0?ooo`030000003ol>H0oo3V04L0oo3V
00000`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08d0oo3V00<000000?ooo`3oool0803o
ool00`000000oo3V0?o`iP170?o`iP0000<000000?ooo`3oool0803oool00`000000oo3V0?o`iP2=
0?o`iP030000003oool0oooo0200oooo00<000000?o`iP3ol>H0A`3ol>H000030000003oool0oooo
0200oooo00<000000?o`iP3ol>H0S@3ol>H00`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V
04L0oo3V00000`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08d0oo3V00<000000?ooo`3o
ool08@3oool00`000000oo3V0?o`iP160?o`iP0000<000000?ooo`3oool0803oool00`000000oo3V
0?o`iP2=0?o`iP030000003oool0oooo0240oooo00<000000?o`iP3ol>H0AP3ol>H000030000003o
ool0oooo0200oooo00<000000?o`iP3ol>H0S@3ol>H00`000000oooo0?ooo`0Q0?ooo`030000003o
l>H0oo3V04H0oo3V00000`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08d0oo3V00<00000
0?ooo`3oool08@3oool00`000000oo3V0?o`iP160?o`iP0000<000000?ooo`3oool0803oool00`00
0000oo3V0?o`iP2=0?o`iP030000003oool0oooo0240oooo00<000000?o`iP3ol>H0AP3ol>H00003
0000003oool0oooo0200oooo00<000000?o`iP3ol>H0S@3ol>H00`000000oooo0?ooo`0P0?ooo`03
0000003ol>H0oo3V04L0oo3V00000`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08d0oo3V
00<000000?ooo`3oool0803oool00`000000oo3V0?o`iP170?o`iP0000<000000?ooo`3oool0803o
ool00`000000oo3V0?o`iP2=0?o`iP030000003oool0oooo0200oooo00<000000?o`iP3ol>H0A`3o
l>H000030?o`iP000000oooo01l0oooo00<000000?o`iP3ol>H0S`3ol>H00`000000oooo0?ooo`0N
0?ooo`030000003ol>H0oo3V04P0oo3V00000`3ol>H000000?ooo`0O0?ooo`030000003ol>H0oo3V
0900oo3V00<000000?ooo`3oool07@3oool00`000000oo3V0?o`iP180?o`iP0000<0oo3V0000003o
ool07P3oool00`000000oo3V0?o`iP2A0?o`iP030000003oool0oooo01d0oooo00<000000?o`iP3o
l>H0B03ol>H00080oo3V00<000000?ooo`3oool0703oool00`000000oo3V0?o`iP2A0?o`iP030000
003oool0oooo01d0oooo00<000000?o`iP3ol>H0B03ol>H00080oo3V00<000000?ooo`3oool06`3o
ool00`000000oo3V0?o`iP2C0?o`iP030000003oool0oooo01X0oooo0P00001;0?o`iP000`3ol>H0
0`000000oooo0?ooo`0I0?ooo`030000003ol>H0oo3V09D0oo3V00<000000?ooo`3oool0603oool0
0`000000oo3V0?o`iP1;0?o`iP00103ol>H2000001L0oooo0P00002I0?o`iP030000003oool0oooo
01D0oooo0P00001>0?o`iP001P3ol>H00`000000oooo0?ooo`0C0?ooo`030000003ol>H0oo3V09X0
oo3V00<000000?ooo`3oool04`3oool00`000000oo3V0?o`iP1>0?o`iP001`3ol>H200000180oooo
00<000000?o`iP3ol>H0W03ol>H200000180oooo00<000000?o`iP3ol>H0C`3ol>H000T0oo3V00<0
00000?ooo`3oool03@3oool200000:40oo3V00<000000?ooo`3oool03@3oool200000580oo3V000:
0?o`iP@000002@3oool200000:@0oo3V1000000:0?ooo`030000003ol>H0oo3V0580oo3V000>0?o`
iPT00000ZP3ol>H:000005D0oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o
0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o
0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o
0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o
0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o
0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o
0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o
0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iPX0oo3V2000000?0?o`iP00o`3ol>H70?o`iP<00000
203oool4000000/0oo3V003o0?o`iPH0oo3V00<000000?ooo`3oool03@3oool2000000T0oo3V003o
0?o`iP@0oo3V0P00000B0?ooo`030000003ol>H0oo3V00H0oo3V003o0?o`iP<0oo3V00<000000?oo
o`3oool04`3oool00`000000oo3V0?o`iP050?o`iP00o`3ol>H10?o`iP8000005P3oool00`000000
oo3V0?o`iP050?o`iP00o`3ol>H00`000000oooo0?ooo`0G0?ooo`030000003ol>H0oo3V00@0oo3V
003n0?o`iP030000003oool0oooo01T0oooo00<000000?o`iP3ol>H00`3ol>H00?h0oo3V00<00000
0?ooo`3oool06@3oool00`000000oo3V0?o`iP030?o`iP00o@3ol>H00`000000oooo0?ooo`0K0?oo
o`030000003ol>H0oo3V0080oo3V003l0?o`iP030000003oool0oooo01d0oooo00<000000?o`iP3o
l>H00@3ol>H00?`0oo3V00<000000?ooo`3oool07P3oool100000040oo3V0@3ol>H00?`0oo3V00<0
00000?ooo`3oool07P3oool100000040oo3V0@3ol>H00?`0oo3V00<000000?ooo`3oool07`3oool1
00000040oo3V003k0?o`iP030000003oool0oooo0200oooo0@0000010?o`iP00n`3ol>H00`000000
oooo0?ooo`0P0?ooo`4000000@3ol>H00?/0oo3V00<000000?ooo`3oool0803oool100000040oo3V
003k0?o`iP030000003oool0oooo0200oooo0@0000010?o`iP00n`3ol>H00`000000oooo0?ooo`0P
0?ooo`4000000@3ol>H00?/0oo3V00<000000?ooo`3oool0803oool100000040oo3V003k0?o`iP03
0000003oool0oooo0200oooo0@0000010?o`iP00n`3ol>H00`000000oooo0?ooo`0P0?ooo`400000
0@3ol>H00?/0oo3V00<000000?ooo`3oool0803oool100000040oo3V003k0?o`iP030000003oool0
oooo0200oooo0@0000010?o`iP00o03ol>H00`000000oooo0?ooo`0O0?ooo`4000000@3ol>H00?`0
oo3V00<000000?ooo`3oool07P3oool100000040oo3V0@3ol>H00?`0oo3V00<000000?ooo`3oool0
7P3oool100000040oo3V0@3ol>H00?d0oo3V00<000000?ooo`3oool0703oool00`000000oo3V0?o`
iP010?o`iP00o@3ol>H00`000000oooo0?ooo`0K0?ooo`030000003ol>H0oo3V0080oo3V003n0?o`
iP030000003oool0oooo01X0oooo00<000000?o`iP3ol>H00P3ol>H00?l0oo3V00<000000?ooo`3o
ool0603oool00`000000oo3V0?o`iP030?o`iP00o`3ol>H10?o`iP030000003oool0oooo01D0oooo
0P0000060?o`iP00o`3ol>H20?o`iP030000003oool0oooo01<0oooo00<000000?o`iP3ol>H01P3o
l>H00?l0oo3V0`3ol>H00`000000oooo0?ooo`0A0?ooo`030000003ol>H0oo3V00L0oo3V003o0?o`
iP@0oo3V1000000=0?ooo`8000002P3ol>H00?l0oo3V203ol>H00`000000oooo0?ooo`070?ooo`<0
0000303ol>H00?l0oo3V2@3ol>H9000000l0oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`
iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V003o0?o`iR40oo3V001h0?o`iP`00000W03ol>H0
07D0oo3V0`00000<0?ooo`030000003ol>H0oo3V09T0oo3V001c0?o`iP800000403oool2000009T0
oo3V001b0?o`iP030000003oool0oooo0180oooo00<000000?o`iP3ol>H0UP3ol>H00740oo3V00<0
00000?ooo`3oool0503oool2000009H0oo3V001a0?o`iP030000003oool0oooo01H0oooo00<00000
0?o`iP3ol>H0T`3ol>H00700oo3V00<000000?ooo`3oool0603oool00`000000oo3V0?o`iP2B0?o`
iP00K`3ol>H00`000000oooo0?ooo`0I0?ooo`030000003ol>H0oo3V0980oo3V001^0?o`iP030000
003oool0oooo01/0oooo00<000000?o`iP3ol>H0T@3ol>H006h0oo3V00<000000?ooo`3oool0703o
ool00`000000oo3V0?o`iP2@0?o`iP00K@3ol>H00`000000oooo0?ooo`0M0?ooo`030000003ol>H0
oo3V0900oo3V001]0?o`iP030000003oool0oooo01h0oooo00<000000?o`iP3ol>H0S`3ol>H006`0
oo3V00<000000?ooo`3oool07`3oool00`000000oo3V0?o`iP2?0?o`iP00K03ol>H00`000000oooo
0?ooo`0O0?ooo`030000003ol>H0oo3V08l0oo3V001/0?o`iP030000003oool0oooo0200oooo00<0
00000?o`iP3ol>H0SP3ol>H006/0oo3V00<000000?ooo`3oool08@3oool00`000000oo3V0?o`iP2>
0?o`iP00J`3ol>H00`000000oooo0?ooo`0Q0?ooo`030000003ol>H0oo3V08h0oo3V001[0?o`iP03
0000003oool0oooo0240oooo00<000000?o`iP3ol>H0SP3ol>H006/0oo3V00<000000?ooo`3oool0
8@3oool00`000000oo3V0?o`iP2>0?o`iP00J`3ol>H00`000000oooo0?ooo`0Q0?ooo`030000003o
l>H0oo3V08h0oo3V001[0?o`iP030000003oool0oooo0240oooo00<000000?o`iP3ol>H0SP3ol>H0
06/0oo3V00<000000?ooo`3oool08@3oool00`000000oo3V0?o`iP2>0?o`iP00K03ol>H00`000000
oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08h0oo3V001/0?o`iP030000003oool0oooo01l0oooo
00<000000?o`iP3ol>H0S`3ol>H006`0oo3V00<000000?ooo`3oool07`3oool00`000000oo3V0?o`
iP2?0?o`iP00K@3ol>H00`000000oooo0?ooo`0N0?ooo`030000003ol>H0oo3V08l0oo3V001]0?o`
iP030000003oool0oooo01d0oooo00<000000?o`iP3ol>H0T03ol>H006h0oo3V00<000000?ooo`3o
ool0703oool00`000000oo3V0?o`iP2@0?o`iP00KP3ol>H00`000000oooo0?ooo`0K0?ooo`030000
003ol>H0oo3V0940oo3V001_0?o`iP030000003oool0oooo01T0oooo00<000000?o`iP3ol>H0TP3o
l>H00700oo3V0P00000H0?ooo`030000003ol>H0oo3V09<0oo3V001b0?o`iP030000003oool0oooo
01@0oooo00<000000?o`iP3ol>H0U03ol>H007<0oo3V00<000000?ooo`3oool04P3oool00`000000
oo3V0?o`iP2E0?o`iP00M03ol>H200000100oooo0P00002H0?o`iP00MP3ol>H00`000000oooo0?oo
o`0:0?ooo`<00000VP3ol>H007L0oo3V1P0000020?ooo`@00000W@3ol>H007d0oo3V0P00002Q0?o`
iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`
iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`
iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`
iP00o`3ol>HQ0?o`iP00o`3ol>HQ0?o`iP00\
\>"],
  ImageRangeCache->{{{0, 287}, {233, 0}} -> {-0.503259, -0.500032, 0.0278973, \
0.0278973}}],

Cell["\<\
In the picture above the four positions of the circle represent \
four positions of  an object maneuvering around some obstacles.  If we \
animate this sequence by lerping between these four positions, the object \
will follow the path below:\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0625 0.125 0.0625 0.125 [
[ 0 0 0 0 ]
[ 1 .8125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .8125 L
0 .8125 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.0625 .0625 m
.4375 .6875 L
.6875 .0625 L
.9375 .3125 L
s
1 1 1 r
.0625 .0625 m
.0625 .0625 .0625 0 365.73 arc
F
.4375 .6875 m
.4375 .6875 .0625 0 365.73 arc
F
.6875 .0625 m
.6875 .0625 .0625 0 365.73 arc
F
.9375 .3125 m
.9375 .3125 .0625 0 365.73 arc
F
0 0 0 r
newpath
.0625 .0625 .0625 0 365.73 arc
s
newpath
.4375 .6875 .0625 0 365.73 arc
s
newpath
.6875 .0625 .0625 0 365.73 arc
s
newpath
.9375 .3125 .0625 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 234},
  ImageMargins->{{94, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jR000`400?l00000o`00003oo`3ol>HQ
0?o`iP002`3ol>H=00000:H0oo3V3@00001E0?o`iP002P3ol>H00`000000oooo0?ooo`0;0?ooo`@0
0000X@3ol>H00`000000oooo0?ooo`0;0?ooo`@00000D@3ol>H000P0oo3V0P00000B0?ooo`030000
003ol>H0oo3V09`0oo3V0P00000B0?ooo`030000003ol>H0oo3V04h0oo3V00070?o`iP030000003o
ool0oooo01<0oooo00<000000?o`iP3ol>H0VP3ol>H00`000000oooo0?ooo`0C0?ooo`030000003o
l>H0oo3V04d0oo3V00060?o`iP030000003oool0oooo01@0oooo00<000000?o`iP3ol>H0V@3ol>H0
0`000000oooo0?ooo`0E0?ooo`030000003ol>H0oo3V04`0oo3V00050?o`iP030000003oool0oooo
01H0oooo00<000000?o`iP3ol>H0U`3ol>H00`000000oooo0?ooo`0G0?ooo`030000003ol>H0oo3V
04/0oo3V00040?o`iP030000003oool0oooo01P0oooo00<000000?o`iP3ol>H0U@3ol>H00`000000
oooo0?ooo`0I0?ooo`030000003ol>H0oo3V04X0oo3V00030?o`iP030000003oool0oooo01T0oooo
00<000000?o`iP3ol>H0U03ol>H00`000000oooo0?ooo`0J0?ooo`030000003ol>H0oo3V04X0oo3V
00020?o`iP030000003oool0oooo01/0oooo00<000000?o`iP3ol>H0TP3ol>H00`000000oooo0?oo
o`0L0?ooo`030000003ol>H0oo3V04T0oo3V00020?o`iP030000003oool0oooo01`0oooo00<00000
0?o`iP3ol>H0T@3ol>H00`000000oooo0?ooo`0M0?ooo`030000003ol>H0oo3V04P0oo3V00000`3o
l>H000000?ooo`0O0?ooo`030000003ol>H0oo3V0900oo3V00<000000?ooo`3oool07@3oool00`00
0000oo3V0?o`iP180?o`iP0000<0oo3V0000003oool07`3oool00`000000oo3V0?o`iP2?0?o`iP03
0000003oool0oooo01h0oooo00<000000?o`iP3ol>H0B03ol>H000030?o`iP000000oooo0200oooo
00<000000?o`iP3ol>H0SP3ol>H00`000000oooo0?ooo`0O0?ooo`030000003ol>H0oo3V04L0oo3V
00000`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08d0oo3V00<000000?ooo`3oool0803o
ool00`000000oo3V0?o`iP170?o`iP0000<000000?ooo`3oool0803oool00`000000oo3V0?o`iP2=
0?o`iP030000003oool0oooo0200oooo00<000000?o`iP3ol>H0A`3ol>H000030000003oool0oooo
0200oooo00<000000?o`iP3ol>H0S@3ol>H00`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V
04L0oo3V00000`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08d0oo3V00<000000?ooo`3o
ool08@3oool00`000000oo3V0?o`iP160?o`iP0000<000000?ooo`3oool0803oool00`000000oo3V
0?o`iP2=0?o`iP030000003oool0oooo0240oooo00<000000?o`iP3ol>H0AP3ol>H000030000003o
ool0oooo0200oooo00<000000?o`iP3ol>H0S@3ol>H00`000000oooo0?ooo`0Q0?ooo`030000003o
l>H0oo3V04H0oo3V00000`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08d0oo3V00<00000
0?ooo`3oool08@3oool00`000000oo3V0?o`iP160?o`iP0000<000000?ooo`3oool0803oool00`00
0000oo3V0?o`iP2=0?o`iP030000003oool0oooo0240oooo00<000000?o`iP3ol>H0AP3ol>H00003
0000003oool0oooo0200oooo00<000000?o`iP3ol>H0S@3ol>H00`000000oooo0?ooo`0P0?ooo`03
0000003ol>H0oo3V04L0oo3V00000`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08d0oo3V
00<000000?ooo`3oool0803oool00`000000oo3V0?o`iP170?o`iP0000<000000?ooo`3oool0803o
ool00`000000oo3V0?o`iP2=0?o`iP030000003oool0oooo0200oooo00<000000?o`iP3ol>H0A`3o
l>H000030?o`iP000000oooo01l0oooo00<000000?o`iP3ol>H0S`3ol>H00`000000oooo0?ooo`0N
0?ooo`030000003ol>H0oo3V04P0oo3V00000`3ol>H000000?ooo`0O0?ooo`030000003ol>H0oo3V
0900oo3V00<000000?ooo`3oool07@3oool00`000000oo3V0?o`iP180?o`iP0000<0oo3V0000003o
ool07P3oool00`000000oo3V0?o`iP2A0?o`iP030000003oool0oooo01d0oooo00<000000?o`iP3o
l>H0B03ol>H00080oo3V00<000000?ooo`3oool0703oool00`000000oo3V0?o`iP2A0?o`iP030000
003oool0oooo01d0oooo00<000000?o`iP3ol>H0B03ol>H00080oo3V00<000000?ooo`3oool06`3o
ool00`000000oo3V0?o`iP2C0?o`iP030000003oool0oooo01X0oooo0P00001;0?o`iP000`3ol>H0
0`000000oooo0?ooo`0I0?ooo`030000003ol>H0oo3V09D0oo3V00<000000?ooo`3oool0603oool0
0`000000oo3V0?o`iP1;0?o`iP00103ol>H2000001L0oooo0P00002I0?o`iP030000003oool0oooo
01D0oooo0P00001>0?o`iP001P3ol>H00`000000oooo0?ooo`0C0?ooo`030000003ol>H0oo3V09X0
oo3V00<000000?ooo`3oool04`3oool010000000oo3V0?o`iP00001=0?o`iP001`3ol>H200000180
oooo00<000000?o`iP3ol>H0W03ol>H200000180oooo00<000000?o`iP3ol>H00P3ol>H00`000000
oo3V0?o`iP1:0?o`iP002@3ol>H00`000000oooo0?ooo`0=0?ooo`<00000X03ol>H00`000000oooo
0?ooo`0=0?ooo`8000001P3ol>H00`000000oo3V0?o`iP190?o`iP002P3ol>H4000000T0oooo0P00
00030?o`iP030000003ol>H0oo3V09h0oo3V1000000:0?ooo`030000003ol>H0oo3V00L0oo3V00<0
00000?o`iP3ol>H0B03ol>H000h0oo3V2@0000050?o`iP030000003ol>H0oo3V09l0oo3V00<00000
0?o`iP3ol>H02P00000;0?o`iP030000003ol>H0oo3V04L0oo3V000M0?o`iP030000003ol>H0oo3V
09h0oo3V00<000000?o`iP3ol>H05P3ol>H00`000000oo3V0?o`iP160?o`iP007P3ol>H00`000000
oo3V0?o`iP2L0?o`iP030000003ol>H0oo3V01P0oo3V00<000000?o`iP3ol>H0A@3ol>H001h0oo3V
00<000000?o`iP3ol>H0W03ol>H00`000000oo3V0?o`iP0I0?o`iP030000003ol>H0oo3V04@0oo3V
000O0?o`iP030000003ol>H0oo3V09X0oo3V00<000000?o`iP3ol>H06`3ol>H00`000000oo3V0?o`
iP130?o`iP007`3ol>H00`000000oo3V0?o`iP2J0?o`iP030000003ol>H0oo3V01`0oo3V00<00000
0?o`iP3ol>H0@P3ol>H00200oo3V00<000000?o`iP3ol>H0V@3ol>H00`000000oo3V0?o`iP0M0?o`
iP030000003ol>H0oo3V0440oo3V000Q0?o`iP030000003ol>H0oo3V09L0oo3V00<000000?o`iP3o
l>H07`3ol>H00`000000oo3V0?o`iP100?o`iP008@3ol>H00`000000oo3V0?o`iP2G0?o`iP030000
003ol>H0oo3V0200oo3V00<000000?o`iP3ol>H0?`3ol>H00280oo3V00<000000?o`iP3ol>H0U@3o
l>H00`000000oo3V0?o`iP0R0?o`iP030000003ol>H0oo3V03h0oo3V000R0?o`iP030000003ol>H0
oo3V09D0oo3V00<000000?o`iP3ol>H08`3ol>H00`000000oo3V0?o`iP0m0?o`iP008`3ol>H00`00
0000oo3V0?o`iP2D0?o`iP030000003ol>H0oo3V02@0oo3V00<000000?o`iP3ol>H0?03ol>H002@0
oo3V00<000000?o`iP3ol>H0TP3ol>H00`000000oo3V0?o`iP0V0?o`iP030000003ol>H0oo3V03/0
oo3V000T0?o`iP030000003ol>H0oo3V0980oo3V00<000000?o`iP3ol>H09`3ol>H00`000000oo3V
0?o`iP0j0?o`iP009@3ol>H00`000000oo3V0?o`iP2@0?o`iP030000003ol>H0oo3V02T0oo3V00<0
00000?o`iP3ol>H0>@3ol>H002D0oo3V00<000000?o`iP3ol>H0T03ol>H00`000000oo3V0?o`iP0Z
0?o`iP030000003ol>H0oo3V03P0oo3V000V0?o`iP030000003ol>H0oo3V08l0oo3V00<000000?o`
iP3ol>H0:`3ol>H00`000000oo3V0?o`iP0g0?o`iP009`3ol>H00`000000oo3V0?o`iP2=0?o`iP03
0000003ol>H0oo3V02d0oo3V00<000000?o`iP3ol>H0=P3ol>H002L0oo3V00<000000?o`iP3ol>H0
S@3ol>H00`000000oo3V0?o`iP0^0?o`iP030000003ol>H0oo3V03D0oo3V000X0?o`iP030000003o
l>H0oo3V08/0oo3V00<000000?o`iP3ol>H0<03ol>H00`000000oo3V0?o`iP0d0?o`iP00:03ol>H0
0`000000oo3V0?o`iP2;0?o`iP030000003ol>H0oo3V0340oo3V00<000000?o`iP3ol>H0<`3ol>H0
02T0oo3V00<000000?o`iP3ol>H0RP3ol>H00`000000oo3V0?o`iP0b0?o`iP030000003ol>H0oo3V
0380oo3V000Y0?o`iP030000003ol>H0oo3V08T0oo3V00<000000?o`iP3ol>H0=03ol>H00`000000
oo3V0?o`iP0a0?o`iP00:P3ol>H00`000000oo3V0?o`iP280?o`iP030000003ol>H0oo3V03D0oo3V
00<000000?o`iP3ol>H0<03ol>H002/0oo3V00<000000?o`iP3ol>H0QP3ol>H00`000000oo3V0?o`
iP0g0?o`iP030000003ol>H0oo3V02l0oo3V000[0?o`iP030000003ol>H0oo3V08H0oo3V00<00000
0?o`iP3ol>H0>03ol>H00`000000oo3V0?o`iP0^0?o`iP00;03ol>H00`000000oo3V0?o`iP250?o`
iP030000003ol>H0oo3V03T0oo3V00<000000?o`iP3ol>H0;@3ol>H002`0oo3V00<000000?o`iP3o
l>H0Q03ol>H00`000000oo3V0?o`iP0k0?o`iP030000003ol>H0oo3V02`0oo3V000]0?o`iP030000
003ol>H0oo3V08<0oo3V00<000000?o`iP3ol>H0?03ol>H00`000000oo3V0?o`iP0[0?o`iP00;P3o
l>H00`000000oo3V0?o`iP210?o`iP030000003ol>H0oo3V03h0oo3V00<000000?o`iP3ol>H0:P3o
l>H002h0oo3V00<000000?o`iP3ol>H0P@3ol>H00`000000oo3V0?o`iP0o0?o`iP030000003ol>H0
oo3V02T0oo3V000_0?o`iP030000003ol>H0oo3V0800oo3V00<000000?o`iP3ol>H0@03ol>H00`00
0000oo3V0?o`iP0X0?o`iP00;`3ol>H00`000000oo3V0?o`iP1o0?o`iP030000003ol>H0oo3V0480
oo3V00<000000?o`iP3ol>H09`3ol>H00300oo3V00<000000?o`iP3ol>H0OP3ol>H00`000000oo3V
0?o`iP130?o`iP030000003ol>H0oo3V02H0oo3V000a0?o`iP030000003ol>H0oo3V07`0oo3V00<0
00000?o`iP3ol>H0A@3ol>H00`000000oo3V0?o`iP0U0?o`iP00<@3ol>H00`000000oo3V0?o`iP1l
0?o`iP030000003ol>H0oo3V04H0oo3V00<000000?o`iP3ol>H0903ol>H00380oo3V00<000000?o`
iP3ol>H0N`3ol>H00`000000oo3V0?o`iP170?o`iP030000003ol>H0oo3V00`0oo3V2000000?0?o`
iP00<P3ol>H00`000000oo3V0?o`iP1j0?o`iP030000003ol>H0oo3V04T0oo3V00<000000?o`iP3o
l>H0203ol>H3000000P0oooo1000000;0?o`iP00<`3ol>H00`000000oo3V0?o`iP1i0?o`iP030000
003ol>H0oo3V04X0oo3V00<000000?o`iP3ol>H01P3ol>H00`000000oooo0?ooo`0=0?ooo`800000
2@3ol>H003@0oo3V00<000000?o`iP3ol>H0M`3ol>H00`000000oo3V0?o`iP1<0?o`iP030000003o
l>H0oo3V00<0oo3V0P00000B0?ooo`030000003ol>H0oo3V00H0oo3V000d0?o`iP030000003ol>H0
oo3V07L0oo3V00<000000?o`iP3ol>H0C@3ol>H01@000000oo3V0?o`iP3ol>H0000001D0oooo00<0
00000?o`iP3ol>H01@3ol>H003D0oo3V00<000000?o`iP3ol>H0MP3ol>H00`000000oo3V0?o`iP1>
0?o`iP<000005P3oool00`000000oo3V0?o`iP050?o`iP00=@3ol>H00`000000oo3V0?o`iP1e0?o`
iP030000003ol>H0oo3V04l0oo3V00<000000?ooo`3oool05`3oool00`000000oo3V0?o`iP040?o`
iP00=P3ol>H00`000000oo3V0?o`iP1d0?o`iP030000003ol>H0oo3V04h0oo3V00<000000?ooo`3o
ool06@3oool00`000000oo3V0?o`iP030?o`iP00=`3ol>H00`000000oo3V0?o`iP1b0?o`iP030000
003ol>H0oo3V04l0oo3V00<000000?ooo`3oool06@3oool00`000000oo3V0?o`iP030?o`iP00=`3o
l>H00`000000oo3V0?o`iP1b0?o`iP030000003ol>H0oo3V04h0oo3V00<000000?ooo`3oool06`3o
ool00`000000oo3V0?o`iP020?o`iP00>03ol>H00`000000oo3V0?o`iP1a0?o`iP030000003ol>H0
oo3V04d0oo3V00<000000?ooo`3oool07@3oool00`000000oo3V0?o`iP010?o`iP00>03ol>H00`00
0000oo3V0?o`iP1`0?o`iP030000003ol>H0oo3V04h0oo3V00<000000?ooo`3oool07P3oool10000
0040oo3V0@3ol>H003T0oo3V00<000000?o`iP3ol>H0K`3ol>H00`000000oo3V0?o`iP1>0?o`iP03
0000003oool0oooo01h0oooo0@0000010?o`iP40oo3V000j0?o`iP030000003ol>H0oo3V06d0oo3V
00<000000?o`iP3ol>H0C`3ol>H00`000000oooo0?ooo`0O0?ooo`4000000@3ol>H003X0oo3V00<0
00000?o`iP3ol>H0K@3ol>H00`000000oo3V0?o`iP1>0?o`iP030000003oool0oooo0200oooo0@00
00010?o`iP00>`3ol>H00`000000oo3V0?o`iP1/0?o`iP030000003ol>H0oo3V04h0oo3V00<00000
0?ooo`3oool0803oool100000040oo3V000k0?o`iP030000003ol>H0oo3V06/0oo3V00<000000?o`
iP3ol>H0C`3ol>H00`000000oooo0?ooo`0P0?ooo`4000000@3ol>H003`0oo3V00<000000?o`iP3o
l>H0JP3ol>H00`000000oo3V0?o`iP1?0?o`iP030000003oool0oooo0200oooo0@0000010?o`iP00
?@3ol>H00`000000oo3V0?o`iP1X0?o`iP030000003ol>H0oo3V0500oo3V00<000000?ooo`3oool0
803oool100000040oo3V000m0?o`iP030000003ol>H0oo3V06P0oo3V00<000000?o`iP3ol>H0D03o
l>H00`000000oooo0?ooo`0P0?ooo`4000000@3ol>H003h0oo3V00<000000?o`iP3ol>H0I`3ol>H0
0`000000oo3V0?o`iP1@0?o`iP030000003oool0oooo0200oooo0@0000010?o`iP00?P3ol>H00`00
0000oo3V0?o`iP1V0?o`iP030000003ol>H0oo3V0540oo3V00<000000?ooo`3oool0803oool10000
0040oo3V000o0?o`iP030000003ol>H0oo3V06D0oo3V00<000000?o`iP3ol>H0D@3ol>H00`000000
oooo0?ooo`0P0?ooo`4000000@3ol>H003l0oo3V00<000000?o`iP3ol>H0I03ol>H00`000000oo3V
0?o`iP1B0?o`iP030000003oool0oooo0200oooo0@0000010?o`iP00@03ol>H00`000000oo3V0?o`
iP1S0?o`iP030000003ol>H0oo3V05<0oo3V00<000000?ooo`3oool07`3oool100000040oo3V0011
0?o`iP030000003ol>H0oo3V0680oo3V00<000000?o`iP3ol>H0D`3ol>H00`000000oooo0?ooo`0N
0?ooo`4000000@3ol>H10?o`iP00@@3ol>H00`000000oo3V0?o`iP1Q0?o`iP030000003ol>H0oo3V
05@0oo3V00<000000?ooo`3oool07P3oool100000040oo3V0@3ol>H00480oo3V00<000000?o`iP3o
l>H0H03ol>H00`000000oo3V0?o`iP1E0?o`iP030000003oool0oooo01`0oooo00<000000?o`iP3o
l>H00@3ol>H00480oo3V00<000000?o`iP3ol>H0G`3ol>H00`000000oo3V0?o`iP1F0?o`iP030000
003oool0oooo01/0oooo00<000000?o`iP3ol>H00P3ol>H004<0oo3V00<000000?o`iP3ol>H0GP3o
l>H00`000000oo3V0?o`iP1G0?o`iP030000003oool0oooo01X0oooo00<000000?o`iP3ol>H00P3o
l>H004@0oo3V00<000000?o`iP3ol>H0G@3ol>H00`000000oo3V0?o`iP1H0?o`iP030000003oool0
oooo01P0oooo00<000000?o`iP3ol>H00`3ol>H004@0oo3V00<000000?o`iP3ol>H0G03ol>H00`00
0000oo3V0?o`iP1J0?o`iP030000003oool0oooo01D0oooo0P0000060?o`iP00A@3ol>H00`000000
oo3V0?o`iP1K0?o`iP030000003ol>H0oo3V05/0oo3V00<000000?ooo`3oool04`3oool00`000000
oo3V0?o`iP060?o`iP00A@3ol>H00`000000oo3V0?o`iP1J0?o`iP030000003ol>H0oo3V05d0oo3V
00<000000?ooo`3oool04@3oool00`000000oo3V0?o`iP070?o`iP00AP3ol>H00`000000oo3V0?o`
iP1I0?o`iP030000003ol>H0oo3V05h0oo3V1000000=0?ooo`8000002P3ol>H004L0oo3V00<00000
0?o`iP3ol>H0F03ol>H00`000000oo3V0?o`iP1R0?o`iP030000003oool0oooo00L0oooo0`00000<
0?o`iP00A`3ol>H00`000000oo3V0?o`iP1G0?o`iP030000003ol>H0oo3V06@0oo3V2@00000?0?o`
iP00B03ol>H00`000000oo3V0?o`iP1F0?o`iP030000003ol>H0oo3V07`0oo3V00180?o`iP030000
003ol>H0oo3V05D0oo3V00<000000?o`iP3ol>H0O@3ol>H004T0oo3V00<000000?o`iP3ol>H0E03o
l>H00`000000oo3V0?o`iP1m0?o`iP00BP3ol>H00`000000oo3V0?o`iP1C0?o`iP030000003ol>H0
oo3V07d0oo3V001:0?o`iP030000003ol>H0oo3V0580oo3V00<000000?o`iP3ol>H0OP3ol>H004/0
oo3V00<000000?o`iP3ol>H0D@3ol>H00`000000oo3V0?o`iP1n0?o`iP00B`3ol>H00`000000oo3V
0?o`iP1@0?o`iP030000003ol>H0oo3V07l0oo3V001<0?o`iP030000003ol>H0oo3V04l0oo3V00<0
00000?o`iP3ol>H0O`3ol>H004d0oo3V00<000000?o`iP3ol>H0CP3ol>H00`000000oo3V0?o`iP1o
0?o`iP00C@3ol>H00`000000oo3V0?o`iP1=0?o`iP030000003ol>H0oo3V0800oo3V001>0?o`iP03
0000003ol>H0oo3V04`0oo3V00<000000?o`iP3ol>H0P03ol>H004h0oo3V00<000000?o`iP3ol>H0
B`3ol>H00`000000oo3V0?o`iP210?o`iP00C`3ol>H00`000000oo3V0?o`iP1:0?o`iP030000003o
l>H0oo3V0840oo3V001@0?o`iP030000003ol>H0oo3V04T0oo3V00<000000?o`iP3ol>H0P@3ol>H0
0500oo3V00<000000?o`iP3ol>H0B03ol>H00`000000oo3V0?o`iP220?o`iP00D@3ol>H00`000000
oo3V0?o`iP170?o`iP030000003ol>H0oo3V0880oo3V001A0?o`iP030000003ol>H0oo3V04H0oo3V
00<000000?o`iP3ol>H0P`3ol>H00580oo3V00<000000?o`iP3ol>H0A@3ol>H00`000000oo3V0?o`
iP230?o`iP00DP3ol>H00`000000oo3V0?o`iP150?o`iP030000003ol>H0oo3V08<0oo3V001C0?o`
iP030000003ol>H0oo3V04<0oo3V00<000000?o`iP3ol>H0Q03ol>H005@0oo3V00<000000?o`iP3o
l>H0@P3ol>H00`000000oo3V0?o`iP240?o`iP00E03ol>H00`000000oo3V0?o`iP110?o`iP030000
003ol>H0oo3V08D0oo3V001E0?o`iP030000003ol>H0oo3V0400oo3V00<000000?o`iP3ol>H0Q@3o
l>H005D0oo3V00<000000?o`iP3ol>H0@03ol>H00`000000oo3V0?o`iP250?o`iP00EP3ol>H00`00
0000oo3V0?o`iP0n0?o`iP030000003ol>H0oo3V08H0oo3V001G0?o`iP030000003ol>H0oo3V03d0
oo3V00<000000?o`iP3ol>H0QP3ol>H005L0oo3V00<000000?o`iP3ol>H0?03ol>H00`000000oo3V
0?o`iP270?o`iP00F03ol>H00`000000oo3V0?o`iP0k0?o`iP030000003ol>H0oo3V08L0oo3V001H
0?o`iP030000003ol>H0oo3V03/0oo3V00<000000?o`iP3ol>H0Q`3ol>H005T0oo3V00<000000?o`
iP3ol>H0>@3ol>H00`000000oo3V0?o`iP280?o`iP00FP3ol>H00`000000oo3V0?o`iP0h0?o`iP03
0000003ol>H0oo3V08P0oo3V001J0?o`iP030000003ol>H0oo3V03L0oo3V00<000000?o`iP3ol>H0
R@3ol>H005/0oo3V00<000000?o`iP3ol>H0=P3ol>H00`000000oo3V0?o`iP290?o`iP00F`3ol>H0
0`000000oo3V0?o`iP0f0?o`iP030000003ol>H0oo3V08T0oo3V001L0?o`iP030000003ol>H0oo3V
03@0oo3V00<000000?o`iP3ol>H0RP3ol>H005d0oo3V00<000000?o`iP3ol>H0<`3ol>H00`000000
oo3V0?o`iP2:0?o`iP00G@3ol>H00`000000oo3V0?o`iP0b0?o`iP030000003ol>H0oo3V08/0oo3V
001N0?o`iP030000003ol>H0oo3V0340oo3V00<000000?o`iP3ol>H0R`3ol>H005h0oo3V00<00000
0?o`iP3ol>H0<@3ol>H00`000000oo3V0?o`iP2;0?o`iP00G`3ol>H00`000000oo3V0?o`iP0_0?o`
iP030000003ol>H0oo3V08`0oo3V001P0?o`iP030000003ol>H0oo3V02h0oo3V00<000000?o`iP3o
l>H0S03ol>H00600oo3V00<000000?o`iP3ol>H0;@3ol>H00`000000oo3V0?o`iP2=0?o`iP00H@3o
l>H00`000000oo3V0?o`iP0/0?o`iP030000003ol>H0oo3V08d0oo3V001Q0?o`iP030000003ol>H0
oo3V02`0oo3V00<000000?o`iP3ol>H0S@3ol>H00680oo3V00<000000?o`iP3ol>H0:P3ol>H00`00
0000oo3V0?o`iP2>0?o`iP00H`3ol>H00`000000oo3V0?o`iP0Y0?o`iP030000003ol>H0oo3V08h0
oo3V001S0?o`iP030000003ol>H0oo3V02P0oo3V00<000000?o`iP3ol>H0S`3ol>H006@0oo3V00<0
00000?o`iP3ol>H09`3ol>H00`000000oo3V0?o`iP2?0?o`iP00I03ol>H00`000000oo3V0?o`iP0W
0?o`iP030000003ol>H0oo3V08l0oo3V001U0?o`iP030000003ol>H0oo3V02D0oo3V00<000000?o`
iP3ol>H0T03ol>H006H0oo3V00<000000?o`iP3ol>H0903ol>H00`000000oo3V0?o`iP2@0?o`iP00
IP3ol>H00`000000oo3V0?o`iP0S0?o`iP030000003ol>H0oo3V0940oo3V001W0?o`iP030000003o
l>H0oo3V0280oo3V00<000000?o`iP3ol>H0T@3ol>H006L0oo3V00<000000?o`iP3ol>H08P3ol>H0
0`000000oo3V0?o`iP2A0?o`iP00J03ol>H00`000000oo3V0?o`iP0P0?o`iP030000003ol>H0oo3V
0980oo3V001X0?o`iP030000003ol>H0oo3V0200oo3V00<000000?o`iP3ol>H0TP3ol>H006T0oo3V
00<000000?o`iP3ol>H07P3ol>H00`000000oo3V0?o`iP2C0?o`iP00JP3ol>H00`000000oo3V0?o`
iP0M0?o`iP030000003ol>H0oo3V09<0oo3V001Z0?o`iP030000003ol>H0oo3V01d0oo3V00<00000
0?o`iP3ol>H0T`3ol>H006/0oo3V00<000000?o`iP3ol>H06`3ol>H00`000000oo3V0?o`iP2D0?o`
iP00J`3ol>H00`000000oo3V0?o`iP0K0?o`iP030000003ol>H0oo3V09@0oo3V001/0?o`iP030000
003ol>H0oo3V01T0oo3V00<000000?o`iP3ol>H0U@3ol>H006d0oo3V00<000000?o`iP3ol>H0603o
l>H00`000000oo3V0?o`iP2E0?o`iP00K@3ol>H00`000000oo3V0?o`iP0H0?o`iP030000003ol>H0
oo3V09D0oo3V001^0?o`iP030000003ol>H0oo3V01H0oo3V00<000000?o`iP3ol>H0UP3ol>H006h0
oo3V00<000000?o`iP3ol>H05P3ol>H00`000000oo3V0?o`iP2F0?o`iP00K`3ol>H00`000000oo3V
0?o`iP0D0?o`iP030000003ol>H0oo3V09L0oo3V001`0?o`iP030000003ol>H0oo3V01<0oo3V00<0
00000?o`iP3ol>H0U`3ol>H00700oo3V00<000000?o`iP3ol>H04`3ol>H00`000000oo3V0?o`iP2G
0?o`iP00L@3ol>H00`000000oo3V0?o`iP0A0?o`iP030000003ol>H0oo3V09P0oo3V001a0?o`iP03
0000003ol>H0oo3V0140oo3V00<000000?o`iP3ol>H0V03ol>H00780oo3V00<000000?o`iP3ol>H0
0`3ol>H=000009/0oo3V001c0?o`iP030000003ol>H0000000800000303oool00`000000oo3V0?o`
iP2I0?o`iP00L`3ol>H200000100oooo0P00002I0?o`iP00LP3ol>H00`000000oooo0?ooo`0B0?oo
o`030000003ol>H0oo3V09H0oo3V001a0?o`iP030000003oool0oooo01@0oooo0P00002F0?o`iP00
L@3ol>H00`000000oooo0?ooo`0F0?ooo`030000003ol>H0oo3V09<0oo3V001`0?o`iP030000003o
ool0oooo01P0oooo00<000000?o`iP3ol>H0TP3ol>H006l0oo3V00<000000?ooo`3oool06@3oool0
0`000000oo3V0?o`iP2B0?o`iP00KP3ol>H00`000000oooo0?ooo`0K0?ooo`030000003ol>H0oo3V
0940oo3V001^0?o`iP030000003oool0oooo01`0oooo00<000000?o`iP3ol>H0T03ol>H006d0oo3V
00<000000?ooo`3oool07@3oool00`000000oo3V0?o`iP2@0?o`iP00K@3ol>H00`000000oooo0?oo
o`0N0?ooo`030000003ol>H0oo3V08l0oo3V001/0?o`iP030000003oool0oooo01l0oooo00<00000
0?o`iP3ol>H0S`3ol>H006`0oo3V00<000000?ooo`3oool07`3oool00`000000oo3V0?o`iP2?0?o`
iP00K03ol>H00`000000oooo0?ooo`0P0?ooo`030000003ol>H0oo3V08h0oo3V001[0?o`iP030000
003oool0oooo0240oooo00<000000?o`iP3ol>H0SP3ol>H006/0oo3V00<000000?ooo`3oool08@3o
ool00`000000oo3V0?o`iP2>0?o`iP00J`3ol>H00`000000oooo0?ooo`0Q0?ooo`030000003ol>H0
oo3V08h0oo3V001[0?o`iP030000003oool0oooo0240oooo00<000000?o`iP3ol>H0SP3ol>H006/0
oo3V00<000000?ooo`3oool08@3oool00`000000oo3V0?o`iP2>0?o`iP00J`3ol>H00`000000oooo
0?ooo`0Q0?ooo`030000003ol>H0oo3V08h0oo3V001[0?o`iP030000003oool0oooo0240oooo00<0
00000?o`iP3ol>H0SP3ol>H006`0oo3V00<000000?ooo`3oool0803oool00`000000oo3V0?o`iP2>
0?o`iP00K03ol>H00`000000oooo0?ooo`0O0?ooo`030000003ol>H0oo3V08l0oo3V001/0?o`iP03
0000003oool0oooo01l0oooo00<000000?o`iP3ol>H0S`3ol>H006d0oo3V00<000000?ooo`3oool0
7P3oool00`000000oo3V0?o`iP2?0?o`iP00K@3ol>H00`000000oooo0?ooo`0M0?ooo`030000003o
l>H0oo3V0900oo3V001^0?o`iP030000003oool0oooo01`0oooo00<000000?o`iP3ol>H0T03ol>H0
06h0oo3V00<000000?ooo`3oool06`3oool00`000000oo3V0?o`iP2A0?o`iP00K`3ol>H00`000000
oooo0?ooo`0I0?ooo`030000003ol>H0oo3V0980oo3V001`0?o`iP800000603oool00`000000oo3V
0?o`iP2C0?o`iP00LP3ol>H00`000000oooo0?ooo`0D0?ooo`030000003ol>H0oo3V09@0oo3V001c
0?o`iP030000003oool0oooo0180oooo00<000000?o`iP3ol>H0U@3ol>H007@0oo3V0P00000@0?oo
o`800000V03ol>H007H0oo3V00<000000?ooo`3oool02P3oool3000009X0oo3V001g0?o`iPH00000
0P3oool4000009d0oo3V001m0?o`iP800000X@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0
oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0
oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0
oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00?l0oo3V8@3ol>H00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {233, 0}} -> {-0.503259, -0.500032, 0.0278973, \
0.0278973}}],

Cell["and  it will appear to bounce off of  non-existent objects.", "Text"],

Cell["\<\
Example:  This code demonstrates the lerping animation described \
above.\
\>", "1ColumnBox",
  CellMargins->{{46.1875, 109.438}, {Inherited, Inherited}}],

Cell["The centers of the 4 circles above.", "Text"],

Cell[BoxData[{
    \(\(Clear[p1, \ p2, \ p3, \ p4];\)\), "\n", 
    \(\(p1\  = \ {0, 0};\)\), "\n", 
    \(\(p2\ \  = \ {3, 5};\)\), "\n", 
    \(\(p3\  = \ {5, 0};\)\), "\n", 
    \(\(p4\  = \ {7, 2};\)\)}], "Input"],

Cell[TextData[{
  "The function f is the parametric equation of the polyline mapping ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  " to the line segment from ",
  Cell[BoxData[
      \(p1\)]],
  " to ",
  Cell[BoxData[
      \(p2\)]],
  ", ",
  Cell[BoxData[
      \(\([1, 2]\)\)]],
  " to the line segment from ",
  Cell[BoxData[
      \(p2\)]],
  " to ",
  Cell[BoxData[
      \(p3\)]],
  ", and ",
  Cell[BoxData[
      \(\([2, 3]\)\)]],
  "to the line segment from ",
  Cell[BoxData[
      \(p3\)]],
  " to ",
  Cell[BoxData[
      \(p4\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(f[t_]\  := 
      Module[{u}, \n\t\t\tIf[
          t\  <= 1, \((1 - t)\)*p1\  + \ t*p2, \n\t\t\tIf[
            t\  <= \ 2, \ \n\t\t\t\tu\  = \ t - 1; \n\t\t\t\((1 - u)\)*p2 + 
              u*p3, \n\t\t\t\ \ \ \ u = t - 2; \n\t\t\t\t\((1 - u)\)*p3 + 
              u*p4]]]\)}], "Input"],

Cell[TextData[{
  "This cell defines the ",
  Cell[BoxData[
      \(73\)]],
  " frames of the animation."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\t\(gr\  = \ 
        Table[Show[
            Graphics[\n\t\t\t\t{Circle[f[t], 
                  0.5]}], \ \tDisplayFunction \[Rule] Identity, 
            Axes \[Rule] False, 
            PlotRange -> {{\(-0.5\), 7.5}, {\(-0.5\), 6}}], {t, 0, 3, 
            1/24}];\)\)}], "Input"],

Cell[TextData[{
  Cell[BoxData[
      \(GLShow\)]],
  " produces the animation."
}], "Text"],

Cell[BoxData[
    \(\(GLShow[gr, AnimateFrames \[Rule] True];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Non-linear interpolation -  Splines", "Subsubsection"],

Cell[TextData[{
  "Given a set of points ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          SubscriptBox[
            OverscriptBox[
              StyleBox["d",
                FontWeight->"Bold"], "\[RightVector]"], "i"], "}"}], \(i = 
          1\), "m"]]],
  " in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ",  a ",
  Cell[BoxData[
      \(k\)]],
  "'th order bspline knot sequence ",
  Cell[BoxData[
      \({t\_j}\_\(j = 1\)\%\(m + k\)\)]],
  " (see Chapter xxx), and a set of distinct values ",
  Cell[BoxData[
      \({\[Tau]\_i}\_\(i = 1\)\%m\)]],
  " in the interval ",
  Cell[BoxData[
      \(\([t\_1, \ t\_\(m + k\)]\)\)]],
  ", under fairly mild conditions on the distribution of the ",
  Cell[BoxData[
      \(\[Tau]\_i\)]],
  "'s  among the ",
  Cell[BoxData[
      \(t\_j\)]],
  "'s (see (dB) p ",
  Cell[BoxData[
      \(200\)]],
  ") it is always possible to solve the following interpolation problem:"
}], "Text"],

Cell[TextData[{
  "Find control points",
  StyleBox[" ", "MathCaption"],
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          SubscriptBox[
            OverscriptBox[
              StyleBox["a",
                FontWeight->"Bold"], "\[RightVector]"], "j"], "}"}], \(j = 
          1\), "m"]]],
  " so that the bspline "
}], "ContentsText"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox["c",
              FontWeight->"Bold"], "\[RightVector]"], \((t)\)}], " ", "=", 
        " ", 
        RowBox[{
          UnderoverscriptBox[
            StyleBox["\[CapitalSigma]",
              FontSize->24], \(j = 1\), "m"], " ", 
          SubscriptBox[
            OverscriptBox[
              StyleBox["a",
                FontWeight->"Bold"], "\[RightVector]"], 
            "j"], \(B\_j\), \((t)\), " "}]}]]]
}], "Text"],

Cell[TextData[{
  "interpolates the points ",
  Cell[BoxData[
      SubsuperscriptBox[
        RowBox[{"{", 
          SubscriptBox[
            OverscriptBox[
              StyleBox["d",
                FontWeight->"Bold"], "\[RightVector]"], "i"], "}"}], \(i = 
          1\), "m"]]],
  " at the parameter values ",
  Cell[BoxData[
      \({\[Tau]\_i}\_\(i = 1\)\%m\)]],
  ";  i.e.  ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["c",
          FontWeight->"Bold"], "\[RightVector]"]]],
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{\((\[Tau]\_i)\), "=", " ", 
          SubscriptBox[
            OverscriptBox[
              StyleBox["d",
                FontWeight->"Bold"], "\[RightVector]"], "i"]}]}]]],
  " for ",
  Cell[BoxData[
      \(1\  \[LessEqual] \ i\  \[LessEqual] \ m\)]],
  "."
}], "ContentsText"],

Cell[TextData[{
  "It is instructive to see how this is done.  The set of positions for the \
round object in the above picture are ",
  Cell[BoxData[
      \(\((0, 0)\), \ \((3, 5)\), \ \((5, 0)\)\)]],
  " and ",
  Cell[BoxData[
      \(\((7, 2)\)\)]],
  ", and these four points will determine quadratic bspline curves with four \
control points or cubic bspline (in this case B\[EAcute]zier ) curves with ",
  Cell[BoxData[
      \(4\)]],
  " points, depending on the values for ",
  Cell[BoxData[
      \({\[Tau]\_i}\_\(i = 1\)\%4\)]],
  "  we choose.  We'll do one of each and compare the results.  We will use \
",
  Cell[BoxData[
      \(bspline\)]],
  ", the implementation of the de Boor algorithm mentioned earlier."
}], "Text"],

Cell[TextData[StyleBox["bspline",
  FontWeight->"Bold"]], "1ColumnBox",
  CellMargins->{{44, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(interval[knots_, \ k_, \ x_]\  := 
        Module[{n, i}, \nn\  = \ Length[knots] - k; \n
          If[x == knots\[LeftDoubleBracket]n + 1\[RightDoubleBracket], 
            Return[n], \n\ \ \ \ \ i = k; \n\ \ \ \ While[
              x >= knots\[LeftDoubleBracket]
                  i\[RightDoubleBracket], \(i++\)]; \n\ \ \ \ \ Return[
              i - 1];\n]];\)\)], "Input"],

Cell[BoxData[
    \(Clear[bspline]\)], "Input"],

Cell[BoxData[
    \(bspline[t_, ct_, x_, der_]\  := \ 
      Module[{u, k, p, alf, d, ind, i, j, n, c, den, 
          km1}, \[IndentingNewLine]u = t; \[IndentingNewLine]k\  = \ 
          Count[u, 
            u\[LeftDoubleBracket]1\[RightDoubleBracket]]; \
\[IndentingNewLine]c\  = \ ct; \[IndentingNewLine]n\  = \ 
          Length[c]; \[IndentingNewLine]If[
          der\  > \ 0, \[IndentingNewLine]For[i = 1, 
            i \[LessEqual] der, \ \(i++\), \[IndentingNewLine]For[
              j\  = \ 1, \ 
              j \[LessEqual] \ 
                n - i, \(j++\), \ \[IndentingNewLine]den\  = \ \((u\
\[LeftDoubleBracket]j + k - i + 1\[RightDoubleBracket] - 
                    u\[LeftDoubleBracket]j + 
                        1\[RightDoubleBracket])\); \[IndentingNewLine]If[
                den\  \[NotEqual] \ 0.0, 
                c\[LeftDoubleBracket]j\[RightDoubleBracket]\  = \ \((k - 
                        i)\) \((c\[LeftDoubleBracket]
                            j + 1\[RightDoubleBracket] - 
                          c\[LeftDoubleBracket]j\[RightDoubleBracket])\)/den, 
                c\[LeftDoubleBracket]j\[RightDoubleBracket]\  = \ 
                  0.0];\[IndentingNewLine]]; \[IndentingNewLine]u\  = \ 
              Take[u, {2, 
                  Length[u] - 
                    1}];\[IndentingNewLine]]; \[IndentingNewLine]k\  = \ 
            k - der;\[IndentingNewLine]]; \[IndentingNewLine]p\  = \ 
          interval[u, k, x]; \[IndentingNewLine]d\  = \ 
          Table[0, {k}]; \[IndentingNewLine]km1\  = \ 
          k - 1; \[IndentingNewLine]For[j = p - k + 2, 
          j \[LessEqual] p, \(j++\), \[IndentingNewLine]alf\  = \ 
            u\[LeftDoubleBracket]j + km1\[RightDoubleBracket] - 
              u\[LeftDoubleBracket]
                j\[RightDoubleBracket]; \[IndentingNewLine]If[
            alf\  \[NotEqual] 0.0, \ 
            alf\  = \ \((x - u\[LeftDoubleBracket]j\[RightDoubleBracket])\)/
                alf]; \[IndentingNewLine]d\[LeftDoubleBracket]
              j - p + km1\[RightDoubleBracket]\  = \ \((1.  - alf)\)*
                c\[LeftDoubleBracket]j - 1\[RightDoubleBracket] + 
              alf*c\[LeftDoubleBracket]
                  j\[RightDoubleBracket];]; \[IndentingNewLine]For[
          i\  = \ 2, \ 
          i \[LessEqual] km1, \ \(i++\), \[IndentingNewLine]For[
            j\  = \ p - km1 + i, \ 
            j \[LessEqual] p, \ \(j++\), \[IndentingNewLine]alf\  = \ 
              u\[LeftDoubleBracket]j + k - i\[RightDoubleBracket] - 
                u\[LeftDoubleBracket]
                  j\[RightDoubleBracket]; \[IndentingNewLine]If[
              alf\  \[NotEqual] 0.0, \ 
              alf\  = \ \((x - u\[LeftDoubleBracket]j\[RightDoubleBracket])\)/
                  alf]; \[IndentingNewLine]ind\  = \ 
              k + j - i - 
                p; \[IndentingNewLine]d\[LeftDoubleBracket]ind\
\[RightDoubleBracket]\  = \ \((1.  - alf)\)*
                  d\[LeftDoubleBracket]ind\[RightDoubleBracket] + 
                alf*d\[LeftDoubleBracket]ind + 
                      1\[RightDoubleBracket]]]; \[IndentingNewLine]Return[
          d\[LeftDoubleBracket]1\[RightDoubleBracket]]]\)], "Input"],

Cell["Quadratic Bspline Interpolant", "Text",
  FontWeight->"Bold"],

Cell["\<\
Using the bspline evaluator above, lets solve the interpolation \
problem above.\
\>", "Text"],

Cell[TextData[StyleBox["Quadratic Knot Sequence for 4 values",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(kt\  = \ {0.0, \ 0.0, \ 0.0, \ 0.5, \ 1.0, \ 1.0, \ 
          1.0};\)\)], "Input"],

Cell[TextData[StyleBox["Unknown Control Points",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    StyleBox[\(ct\  = \ {{x1, y1}, {x2, y2}, {x3, y3}, {x4, y4}};\),
      "Outputb"]], "Input"],

Cell[TextData[StyleBox["Unknown spline function",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[c];\)\), "\n", 
    \(\tc[t_]\ \  := \ \ bspline[kt, \ ct, t, 0]\)}], "Input"],

Cell[TextData[{
  "(evaluate the above cells and then evaluate ",
  Cell[BoxData[
      StyleBox["c",
        FontWeight->"Bold"]]],
  " at several values of ",
  Cell[BoxData[
      \(t\)]],
  " between ",
  Cell[BoxData[
      \(0\)]],
  " and ",
  Cell[BoxData[
      \(1\)]],
  " to see what the function ",
  StyleBox["c",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does with the unknown control points.)"
}], "Text",
  CellMargins->{{58, Inherited}, {Inherited, Inherited}}],

Cell[TextData[StyleBox["The points to be interpolated",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(d\  = \ {{0.0, 0.0}, {3.0, 5.0}, {5.0, 0.0}, {7.0, 2.0}}\)], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" will do all the work.",
    FontWeight->"Bold"],
  "  The only thing we have to do is decide on the values for ",
  Cell[BoxData[
      \(\[Tau]\_i\)]],
  " in the parametric domain interval where the points in ",
  Cell[BoxData[
      StyleBox["d",
        FontWeight->"Bold"]]],
  " will be interpolated.  In the input line below the values in ",
  Cell[BoxData[
      \({0.0, \ 0.33, \ 0.66, \ 1.0}\)]],
  "   have been chosen as the values for the ",
  Cell[BoxData[Cell[TextData[Cell[BoxData[
          \(\[Tau]\_i\)]]]]]],
  "'s ."
}], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(ans\  = \ Solve[{c[0]\ , c[0.33], c[0.66], c[1.0]} == d]\)], "Input"],

Cell[BoxData[
    \(ctrl\  = \ 
      ct /. ans\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell["\<\
All that is left for us to do is to plot the curve, along with the \
original round objects  and see if we like it.\
\>", "Text"],

Cell[BoxData[
    \(\(curve\  = 
        ParametricPlot[bspline[kt, ctrl, t, 0], {t, 0, 1}, \ 
          PlotRange -> All, AspectRatio -> Automatic, \ 
          DisplayFunction -> Identity];\)\)], "Input"],

Cell[BoxData[
    \(Show[{curve, 
        Graphics[{Circle[d\[LeftDoubleBracket]1\[RightDoubleBracket], 0.5], 
            Circle[d\[LeftDoubleBracket]2\[RightDoubleBracket], 0.5], 
            Circle[d\[LeftDoubleBracket]3\[RightDoubleBracket], 0.5], 
            Circle[d\[LeftDoubleBracket]4\[RightDoubleBracket], 
              0.5]}]}, \ \tAxes \[Rule] False, 
      PlotRange -> {{\(-0.5\), 7.5}, {\(-0.5\), 6}}, 
      DisplayFunction -> $DisplayFunction]\)], "Input"],

Cell["Do we like it?", "Text"],

Cell["Cubic Bspline Interpolant", "Text",
  FontWeight->"Bold"],

Cell["\<\
Well no, we didn't like it.  We repeat the above process with a \
cubic bspline.\
\>", "Text"],

Cell[TextData[StyleBox["Cubic Knot Sequence for 4 values",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[kt];\)\), "\n", 
    \(\(kt\  = \ {0.0, \ 0.0, \ 0.0, \ 0.0, \ 1.0, \ 1.0, \ 1.0, \ 
          1.0};\)\)}], "Input"],

Cell[TextData[StyleBox["Unknown Control Points",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[ct];\)\), "\n", 
    \(\(ct\  = \ {{x1, y1}, {x2, y2}, {x3, y3}, {x4, y4}};\)\)}], "Input"],

Cell[TextData[StyleBox["Unknown spline function",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[c];\)\), "\n", 
    \(\tc[t_]\ \  := \ \ bspline[kt, \ ct, t, 0]\)}], "Input"],

Cell[TextData[{
  "(Again, evaluate the above cells and then evaluate ",
  StyleBox["c",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at several values of ",
  Cell[BoxData[
      \(t\)]],
  " between ",
  Cell[BoxData[
      \(0\)]],
  " and ",
  Cell[BoxData[
      \(1\)]],
  " to see what the function ",
  StyleBox["c",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does with the unknown control points.)"
}], "Text",
  CellMargins->{{37.625, Inherited}, {Inherited, Inherited}}],

Cell[TextData[StyleBox["The points to be interpolated",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(d\  = \ {{0.0, 0.0}, {3.0, 5.0}, {5.0, 0.0}, {7.0, 2.0}}\)], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" will do all the work.",
    FontWeight->"Bold"],
  "   The only thing we have to do is decide on the values for ",
  Cell[BoxData[
      \(\[Tau]\_i\)]],
  " where the points in ",
  Cell[BoxData[
      StyleBox["d",
        FontWeight->"Bold"]]],
  " will be interpolated.  Again in the input line below the values in ",
  Cell[BoxData[
      \({0.0, \ 0.33, \ 0.66, \ 1.0}\)]],
  "   have been chosen as the values for the ",
  Cell[BoxData[
      \(\[Tau]\_i\)]],
  "'s ."
}], "Text",
  CellMargins->{{36.375, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[ans];\)\), "\n", 
    \(ans\  = \ Solve[{c[0]\ , c[0.33], c[0.66], c[1.0]} == d]\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[ctrl];\)\), "\n", 
    \(ctrl\  = \ 
      ct /. ans\[LeftDoubleBracket]1\[RightDoubleBracket]\)}], "Input"],

Cell["\<\
We plot the curve, along with the original round objects  and see \
if we like it.\
\>", "Text"],

Cell[BoxData[
    \(\(curve\  = 
        ParametricPlot[bspline[kt, ctrl, t, 0], {t, 0, 1}, \ 
          PlotRange -> All, AspectRatio -> Automatic, \ 
          DisplayFunction -> Identity];\)\)], "Input"],

Cell[BoxData[
    \(Show[{curve, 
        Graphics[{Circle[d\[LeftDoubleBracket]1\[RightDoubleBracket], 0.5], 
            Circle[d\[LeftDoubleBracket]2\[RightDoubleBracket], 0.5], 
            Circle[d\[LeftDoubleBracket]3\[RightDoubleBracket], 0.5], 
            Circle[d\[LeftDoubleBracket]4\[RightDoubleBracket], 
              0.5]}]}, \ \tAxes \[Rule] False, 
      PlotRange -> {{\(-0.5\), 7.5}, {\(-2\), 6}}, 
      DisplayFunction -> $DisplayFunction]\)], "Input"],

Cell[TextData[{
  "The results here still may not be what you had in mind.  If you want the \
inculpated circles to be at the top and bottom of the respective arcs, try \
interpolating the cubic at the points ",
  Cell[BoxData[
      \({0, \ 0.26, \ 0.8, \ 1.0}\)]],
  ".  The animation below uses the results from this suggested \
interpolation."
}], "Text"],

Cell["Example:  The animated smooth version of the obstacle path.", \
"1ColumnBox",
  CellMargins->{{45.75, 108.75}, {Inherited, Inherited}}],

Cell[TextData[{
  "The first three cells below construct the curve that interpolates the \
centers of the four circles at the parametric values ",
  Cell[BoxData[
      \({0, \ 0.26, \ 0.8, \ 1.0}\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[ctrl];\)\), "\n", 
    \(\(ctrl\  = \ {{0.0, 0.0}, {5.96385, 
            13.7703}, {2.19654, \ \(-6.10924\)}, {7.0, 2.0}};\)\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[kt];\)\), "\n", 
    \(\(kt\  = \ {0.0, \ 0.0, \ 0.0, \ 0.0, \ 1.0, \ 1.0, \ 1.0, \ 
          1.0};\)\)}], "Input"],

Cell[BoxData[
    \(\(curve\  = 
        ParametricPlot[bspline[kt, ctrl, t, 0], {t, 0, 1}, \ 
          PlotRange -> All, AspectRatio -> Automatic, \ 
          DisplayFunction -> Identity];\)\)], "Input"],

Cell[TextData[{
  "Construct the ",
  Cell[BoxData[
      \(73\)]],
  " frames of the animation and call ",
  Cell[BoxData[
      \(GLShow\)]],
  " to produce the animation."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\t\(gr\  = \ 
        Table[Show[{curve, 
              Graphics[{Circle[d\[LeftDoubleBracket]1\[RightDoubleBracket], 
                    0.5], Circle[d\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    0.5], Circle[d\[LeftDoubleBracket]3\[RightDoubleBracket], 
                    0.5], Circle[d\[LeftDoubleBracket]4\[RightDoubleBracket], 
                    0.5]}], \n\t\t\t\tGraphics[{Circle[
                    bspline[kt, ctrl, t, 0], 
                    0.5]}]}, \ \tDisplayFunction \[Rule] Identity, 
            Axes \[Rule] False, 
            PlotRange -> {{\(-0.5\), 7.5}, {\(-0.5\), 6}}], {t, 0, 1, 
            1/72}];\)\)}], "Input"],

Cell[BoxData[
    \(\(GLShow[gr, AnimateFrames \[Rule] True];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Controlling Kinetic Parameters", "Subsection"],

Cell[TextData[{
  "Watch the smooth animation above several times.  The ",
  Cell[BoxData[
      \(73\)]],
  " frames of the animation were created by evaluating the spline we \
constructed at equally spaced parameter points.  But in some places the \
circle seems to be moving faster than in other places (notably at the \
beginning of the animation and at the end).  It does not cover the path we \
have created at a uniform speed.  The reason for this is the parameterization \
of the spline function."
}], "Text"],

Cell[TextData[{
  "To get some idea of how \"bad\" the parameterization really is, we look at \
the distance between contiguous evaluations of the spline used to plot the \
curve.  The following two commands will create a table of the distances \
between the points ",
  Cell[BoxData[
      \(\(\(bspline[tk, \ ctrl, \ \((i + 1)\)/72.0, \ 0]\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(bspline[kt, \ ctrl, \ i/72.0, \ 0]\)]],
  StyleBox[" ",
    FontFamily->"Courier"],
  "for values of ",
  Cell[BoxData[
      \(i\)]],
  " between ",
  Cell[BoxData[
      \(0\)]],
  " and ",
  Cell[BoxData[
      \(71\)]],
  ", and then plot these values (assuming you have not cleared ",
  Cell[BoxData[
      \(kt\)]],
  "  and ",
  Cell[BoxData[
      \(ctrl\)]],
  " from the animation above).  If equally spaced parameter values implied \
equally spaced values along the curve, we would expect the distances between \
two successive points on the curve to be about the same (allowing for \
variations due to large changes in curvature). If the distances between the \
points were roughly constant the following graph would be approximately a \
horizontal straight line."
}], "Text"],

Cell[BoxData[
    \(data\  = 
      Table[Sqrt[\((v\  = \((bspline[kt, ctrl, \((i + 1)\)/72. , 0] - 
                    bspline[kt, ctrl, i/72. , 0])\))\) . v], \ {i, 0, 
          71}]\)], "Input"],

Cell[BoxData[
    \(ListPlot[data]\)], "Input"],

Cell[TextData[{
  "Suppose the total length of the spline constructed above is ",
  Cell[BoxData[
      \(L\)]],
  " .  What we need is an \"arc length parameterization\"; a function ",
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["C",
            FontFamily->"Courier",
            FontWeight->"Bold"], "\[RightVector]"],
        FontSize->16]]],
  "  that maps the interval ",
  Cell[BoxData[
      \(\([0, \ L]\)\)]],
  "onto the spline curve so that  ",
  Cell[BoxData[
      StyleBox[
        OverscriptBox[
          StyleBox["C",
            FontFamily->"Courier",
            FontWeight->"Bold"], "\[RightVector]"],
        FontSize->16]]],
  Cell[BoxData[
      \(\((s)\)\)]],
  " is the point on the curve that is ",
  Cell[BoxData[
      \(s\)]],
  " units from the first point on the curve, measured along the curve."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .11429 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0510204 0.0544218 0.0571429 0.0544218 [
[.05102 .04464 -3 -9 ]
[.05102 .04464 3 0 ]
[.18707 .04464 -9 -9 ]
[.18707 .04464 9 0 ]
[.32313 .04464 -3 -9 ]
[.32313 .04464 3 0 ]
[.45918 .04464 -9 -9 ]
[.45918 .04464 9 0 ]
[.59524 .04464 -6 -9 ]
[.59524 .04464 6 0 ]
[.73129 .04464 -12 -9 ]
[.73129 .04464 12 0 ]
[.86735 .04464 -6 -9 ]
[.86735 .04464 6 0 ]
[ 0 0 0 0 ]
[ 1 .11429 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05102 .05714 m
.05102 .06339 L
s
[(0)] .05102 .04464 0 1 Mshowa
.18707 .05714 m
.18707 .06339 L
s
[(2.5)] .18707 .04464 0 1 Mshowa
.32313 .05714 m
.32313 .06339 L
s
[(5)] .32313 .04464 0 1 Mshowa
.45918 .05714 m
.45918 .06339 L
s
[(7.5)] .45918 .04464 0 1 Mshowa
.59524 .05714 m
.59524 .06339 L
s
[(10)] .59524 .04464 0 1 Mshowa
.73129 .05714 m
.73129 .06339 L
s
[(12.5)] .73129 .04464 0 1 Mshowa
.86735 .05714 m
.86735 .06339 L
s
[(15)] .86735 .04464 0 1 Mshowa
.125 Mabswid
.07823 .05714 m
.07823 .06089 L
s
.10544 .05714 m
.10544 .06089 L
s
.13265 .05714 m
.13265 .06089 L
s
.15986 .05714 m
.15986 .06089 L
s
.21429 .05714 m
.21429 .06089 L
s
.2415 .05714 m
.2415 .06089 L
s
.26871 .05714 m
.26871 .06089 L
s
.29592 .05714 m
.29592 .06089 L
s
.35034 .05714 m
.35034 .06089 L
s
.37755 .05714 m
.37755 .06089 L
s
.40476 .05714 m
.40476 .06089 L
s
.43197 .05714 m
.43197 .06089 L
s
.48639 .05714 m
.48639 .06089 L
s
.51361 .05714 m
.51361 .06089 L
s
.54082 .05714 m
.54082 .06089 L
s
.56803 .05714 m
.56803 .06089 L
s
.62245 .05714 m
.62245 .06089 L
s
.64966 .05714 m
.64966 .06089 L
s
.67687 .05714 m
.67687 .06089 L
s
.70408 .05714 m
.70408 .06089 L
s
.7585 .05714 m
.7585 .06089 L
s
.78571 .05714 m
.78571 .06089 L
s
.81293 .05714 m
.81293 .06089 L
s
.84014 .05714 m
.84014 .06089 L
s
.89456 .05714 m
.89456 .06089 L
s
.92177 .05714 m
.92177 .06089 L
s
.94898 .05714 m
.94898 .06089 L
s
.97619 .05714 m
.97619 .06089 L
s
.02381 .05714 m
.02381 .06089 L
s
.25 Mabswid
0 .05714 m
1 .05714 L
s
0 0 m
1 0 L
1 .11429 L
0 .11429 L
closepath
clip
newpath
.5 Mabswid
.02381 .05714 m
.97619 .05714 L
s
1 0 0 r
4 Mabswid
.43197 .05714 Mdot
gsave
.43197 .05714 -66.5938 -0.4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(7) show
70.188 13.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.05102 .05714 m
.43197 .05714 L
s
0 g
gsave
.05102 .05714 -67.1875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.375 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.750 moveto
(@) show
71.375 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84245 .05714 -67.1875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.375 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.750 moveto
(D) show
71.375 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84245 .05714 -67.1875 -23.4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.125 translate 1 -1 scale
63.000 13.125 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.125 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
71.375 13.125 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{390.062, 44.5},
  ImageMargins->{{115, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000;2000`400?l00000o`00003oo`3ol>J7
0?o`iP00o`3ol>J70?o`iP00o`3ol>J70?o`iP00o`3ol>J70?o`iP00o`3ol>J70?o`iP00o`3ol>J7
0?o`iP00o`3ol>I20?o`iPL00000?P3ol>H00?l0oo3V@`3ol>H2000000<0oo3V00<000000?o`iP3o
l>H0?03ol>H00?l0oo3V@`3ol>H2000000<0oo3V00<000000?o`iP3ol>H0?03ol>H001H0oo3V0P00
000Z0?o`iPD000000`3ol>H00`000000oo3V0?o`iP020?o`iP<00000:`3ol>H3000002/0oo3V00<0
00000?o`iP3ol>H00`3ol>H00`000000oo3V0?o`iP020?o`iP<00000:03ol>H3000000@0oo3V0P00
000U0?o`iP<000000P3ol>H5000000<0oo3V00<000000?o`iP3ol>H00P3ol>H3000001h0oo3V0P00
00030?o`iP030000003ol>H00000008000000`3ol>H3000003@0oo3V000E0?o`iP040000003ol>H0
oo3V000002X0oo3V00@000000?o`iP3ol>H000001`3ol>H01@000000oo3V0?o`iP3ol>H0000002T0
oo3V00D000000?o`iP3ol>H0oo3V0000000Z0?o`iP030000003ol>H0oo3V00L0oo3V00D000000?o`
iP3ol>H0oo3V0000000X0?o`iP030000003ol>H0oo3V0080oo3V00@000000?o`iP3ol>H000009@3o
l>H00`000000oo3V0?o`iP020?o`iP040000003ol>H0oo3V000000L0oo3V00D000000?o`iP3ol>H0
oo3V0000000M0?o`iP8000001P3ol>H01@000000oo3V0?o`iP3ol>H0000000<0oo3V00<000000?o`
iP3ol>H0<@3ol>H001D0oo3V00@000000?o`iP3ol>H00000:`3ol>H00`000000oo3V0?o`iP0;0?o`
iP030000003ol>H0oo3V02/0oo3V00<000000?o`iP3ol>H0:@3ol>H00`000000oo3V0?o`iP0:0?o`
iP030000003ol>H0oo3V02H0oo3V00<000000?o`iP3ol>H00P3ol>H010000000oo3V0?o`iP00000U
0?o`iP030000003ol>H0oo3V00<0oo3V00<000000?o`iP3ol>H02`3ol>H00`000000oo3V0?o`iP0K
0?o`iP8000001P3ol>H00`000000oo3V0?o`iP050?o`iP030000003ol>H0oo3V0340oo3V000E0?o`
iP040000003ol>H0oo3V000002`0oo3V00<000000?o`iP3ol>H02P3ol>H00`000000oo3V0?o`iP0[
0?o`iP030000003ol>H0oo3V02T0oo3V00<000000?o`iP3ol>H02P3ol>H00`000000oo3V0?o`iP0V
0?o`iP030000003ol>H0oo3V0080oo3V00@000000?o`iP3ol>H000009@3ol>H00`000000oo3V0?o`
iP040?o`iP030000003ol>H0oo3V00X0oo3V00<000000?o`iP3ol>H06`3ol>H2000000H0oo3V00<0
00000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`iP0a0?o`iP005@3ol>H010000000oo3V0?o`iP00
000Y0?o`iP050000003ol>H0oo3V0?o`iP0000001`3ol>H4000002X0oo3V1000000]0?o`iP030000
003ol>H0oo3V00D0oo3V1000000Y0?o`iP030000003ol>H0oo3V0080oo3V00@000000?o`iP3ol>H0
00009@3ol>H01@000000oo3V0?o`iP3ol>H0000000<0oo3V00<000000?o`iP3ol>H01@3ol>H40000
01d0oo3V100000050?o`iP040000003ol>H0oo3V0?o`iP@00000=03ol>H001D0oo3V00@000000?o`
iP3ol>H00000:@3ol>H01@000000oo3V0?o`iP3ol>H0000000L0oo3V00<000000?o`iP3ol>H0:`3o
l>H00`000000oo3V0?o`iP0Z0?o`iP050000003ol>H0oo3V0?o`iP0000001`3ol>H00`000000oo3V
0?o`iP0Y0?o`iP800000103ol>H010000000oo3V0?o`iP00000T0?o`iP8000000`3ol>H01@000000
oo3V0?o`iP3ol>H0000000L0oo3V00<000000?o`iP3ol>H09P3ol>H2000000<0oo3V00<000000?o`
iP3ol>H0=@3ol>H001H0oo3V0P00000[0?o`iP<00000203ol>H5000002T0oo3V1@00000X0?o`iPD0
00001`3ol>H5000002P0oo3V00<000000?o`iP3ol>H00`3ol>H2000002H0oo3V00<000000?o`iP3o
l>H00P3ol>H3000000P0oo3V1@00000U0?o`iP040000003ol>H0oo3V0?o`iPD00000<`3ol>H00?l0
oo3VQ`3ol>H001H0oo3V0`00003o0?o`iRX0oo3V0`0000110?o`iP005P3ol>H200000?l0oo3V;03o
l>H200000440oo3V000F0?o`iP800000o`3ol>H/0?o`iP800000@@3ol>H001H0oo3V0P00002@0?o`
iP80o`00V@3ol>H200000440oo3V000F0?o`iP800000S`3ol>H40?l009P0oo3V0P0000110?o`iP00
103ol>HD000009<0o`00eP0000050?o`iP003@3ol>H00`000000oo3V0?o`iP060?o`iP8000002P3o
l>H00`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203o
l>H00`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203o
l>H00`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203o
l>H00`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203o
l>H00`000000oo3V0?o`iP070?o`iP80o`00203ol>H00`000000oo3V0?o`iP080?o`iP030000003o
l>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203ol>H00`000000oo3V0?o`iP070?o`iP030000003o
l>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203ol>H00`000000oo3V0?o`iP070?o`iP030000003o
l>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203ol>H00`000000oo3V0?o`iP070?o`iP030000003o
l>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203ol>H00`000000oo3V0?o`iP070?o`iP030000003o
l>H0oo3V00L0oo3V0P0000090?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H0203o
l>H00`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H0303o
l>H001H0oo3V0P00000c0?o`iP030000003ol>H0oo3V0340oo3V00<000000?o`iP3ol>H0<03ol>H0
0`000000oo3V0?o`iP0a0?o`iP030000003ol>H0oo3V0340oo3V00<000000?o`iP3ol>H09P3ol>H2
000000T0oo3V00<000000?o`iP3ol>H0=@3ol>H001H0oo3V0P00003o0?o`iR`0oo3V0P0000110?o`
iP005P3ol>H200000?l0oo3V;03ol>H200000440oo3V000F0?o`iP800000o`3ol>H/0?o`iP800000
@@3ol>H001H0oo3V0`00003o0?o`iRX0oo3V0`0000110?o`iP00Z03ol>H20?l00=`0oo3V002X0?o`
iP80o`00g03ol>H00:P0oo3V0P3o003L0?o`iP00Z@3ol>H20?l00=/0oo3V002Y0?o`iP80o`00f`3o
l>H00:X0oo3V0P3o003J0?o`iP00YP3ol>H20?l00080oo3V0P3o003J0?o`iP00YP3ol>H60?l00=X0
oo3V003o0?o`iXL0oo3V003o0?o`iXL0oo3V003o0?o`iXL0oo3V003o0?o`iXL0oo3V003o0?o`iXL0
oo3V003o0?o`iXL0oo3V003o0?o`iXL0oo3V0000\
\>"],
  ImageRangeCache->{{{0, 389.062}, {43.5, 0}} -> {-1.14161, -1.05001, \
0.0482781, 0.0482781}}],

Cell[TextData[{
  "The interval from ",
  StyleBox["0", "Input",
    FontWeight->"Plain"],
  " to ",
  StyleBox["L", "Input",
    FontWeight->"Plain"],
  "."
}], "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .71805 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0195449 0.136054 [
[.15986 .00704 -3 -9 ]
[.15986 .00704 3 0 ]
[.29592 .00704 -3 -9 ]
[.29592 .00704 3 0 ]
[.43197 .00704 -3 -9 ]
[.43197 .00704 3 0 ]
[.56803 .00704 -3 -9 ]
[.56803 .00704 3 0 ]
[.70408 .00704 -3 -9 ]
[.70408 .00704 3 0 ]
[.84014 .00704 -3 -9 ]
[.84014 .00704 3 0 ]
[.97619 .00704 -3 -9 ]
[.97619 .00704 3 0 ]
[.01131 .1556 -6 -4.5 ]
[.01131 .1556 0 4.5 ]
[.01131 .29165 -6 -4.5 ]
[.01131 .29165 0 4.5 ]
[.01131 .42771 -6 -4.5 ]
[.01131 .42771 0 4.5 ]
[.01131 .56376 -6 -4.5 ]
[.01131 .56376 0 4.5 ]
[.01131 .69982 -6 -4.5 ]
[.01131 .69982 0 4.5 ]
[.29592 .22363 0 0 ]
[.29592 .22363 62.625 13.375 ]
[.56681 .40132 0 0 ]
[.56681 .40132 41.5625 20.9375 ]
[ 0 0 0 0 ]
[ 1 .71805 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .01954 m
.15986 .02579 L
s
[(1)] .15986 .00704 0 1 Mshowa
.29592 .01954 m
.29592 .02579 L
s
[(2)] .29592 .00704 0 1 Mshowa
.43197 .01954 m
.43197 .02579 L
s
[(3)] .43197 .00704 0 1 Mshowa
.56803 .01954 m
.56803 .02579 L
s
[(4)] .56803 .00704 0 1 Mshowa
.70408 .01954 m
.70408 .02579 L
s
[(5)] .70408 .00704 0 1 Mshowa
.84014 .01954 m
.84014 .02579 L
s
[(6)] .84014 .00704 0 1 Mshowa
.97619 .01954 m
.97619 .02579 L
s
[(7)] .97619 .00704 0 1 Mshowa
.125 Mabswid
.05102 .01954 m
.05102 .02329 L
s
.07823 .01954 m
.07823 .02329 L
s
.10544 .01954 m
.10544 .02329 L
s
.13265 .01954 m
.13265 .02329 L
s
.18707 .01954 m
.18707 .02329 L
s
.21429 .01954 m
.21429 .02329 L
s
.2415 .01954 m
.2415 .02329 L
s
.26871 .01954 m
.26871 .02329 L
s
.32313 .01954 m
.32313 .02329 L
s
.35034 .01954 m
.35034 .02329 L
s
.37755 .01954 m
.37755 .02329 L
s
.40476 .01954 m
.40476 .02329 L
s
.45918 .01954 m
.45918 .02329 L
s
.48639 .01954 m
.48639 .02329 L
s
.51361 .01954 m
.51361 .02329 L
s
.54082 .01954 m
.54082 .02329 L
s
.59524 .01954 m
.59524 .02329 L
s
.62245 .01954 m
.62245 .02329 L
s
.64966 .01954 m
.64966 .02329 L
s
.67687 .01954 m
.67687 .02329 L
s
.73129 .01954 m
.73129 .02329 L
s
.7585 .01954 m
.7585 .02329 L
s
.78571 .01954 m
.78571 .02329 L
s
.81293 .01954 m
.81293 .02329 L
s
.86735 .01954 m
.86735 .02329 L
s
.89456 .01954 m
.89456 .02329 L
s
.92177 .01954 m
.92177 .02329 L
s
.94898 .01954 m
.94898 .02329 L
s
.25 Mabswid
0 .01954 m
1 .01954 L
s
.02381 .1556 m
.03006 .1556 L
s
[(1)] .01131 .1556 1 0 Mshowa
.02381 .29165 m
.03006 .29165 L
s
[(2)] .01131 .29165 1 0 Mshowa
.02381 .42771 m
.03006 .42771 L
s
[(3)] .01131 .42771 1 0 Mshowa
.02381 .56376 m
.03006 .56376 L
s
[(4)] .01131 .56376 1 0 Mshowa
.02381 .69982 m
.03006 .69982 L
s
[(5)] .01131 .69982 1 0 Mshowa
.125 Mabswid
.02381 .04676 m
.02756 .04676 L
s
.02381 .07397 m
.02756 .07397 L
s
.02381 .10118 m
.02756 .10118 L
s
.02381 .12839 m
.02756 .12839 L
s
.02381 .18281 m
.02756 .18281 L
s
.02381 .21002 m
.02756 .21002 L
s
.02381 .23723 m
.02756 .23723 L
s
.02381 .26444 m
.02756 .26444 L
s
.02381 .31886 m
.02756 .31886 L
s
.02381 .34608 m
.02756 .34608 L
s
.02381 .37329 m
.02756 .37329 L
s
.02381 .4005 m
.02756 .4005 L
s
.02381 .45492 m
.02756 .45492 L
s
.02381 .48213 m
.02756 .48213 L
s
.02381 .50934 m
.02756 .50934 L
s
.02381 .53655 m
.02756 .53655 L
s
.02381 .59097 m
.02756 .59097 L
s
.02381 .61818 m
.02756 .61818 L
s
.02381 .6454 m
.02756 .6454 L
s
.02381 .67261 m
.02756 .67261 L
s
.25 Mabswid
.02381 0 m
.02381 .71805 L
s
.5 Mabswid
.02381 .01955 m
.11619 .22551 L
.2032 .40254 L
.273 .52737 L
.33025 .613 L
.35832 .64728 L
.38164 .67071 L
.3925 .67975 L
.40376 .68768 L
.41383 .69337 L
.42284 .69723 L
.42717 .69863 L
.43172 .69976 L
.43426 .70024 L
.4355 .70043 L
.43664 .70058 L
.43775 .7007 L
.43875 .70079 L
.43986 .70087 L
.44046 .7009 L
.44103 .70092 L
.44209 .70095 L
.44269 .70095 L
.44325 .70095 L
.44437 .70093 L
.445 .7009 L
.44556 .70087 L
.44657 .7008 L
.44767 .7007 L
.44963 .70046 L
.4519 .70007 L
.45428 .69954 L
.45847 .69828 L
.46226 .69676 L
.46567 .69507 L
.47306 .69028 L
.47927 .68497 L
.48551 .67831 L
.49773 .66095 L
.50806 .64104 L
.51854 .61506 L
.52722 .58838 L
.54378 .52286 L
.55779 .45221 L
.57176 .3726 L
.58537 .29526 L
.59962 .22362 L
.6171 .15389 L
.63722 .09665 L
.64992 .07075 L
Mistroke
.66329 .05028 L
.67019 .04205 L
.6779 .03447 L
.68549 .02854 L
.6928 .02412 L
.69702 .02211 L
.70177 .02028 L
.70667 .01885 L
.7094 .01824 L
.71198 .01779 L
.71316 .01762 L
.71446 .01746 L
.71561 .01735 L
.71684 .01725 L
.71795 .01718 L
.71918 .01713 L
.72031 .0171 L
.72137 .0171 L
.72264 .01711 L
.72328 .01713 L
.72398 .01715 L
.72523 .01722 L
.72639 .0173 L
.72906 .01756 L
.73193 .01795 L
.73465 .01843 L
.73755 .01905 L
.74285 .02047 L
.75527 .02514 L
.76653 .03087 L
.77948 .03904 L
.80506 .05949 L
.83502 .08961 L
.90255 .17606 L
.97619 .29165 L
Mfstroke
1 .4 .4 r
.02381 .01955 m
.07372 .13276 L
.12424 .24268 L
.16813 .33359 L
.20724 .41024 L
.24567 .48074 L
.27971 .53832 L
.31289 .58901 L
.34207 .62816 L
.36772 .65735 L
.37985 .6691 L
.39257 .67981 L
.40417 .68793 L
.41427 .69359 L
.42421 .69771 L
.42676 .69851 L
.42949 .69926 L
.43186 .69979 L
.43438 .70026 L
.43569 .70046 L
.43688 .70061 L
.43799 .70072 L
.43921 .70082 L
.43973 .70086 L
.44029 .70089 L
.44077 .70091 L
.44129 .70093 L
.44188 .70094 L
.44244 .70095 L
.44298 .70095 L
.44347 .70095 L
.44401 .70094 L
.44459 .70092 L
.44514 .70089 L
.44564 .70087 L
.44679 .70079 L
.448 .70067 L
.45024 .70037 L
.45267 .69992 L
.45491 .69938 L
.457 .69877 L
.46083 .69738 L
.46485 .6955 L
.46909 .69305 L
.47652 .68747 L
.48397 .68008 L
.49639 .66316 L
.50832 .64047 L
.5187 .61459 L
.52872 .58328 L
Mistroke
.53753 .54995 L
.54538 .51545 L
.55321 .47665 L
.5604 .43777 L
.56681 .40132 L
Mfstroke
1 0 0 r
5 Mabswid
.56681 .40132 Mdot
gsave
.29592 .22363 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.375 translate 1 -1 scale
63.000 14.375 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.375 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(7) show
79.750 14.375 moveto
(units) show
121.625 14.375 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56681 .40132 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 28.9375 translate 1 -1 scale
63.000 21.375 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
65.000 21.375 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(C) show
%%IncludeResource: font Math4Mono-Bold
%%IncludeFont: Math4Mono-Bold
/Math4Mono-Bold findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
65.625 10.375 moveto
(1) show
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
75.438 21.375 moveto
(H) show
83.812 21.375 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(7) show
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
92.188 21.375 moveto
(L) show
100.562 21.375 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .71805 L
0 .71805 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{311.625, 223.75},
  ImageMargins->{{119, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004g0000gb000`400?l00000o`00003oo`3ol>Hh
0?o`iP00=03ol>H3000002D0oo3V1@00000U0?o`iP<000009`3ol>H3000002@0oo3V0`00000V0?o`
iP<000009`3ol>H00`000000oo3V0?o`iP0:0?o`iP00=@3ol>H00`000000oo3V0?o`iP0U0?o`iP04
0000003ol>H0oo3V000002@0oo3V00D000000?o`iP3ol>H0oo3V0000000W0?o`iP030000003ol>H0
oo3V0280oo3V00D000000?o`iP3ol>H0oo3V0000000T0?o`iP050000003ol>H0oo3V0?o`iP000000
9P3ol>H00`000000oo3V0?o`iP0:0?o`iP00=@3ol>H00`000000oo3V0?o`iP0V0?o`iP030000003o
l>H0oo3V02P0oo3V00<000000?o`iP3ol>H08P3ol>H5000002L0oo3V00<000000?o`iP3ol>H08P3o
l>H01@000000oo3V0?o`iP3ol>H0000002L0oo3V00<000000?o`iP3ol>H02@3ol>H003D0oo3V00<0
00000?o`iP3ol>H09`3ol>H00`000000oo3V0?o`iP0U0?o`iP8000009@3ol>H010000000oo3V0?o`
iP00000X0?o`iP030000003ol>H0oo3V0280oo3V1000000X0?o`iP030000003ol>H0oo3V00T0oo3V
000e0?o`iP030000003ol>H0oo3V02@0oo3V00D000000?o`iP3ol>H0oo3V0000000X0?o`iP030000
003ol>H0oo3V02<0oo3V00<000000?o`iP000000903ol>H4000002D0oo3V00<000000?o`iP3ol>H0
:P3ol>H00`000000oo3V0?o`iP080?o`iP00=03ol>H2000002H0oo3V00D000000?o`iP3ol>H0oo3V
0000000T0?o`iP050000003ol>H0oo3V0?o`iP0000009P3ol>H2000002@0oo3V00<000000?o`iP3o
l>H09`3ol>H00`000000oo3V0?o`iP0U0?o`iP050000003ol>H0oo3V0?o`iP0000002P3ol>H000d0
oo3V00<000000?o`iP3ol>H09@3ol>H00`000000oo3V0?o`iP0U0?o`iP<000009P3ol>H3000002P0
oo3V00<000000?o`iP3ol>H08P3ol>H5000002H0oo3V0P00000U0?o`iPD000002P3ol>H000d0oo3V
00<000000?o`iP3ol>H0o`3ol>HX0?o`iP003@3ol>H00`000000oo3V0?o`iP3o0?o`iRP0oo3V000=
0?o`iP030000003ol>H0oo3V0?l0oo3V:03ol>H000d0oo3V00<000000?o`iP3ol>H0o`3ol>HX0?o`
iP003@3ol>H00`000000oo3V0?o`iP3:0?o`iP/00000DP3ol>H000H0oo3V1`0000000`3oIVH00000
0000003o000002@00000103ol>H000d0oo3V00<0ofIV0?o`iP3ol>H01@3ol>H00`000000oo3V0?o`
iP050?o`iP030000003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01P3ol>H00`000000oo3V0?o`
iP050?o`iP030000003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`
iP050?o`iP030000003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`
iP050?o`iP030000003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`
iP050?o`iP030000003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`
iP050?o`iP030000003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`
iP060?o`iP030000003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`
iP050?o`iP030000003ol>H0oo3V00D0oo3V00@000000?o`iP3ol>H0oo3V0P0000020?o`iP030000
003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H00`3ol>H3000000L0oo3V00<000000?o`iP3ol>H0
1@3ol>H00`000000oo3V0?o`iP050?o`iP030000003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H0
1@3ol>H00`000000oo3V0?o`iP050?o`iP030000003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H0
1@3ol>H00`000000oo3V0?o`iP090?o`iP003@3ol>H00`000000ofIV0?o`iP340?o`iP030000003o
l>H0oo3V01@0oo3V00<000000?o`iP3ol>H0B@3ol>H000d0oo3V00<000000?mVIP3ol>H0``3ol>H0
0`000000oo3V0?o`iP0F0?o`iP800000B@3ol>H000d0oo3V00<000000?o`iP3oIVH0`@3ol>H20000
01/0oo3V0P0000170?o`iP003@3ol>H00`000000oo3V0?mVIP300?o`iP030000003ol>H0oo3V01d0
oo3V0P0000150?o`iP003@3ol>H010000000oo3V0?mVIP00002n0?o`iP030000003ol>H0oo3V0200
oo3V00<000000?o`iP3ol>H0@P3ol>H000d0oo3V00@000000?o`iP3ol>H0ofIV_P3ol>H00`000000
oo3V0?o`iP0Q0?o`iP030000003ol>H0oo3V0440oo3V000=0?o`iP80000000<0oo3V0?mVIP3ol>H0
_03ol>H00`000000oo3V0?o`iP0S0?o`iP030000003ol>H0oo3V0400oo3V000=0?o`iP050000003o
l>H0oo3V0?o`iP3oIVH0^`3ol>H00`000000oo3V0?o`iP0U0?o`iP030000003ol>H0oo3V03l0oo3V
000=0?o`iP050000003ol>H0oo3V0?o`iP3oIVH0^`3ol>H00`000000oo3V0?o`iP0V0?o`iP030000
003ol>H0oo3V03h0oo3V000=0?o`iP030000003ol>H0oo3V0080oo3V00<0ofIV0?o`iP3ol>H0]`3o
l>H00`000000oo3V0?o`iP0X0?o`iP030000003ol>H0oo3V03d0oo3V000=0?o`iP030000003ol>H0
oo3V0080oo3V00<0ofIV0?o`iP3ol>H0]P3ol>H00`000000oo3V0?o`iP0Z0?o`iP030000003ol>H0
oo3V03`0oo3V000=0?o`iP030000003ol>H0oo3V00<0oo3V00<0ofIV0?o`iP3ol>H0]@3ol>H00`00
0000oo3V0?o`iP0[0?o`iP030000003ol>H0oo3V03/0oo3V000=0?o`iP030000003ol>H0oo3V00<0
oo3V00<0ofIV0?o`iP3ol>H0]03ol>H00`000000oo3V0?o`iP0]0?o`iP030000003ol>H0oo3V03X0
oo3V000=0?o`iP030000003ol>H0oo3V00<0oo3V00<0ofIV0000003ol>H0/`3ol>H00`000000oo3V
0?o`iP0_0?o`iP030000003ol>H0oo3V03T0oo3V000=0?o`iP8000001@3ol>H00`3oIVH0oo3V0?o`
iP2b0?o`iP030000003ol>H0oo3V0300oo3V00<000000?o`iP3ol>H0>03ol>H000d0oo3V00<00000
0?o`iP3ol>H0103ol>H00`3oIVH000000?o`iP2a0?o`iP030000003ol>H0oo3V0380oo3V00<00000
0?o`iP3ol>H0=`3ol>H000d0oo3V00<000000?o`iP3ol>H01@3ol>H00`3oIVH0oo3V0?o`iP2`0?o`
iP030000003ol>H0oo3V03<0oo3V00<000000?o`iP3ol>H0=P3ol>H000d0oo3V00<000000?o`iP3o
l>H01@3ol>H00`3oIVH0oo3V0?o`iP2_0?o`iP030000003ol>H0oo3V03D0oo3V00<000000?o`iP3o
l>H0=@3ol>H000d0oo3V00<000000?o`iP3ol>H01P3ol>H00`3oIVH0oo3V0?o`iP2^0?o`iP030000
003ol>H0oo3V03H0oo3V00<000000?o`iP3ol>H0=03ol>H000d0oo3V00<000000?o`iP3ol>H01P3o
l>H00`3oIVH0oo3V0?o`iP2]0?o`iP030000003ol>H0oo3V03P0oo3V00<000000?o`iP3ol>H0<`3o
l>H000d0oo3V00<000000?o`iP3ol>H01P3ol>H00`3oIVH000000?o`iP2]0?o`iP030000003ol>H0
oo3V03P0oo3V00<000000?o`iP3ol>H0<`3ol>H000d0oo3V00<000000?o`iP3ol>H01`3ol>H00`3o
IVH0oo3V0?o`iP2[0?o`iP030000003ol>H0oo3V03X0oo3V00<000000?o`iP3ol>H0<P3ol>H000d0
oo3V0P0000080?o`iP030?mVIP000000oo3V0:/0oo3V00<000000?o`iP3ol>H0>`3ol>H00`000000
oo3V0?o`iP0a0?o`iP003@3ol>H00`000000oo3V0?o`iP080?o`iP030?mVIP3ol>H0oo3V0:T0oo3V
00<000000?o`iP3ol>H0?@3ol>H00`000000oo3V0?o`iP0`0?o`iP003@3ol>H00`000000oo3V0?o`
iP080?o`iP030?mVIP000000oo3V0:T0oo3V00<000000?o`iP3ol>H0?@3ol>H00`000000oo3V0?o`
iP0`0?o`iP003@3ol>H00`000000oo3V0?o`iP090?o`iP030?mVIP3ol>H0oo3V0:P0oo3V00<00000
0?o`iP3ol>H0?P3ol>H00`000000oo3V0?o`iP0_0?o`iP003@3ol>H00`000000oo3V0?o`iP090?o`
iP030?mVIP000000oo3V0:L0oo3V00<000000?o`iP3ol>H0@03ol>H00`000000oo3V0?o`iP0^0?o`
iP003@3ol>H00`000000oo3V0?o`iP0:0?o`iP030?mVIP3ol>H0oo3V0:H0oo3V00<000000?o`iP3o
l>H0@@3ol>H00`000000oo3V0?o`iP0]0?o`iP003@3ol>H00`000000oo3V0?o`iP0:0?o`iP030?mV
IP000000oo3V0:H0oo3V00<000000?o`iP3ol>H0@P3ol>H00`000000oo3V0?o`iP0/0?o`iP003@3o
l>H00`000000oo3V0?o`iP0:0?o`iP030?mVIP000000oo3V0:D0oo3V00<000000?o`iP3ol>H0@`3o
l>H00`000000oo3V0?o`iP0/0?o`iP003@3ol>H2000000`0oo3V00<0ofIV0?o`iP3ol>H0Y03ol>H0
0`000000oo3V0?o`iP140?o`iP030000003ol>H0oo3V02/0oo3V000=0?o`iP030000003ol>H0oo3V
00/0oo3V00<0ofIV0000003ol>H0Y03ol>H00`000000oo3V0?o`iP150?o`iP030000003ol>H0oo3V
02X0oo3V000=0?o`iP030000003ol>H0oo3V00`0oo3V00<0ofIV0?o`iP3ol>H0XP3ol>H00`000000
oo3V0?o`iP170?o`iP030000003ol>H0oo3V02T0oo3V000=0?o`iP030000003ol>H0oo3V00`0oo3V
00<0ofIV0000003ol>H0XP3ol>H00`000000oo3V0?o`iP170?o`iP030000003ol>H0oo3V02T0oo3V
000=0?o`iP030000003ol>H0oo3V00d0oo3V00<0ofIV0?o`iP3ol>H0X@3ol>H00`000000oo3V0?o`
iP180?o`iP030000003ol>H0oo3V02P0oo3V000=0?o`iP030000003ol>H0oo3V00d0oo3V00<0ofIV
0000003ol>H0X03ol>H00`000000oo3V0?o`iP1:0?o`iP030000003ol>H0oo3V02L0oo3V00040?o`
iP<000001P3ol>H00`000000oo3V0?o`iP0>0?o`iP030?mVIP3ol>H0oo3V09l0oo3V00<000000?o`
iP3ol>H0B`3ol>H00`000000oo3V0?o`iP0V0?o`iP001@3ol>H00`000000oo3V0?o`iP050?o`iP03
0000003ol>H0oo3V00h0oo3V00<0ofIV0000003ol>H0W`3ol>H00`000000oo3V0?o`iP1;0?o`iP03
0000003ol>H0oo3V02H0oo3V00050?o`iP030000003ol>H0oo3V00D0oo3V0`00000?0?o`iP030?mV
IP3ol>H0oo3V09d0oo3V00<000000?o`iP3ol>H0C@3ol>H00`000000oo3V0?o`iP0U0?o`iP001@3o
l>H00`000000oo3V0?o`iP050?o`iP030000003ol>H0oo3V00l0oo3V00<0ofIV0000003ol>H0W@3o
l>H00`000000oo3V0?o`iP1>0?o`iP030000003ol>H0oo3V02@0oo3V00050?o`iP030000003ol>H0
oo3V00D0oo3V00<000000?o`iP3ol>H03`3ol>H00`3oIVH000000?o`iP2M0?o`iP030000003ol>H0
oo3V04l0oo3V00<000000?o`iP3ol>H08`3ol>H000@0oo3V0P0000070?o`iP030000003ol>H0oo3V
0100oo3V00<0ofIV0000003ol>H0V`3ol>H00`000000oo3V0?o`iP1A0?o`iP030000003ol>H0oo3V
0280oo3V00050?o`iP030000003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H0403ol>H00`3oIVH0
00000?o`iP2K0?o`iP030000003ol>H0oo3V0540oo3V00<000000?o`iP3ol>H08P3ol>H000d0oo3V
00<000000?o`iP3ol>H04@3ol>H00`3oIVH0oo3V0?o`iP2J0?o`iP030000003ol>H0oo3V0580oo3V
00<000000?o`iP3ol>H08@3ol>H000d0oo3V00<000000?o`iP3ol>H04@3ol>H00`3oIVH000000?o`
iP2J0?o`iP030000003ol>H0oo3V05<0oo3V00<000000?o`iP3ol>H0803ol>H000d0oo3V00<00000
0?o`iP3ol>H04P3ol>H00`3oIVH0oo3V0?o`iP2H0?o`iP030000003ol>H0oo3V05D0oo3V00<00000
0?o`iP3ol>H07`3ol>H000d0oo3V00<000000?o`iP3ol>H04P3ol>H00`3oIVH000000?o`iP2H0?o`
iP030000003ol>H0oo3V05D0oo3V00<000000?o`iP3ol>H07`3ol>H000d0oo3V0P00000D0?o`iP03
0?mVIP3ol>H0oo3V09L0oo3V00<000000?o`iP3ol>H0EP3ol>H00`000000oo3V0?o`iP0N0?o`iP00
3@3ol>H00`000000oo3V0?o`iP0C0?o`iP030?mVIP000000oo3V09L0oo3V00<000000?o`iP3ol>H0
E`3ol>H00`000000oo3V0?o`iP0M0?o`iP003@3ol>H00`000000oo3V0?o`iP0D0?o`iP030?mVIP3o
l>H0oo3V09D0oo3V00<000000?o`iP3ol>H0F03ol>H00`000000oo3V0?o`iP0M0?o`iP003@3ol>H0
0`000000oo3V0?o`iP0D0?o`iP030?mVIP000000oo3V09D0oo3V00<000000?o`iP3ol>H0F@3ol>H0
0`000000oo3V0?o`iP0L0?o`iP003@3ol>H00`000000oo3V0?o`iP0D0?o`iP030?mVIP000000oo3V
09D0oo3V00<000000?o`iP3ol>H0FP3ol>H00`000000oo3V0?o`iP0K0?o`iP003@3ol>H00`000000
oo3V0?o`iP0E0?o`iP030?mVIP000000oo3V09@0oo3V00<000000?o`iP3ol>H0FP3ol>H00`000000
oo3V0?o`iP0K0?o`iP003@3ol>H00`000000oo3V0?o`iP0E0?o`iP030?mVIP000000oo3V09@0oo3V
00<000000?o`iP3ol>H0F`3ol>H00`000000oo3V0?o`iP0J0?o`iP003@3ol>H00`000000oo3V0?o`
iP0F0?o`iP030?mVIP3ol>H0oo3V0980oo3V00<000000?o`iP3ol>H0G@3ol>H00`000000oo3V0?o`
iP0I0?o`iP003@3ol>H2000001L0oo3V00<0ofIV0000003ol>H0TP3ol>H00`000000oo3V0?o`iP1M
0?o`iP030000003ol>H0oo3V01T0oo3V000=0?o`iP030000003ol>H0oo3V01L0oo3V00<0ofIV0?o`
iP3ol>H0T@3ol>H00`000000oo3V0?o`iP1N0?o`iP030000003ol>H0oo3V01P0oo3V000=0?o`iP03
0000003ol>H0oo3V01L0oo3V00<0ofIV0000003ol>H0T@3ol>H00`000000oo3V0?o`iP1N0?o`iP03
0000003ol>H0oo3V01P0oo3V000=0?o`iP030000003ol>H0oo3V01P0oo3V00<0ofIV0?o`iP3ol>H0
S`3ol>H00`000000oo3V0?o`iP1P0?o`iP030000003ol>H0oo3V01L0oo3V000=0?o`iP030000003o
l>H0oo3V01P0oo3V00<0ofIV0000003ol>H0S`3ol>H00`000000oo3V0?o`iP1Q0?o`iP030000003o
l>H0oo3V01H0oo3V000=0?o`iP030000003ol>H0oo3V01T0oo3V00<0ofIV0?o`iP3ol>H0SP3ol>H0
0`000000oo3V0?o`iP1Q0?o`iP030000003ol>H0oo3V01H0oo3V000=0?o`iP030000003ol>H0oo3V
01T0oo3V00<0ofIV0000003ol>H0SP3ol>H00`000000oo3V0?o`iP1R0?o`iP030000003ol>H0oo3V
01D0oo3V000=0?o`iP030000003ol>H0oo3V01T0oo3V00<0ofIV0000003ol>H0SP3ol>H00`000000
oo3V0?o`iP1S0?o`iP030000003ol>H0oo3V01@0oo3V000=0?o`iP8000006`3ol>H00`3oIVH00000
0?o`iP0g0?o`iP80o`003P3ol>H:0?l000050?o`iP3o0000o`000?l0003ol>H01P3o00040?o`iP@0
o`000P3ol>H50?l00240oo3V00<000000?o`iP3ol>H0I03ol>H00`000000oo3V0?o`iP0D0?o`iP00
3@3ol>H00`000000oo3V0?o`iP0J0?o`iP030?mVIP000000oo3V03L0oo3V0P3o000=0?o`iP80o`00
0P3ol>H20?l00080oo3V0P3o00020?o`iP80o`00103ol>H20?l000D0oo3V0P3o00020?o`iP80o`00
00<0oo3V0?l0003ol>H00P3ol>H20?l00200oo3V00<000000?o`iP3ol>H0I@3ol>H00`000000oo3V
0?o`iP0C0?o`iP003@3ol>H00`000000oo3V0?o`iP0K0?o`iP030?mVIP000000oo3V03L0oo3V00<0
o`000?o`iP3ol>H02`3ol>H20?l00080oo3V0P3o00020?o`iP80o`000P3ol>H20?l000@0oo3V0P3o
00050?o`iP80o`001`3ol>H40?l00200oo3V00<000000?o`iP3ol>H0IP3ol>H00`000000oo3V0?o`
iP0B0?o`iP003@3ol>H00`000000oo3V0?o`iP0K0?o`iP030?mVIP000000oo3V03L0oo3V0P3o000<
0?o`iP80o`000P3ol>H20?l00080oo3V0P3o00020?o`iP80o`00103ol>H20?l000D0oo3V0P3o0005
0?o`iPD0o`008@3ol>H00`000000oo3V0?o`iP1V0?o`iP030000003ol>H0oo3V0180oo3V000=0?o`
iP030000003ol>H0oo3V01`0oo3V00<0ofIV0000003ol>H0=P3ol>H20?l000`0oo3V0P3o00020?o`
iP80o`000P3ol>H20?l00080oo3V0P3o00040?o`iP80o`001@3ol>H20?l000D0oo3V0P3o00030?o`
iP030?l0003ol>H0oo3V01h0oo3V00<000000?o`iP3ol>H0I`3ol>H00`000000oo3V0?o`iP0A0?o`
iP003@3ol>H00`000000oo3V0?o`iP0L0?o`iP030?mVIP000000oo3V03H0oo3V0P3o000;0?o`iP<0
o`0000D0oo3V0?l0003o0000o`000?o`iP060?l000@0oo3V0`3o00030?o`iPL0o`000`3ol>H50?l0
01l0oo3V00<000000?o`iP3ol>H0J@3ol>H00`000000oo3V0?o`iP0@0?o`iP003@3ol>H00`000000
oo3V0?o`iP0M0?o`iP030?mVIP000000oo3V03H0oo3V00<0o`000?o`iP3ol>H08`3ol>H20?l002X0
oo3V00<000000?o`iP3ol>H0J@3ol>H00`000000oo3V0?o`iP0@0?o`iP003@3ol>H00`000000oo3V
0?o`iP0M0?o`iP030?mVIP000000oo3V0380oo3V00@0o`000?o`iP3ol>H0oo3V0P3o000M0?o`iP80
o`001@3ol>H20?l002X0oo3V00<000000?o`iP3ol>H0JP3ol>H00`000000oo3V0?o`iP0?0?o`iP00
3@3ol>H2000001l0oo3V00<0ofIV0000003ol>H0<@3ol>H60?l001d0oo3V0P3o000a0?o`iP030000
003ol>H0oo3V06/0oo3V00<000000?o`iP3ol>H03P3ol>H000d0oo3V00<000000?o`iP3ol>H07P3o
l>H00`3oIVH000000?o`iP270?o`iP030000003ol>H0oo3V06/0oo3V00<000000?o`iP3ol>H03P3o
l>H000d0oo3V00<000000?o`iP3ol>H07`3ol>H00`3oIVH000000?o`iP250?o`iP030000003ol>H0
oo3V06d0oo3V00<000000?o`iP3ol>H03@3ol>H000d0oo3V00<000000?o`iP3ol>H07`3ol>H00`3o
IVH000000?o`iP250?o`iP030000003ol>H0oo3V06d0oo3V00<000000?o`iP3ol>H03@3ol>H000d0
oo3V00<000000?o`iP3ol>H0803ol>H00`3oIVH0oo3V0?o`iP240?o`iP030000003ol>H0oo3V06h0
oo3V00<000000?o`iP3ol>H0303ol>H000d0oo3V00<000000?o`iP3ol>H0803ol>H00`3oIVH00000
0?o`iP240?o`iP030000003ol>H0oo3V06l0oo3V00<000000?o`iP3ol>H02`3ol>H000<0oo3V1@00
00050?o`iP030000003ol>H0oo3V0240oo3V00<0ofIV0?o`iP3ol>H0P`3ol>H00`000000oo3V0?o`
iP1_0?o`iP030000003ol>H0oo3V00/0oo3V00040?o`iP040000003ol>H0oo3V000000D0oo3V00<0
00000?o`iP3ol>H08@3ol>H00`3oIVH000000?o`iP220?o`iP030000003ol>H0oo3V0740oo3V00<0
00000?o`iP3ol>H02P3ol>H000D0oo3V00<000000?o`iP3ol>H01@3ol>H300000280oo3V00<0ofIV
0?o`iP3ol>H0P@3ol>H00`000000oo3V0?o`iP1b0?o`iP030000003ol>H0oo3V00T0oo3V00060?o`
iP030000003ol>H0oo3V00@0oo3V00<000000?o`iP3ol>H08P3ol>H00`3oIVH000000?o`iP210?o`
iP030000003ol>H0oo3V07h0oo3V00030?o`iP050000003ol>H0oo3V0?o`iP0000001@3ol>H00`00
0000oo3V0?o`iP0R0?o`iP030?mVIP000000oo3V0840oo3V00<000000?o`iP3ol>H0OP3ol>H000<0
oo3V00D000000?o`iP3ol>H0oo3V000000050?o`iP030000003ol>H0oo3V02<0oo3V00<0ofIV0000
003ol>H0P03ol>H00`000000oo3V0?o`iP1n0?o`iP00103ol>H3000000H0oo3V00<000000?o`iP3o
l>H08`3ol>H00`3oIVH000000?o`iP200?o`iP030000003ol>H0oo3V07h0oo3V000=0?o`iP030000
003ol>H0oo3V02@0oo3V00<0ofIV0000003ol>H0OP3ol>H00`000000oo3V0?o`iP1o0?o`iP003@3o
l>H00`000000oo3V0?o`iP0T0?o`iP030?mVIP000000oo3V07h0oo3V00<000000?o`iP3ol>H0O`3o
l>H000d0oo3V00<000000?o`iP3ol>H09@3ol>H00`3oIVH000000?o`iP1m0?o`iP030000003ol>H0
oo3V07l0oo3V000=0?o`iP8000009P3ol>H00`3oIVH000000?o`iP1m0?o`iP030000003ol>H0oo3V
07l0oo3V000=0?o`iP030000003ol>H0oo3V02H0oo3V00<0ofIV0000003ol>H0O03ol>H00`000000
oo3V0?o`iP1o0?o`iP003@3ol>H00`000000oo3V0?o`iP0V0?o`iP030?mVIP000000oo3V07`0oo3V
00<000000?o`iP3ol>H0O`3ol>H000d0oo3V00<000000?o`iP3ol>H09`3ol>H00`3oIVH000000?o`
iP1j0?o`iP030000003ol>H0oo3V0800oo3V000=0?o`iP030000003ol>H0oo3V02L0oo3V00<0ofIV
0000003ol>H0NP3ol>H00`000000oo3V0?o`iP200?o`iP003@3ol>H00`000000oo3V0?o`iP0X0?o`
iP030?mVIP000000oo3V07T0oo3V00<000000?o`iP3ol>H0P03ol>H000d0oo3V00<000000?o`iP3o
l>H0:03ol>H00`3oIVH000000?o`iP1i0?o`iP030000003ol>H0oo3V0800oo3V000=0?o`iP030000
003ol>H0oo3V02T0oo3V00<0ofIV0000003ol>H0N03ol>H00`000000oo3V0?o`iP200?o`iP003@3o
l>H00`000000oo3V0?o`iP0Y0?o`iP030?mVIP000000oo3V07P0oo3V00<000000?o`iP3ol>H0P03o
l>H000d0oo3V0P00000[0?o`iP030?mVIP000000oo3V07H0oo3V00<000000?o`iP3ol>H0P@3ol>H0
00d0oo3V00<000000?o`iP3ol>H0:P3ol>H00`3oIVH000000?o`iP1f0?o`iP030000003ol>H0oo3V
0840oo3V000=0?o`iP030000003ol>H0oo3V02/0oo3V00<0ofIV0000003ol>H0M@3ol>H00`000000
oo3V0?o`iP210?o`iP003@3ol>H00`000000oo3V0?o`iP0[0?o`iP030?mVIP000000oo3V07D0oo3V
00<000000?o`iP3ol>H0P@3ol>H000d0oo3V00<000000?o`iP3ol>H0;03ol>H00`3oIVH000000?o`
iP1d0?o`iP030000003ol>H0oo3V0840oo3V000=0?o`iP030000003ol>H0oo3V02`0oo3V00<0ofIV
0000003ol>H0M03ol>H00`000000oo3V0?o`iP210?o`iP003@3ol>H00`000000oo3V0?o`iP0]0?o`
iP030?mVIP3ol>H0oo3V0780oo3V00<000000?o`iP3ol>H0PP3ol>H000d0oo3V00<000000?o`iP3o
l>H0;@3ol>H00`3oIVH000000?o`iP1b0?o`iP030000003ol>H0oo3V0880oo3V000=0?o`iP800000
;`3ol>H00`3oIVH0oo3V0?o`iP1a0?o`iP030000003ol>H0oo3V0880oo3V000=0?o`iP030000003o
l>H0oo3V02l0oo3V00<0ofIV0?o`iP3ol>H0L03ol>H00`000000oo3V0?o`iP220?o`iP003@3ol>H0
0`000000oo3V0?o`iP0_0?o`iP030?mVIP3ol>H0oo3V0700oo3V00<000000?o`iP3ol>H0PP3ol>H0
00d0oo3V00<000000?o`iP3ol>H0<03ol>H00`3oIVH0oo3V0?o`iP1^0?o`iP030000003ol>H0oo3V
08<0oo3V000=0?o`iP030000003ol>H0oo3V0300oo3V00<0ofIV0?o`iP3ol>H0KP3ol>H00`000000
oo3V0?o`iP230?o`iP003@3ol>H00`000000oo3V0?o`iP0a0?o`iP030?mVIP3ol>H0oo3V06d0oo3V
00<000000?o`iP3ol>H0P`3ol>H000d0oo3V00<000000?o`iP3ol>H0<@3ol>H00`3oIVH0oo3V0?o`
iP1[0?o`iP<0o`00Q@3ol>H000d0oo3V00<000000?o`iP3ol>H0<P3ol>H00`3oIVH0oo3V0?o`iP1Y
0?o`iPD0o`00Q03ol>H000d0oo3V0P00000c0?o`iP030?mVIP3ol>H0oo3V06T0oo3V1@3o00240?o`
iP003@3ol>H00`000000oo3V0?o`iP0c0?o`iP030?mVIP3ol>H0oo3V06P0oo3V1@3o00240?o`iP00
3@3ol>H00`000000oo3V0?o`iP0c0?o`iP030?mVIP3ol>H0oo3V06T0oo3V0`3o000A0?o`iP030?n_
Z03o3`l0oo3V00/0oo3V00<0o`l?0?n_Z03ol>H0H`3ol>H000d0oo3V00<000000?o`iP3ol>H0=03o
l>H00`3oIVH0oo3V0?o`iP1Y0?o`iP030?mVIP3ol>H0oo3V0100oo3V00<0obl]0?m@C03ol>H02`3o
l>H00`3oD4`0obl]0?o`iP1S0?o`iP003@3ol>H00`000000oo3V0?o`iP0d0?o`iP030?mVIP3ol>H0
oo3V06P0oo3V00<0ofIV0000003ol>H0403ol>H00`3o[jP0o`000?moNP0<0?o`iP030?moNP3o0000
ojnX06<0oo3V000=0?o`iP030000003ol>H0oo3V03D0oo3V00<0ofIV0?o`iP3ol>H0I`3ol>H00`3o
IVH0oo3V0?o`iP040?o`iP@0o`00203ol>H00`3oD4`0o`000?n_Z0050?o`iP80o`001@3ol>H00`3o
[jP0o`000?m@C01S0?o`iP00103ol>H3000000H0oo3V00<000000?o`iP3ol>H0=@3ol>H00`3oIVH0
00000?o`iP1W0?o`iP030?mVIP3ol>H0oo3V00<0oo3V0P3o00020?o`iP80o`001`3ol>H00`3o3`l0
o`000?o`iP050?o`iP80o`001P3ol>H00`3o0000o`l?0?o`iP1R0?o`iP000`3ol>H01@000000oo3V
0?o`iP3ol>H0000000D0oo3V00<000000?o`iP3ol>H0=P3ol>H00`3oIVH0oo3V0?o`iP1V0?o`iP03
0?mVIP3ol>H0oo3V0080oo3V0P3o000<0?o`iP80o`001`3ol>H00`3o0000oo3V0?o`iP040?o`iP80
o`00H`3ol>H000L0oo3V00<000000?o`iP3ol>H00`3ol>H3000003L0oo3V00<0ofIV0?o`iP3ol>H0
I@3ol>H00`3oIVH0oo3V0?o`iP020?o`iP80o`00303ol>H20?l000L0oo3V0P3o00050?o`iP80o`00
H`3ol>H000D0oo3V0P0000060?o`iP030000003ol>H0oo3V03L0oo3V00<0ofIV0?o`iP3ol>H0I03o
l>H00`3oIVH000000?o`iP030?o`iP80o`00303ol>H00`3o3`l0o`000?oPeP060?o`iP80o`001@3o
l>H00`3o0000o`l?0?o`iP1R0?o`iP001`3ol>H00`000000oo3V0?o`iP030?o`iP030000003ol>H0
oo3V03P0oo3V00<0ofIV0?o`iP3ol>H0H`3ol>H00`3oIVH0oo3V0?o`iP030?o`iP80o`00103ol>H0
0`3o0000oo3V0?o`iP050?o`iP030?m@C03o0000ojnX00H0oo3V0P3o00040?o`iP030?n_Z03o0000
oe1<06<0oo3V00030?o`iP050000003ol>H0oo3V0?o`iP0000001@3ol>H00`000000oo3V0?o`iP0h
0?o`iP030?mVIP3ol>H0oo3V06<0oo3V00<0ofIV0?o`iP3ol>H0103ol>H20?l00080oo3V0P3o0007
0?o`iP030?n_Z03o0000ogmj00L0oo3V00<0o`000?o`iP3ol>H00P3ol>H00`3oOgX0o`000?n_Z01S
0?o`iP00103ol>H3000000H0oo3V00<000000?o`iP3ol>H0>@3ol>H00`3oIVH0oo3V0?o`iP1R0?o`
iP030?mVIP3ol>H0oo3V00D0oo3V1@3o00080?o`iP030?l_;@3oD4`0oo3V0080oo3V00@0o`000?o`
iP3ol>H0oo3V0P3o00030?o`iP030?m@C03o;bd0oo3V06<0oo3V000=0?o`iP030000003ol>H0oo3V
03T0oo3V00<0ofIV0000003ol>H0HP3ol>H00`3oIVH0oo3V0?o`iP0B0?o`iP030?n_Z03o3`l0oo3V
0080oo3V1P3o00030?o`iP030?l?3`3o[jP0oo3V06<0oo3V000=0?o`iP030000003ol>H0oo3V03X0
oo3V00<0ofIV0?o`iP3ol>H0H@3ol>H00`3oIVH0oo3V0?o`iP260?o`iP003@3ol>H00`000000oo3V
0?o`iP0k0?o`iP030?mVIP3ol>H0oo3V05l0oo3V00<0ofIV0?o`iP3ol>H0Q`3ol>H000d0oo3V0P00
000l0?o`iP030?mVIP3ol>H0oo3V05l0oo3V00<0ofIV0?o`iP3ol>H0Q`3ol>H000d0oo3V00<00000
0?o`iP3ol>H0?03ol>H00`3oIVH0oo3V0?o`iP1N0?o`iP030?mVIP3ol>H0oo3V08L0oo3V000=0?o`
iP030000003ol>H0oo3V03`0oo3V00<0ofIV0?o`iP3ol>H0GP3ol>H00`3oIVH0oo3V0?o`iP050?o`
iPL0o`00N`3ol>H000d0oo3V00<000000?o`iP3ol>H0?@3ol>H00`3oIVH0oo3V0?o`iP1M0?o`iP03
0?mVIP3ol>H0oo3V00X0oo3V00<0o`000?o`iP3ol>H0NP3ol>H000d0oo3V00<000000?o`iP3ol>H0
?@3ol>H00`3oIVH000000?o`iP1L0?o`iP030000003oIVH0oo3V00X0oo3V00<0o`000?o`iP3ol>H0
N`3ol>H000d0oo3V00<000000?o`iP3ol>H0?P3ol>H00`3oIVH0oo3V0?o`iP1K0?o`iP030?mVIP3o
l>H0oo3V08P0oo3V000=0?o`iP030000003ol>H0oo3V03l0oo3V00<0ofIV0?o`iP3ol>H0FP3ol>H0
0`3oIVH0oo3V0?o`iP280?o`iP003@3ol>H00`000000oo3V0?o`iP0o0?o`iP030?mVIP3ol>H0oo3V
05X0oo3V00<0ofIV0?o`iP3ol>H0R03ol>H000d0oo3V00<000000?o`iP3ol>H0@03ol>H00`3oIVH0
oo3V0?o`iP1I0?o`iP030?mVIP3ol>H0oo3V08P0oo3V000=0?o`iP800000@@3ol>H00`3oIVH0oo3V
0?o`iP1H0?o`iP030000003oIVH0oo3V08T0oo3V000=0?o`iP030000003ol>H0oo3V0440oo3V00<0
ofIV0?o`iP3ol>H0E`3ol>H00`000000ofIV0?o`iP290?o`iP003@3ol>H00`000000oo3V0?o`iP11
0?o`iP030?mVIP3ol>H0oo3V05L0oo3V00<0ofIV0?o`iP3ol>H0R@3ol>H000d0oo3V00<000000?o`
iP3ol>H0@P3ol>H00`3oIVH0oo3V0?o`iP1F0?o`iP030?mVIP3ol>H0oo3V08T0oo3V000=0?o`iP03
0000003ol>H0oo3V04<0oo3V00<0ofIV0?o`iP3ol>H0E@3ol>H00`3oIVH0oo3V0?o`iP290?o`iP00
3@3ol>H00`000000oo3V0?o`iP130?o`iP030?mVIP3ol>H0oo3V05@0oo3V00<000000?mVIP3ol>H0
RP3ol>H000d0oo3V00<000000?o`iP3ol>H0A03ol>H00`3oIVH0oo3V0?o`iP1C0?o`iP030000003o
IVH0oo3V08X0oo3V000=0?o`iP030000003ol>H0oo3V04@0oo3V00<0ofIV0?o`iP3ol>H0D`3ol>H0
0`000000ofIV0?o`iP2:0?o`iP003@3ol>H2000004H0oo3V00<0ofIV0?o`iP3ol>H0DP3ol>H00`3o
IVH0oo3V0?o`iP2:0?o`iP003@3ol>H00`000000oo3V0?o`iP150?o`iP030000003oIVH0oo3V0580
oo3V00<0ofIV0?o`iP3ol>H0RP3ol>H000d0oo3V00<000000?o`iP3ol>H0AP3ol>H00`3oIVH0oo3V
0?o`iP1@0?o`iP030000003oIVH0oo3V08/0oo3V000=0?o`iP030000003ol>H0oo3V04L0oo3V00<0
ofIV0?o`iP3ol>H0C`3ol>H00`000000ofIV0?o`iP2;0?o`iP003@3ol>H00`000000oo3V0?o`iP17
0?o`iP030?mVIP3ol>H0oo3V04l0oo3V00<000000?mVIP3ol>H0R`3ol>H000d0oo3V00<000000?o`
iP3ol>H0B03ol>H00`3oIVH0oo3V0?o`iP1>0?o`iP030?mVIP3ol>H0oo3V08/0oo3V000=0?o`iP03
0000003ol>H0oo3V04P0oo3V00<000000?mVIP3ol>H0CP3ol>H00`3oIVH0oo3V0?o`iP2;0?o`iP00
3@3ol>H00`000000oo3V0?o`iP190?o`iP030?mVIP3ol>H0oo3V04`0oo3V00<000000?mVIP3ol>H0
S03ol>H000d0oo3V0P00001;0?o`iP030?mVIP3ol>H0oo3V04/0oo3V00<0ofIV0?o`iP3ol>H0S03o
l>H000d0oo3V00<000000?o`iP3ol>H0BP3ol>H00`3oIVH0oo3V0?o`iP1;0?o`iP030?mVIP3ol>H0
oo3V08`0oo3V000=0?o`iP030000003ol>H0oo3V04/0oo3V00<0ofIV0?o`iP3ol>H0BP3ol>H00`3o
IVH0oo3V0?o`iP2<0?o`iP003@3ol>H00`000000oo3V0?o`iP1<0?o`iP030?mVIP3ol>H0oo3V04P0
oo3V00<0ofIV0?o`iP3ol>H0S@3ol>H000d0oo3V00<000000?o`iP3ol>H0C03ol>H00`3oIVH0oo3V
0?o`iP180?o`iP030?mVIP3ol>H0oo3V08d0oo3V000=0?o`iP030000003ol>H0oo3V04d0oo3V00<0
ofIV0?o`iP3ol>H0A`3ol>H00`3oIVH0oo3V0?o`iP2=0?o`iP001@3ol>H3000000D0oo3V00<00000
0?o`iP3ol>H0C@3ol>H00`3oIVH000000?o`iP170?o`iP030?mVIP3ol>H0oo3V08d0oo3V00060?o`
iP030000003ol>H0oo3V00@0oo3V00<000000?o`iP3ol>H0CP3ol>H00`3oIVH0oo3V0?o`iP150?o`
iP030?mVIP3ol>H0oo3V08h0oo3V00030?o`iPD000001@3ol>H3000004l0oo3V00<0ofIV0?o`iP3o
l>H0A03ol>H00`3oIVH0oo3V0?o`iP2>0?o`iP000`3ol>H010000000oo3V0?o`iP0000060?o`iP03
0000003ol>H0oo3V04l0oo3V00<0ofIV0000003ol>H0A03ol>H00`3oIVH0oo3V0?o`iP2>0?o`iP00
103ol>H00`000000oo3V000000060?o`iP030000003ol>H0oo3V0500oo3V00<0ofIV0?o`iP3ol>H0
@`3ol>H00`3oIVH0oo3V0?o`iP2>0?o`iP001@3ol>H2000000H0oo3V00<000000?o`iP3ol>H0D@3o
l>H00`3oIVH0oo3V0?o`iP110?o`iP030000003oIVH0oo3V08l0oo3V00060?o`iP030000003ol>H0
oo3V00@0oo3V00<000000?o`iP3ol>H0D@3ol>H00`3oIVH0oo3V0?o`iP110?o`iP030?mVIP3ol>H0
oo3V08l0oo3V000=0?o`iP030000003ol>H0oo3V0580oo3V00<0ofIV0?o`iP3ol>H0@03ol>H00`3o
IVH0oo3V0?o`iP2?0?o`iP003@3ol>H00`000000oo3V0?o`iP1B0?o`iP030?mVIP000000oo3V0400
oo3V00<0ofIV0?o`iP3ol>H0S`3ol>H000d0oo3V00<000000?o`iP3ol>H0D`3ol>H00`3oIVH0oo3V
0?o`iP0n0?o`iP030000003oIVH0oo3V0900oo3V000=0?o`iP800000E@3ol>H00`3oIVH0oo3V0?o`
iP0m0?o`iP030?mVIP3ol>H0oo3V0900oo3V000=0?o`iP030000003ol>H0oo3V05@0oo3V00<0ofIV
0000003ol>H0?@3ol>H00`3oIVH0oo3V0?o`iP2@0?o`iP003@3ol>H00`000000oo3V0?o`iP1E0?o`
iP030?mVIP3ol>H0oo3V03`0oo3V00<0ofIV0?o`iP3ol>H0T03ol>H000d0oo3V00<000000?o`iP3o
l>H0EP3ol>H00`3oIVH0oo3V0?o`iP0j0?o`iP030?mVIP3ol>H0oo3V0940oo3V000=0?o`iP030000
003ol>H0oo3V05L0oo3V00<0ofIV0?o`iP3ol>H0>@3ol>H00`3oIVH0oo3V0?o`iP2A0?o`iP003@3o
l>H00`000000oo3V0?o`iP1G0?o`iP030000003oIVH0oo3V03T0oo3V00<0ofIV0?o`iP3ol>H0T@3o
l>H000d0oo3V00<000000?o`iP3ol>H0F03ol>H00`000000ofIV0?o`iP0g0?o`iP030?mVIP000000
oo3V0980oo3V000=0?o`iP030000003ol>H0oo3V05T0oo3V00<0ofIV0?o`iP3ol>H0=P3ol>H00`3o
IVH0oo3V0?o`iP2B0?o`iP003@3ol>H2000005X0oo3V00<000000?mVIP3ol>H0=P3ol>H00`3oIVH0
oo3V0?o`iP2B0?o`iP003@3ol>H00`000000oo3V0?o`iP1J0?o`iP030000003oIVH0oo3V03@0oo3V
00<0ofIV0000003ol>H0T`3ol>H000d0oo3V00<000000?o`iP3ol>H0F`3ol>H00`000000ofIV0?o`
iP0c0?o`iP030?mVIP3ol>H0oo3V09<0oo3V000=0?o`iP030000003ol>H0oo3V05`0oo3V00<00000
0?mVIP3ol>H0<P3ol>H00`3oIVH0oo3V0?o`iP2C0?o`iP003@3ol>H00`000000oo3V0?o`iP1M0?o`
iP030?mVIP3ol>H0oo3V0300oo3V00<0ofIV0?o`iP3ol>H0U03ol>H000d0oo3V00<000000?o`iP3o
l>H0GP3ol>H00`3oIVH0oo3V0?o`iP0_0?o`iP030?mVIP3ol>H0oo3V09@0oo3V000=0?o`iP030000
003ol>H0oo3V05l0oo3V00<0ofIV0?o`iP3ol>H0;P3ol>H00`3oIVH0oo3V0?o`iP2D0?o`iP003@3o
l>H00`000000oo3V0?o`iP1P0?o`iP030?mVIP3ol>H0oo3V02`0oo3V00<0ofIV0?o`iP3ol>H0U@3o
l>H000d0oo3V00<000000?o`iP3ol>H0H@3ol>H00`3oIVH0oo3V0?o`iP0[0?o`iP030?mVIP3ol>H0
oo3V09D0oo3V000=0?o`iP800000HP3ol>H00`3oIVH000000?o`iP0Z0?o`iP030?mVIP3ol>H0oo3V
09H0oo3V000=0?o`iP030000003ol>H0oo3V0680oo3V00<0ofIV0000003ol>H0:03ol>H00`000000
ofIV0?o`iP2G0?o`iP003@3ol>H00`000000oo3V0?o`iP1S0?o`iP030?mVIP000000oo3V02L0oo3V
00<0ofIV0?o`iP3ol>H0U`3ol>H000d0oo3V00<000000?o`iP3ol>H0I03ol>H00`3oIVH000000?o`
iP0U0?o`iP030?mVIP3ol>H0oo3V09P0oo3V000=0?o`iP030000003ol>H0oo3V06D0oo3V00<0ofIV
0000003ol>H08`3ol>H00`000000ofIV0?o`iP2I0?o`iP003@3ol>H00`000000oo3V0?o`iP1V0?o`
iP030?mVIP000000oo3V0280oo3V00<0ofIV0?o`iP3ol>H0V@3ol>H000d0oo3V00<000000?o`iP3o
l>H0I`3ol>H00`3oIVH000000?o`iP0P0?o`iP030000003oIVH0oo3V09X0oo3V000=0?o`iP030000
003ol>H0oo3V06P0oo3V0P3oIVHP0?o`iP030?mVIP3ol>H0oo3V09X0oo3V000=0?o`iP800000J`3o
l>H00`3oIVH0oo3V0?o`iP0L0?o`iP030?mVIP3ol>H0oo3V09/0oo3V000=0?o`iP030000003ol>H0
oo3V06/0oo3V00<0ofIV0?o`iP3ol>H06P3ol>H00`3oIVH000000?o`iP2L0?o`iP003@3ol>H00`00
0000oo3V0?o`iP1/0?o`iP80ofIV6@3ol>H00`3oIVH000000?o`iP2M0?o`iP003@3ol>H00`000000
oo3V0?o`iP1^0?o`iP030?mVIP3ol>H0oo3V01D0oo3V00<0ofIV0000003ol>H0WP3ol>H000d0oo3V
00<000000?o`iP3ol>H0K`3ol>H20?mVIQ@0oo3V00<0ofIV0000003ol>H0W`3ol>H000d0oo3V00<0
00000?o`iP3ol>H0L@3ol>H00`3oIVH0oo3V0?o`iP0@0?o`iP030?mVIP3ol>H0oo3V0:00oo3V0004
0?o`iP<000001P3ol>H00`000000oo3V0?o`iP1b0?o`iP<0ofIV3P3ol>H00`3oIVH0oo3V0?o`iP2Q
0?o`iP000`3ol>H01@000000oo3V0?o`iP3ol>H0000000D0oo3V00<000000?o`iP3ol>H0M@3ol>H0
0`3oIVH0oo3V0?o`iP080?o`iP<0ofIVY03ol>H000L0oo3V00<000000?o`iP3ol>H00`3ol>H30000
07H0oo3V2P3oIVH00`000000oo3V0?o`iP2T0?o`iP001`3ol>H00`000000oo3V0?o`iP030?o`iP03
0000003ol>H0oo3V0?l0oo3V:03ol>H000<0oo3V100000060?o`iP030000003ol>H0oo3V0?l0oo3V
:03ol>H000<0oo3V00<000000?o`iP3ol>H01`3ol>H00`000000oo3V0?o`iP3o0?o`iRP0oo3V0003
0?o`iPD000001@3ol>H00`000000oo3V0?o`iP3o0?o`iRP0oo3V000=0?o`iP030000003ol>H0oo3V
0?l0oo3V:03ol>H00001\
\>"],
  ImageRangeCache->{{{0, 310.625}, {222.75, 0}} -> {-0.32902, -0.311979, \
0.0244491, 0.0244491}}],

Cell[TextData[{
  "The arc of length ",
  StyleBox["7", "Input",
    FontWeight->"Plain"],
  " along the spline curve."
}], "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "We recall from calculus that the arc length function for a parametric \
curve ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold"], "\[RightVector]"], 
        StyleBox[Cell["(t)"],
          "Output"]}]]],
  " is the integral of the speed function for the curve, the integral of the \
length of the derivative of the function  ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["c",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  ","
}], "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        RowBox[{Cell["s"], \((t)\)}], " ", "=", " ", 
        RowBox[{
          RowBox[{\(\[Integral]\+0\%t\), " ", 
            RowBox[{
              RowBox[{"\[LeftDoubleBracketingBar]", " ", 
                RowBox[{
                  SuperscriptBox[
                    OverscriptBox[
                      StyleBox["c",
                        FontWeight->"Bold"], "\[RightVector]"], 
                    "\[Prime]"], \((u)\)}], "\[RightDoubleBracketingBar]"}], 
              " ", "du"}]}], " ", "=", " ", 
          RowBox[{\(\[Integral]\+0\%t\), 
            RowBox[{
              SqrtBox[
                RowBox[{
                  SuperscriptBox[
                    OverscriptBox[
                      StyleBox["c",
                        FontWeight->"Bold"], "\[RightVector]"], 
                    "\[Prime]"], \((u)\), "\[Bullet]", 
                  SuperscriptBox[
                    OverscriptBox[
                      StyleBox["c",
                        FontWeight->"Bold"], "\[RightVector]"], 
                    "\[Prime]"], \((u)\)}]], "du"}]}]}]}]}]], "Text"],

Cell[TextData[{
  "Since our curves are bsplines, they are piecewise polynomial.  Except for \
quadratic polynomials (whose derivatives are linear), there is no closed form \
integral formula for the above integral and therefore there is no closed form \
arc length parameterization for our cubic bspline curves.  When we really \
need to have arc length spacing, we'll have to do it by hand (well, in our \
case we can do it by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " )."
}], "Text"],

Cell[CellGroupData[{

Cell["Pseudo-arclength Parameterization", "Subsubsection"],

Cell[TextData[{
  "Once we have the parametric curve ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["c",
            FontWeight->"Bold"], "\[RightVector]"], \((t)\)}]]],
  " with the shape we want, either two or three dimensional, we can find \
equally spaced points along that curve using the following algorithm."
}], "Text"],

Cell["Pseudo Arc Length Parameterization Algorithm", "ContentsText"],

Cell[BoxData[GridBox[{
        {\((1)\), 
          RowBox[{
            RowBox[{
              StyleBox["Define",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["the",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["speed",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["function",
                FontFamily->"Times"], " ", "v", \((t)\)}], "=", " ", 
            SqrtBox[
              RowBox[{
                SuperscriptBox[
                  OverscriptBox[
                    StyleBox["c",
                      FontWeight->"Bold"], "\[RightVector]"], 
                  "\[Prime]"], \((t)\), "\[Bullet]", 
                SuperscriptBox[
                  OverscriptBox[
                    StyleBox["c",
                      FontWeight->"Bold"], "\[RightVector]"], 
                  "\[Prime]"], \((t)\)}]]}]},
        {\((2)\), 
          RowBox[{
            RowBox[{
              StyleBox["Define",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["the",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["arclength",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["function",
                FontFamily->"Times"], "   ", "s", \((t)\), "  ", 
              StyleBox["using",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], "NIntegrate"}], 
            StyleBox[",",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            
            StyleBox[\(the\ numerical\ integration\ function\ in\ \
\(\(Mathematica\)\(.\)\)\),
              FontFamily->"Times"]}]},
        {\((3)\), 
          RowBox[{
            StyleBox["Find",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            StyleBox["the",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            StyleBox["length",
              FontFamily->"Times"], " ", "L", 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["of",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox["the",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox["entire",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox["curve",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox["using",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox["the",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox["function",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox["  ",
              FontWeight->"Plain"], 
            StyleBox["s",
              FontWeight->"Plain"], 
            StyleBox["  ",
              FontWeight->"Plain"], 
            StyleBox["from",
              FontFamily->"Times",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[\((2)\),
              FontWeight->"Plain"]}]},
        {\((4)\), 
          RowBox[{
            StyleBox[\(Use\ FindRoot\),
              FontFamily->"Times"], 
            StyleBox[",",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            RowBox[{
              RowBox[{
                StyleBox[\(Mathematica'\),
                  FontFamily->"Times"], 
                StyleBox["s",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["numerical",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["equation",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["solver",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["to",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["find",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["solutions",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["to",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["the",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], 
                StyleBox["equations",
                  FontFamily->"Times"], 
                StyleBox[
                  RowBox[{"  ", 
                    StyleBox["  ",
                      FontFamily->"Courier"]}]], 
                StyleBox["s",
                  FontFamily->"Courier"], 
                StyleBox[\((t)\),
                  FontFamily->"Courier"]}], 
              StyleBox[" ",
                FontFamily->"Courier"], 
              StyleBox["=",
                FontFamily->"Courier"], 
              StyleBox[" ",
                FontFamily->"Courier"], 
              RowBox[{
                StyleBox[\(\[Alpha]\_i\),
                  FontFamily->"Courier",
                  FontSize->14], 
                StyleBox["*",
                  FontFamily->"Courier"], 
                StyleBox["L",
                  FontFamily->"Courier"]}]}], ",", " ", 
            RowBox[{
              StyleBox["where",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["the",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Courier"], 
              StyleBox[\(\[Alpha]\_i\),
                FontFamily->"Courier",
                FontSize->14], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["are",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["equally",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["spaced",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              StyleBox["values",
                FontFamily->"Times"], 
              StyleBox[" ",
                FontFamily->"Times"], 
              RowBox[{
                StyleBox["in",
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Courier"], 
                StyleBox["[",
                  FontFamily->"Courier"], 
                StyleBox[\(0, 1\),
                  FontFamily->"Courier"], 
                StyleBox["]",
                  FontFamily->"Courier"]}]}], ",", "    ", 
            
            StyleBox[\(for\ the\ number\ of\ equally\ spaced\ points\ on\ the\
\ curve\ that\ are\ \(\(needed\)\(.\)\)\),
              FontFamily->"Times"]}]},
        {\((5)\), 
          StyleBox[
            RowBox[{
            "Define", " ", "the", " ", "pseudo", " ", "arclength", " ", 
              "curve", "  ", "using", " ", "table", " ", "lookup", " ", "and",
               " ", "the", "  ", "values", " ", "created", " ", "in", " ", 
              RowBox[{
                RowBox[{"(", 
                  StyleBox["4",
                    FontFamily->"Courier"], ")"}], "."}]}],
            "Text"]}
        }]], "TwoColumnBox"],

Cell["\<\
We'll illustrate this example using the two dimensional curve \
defined above.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[kt, \ ctrl];\)\), "\n", 
    \(\(kt\  = \ {0.0, \ 0.0, \ 0.0, \ 0.0, \ 1.0, \ 1.0, \ 1.0, \ 
          1.0};\)\), "\n", 
    \(\(ctrl\  = \ {{0.0, 0.0}, {5.96385, 
            13.7703}, {2.19654, \ \(-6.10924\)}, {7.0, 2.0}};\)\)}], "Input"],

Cell["(1) - define the speed function.....", "Text",
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\ \(Clear[v];\)\), "\n", 
    \(v[t_]\  := \ 
      Module[{w\ }, \[IndentingNewLine]w = 
          bspline[kt, ctrl, t, 1]; \[IndentingNewLine]Sqrt[
          w . w]]\)}], "Input"],

Cell[TextData[{
  "Note that the last parameter in the call to ",
  Cell[BoxData[
      \(bspline\)]],
  " is ",
  Cell[BoxData[
      \(1\)]],
  ", indicating that ",
  Cell[BoxData[
      \(bspline\)]],
  " should return the first derivative of our bspline curve."
}], "Text"],

Cell[TextData[{
  "(2) - define the arclength function ",
  Cell[BoxData[
      \(s\)]]
}], "Text",
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[s];\)\), "\n", 
    \(s[t_]\  := \ NIntegrate[v[x], \ {x, 0, t}]\)}], "Input"],

Cell[TextData[{
  "(3) - Compute the length of the curve, ",
  Cell[BoxData[
      RowBox[{
        StyleBox["s",
          FontFamily->"Courier"], 
        RowBox[{
          StyleBox["(",
            FontFamily->"Courier"], 
          SubscriptBox[
            StyleBox["t",
              FontFamily->"Courier"], "max"], 
          StyleBox[")",
            FontFamily->"Courier"]}]}]]],
  " where ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["t",
          FontFamily->"Courier"], "max"]]],
  " is the value of the largest knot, in this case ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["t",
          FontFamily->"Courier"], "max"]]],
  " = ",
  Cell[BoxData[
      \(1\)]],
  "."
}], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(len\  = \ s[1]\)], "Input"],

Cell[TextData[StyleBox["(4) - Make a table of equally spaced values",
  FontWeight->"Bold"]], "Text"],

Cell[TextData[{
  StyleBox["FindRoot", "Input",
    FontWeight->"Plain"],
  " is ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s root finding function.  With the syntax"
}], "Text"],

Cell[TextData[StyleBox["FindRoot[expr1 == expr2, {t,t1,t2}]", "Input",
  FontWeight->"Plain"]], "ContentsText"],

Cell[TextData[{
  "FindRoot attempts to solve the equation given using a variation of the \
secant method with starting values ",
  Cell[BoxData[
      \(t\_1\)]],
  "and ",
  Cell[BoxData[
      \(t\_2\)]],
  "  (see (RAL)).  The answer is returned in the form "
}], "Text"],

Cell[TextData[{
  StyleBox["{t->t0}", "Input",
    FontWeight->"Plain"],
  "."
}], "ContentsText"],

Cell["What we want to do is to solve the following equation", "Text"],

Cell[TextData[StyleBox["s[t]=len*alf\[LeftDoubleBracket]i\[RightDoubleBracket]\
", "Input",
  FontWeight->"Plain"]], "ContentsText"],

Cell[TextData[{
  "where ",
  StyleBox["alf ", "Input",
    FontWeight->"Plain"],
  "is a table of equally spaced values in ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  ".  Note that we do not need to solve the equations"
}], "Text"],

Cell[TextData[StyleBox["s[t] = 0 and s[t] = len", "Input",
  FontWeight->"Plain"]], "ContentsText"],

Cell[TextData[{
  "since we already know the answers.  Execute the code below, computing ",
  Cell[BoxData[
      \(71\)]],
  " equally spaced points. (Note the use of the previous answer to ",
  Cell[BoxData[
      \(FindRoot\)]],
  " as the starting point for the next computation.  Go have a cup of coffee, \
this takes a little time, ",
  Cell[BoxData[
      \(3\  - \ 5\)]],
  " minutes.  )"
}], "Text"],

Cell[BoxData[{
    \(\(alf\  = \ Table[N[i/72], \ {i, 1, 71}];\)\), "\[IndentingNewLine]", 
    \(\(val\  = \ Table[0, {i, 1, 73}];\)\), "\n", 
    \(\(For[i = 1, \ 
        i \[LessEqual] 
          71, \ \(i++\), \ \(val\[LeftDoubleBracket]
              i + 1\[RightDoubleBracket]\  = \ 
            t /. \(FindRoot[
                  s[t] == alf\[LeftDoubleBracket]i\[RightDoubleBracket]*
                      len, \ {t, {val\[LeftDoubleBracket]
                        i\[RightDoubleBracket], 
                      val\[LeftDoubleBracket]i\[RightDoubleBracket] + 
                        0.01}}]\)\[LeftDoubleBracket]1\[RightDoubleBracket];\)\
\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(\(val\[LeftDoubleBracket]73\[RightDoubleBracket]\  = \ 
        1.0;\)\)], "Input"],

Cell["\<\
Check out the new parameters by making a table similar to the one \
above.  In case you don't think there is much improvement, notice the scale \
along the y-axis.\
\>", "Text"],

Cell[BoxData[
    \(data\  = 
      Table[Sqrt[\((v\  = \((bspline[kt, ctrl, 
                      val\[LeftDoubleBracket]i + 1\[RightDoubleBracket], 0] - 
                    bspline[kt, ctrl, 
                      val\[LeftDoubleBracket]i\[RightDoubleBracket], 
                      0])\))\) . v], \ {i, 1, 71}]\)], "Input"],

Cell[BoxData[
    \(\(\(ListPlot[data]\)\(\ \)\)\)], "Input"],

Cell["\<\
(5) - Use the table as a pseudo arclength parameterization...\
\>", \
"Text",
  FontWeight->"Bold"],

Cell["The following figures illustrate the above algorithm.", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .71805 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0195449 0.136054 [
[.15986 .00704 -3 -9 ]
[.15986 .00704 3 0 ]
[.29592 .00704 -3 -9 ]
[.29592 .00704 3 0 ]
[.43197 .00704 -3 -9 ]
[.43197 .00704 3 0 ]
[.56803 .00704 -3 -9 ]
[.56803 .00704 3 0 ]
[.70408 .00704 -3 -9 ]
[.70408 .00704 3 0 ]
[.84014 .00704 -3 -9 ]
[.84014 .00704 3 0 ]
[.97619 .00704 -3 -9 ]
[.97619 .00704 3 0 ]
[.01131 .1556 -6 -4.5 ]
[.01131 .1556 0 4.5 ]
[.01131 .29165 -6 -4.5 ]
[.01131 .29165 0 4.5 ]
[.01131 .42771 -6 -4.5 ]
[.01131 .42771 0 4.5 ]
[.01131 .56376 -6 -4.5 ]
[.01131 .56376 0 4.5 ]
[.01131 .69982 -6 -4.5 ]
[.01131 .69982 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .71805 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .01954 m
.15986 .02579 L
s
[(1)] .15986 .00704 0 1 Mshowa
.29592 .01954 m
.29592 .02579 L
s
[(2)] .29592 .00704 0 1 Mshowa
.43197 .01954 m
.43197 .02579 L
s
[(3)] .43197 .00704 0 1 Mshowa
.56803 .01954 m
.56803 .02579 L
s
[(4)] .56803 .00704 0 1 Mshowa
.70408 .01954 m
.70408 .02579 L
s
[(5)] .70408 .00704 0 1 Mshowa
.84014 .01954 m
.84014 .02579 L
s
[(6)] .84014 .00704 0 1 Mshowa
.97619 .01954 m
.97619 .02579 L
s
[(7)] .97619 .00704 0 1 Mshowa
.125 Mabswid
.05102 .01954 m
.05102 .02329 L
s
.07823 .01954 m
.07823 .02329 L
s
.10544 .01954 m
.10544 .02329 L
s
.13265 .01954 m
.13265 .02329 L
s
.18707 .01954 m
.18707 .02329 L
s
.21429 .01954 m
.21429 .02329 L
s
.2415 .01954 m
.2415 .02329 L
s
.26871 .01954 m
.26871 .02329 L
s
.32313 .01954 m
.32313 .02329 L
s
.35034 .01954 m
.35034 .02329 L
s
.37755 .01954 m
.37755 .02329 L
s
.40476 .01954 m
.40476 .02329 L
s
.45918 .01954 m
.45918 .02329 L
s
.48639 .01954 m
.48639 .02329 L
s
.51361 .01954 m
.51361 .02329 L
s
.54082 .01954 m
.54082 .02329 L
s
.59524 .01954 m
.59524 .02329 L
s
.62245 .01954 m
.62245 .02329 L
s
.64966 .01954 m
.64966 .02329 L
s
.67687 .01954 m
.67687 .02329 L
s
.73129 .01954 m
.73129 .02329 L
s
.7585 .01954 m
.7585 .02329 L
s
.78571 .01954 m
.78571 .02329 L
s
.81293 .01954 m
.81293 .02329 L
s
.86735 .01954 m
.86735 .02329 L
s
.89456 .01954 m
.89456 .02329 L
s
.92177 .01954 m
.92177 .02329 L
s
.94898 .01954 m
.94898 .02329 L
s
.25 Mabswid
0 .01954 m
1 .01954 L
s
.02381 .1556 m
.03006 .1556 L
s
[(1)] .01131 .1556 1 0 Mshowa
.02381 .29165 m
.03006 .29165 L
s
[(2)] .01131 .29165 1 0 Mshowa
.02381 .42771 m
.03006 .42771 L
s
[(3)] .01131 .42771 1 0 Mshowa
.02381 .56376 m
.03006 .56376 L
s
[(4)] .01131 .56376 1 0 Mshowa
.02381 .69982 m
.03006 .69982 L
s
[(5)] .01131 .69982 1 0 Mshowa
.125 Mabswid
.02381 .04676 m
.02756 .04676 L
s
.02381 .07397 m
.02756 .07397 L
s
.02381 .10118 m
.02756 .10118 L
s
.02381 .12839 m
.02756 .12839 L
s
.02381 .18281 m
.02756 .18281 L
s
.02381 .21002 m
.02756 .21002 L
s
.02381 .23723 m
.02756 .23723 L
s
.02381 .26444 m
.02756 .26444 L
s
.02381 .31886 m
.02756 .31886 L
s
.02381 .34608 m
.02756 .34608 L
s
.02381 .37329 m
.02756 .37329 L
s
.02381 .4005 m
.02756 .4005 L
s
.02381 .45492 m
.02756 .45492 L
s
.02381 .48213 m
.02756 .48213 L
s
.02381 .50934 m
.02756 .50934 L
s
.02381 .53655 m
.02756 .53655 L
s
.02381 .59097 m
.02756 .59097 L
s
.02381 .61818 m
.02756 .61818 L
s
.02381 .6454 m
.02756 .6454 L
s
.02381 .67261 m
.02756 .67261 L
s
.25 Mabswid
.02381 0 m
.02381 .71805 L
s
0 0 m
1 0 L
1 .71805 L
0 .71805 L
closepath
clip
newpath
.5 Mabswid
.02381 .01955 m
.11619 .22551 L
.2032 .40254 L
.273 .52737 L
.33025 .613 L
.35832 .64728 L
.38164 .67071 L
.3925 .67975 L
.40376 .68768 L
.41383 .69337 L
.42284 .69723 L
.42717 .69863 L
.43172 .69976 L
.43426 .70024 L
.4355 .70043 L
.43664 .70058 L
.43775 .7007 L
.43875 .70079 L
.43986 .70087 L
.44046 .7009 L
.44103 .70092 L
.44209 .70095 L
.44269 .70095 L
.44325 .70095 L
.44437 .70093 L
.445 .7009 L
.44556 .70087 L
.44657 .7008 L
.44767 .7007 L
.44963 .70046 L
.4519 .70007 L
.45428 .69954 L
.45847 .69828 L
.46226 .69676 L
.46567 .69507 L
.47306 .69028 L
.47927 .68497 L
.48551 .67831 L
.49773 .66095 L
.50806 .64104 L
.51854 .61506 L
.52722 .58838 L
.54378 .52286 L
.55779 .45221 L
.57176 .3726 L
.58537 .29526 L
.59962 .22362 L
.6171 .15389 L
.63722 .09665 L
.64992 .07075 L
Mistroke
.66329 .05028 L
.67019 .04205 L
.6779 .03447 L
.68549 .02854 L
.6928 .02412 L
.69702 .02211 L
.70177 .02028 L
.70667 .01885 L
.7094 .01824 L
.71198 .01779 L
.71316 .01762 L
.71446 .01746 L
.71561 .01735 L
.71684 .01725 L
.71795 .01718 L
.71918 .01713 L
.72031 .0171 L
.72137 .0171 L
.72264 .01711 L
.72328 .01713 L
.72398 .01715 L
.72523 .01722 L
.72639 .0173 L
.72906 .01756 L
.73193 .01795 L
.73465 .01843 L
.73755 .01905 L
.74285 .02047 L
.75527 .02514 L
.76653 .03087 L
.77948 .03904 L
.80506 .05949 L
.83502 .08961 L
.90255 .17606 L
.97619 .29165 L
Mfstroke
1 0 0 r
5 Mabswid
.02381 .01954 Mdot
.10444 .20022 Mdot
.19066 .37829 Mdot
.28751 .55075 Mdot
.41878 .69564 Mdot
.5335 .56591 Mdot
.57188 .37187 Mdot
.61049 .17788 Mdot
.71089 .01797 Mdot
.86653 .12713 Mdot
.97619 .29165 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{359.625, 258.188},
  ImageMargins->{{93, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005W00010R000`400?l00000o`00003oo`3ol>IX
0?o`iP00>`3ol>H3000002`0oo3V1@00000[0?o`iP<00000;P3ol>H3000002/0oo3V0`00000]0?o`
iP<00000;@3ol>H00`000000oo3V0?o`iP0;0?o`iP00?03ol>H00`000000oo3V0?o`iP0/0?o`iP04
0000003ol>H0oo3V000002X0oo3V00D000000?o`iP3ol>H0oo3V0000000^0?o`iP030000003ol>H0
oo3V02T0oo3V00D000000?o`iP3ol>H0oo3V0000000[0?o`iP050000003ol>H0oo3V0?o`iP000000
;03ol>H00`000000oo3V0?o`iP0;0?o`iP00?03ol>H00`000000oo3V0?o`iP0]0?o`iP030000003o
l>H0oo3V02h0oo3V00<000000?o`iP3ol>H0:@3ol>H5000002h0oo3V00<000000?o`iP3ol>H0:@3o
l>H01@000000oo3V0?o`iP3ol>H0000002d0oo3V00<000000?o`iP3ol>H02P3ol>H003`0oo3V00<0
00000?o`iP3ol>H0;P3ol>H00`000000oo3V0?o`iP0[0?o`iP800000;03ol>H010000000oo3V0?o`
iP00000_0?o`iP030000003ol>H0oo3V02T0oo3V1000000^0?o`iP030000003ol>H0oo3V00X0oo3V
000l0?o`iP030000003ol>H0oo3V02/0oo3V00D000000?o`iP3ol>H0oo3V0000000^0?o`iP030000
003ol>H0oo3V02X0oo3V00<000000?o`iP000000:`3ol>H4000002`0oo3V00<000000?o`iP3ol>H0
<03ol>H00`000000oo3V0?o`iP090?o`iP00>`3ol>H2000002d0oo3V00D000000?o`iP3ol>H0oo3V
0000000Z0?o`iP050000003ol>H0oo3V0?o`iP000000;@3ol>H2000002/0oo3V00<000000?o`iP3o
l>H0;P3ol>H00`000000oo3V0?o`iP0[0?o`iP050000003ol>H0oo3V0?o`iP0000002`3ol>H000h0
oo3V00<000000?o`iP3ol>H0:`3ol>H00`000000oo3V0?o`iP0/0?o`iP<00000;03ol>H3000002l0
oo3V00<000000?o`iP3ol>H0:@3ol>H5000002d0oo3V0P00000[0?o`iPD000002`3ol>H000h0oo3V
00<000000?o`iP3ol>H0o`3ol>IG0?o`iP003P3ol>H00`000000oo3V0?o`iP3o0?o`iUL0oo3V000>
0?o`iP030000003ol>H0oo3V0?l0oo3VE`3ol>H000h0oo3V00<000000?o`iP3ol>H0j`3ol>H30?l0
06P0oo3V000=0?o`iP<0o`00j`3ol>H50?l006L0oo3V000<0?o`iPD0o`00jP3ol>H50?l000L00000
H03ol>H000D0oo3V1`0000050?l00>X000001@3o001S000000@0oo3V000<0?o`iPD0o`001P3ol>H0
0`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H01`3ol>H0
0`000000oo3V0?o`iP060?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H01P3ol>H0
0`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H01`3ol>H0
0`000000oo3V0?o`iP060?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H01P3ol>H0
0`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H01`3ol>H0
0`000000oo3V0?o`iP060?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H01P3ol>H0
0`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H01`3ol>H0
0`000000oo3V0?o`iP060?o`iP030000003ol>H0oo3V00L0oo3V00<000000?o`iP3ol>H00P3ol>H3
000000030?o`iP000000o`000080o`001P3ol>H00`000000oo3V0?o`iP030?o`iP80000000<0oo3V
0000003ol>H0203ol>H00`000000oo3V0?o`iP060?o`iP030000003ol>H0oo3V00L0oo3V00<00000
0?o`iP3ol>H01P3ol>H00`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V00H0oo3V00<00000
0?o`iP3ol>H01`3ol>H00`000000oo3V0?o`iP060?o`iP030000003ol>H0oo3V00X0oo3V000=0?o`
iP<0o`00;@3ol>H00`000000oo3V0?o`iP0]0?o`iP030000003ol>H0oo3V02`0oo3V00<000000?o`
iP3ol>H0;@3ol>H00`000000oo3V0?o`iP0W0?o`iP030000003ol>H0oo3V0080oo3V00<000000?o`
iP3ol>H03`3ol>H2000001`0oo3V00<000000?o`iP3ol>H0;03ol>H00`000000oo3V0?o`iP0:0?o`
iP003P3ol>H200000>@0oo3V0P00000I0?o`iP800000EP3ol>H000h0oo3V00<000000?o`iP000000
hP3ol>H00`000000oo3V0?o`iP0K0?o`iP800000E03ol>H000h0oo3V00<000000?o`iP000000h@3o
l>H00`000000oo3V0?o`iP0N0?o`iP800000DP3ol>H000h0oo3V00<000000?o`iP000000h03ol>H0
0`000000oo3V0?o`iP0Q0?o`iP800000D03ol>H000h0oo3V00@000000?o`iP3ol>H00000gP3ol>H0
0`000000oo3V0?o`iP0T0?o`iP030000003ol>H0oo3V04d0oo3V000>0?o`iP040000003ol>H0oo3V
00000=d0oo3V00<000000?o`iP3ol>H09P3ol>H00`000000oo3V0?o`iP1<0?o`iP003P3ol>H20000
0080oo3V00<000000?o`iP3ol>H0f@3ol>H00`000000oo3V0?o`iP0X0?o`iP030000003ol>H0oo3V
04/0oo3V000>0?o`iP050000003ol>H0oo3V0?o`iP000000fP3ol>H00`000000oo3V0?o`iP0Z0?o`
iP030000003ol>H0oo3V04X0oo3V000>0?o`iP030000003ol>H0oo3V0080oo3V00<000000?o`iP3o
l>H0e`3ol>H00`000000oo3V0?o`iP0[0?o`iP030000003ol>H0oo3V04T0oo3V000>0?o`iP030000
003ol>H0oo3V0080oo3V00<000000?o`iP3ol>H0eP3ol>H00`000000oo3V0?o`iP0]0?o`iP030000
003ol>H0oo3V04P0oo3V000>0?o`iP030000003ol>H0oo3V00<0oo3V00<000000?o`iP3ol>H0e03o
l>H00`000000oo3V0?o`iP0_0?o`iP030000003ol>H0oo3V04L0oo3V000>0?o`iP030000003ol>H0
oo3V00<0oo3V00<000000?o`iP3ol>H0e03ol>H00`000000oo3V0?o`iP0`0?o`iP800000A`3ol>H0
00h0oo3V00<000000?o`iP3ol>H00`3ol>H00`000000oo3V0?o`iP3C0?o`iP030000003ol>H0oo3V
03<0oo3V00<000000?o`iP3ol>H0A03ol>H000h0oo3V00<000000?o`iP3ol>H0103ol>H00`000000
oo3V0?o`iP3B0?o`iP030000003ol>H0oo3V03@0oo3V00<000000?o`iP3ol>H0@`3ol>H000h0oo3V
00<000000?o`iP3ol>H0103ol>H00`000000oo3V0?o`iP3A0?o`iP030000003ol>H0oo3V03H0oo3V
00<000000?o`iP3ol>H0@P3ol>H000h0oo3V00<000000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`
iP3?0?o`iP030000003ol>H0oo3V03P0oo3V00<000000?o`iP3ol>H0@@3ol>H000h0oo3V0P000006
0?o`iP030000003ol>H0oo3V0<l0oo3V00<000000?o`iP3ol>H0>@3ol>H00`000000oo3V0?o`iP10
0?o`iP003P3ol>H00`000000oo3V0?o`iP060?o`iP030000003ol>H0oo3V0<d0oo3V00<000000?o`
iP3ol>H0>`3ol>H00`000000oo3V0?o`iP0o0?o`iP003P3ol>H00`000000oo3V0?o`iP060?o`iP03
0000003ol>H0oo3V0<d0oo3V00<000000?o`iP3ol>H0?03ol>H00`000000oo3V0?o`iP0n0?o`iP00
3P3ol>H00`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V0</0oo3V00<000000?o`iP3ol>H0
?P3ol>H00`000000oo3V0?o`iP0m0?o`iP003P3ol>H00`000000oo3V0?o`iP070?o`iP030000003o
l>H0oo3V0</0oo3V00<000000?o`iP3ol>H0?`3ol>H00`000000oo3V0?o`iP0l0?o`iP003P3ol>H0
0`000000oo3V0?o`iP070?o`iP030000003ol>H0oo3V0</0oo3V00<000000?o`iP3ol>H0@03ol>H0
0`000000oo3V0?o`iP0k0?o`iP003P3ol>H00`000000oo3V0?o`iP080?o`iP030000003ol>H0oo3V
0<T0oo3V00<000000?o`iP3ol>H0@@3ol>H00`000000oo3V0?o`iP0k0?o`iP003P3ol>H00`000000
oo3V0?o`iP080?o`iP030000003ol>H0oo3V0<T0oo3V00<000000?o`iP3ol>H0@P3ol>H00`000000
oo3V0?o`iP0j0?o`iP003P3ol>H00`000000oo3V0?o`iP090?o`iP030000003ol>H0oo3V0<L0oo3V
00<000000?o`iP3ol>H0A03ol>H00`000000oo3V0?o`iP0i0?o`iP003P3ol>H2000000X0oo3V00<0
00000?o`iP3ol>H0a`3ol>H00`000000oo3V0?o`iP150?o`iP030000003ol>H0oo3V03P0oo3V000>
0?o`iP030000003ol>H0oo3V00X0oo3V00<000000?o`iP3ol>H0a@3ol>H00`000000oo3V0?o`iP16
0?o`iP030000003ol>H0oo3V03P0oo3V000>0?o`iP030000003ol>H0oo3V00X0oo3V00<000000?o`
iP3ol>H0a@3ol>H00`000000oo3V0?o`iP170?o`iP030000003ol>H0oo3V03L0oo3V000>0?o`iP03
0000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H0a03ol>H00`000000oo3V0?o`iP180?o`iP03
0000003ol>H0oo3V03H0oo3V000>0?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H0
``3ol>H00`000000oo3V0?o`iP1:0?o`iP030000003ol>H0oo3V03D0oo3V000>0?o`iP030000003o
l>H0oo3V00/0oo3V00<000000?o`iP3ol>H0``3ol>H00`000000oo3V0?o`iP1;0?o`iP030000003o
l>H0oo3V03@0oo3V000>0?o`iP030000003ol>H0oo3V00`0oo3V00<000000?o`iP3ol>H0`P3ol>H0
0`000000oo3V0?o`iP1;0?o`iP030000003ol>H0oo3V03@0oo3V000>0?o`iP030000003ol>H0oo3V
00`0oo3V00<000000?o`iP3ol>H0`@3ol>H00`000000oo3V0?o`iP1=0?o`iP030000003ol>H0o`00
0080o`00<@3ol>H000h0oo3V00<000000?o`iP3ol>H03@3ol>H00`000000oo3V0?o`iP300?o`iP03
0000003ol>H0oo3V04h0oo3V1@3o000`0?o`iP003P3ol>H00`000000oo3V0?o`iP0=0?o`iP030000
003ol>H0oo3V0<00oo3V00<000000?o`iP3ol>H0CP3ol>H50?l00300oo3V000>0?o`iP8000003`3o
l>H00`000000oo3V0?o`iP2n0?o`iP030000003ol>H0oo3V04l0oo3V1@3o000`0?o`iP003P3ol>H0
0`000000oo3V0?o`iP0>0?o`iP030000003ol>H0oo3V0;h0oo3V00<000000?o`iP3ol>H0D03ol>H3
0?l00340oo3V000>0?o`iP030000003ol>H0oo3V00l0oo3V00<000000?o`iP3ol>H0_@3ol>H00`00
0000oo3V0?o`iP1B0?o`iP030000003ol>H0oo3V02l0oo3V000>0?o`iP030000003ol>H0oo3V00l0
oo3V00<000000?o`iP3ol>H0_03ol>H00`000000oo3V0?o`iP1D0?o`iP030000003ol>H0oo3V02h0
oo3V000>0?o`iP030000003ol>H0oo3V00l0oo3V00<000000?o`iP3ol>H0_03ol>H00`000000oo3V
0?o`iP1D0?o`iP030000003ol>H0oo3V02h0oo3V000>0?o`iP030000003ol>H0oo3V0100oo3V00<0
00000?o`iP3ol>H0^`3ol>H00`000000oo3V0?o`iP1E0?o`iP030000003ol>H0oo3V02d0oo3V000>
0?o`iP030000003ol>H0oo3V0100oo3V00<000000?o`iP3ol>H0^P3ol>H00`000000oo3V0?o`iP1G
0?o`iP030000003ol>H0oo3V02`0oo3V00040?o`iP<000001`3ol>H00`000000oo3V0?o`iP0A0?o`
iP030000003ol>H0oo3V0;T0oo3V00<000000?o`iP3ol>H0F03ol>H00`000000oo3V0?o`iP0[0?o`
iP001@3ol>H00`000000oo3V0?o`iP060?o`iP030000003ol>H0oo3V0140oo3V00<000000?o`iP3o
l>H0^@3ol>H00`000000oo3V0?o`iP1H0?o`iP030000003ol>H0oo3V02/0oo3V00050?o`iP030000
003ol>H0oo3V00H0oo3V0`00000B0?o`iP030000003ol>H0oo3V0;L0oo3V00<000000?o`iP3ol>H0
FP3ol>H00`000000oo3V0?o`iP0Z0?o`iP001@3ol>H00`000000oo3V0?o`iP060?o`iP030000003o
l>H0oo3V0180oo3V00<000000?o`iP3ol>H0]`3ol>H00`000000oo3V0?o`iP1K0?o`iP030000003o
l>H0oo3V02T0oo3V00050?o`iP030000003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H04`3ol>H0
0`000000oo3V0?o`iP2f0?o`iP030000003ol>H0oo3V05`0oo3V00<000000?o`iP3ol>H0:03ol>H0
00@0oo3V0P0000080?o`iP030000003ol>H0oo3V01<0oo3V00<000000?o`iP3ol>H0]@3ol>H00`00
0000oo3V0?o`iP1N0?o`iP030000003ol>H0oo3V02L0oo3V00050?o`iP030000003ol>H0oo3V00H0
oo3V00<000000?o`iP3ol>H04`3ol>H00`000000oo3V0?o`iP2e0?o`iP030000003ol>H0oo3V05h0
oo3V00<000000?o`iP3ol>H09`3ol>H000h0oo3V00<000000?o`iP3ol>H0503ol>H00`000000oo3V
0?o`iP2d0?o`iP030000003ol>H0oo3V05l0oo3V00<000000?o`iP3ol>H09P3ol>H000h0oo3V00<0
00000?o`iP3ol>H0503ol>H00`000000oo3V0?o`iP2a0?o`iP<0o`0000<000000?o`iP3ol>H0H03o
l>H00`000000oo3V0?o`iP0U0?o`iP003P3ol>H00`000000oo3V0?o`iP0E0?o`iP030000003ol>H0
oo3V0:l0oo3V1@3o001S0?o`iP030000003ol>H0oo3V02@0oo3V000>0?o`iP030000003ol>H0oo3V
01D0oo3V00<000000?o`iP3ol>H0[`3ol>H50?l006<0oo3V00<000000?o`iP3ol>H0903ol>H000h0
oo3V00<000000?o`iP3ol>H05P3ol>H00`000000oo3V0?o`iP2^0?o`iPD0o`00I03ol>H00`000000
oo3V0?o`iP0S0?o`iP003P3ol>H2000001L0oo3V00<000000?o`iP3ol>H0[`3ol>H30?l006H0oo3V
00<000000?o`iP3ol>H08P3ol>H000h0oo3V00<000000?o`iP3ol>H05`3ol>H00`000000oo3V0?o`
iP2_0?o`iP030000003ol>H0oo3V06D0oo3V00<000000?o`iP3ol>H08P3ol>H000h0oo3V00<00000
0?o`iP3ol>H05`3ol>H00`000000oo3V0?o`iP2_0?o`iP030000003ol>H0oo3V06H0oo3V00<00000
0?o`iP3ol>H08@3ol>H000h0oo3V00<000000?o`iP3ol>H05`3ol>H00`000000oo3V0?o`iP2_0?o`
iP030000003ol>H0oo3V06H0oo3V00<000000?o`iP3ol>H08@3ol>H000h0oo3V00<000000?o`iP3o
l>H0603ol>H30?l00:h0oo3V00<000000?o`iP3ol>H0I`3ol>H00`000000oo3V0?o`iP0P0?o`iP00
3P3ol>H00`000000oo3V0?o`iP0G0?o`iPD0o`00[03ol>H00`000000oo3V0?o`iP1Y0?o`iP030000
003ol>H0oo3V01l0oo3V000>0?o`iP030000003ol>H0oo3V01L0oo3V1@3o002/0?o`iP030000003o
l>H0oo3V06T0oo3V00<000000?o`iP3ol>H07`3ol>H000h0oo3V00<000000?o`iP3ol>H05`3ol>H5
0?l00:`0oo3V00<000000?o`iP3ol>H0JP3ol>H00`000000oo3V0?o`iP0N0?o`iP003P3ol>H00`00
0000oo3V0?o`iP0H0?o`iP<0o`00[@3ol>H00`000000oo3V0?o`iP1[0?o`iP030000003ol>H0oo3V
01d0oo3V000>0?o`iP8000006`3ol>H00`000000oo3V0?o`iP2Z0?o`iP030000003ol>H0oo3V06`0
oo3V00<000000?o`iP3ol>H07@3ol>H000h0oo3V00<000000?o`iP3ol>H06`3ol>H00`000000oo3V
0?o`iP2Y0?o`iP030000003ol>H0oo3V06d0oo3V00<000000?o`iP3ol>H0703ol>H000h0oo3V00<0
00000?o`iP3ol>H06`3ol>H00`000000oo3V0?o`iP2Y0?o`iP030000003ol>H0oo3V06h0oo3V00<0
00000?o`iP3ol>H06`3ol>H000h0oo3V00<000000?o`iP3ol>H06`3ol>H00`000000oo3V0?o`iP2Y
0?o`iP030000003ol>H0oo3V06h0oo3V00<000000?o`iP3ol>H06`3ol>H000h0oo3V00<000000?o`
iP3ol>H0703ol>H00`000000oo3V0?o`iP2W0?o`iP030000003ol>H0oo3V0700oo3V00<000000?o`
iP3ol>H06P3ol>H000h0oo3V00<000000?o`iP3ol>H0703ol>H00`000000oo3V0?o`iP2W0?o`iP03
0000003ol>H0oo3V0700oo3V00<000000?o`iP3ol>H06P3ol>H000h0oo3V00<000000?o`iP3ol>H0
7@3ol>H00`000000oo3V0?o`iP2V0?o`iP030000003ol>H0oo3V0740oo3V00<000000?o`iP3ol>H0
6@3ol>H000h0oo3V00<000000?o`iP3ol>H07@3ol>H00`000000oo3V0?o`iP2V0?o`iP030000003o
l>H0oo3V0780oo3V00<000000?o`iP3ol>H0603ol>H000h0oo3V00<000000?o`iP3ol>H07P3ol>H0
0`000000oo3V0?o`iP2T0?o`iP030000003ol>H0oo3V07<0oo3V00<000000?o`iP3ol>H0603ol>H0
00h0oo3V00<000000?o`iP3ol>H07P3ol>H00`000000oo3V0?o`iP2T0?o`iP030000003ol>H0oo3V
07@0oo3V00<000000?o`iP3ol>H05`3ol>H000h0oo3V0P00000P0?o`iP030000003ol>H0oo3V0:<0
oo3V00<000000?o`iP3ol>H0M@3ol>H00`000000oo3V0?o`iP0F0?o`iP003P3ol>H00`000000oo3V
0?o`iP0O0?o`iP030000003ol>H0oo3V0:<0oo3V00<000000?o`iP3ol>H0M@3ol>H00`000000oo3V
0?o`iP0F0?o`iP003P3ol>H00`000000oo3V0?o`iP0P0?o`iP030000003ol>H0oo3V0:80oo3V00<0
00000?o`iP3ol>H0MP3ol>H00`000000oo3V0?o`iP0E0?o`iP003P3ol>H00`000000oo3V0?o`iP0P
0?o`iP030000003ol>H0oo3V0:40oo3V00<000000?o`iP3ol>H0N03ol>H00`000000oo3V0?o`iP0D
0?o`iP003P3ol>H00`000000oo3V0?o`iP0Q0?o`iP030000003ol>H0oo3V0:00oo3V00<000000?o`
iP3ol>H0N03ol>H00`000000oo3V0?o`iP0D0?o`iP003P3ol>H00`000000oo3V0?o`iP0Q0?o`iP03
0000003ol>H0oo3V0:00oo3V00<000000?o`iP3ol>H0N@3ol>H00`000000oo3V0?o`iP0C0?o`iP00
3P3ol>H00`000000oo3V0?o`iP0R0?o`iP030000003ol>H0oo3V09l0oo3V00<000000?o`iP3ol>H0
N@3ol>H00`000000oo3V0?o`iP0C0?o`iP003P3ol>H00`000000oo3V0?o`iP0R0?o`iP030000003o
l>H0oo3V09l0oo3V00<000000?o`iP3ol>H0NP3ol>H00`000000oo3V0?o`iP0B0?o`iP003P3ol>H0
0`000000oo3V0?o`iP0S0?o`iP030000003ol>H0oo3V09d0oo3V00<000000?o`iP3ol>H0O03ol>H0
0`000000oo3V0?o`iP0A0?o`iP003P3ol>H2000002@0oo3V00<000000?o`iP3ol>H0W@3ol>H00`00
0000oo3V0?o`iP1l0?o`iP030000003ol>H0oo3V0140oo3V000>0?o`iP030000003ol>H0oo3V02@0
oo3V00<000000?o`iP3ol>H0W03ol>H00`000000oo3V0?o`iP1m0?o`iP030000003ol>H0oo3V0100
oo3V000>0?o`iP030000003ol>H0oo3V02@0oo3V00<000000?o`iP3ol>H0W03ol>H00`000000oo3V
0?o`iP1n0?o`iP030000003ol>H0oo3V00l0oo3V000>0?o`iP030000003ol>H0oo3V02D0oo3V00<0
00000?o`iP3ol>H0V`3ol>H00`000000oo3V0?o`iP1n0?o`iP030000003ol>H0oo3V00l0oo3V000>
0?o`iP030000003ol>H0oo3V02D0oo3V00<000000?o`iP3ol>H0VP3ol>H00`000000oo3V0?o`iP20
0?o`iP030000003ol>H0oo3V00h0oo3V000>0?o`iP030000003ol>H0oo3V02H0oo3V00<000000?o`
iP3ol>H0V@3ol>H00`000000oo3V0?o`iP210?o`iP030000003ol>H0oo3V00d0oo3V000>0?o`iP03
0000003ol>H0oo3V02H0oo3V00<000000?o`iP3ol>H0V@3ol>H00`000000oo3V0?o`iP210?o`iP03
0000003ol>H0oo3V00d0oo3V00030?o`iPD000001P3ol>H00`000000oo3V0?o`iP0W0?o`iP030000
003ol>H0oo3V09P0oo3V00<000000?o`iP3ol>H0PP3ol>H00`000000oo3V0?o`iP0<0?o`iP00103o
l>H010000000oo3V0?o`iP0000060?o`iP030000003ol>H0oo3V02L0oo3V00<000000?o`iP3ol>H0
V03ol>H00`000000oo3V0?o`iP220?o`iP040000003o0000o`000?l000/0oo3V00050?o`iP030000
003ol>H0oo3V00H0oo3V00<000000?o`iP3ol>H0:03ol>H00`000000oo3V0?o`iP2F0?o`iP030000
003ol>H0oo3V08<0oo3V1@3o000:0?o`iP001P3ol>H00`000000oo3V0?o`iP050?o`iP<00000:03o
l>H00`000000oo3V0?o`iP2F0?o`iP030000003ol>H0oo3V08<0oo3V1@3o000:0?o`iP000`3ol>H0
1@000000oo3V0?o`iP3ol>H0000000H0oo3V00<000000?o`iP3ol>H0:@3ol>H00`000000oo3V0?o`
iP2E0?o`iP030000003ol>H0oo3V08<0oo3V1@3o000:0?o`iP000`3ol>H01@000000oo3V0?o`iP3o
l>H0000000H0oo3V00<000000?o`iP3ol>H0:@3ol>H00`000000oo3V0?o`iP2E0?o`iP030000003o
l>H0oo3V08@0oo3V0`3o000;0?o`iP00103ol>H3000000L0oo3V00<000000?o`iP3ol>H0:P3ol>H0
0`000000oo3V0?o`iP2D0?o`iP030000003ol>H0oo3V0980oo3V000>0?o`iP030000003ol>H0oo3V
02X0oo3V00<000000?o`iP3ol>H0U03ol>H00`000000oo3V0?o`iP2B0?o`iP003P3ol>H00`000000
oo3V0?o`iP0[0?o`iP030000003ol>H0oo3V0980oo3V00<000000?o`iP3ol>H0T`3ol>H000h0oo3V
00<000000?o`iP3ol>H0:`3ol>H00`000000oo3V0?o`iP2B0?o`iP030000003ol>H0oo3V09<0oo3V
000>0?o`iP030000003ol>H0oo3V02`0oo3V00<000000?o`iP3ol>H0T@3ol>H00`000000oo3V0?o`
iP2C0?o`iP003P3ol>H00`000000oo3V0?o`iP0/0?o`iP030000003ol>H0oo3V0940oo3V00<00000
0?o`iP3ol>H0T`3ol>H000h0oo3V0P00000]0?o`iP030000003ol>H0oo3V0940oo3V00<000000?o`
iP3ol>H0T`3ol>H000h0oo3V00<000000?o`iP3ol>H0;@3ol>H00`000000oo3V0?o`iP2?0?o`iP03
0000003ol>H0oo3V09@0oo3V000>0?o`iP030000003ol>H0oo3V02d0oo3V00<000000?o`iP3ol>H0
S`3ol>H00`000000oo3V0?o`iP2D0?o`iP003P3ol>H00`000000oo3V0?o`iP0^0?o`iP030000003o
l>H0oo3V08h0oo3V00<000000?o`iP3ol>H0U03ol>H000h0oo3V00<000000?o`iP3ol>H0;P3ol>H0
0`000000oo3V0?o`iP2>0?o`iP030000003ol>H0oo3V09@0oo3V000>0?o`iP030000003ol>H0oo3V
02l0oo3V00<000000?o`iP3ol>H0S@3ol>H00`000000oo3V0?o`iP2D0?o`iP003P3ol>H00`000000
oo3V0?o`iP0_0?o`iP030000003ol>H0oo3V08`0oo3V00<000000?o`iP3ol>H0U@3ol>H000h0oo3V
00<000000?o`iP3ol>H0<03ol>H00`000000oo3V0?o`iP2;0?o`iP030000003ol>H0oo3V09D0oo3V
000>0?o`iP030000003ol>H0oo3V0300oo3V00<000000?o`iP3ol>H0R`3ol>H00`000000oo3V0?o`
iP2E0?o`iP003P3ol>H00`000000oo3V0?o`iP0a0?o`iP030000003ol>H0oo3V08X0oo3V00<00000
0?o`iP3ol>H0U@3ol>H000h0oo3V0P00000b0?o`iP030000003ol>H0oo3V08X0oo3V00<000000?o`
iP3ol>H0U@3ol>H000h0oo3V00<000000?o`iP3ol>H0<P3ol>H00`000000oo3V0?o`iP290?o`iP03
0000003ol>H0oo3V09D0oo3V000>0?o`iP030000003ol>H0oo3V0380oo3V00<000000?o`iP3ol>H0
R03ol>H00`000000oo3V0?o`iP2F0?o`iP003P3ol>H00`000000oo3V0?o`iP0c0?o`iP030000003o
l>H0oo3V08L0oo3V00<000000?o`iP3ol>H0UP3ol>H000h0oo3V00<000000?o`iP3ol>H0<`3ol>H0
0`000000oo3V0?o`iP270?o`iP030000003ol>H0oo3V09H0oo3V000>0?o`iP030000003ol>H0oo3V
03@0oo3V00<000000?o`iP3ol>H0QP3ol>H00`000000oo3V0?o`iP2F0?o`iP003P3ol>H00`000000
oo3V0?o`iP0d0?o`iP030000003ol>H0oo3V08H0oo3V00<000000?o`iP3ol>H0UP3ol>H000h0oo3V
00<000000?o`iP3ol>H0=@3ol>H00`000000oo3V0?o`iP230?o`iP<0o`00V03ol>H000h0oo3V00<0
00000?o`iP3ol>H0=@3ol>H00`000000oo3V0?o`iP220?o`iPD0o`00U`3ol>H000h0oo3V0P00000g
0?o`iP<0o`00P@3ol>H50?l009L0oo3V000>0?o`iP030000003ol>H0oo3V03D0oo3V1@3o00200?o`
iPD0o`00U`3ol>H000h0oo3V00<000000?o`iP3ol>H0=@3ol>H50?l00840oo3V0`3o002H0?o`iP00
3P3ol>H00`000000oo3V0?o`iP0e0?o`iPD0o`00PP3ol>H00`000000oo3V0?o`iP2G0?o`iP003P3o
l>H00`000000oo3V0?o`iP0f0?o`iP<0o`00PP3ol>H00`000000oo3V0?o`iP2H0?o`iP003P3ol>H0
0`000000oo3V0?o`iP0h0?o`iP030000003ol>H0oo3V0800oo3V00<000000?o`iP3ol>H0V03ol>H0
00h0oo3V00<000000?o`iP3ol>H0>@3ol>H00`000000oo3V0?o`iP1o0?o`iP030000003ol>H0oo3V
09P0oo3V000>0?o`iP030000003ol>H0oo3V03T0oo3V00<000000?o`iP3ol>H0O`3ol>H00`000000
oo3V0?o`iP2H0?o`iP003P3ol>H00`000000oo3V0?o`iP0j0?o`iP030000003ol>H0oo3V07h0oo3V
00<000000?o`iP3ol>H0V03ol>H000h0oo3V00<000000?o`iP3ol>H0>P3ol>H00`000000oo3V0?o`
iP1m0?o`iP030000003ol>H0oo3V09T0oo3V000>0?o`iP800000?03ol>H00`000000oo3V0?o`iP1l
0?o`iP030000003ol>H0oo3V09T0oo3V000>0?o`iP030000003ol>H0oo3V03/0oo3V00<000000?o`
iP3ol>H0O03ol>H00`000000oo3V0?o`iP2I0?o`iP003P3ol>H00`000000oo3V0?o`iP0l0?o`iP03
0000003ol>H0oo3V07/0oo3V00<000000?o`iP3ol>H0V@3ol>H000h0oo3V00<000000?o`iP3ol>H0
?03ol>H00`000000oo3V0?o`iP1k0?o`iP030000003ol>H0oo3V09T0oo3V000>0?o`iP030000003o
l>H0oo3V03d0oo3V00<000000?o`iP3ol>H0NP3ol>H00`000000oo3V0?o`iP2I0?o`iP003P3ol>H0
0`000000oo3V0?o`iP0n0?o`iP030000003ol>H0oo3V07P0oo3V00<000000?o`iP3ol>H0VP3ol>H0
00h0oo3V00<000000?o`iP3ol>H0?P3ol>H00`000000oo3V0?o`iP1h0?o`iP030000003ol>H0oo3V
09X0oo3V00040?o`iP<000001`3ol>H00`000000oo3V0?o`iP0o0?o`iP030000003ol>H0oo3V07L0
oo3V00<000000?o`iP3ol>H0VP3ol>H000<0oo3V00D000000?o`iP3ol>H0oo3V000000060?o`iP03
0000003ol>H0oo3V03l0oo3V00<000000?o`iP3ol>H0M`3ol>H00`000000oo3V0?o`iP2J0?o`iP00
1`3ol>H00`000000oo3V0?o`iP040?o`iP<00000@03ol>H00`000000oo3V0?o`iP1f0?o`iP030000
003ol>H0oo3V09X0oo3V00050?o`iP8000001`3ol>H00`000000oo3V0?o`iP100?o`iP030000003o
l>H0oo3V07H0oo3V00<000000?o`iP3ol>H0VP3ol>H000L0oo3V00<000000?o`iP3ol>H0103ol>H0
0`000000oo3V0?o`iP110?o`iP030000003ol>H0oo3V07@0oo3V00<000000?o`iP3ol>H0V`3ol>H0
00<0oo3V00D000000?o`iP3ol>H0oo3V000000060?o`iP030000003ol>H0oo3V0480oo3V00<00000
0?o`iP3ol>H0L`3ol>H00`000000oo3V0?o`iP2K0?o`iP00103ol>H3000000L0oo3V00<000000?o`
iP3ol>H0@P3ol>H00`000000oo3V0?o`iP1c0?o`iP030000003ol>H0oo3V09/0oo3V000>0?o`iP03
0000003ol>H0oo3V04<0oo3V00<000000?o`iP3ol>H0LP3ol>H00`000000oo3V0?o`iP2K0?o`iP00
3P3ol>H00`000000oo3V0?o`iP130?o`iP030000003ol>H0oo3V0780oo3V00<000000?o`iP3ol>H0
V`3ol>H000h0oo3V00<000000?o`iP3ol>H0A03ol>H00`000000oo3V0?o`iP1`0?o`iP030000003o
l>H0oo3V09`0oo3V000>0?o`iP030000003ol>H0oo3V04@0oo3V00<000000?o`iP3ol>H0L03ol>H0
0`000000oo3V0?o`iP2L0?o`iP003P3ol>H00`000000oo3V0?o`iP150?o`iP030000003ol>H0oo3V
06l0oo3V00<000000?o`iP3ol>H0W03ol>H000h0oo3V0P0000170?o`iP030000003ol>H0oo3V06h0
oo3V00<000000?o`iP3ol>H0W03ol>H000h0oo3V00<000000?o`iP3ol>H0AP3ol>H00`000000oo3V
0?o`iP1^0?o`iP030000003ol>H0oo3V09`0oo3V000>0?o`iP030000003ol>H0oo3V04L0oo3V00<0
00000?o`iP3ol>H0K03ol>H00`000000oo3V0?o`iP2M0?o`iP003P3ol>H00`000000oo3V0?o`iP17
0?o`iP030000003ol>H0oo3V06`0oo3V00<000000?o`iP3ol>H0W@3ol>H000h0oo3V00<000000?o`
iP3ol>H0B03ol>H00`000000oo3V0?o`iP1[0?o`iP030000003ol>H0oo3V09d0oo3V000>0?o`iP03
0000003ol>H0oo3V04P0oo3V00<000000?o`iP3ol>H0J`3ol>H00`000000oo3V0?o`iP2M0?o`iP00
3P3ol>H00`000000oo3V0?o`iP190?o`iP030000003ol>H0oo3V06X0oo3V00<000000?o`iP3ol>H0
W@3ol>H000h0oo3V00<000000?o`iP3ol>H0B@3ol>H00`000000oo3V0?o`iP1Y0?o`iP030000003o
l>H0oo3V09h0oo3V000>0?o`iP030000003ol>H0oo3V04X0oo3V00<000000?o`iP3ol>H0J03ol>H0
0`000000oo3V0?o`iP2N0?o`iP003P3ol>H2000004`0oo3V00<000000?o`iP3ol>H0I`3ol>H00`00
0000oo3V0?o`iP2N0?o`iP003P3ol>H00`000000oo3V0?o`iP1;0?o`iP030000003ol>H0oo3V06L0
oo3V00<000000?o`iP3ol>H0WP3ol>H000h0oo3V00<000000?o`iP3ol>H0C03ol>H00`000000oo3V
0?o`iP1V0?o`iP030000003ol>H0oo3V09h0oo3V000>0?o`iP030000003ol>H0oo3V04`0oo3V00<0
00000?o`iP3ol>H0I@3ol>H00`000000oo3V0?o`iP2O0?o`iP003P3ol>H00`000000oo3V0?o`iP1=
0?o`iP030000003ol>H0oo3V06@0oo3V00<000000?o`iP3ol>H0W`3ol>H000h0oo3V00<000000?o`
iP3ol>H0C@3ol>H00`000000oo3V0?o`iP1T0?o`iP030000003ol>H0oo3V09l0oo3V000>0?o`iP03
0000003ol>H0oo3V04h0oo3V00<000000?o`iP3ol>H0H`3ol>H00`000000oo3V0?o`iP2O0?o`iP00
3P3ol>H00`000000oo3V0?o`iP1?0?o`iP030000003ol>H0oo3V0680oo3V00<000000?o`iP3ol>H0
W`3ol>H000h0oo3V00<000000?o`iP3ol>H0C`3ol>H00`000000oo3V0?o`iP1Q0?o`iP030000003o
l>H0oo3V0:00oo3V000>0?o`iP030000003ol>H0oo3V0500oo3V00<000000?o`iP3ol>H0H03ol>H0
0`000000oo3V0?o`iP2P0?o`iP003P3ol>H200000540oo3V00<000000?o`iP3ol>H0H03ol>H00`00
0000oo3V0?o`iP2P0?o`iP003P3ol>H00`000000oo3V0?o`iP1A0?o`iP030000003ol>H0oo3V05l0
oo3V00<000000?o`iP3ol>H0X03ol>H000h0oo3V00<000000?o`iP3ol>H0D@3ol>H00`000000oo3V
0?o`iP1O0?o`iP030000003ol>H0oo3V0:00oo3V000>0?o`iP030000003ol>H0oo3V0580oo3V00<0
00000?o`iP3ol>H0G@3ol>H00`000000oo3V0?o`iP2Q0?o`iP003P3ol>H00`000000oo3V0?o`iP1C
0?o`iP030000003ol>H0oo3V05`0oo3V00<000000?o`iP3ol>H0X@3ol>H000h0oo3V00<000000?o`
iP3ol>H0D`3ol>H00`000000oo3V0?o`iP1L0?o`iP030000003ol>H0oo3V0:40oo3V000>0?o`iP03
0000003ol>H0oo3V05@0oo3V00<000000?o`iP3ol>H0F`3ol>H00`000000oo3V0?o`iP2Q0?o`iP00
3P3ol>H00`000000oo3V0?o`iP1D0?o`iP030000003ol>H0oo3V05X0oo3V00<000000?o`iP3ol>H0
XP3ol>H000h0oo3V00<000000?o`iP3ol>H0E@3ol>H00`000000oo3V0?o`iP1I0?o`iP030000003o
l>H0oo3V0:80oo3V000>0?o`iP800000E`3ol>H00`000000oo3V0?o`iP1H0?o`iP030000003ol>H0
oo3V0:80oo3V000>0?o`iP030000003ol>H0oo3V05H0oo3V00<000000?o`iP3ol>H0F03ol>H00`00
0000oo3V0?o`iP2R0?o`iP003P3ol>H00`000000oo3V0?o`iP1G0?o`iP030000003ol>H0oo3V05H0
oo3V00<000000?o`iP3ol>H0X`3ol>H000h0oo3V00<000000?o`iP3ol>H0F03ol>H30?l005D0oo3V
00<000000?o`iP3ol>H0X`3ol>H000h0oo3V00<000000?o`iP3ol>H0E`3ol>H50?l005@0oo3V00<0
00000?o`iP3ol>H0X`3ol>H000h0oo3V00<000000?o`iP3ol>H0E`3ol>H50?l005@0oo3V00<00000
0?o`iP3ol>H0X`3ol>H000h0oo3V00<000000?o`iP3ol>H0E`3ol>H50?l005<0oo3V00<000000?o`
iP3ol>H0Y03ol>H000D0oo3V0`0000060?o`iP030000003ol>H0oo3V05P0oo3V0`3o001D0?o`iP03
0000003ol>H0oo3V0:@0oo3V00060?o`iP030000003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H0
F`3ol>H00`000000oo3V0?o`iP1@0?o`iP<0o`00Y@3ol>H000<0oo3V1@0000060?o`iP030000003o
l>H0oo3V05`0oo3V00<000000?o`iP3ol>H0CP3ol>H50?l00:@0oo3V00030?o`iP040000003ol>H0
oo3V000000L0oo3V0`00001L0?o`iP030000003ol>H0oo3V04h0oo3V1@3o002T0?o`iP00103ol>H0
0`000000oo3V000000070?o`iP030000003ol>H0oo3V05d0oo3V00<000000?o`iP3ol>H0C@3ol>H5
0?l00:@0oo3V00050?o`iP8000001`3ol>H00`000000oo3V0?o`iP1N0?o`iP030000003ol>H0oo3V
04d0oo3V0`3o002U0?o`iP001P3ol>H00`000000oo3V0?o`iP050?o`iP030000003ol>H0oo3V05h0
oo3V00<000000?o`iP3ol>H0C03ol>H00`000000oo3V0?o`iP2V0?o`iP003P3ol>H00`000000oo3V
0?o`iP1O0?o`iP030000003ol>H0oo3V04/0oo3V00<000000?o`iP3ol>H0YP3ol>H000h0oo3V00<0
00000?o`iP3ol>H0H03ol>H00`000000oo3V0?o`iP1:0?o`iP030000003ol>H0oo3V0:H0oo3V000>
0?o`iP030000003ol>H0oo3V0600oo3V00<000000?o`iP3ol>H0BP3ol>H00`000000oo3V0?o`iP2V
0?o`iP003P3ol>H00`000000oo3V0?o`iP1Q0?o`iP030000003ol>H0oo3V04P0oo3V00<000000?o`
iP3ol>H0Y`3ol>H000h0oo3V00<000000?o`iP3ol>H0HP3ol>H00`000000oo3V0?o`iP170?o`iP03
0000003ol>H0oo3V0:L0oo3V000>0?o`iP800000H`3ol>H00`000000oo3V0?o`iP170?o`iP030000
003ol>H0oo3V0:L0oo3V000>0?o`iP030000003ol>H0oo3V06<0oo3V00<000000?o`iP3ol>H0AP3o
l>H00`000000oo3V0?o`iP2W0?o`iP003P3ol>H00`000000oo3V0?o`iP1T0?o`iP030000003ol>H0
oo3V04@0oo3V00<000000?o`iP3ol>H0Z03ol>H000h0oo3V00<000000?o`iP3ol>H0I03ol>H00`00
0000oo3V0?o`iP140?o`iP030000003ol>H0oo3V0:P0oo3V000>0?o`iP030000003ol>H0oo3V06D0
oo3V00<000000?o`iP3ol>H0@`3ol>H00`000000oo3V0?o`iP2X0?o`iP003P3ol>H00`000000oo3V
0?o`iP1V0?o`iP030000003ol>H0oo3V0440oo3V00<000000?o`iP3ol>H0Z@3ol>H000h0oo3V00<0
00000?o`iP3ol>H0IP3ol>H00`000000oo3V0?o`iP110?o`iP030000003ol>H0oo3V0:T0oo3V000>
0?o`iP030000003ol>H0oo3V06L0oo3V00<000000?o`iP3ol>H0@03ol>H00`000000oo3V0?o`iP2Y
0?o`iP003P3ol>H00`000000oo3V0?o`iP1X0?o`iP030000003ol>H0oo3V03h0oo3V00<000000?o`
iP3ol>H0ZP3ol>H000h0oo3V00<000000?o`iP3ol>H0J03ol>H00`000000oo3V0?o`iP0n0?o`iP03
0000003ol>H0oo3V0:X0oo3V000>0?o`iP800000JP3ol>H00`000000oo3V0?o`iP0m0?o`iP030000
003ol>H0oo3V0:X0oo3V000>0?o`iP030000003ol>H0oo3V06X0oo3V00<000000?o`iP3ol>H0>`3o
l>H00`000000oo3V0?o`iP2[0?o`iP003P3ol>H00`000000oo3V0?o`iP1[0?o`iP030000003ol>H0
oo3V03X0oo3V00<000000?o`iP3ol>H0Z`3ol>H000h0oo3V00<000000?o`iP3ol>H0J`3ol>H00`00
0000oo3V0?o`iP0j0?o`iP030000003ol>H0oo3V0:/0oo3V000>0?o`iP030000003ol>H0oo3V06`0
oo3V00<000000?o`iP3ol>H0>03ol>H00`000000oo3V0?o`iP2/0?o`iP003P3ol>H00`000000oo3V
0?o`iP1]0?o`iP030000003ol>H0oo3V03L0oo3V00<000000?o`iP3ol>H0[03ol>H000h0oo3V00<0
00000?o`iP3ol>H0KP3ol>H00`000000oo3V0?o`iP0f0?o`iP030000003ol>H0oo3V0:`0oo3V000>
0?o`iP030000003ol>H0oo3V06h0oo3V00<000000?o`iP3ol>H0=@3ol>H00`000000oo3V0?o`iP2]
0?o`iP003P3ol>H00`000000oo3V0?o`iP1_0?o`iP030000003ol>H0oo3V03@0oo3V00<000000?o`
iP3ol>H0[@3ol>H000h0oo3V0P00001a0?o`iP030000003ol>H0oo3V03<0oo3V00<000000?o`iP3o
l>H0[@3ol>H000h0oo3V00<000000?o`iP3ol>H0L@3ol>H200000380oo3V00<000000?o`iP3ol>H0
[P3ol>H000h0oo3V00<000000?o`iP3ol>H0L`3ol>H00`000000oo3V0?o`iP0_0?o`iP030000003o
l>H0oo3V0:h0oo3V000>0?o`iP030000003ol>H0oo3V07@0oo3V00<000000?o`iP3ol>H0;@3ol>H0
0`000000oo3V0?o`iP2_0?o`iP003P3ol>H00`000000oo3V0?o`iP1e0?o`iP030000003ol>H0oo3V
02/0oo3V00<000000?o`iP3ol>H0/03ol>H000h0oo3V00<000000?o`iP3ol>H0MP3ol>H00`000000
oo3V0?o`iP0Z0?o`iP030000003ol>H0oo3V0;00oo3V000>0?o`iP030000003ol>H0oo3V07L0oo3V
00<000000?o`iP3ol>H0:03ol>H00`000000oo3V0?o`iP2a0?o`iP003P3ol>H00`000000oo3V0?o`
iP1h0?o`iP030000003ol>H0oo3V02L0oo3V00<000000?o`iP3ol>H0/@3ol>H000h0oo3V00<00000
0?o`iP3ol>H0N@3ol>H00`000000oo3V0?o`iP0U0?o`iP030000003ol>H0oo3V0;80oo3V000>0?o`
iP030000003ol>H0oo3V07X0oo3V00<000000?o`iP3ol>H08`3ol>H00`000000oo3V0?o`iP2c0?o`
iP003P3ol>H2000007`0oo3V00<000000?o`iP3ol>H08P3ol>H00`000000oo3V0?o`iP2c0?o`iP00
3P3ol>H00`000000oo3V0?o`iP1l0?o`iP030000003ol>H0oo3V0200oo3V00<000000?o`iP3ol>H0
]03ol>H000h0oo3V00<000000?o`iP3ol>H0O@3ol>H2000001l0oo3V00<000000?o`iP3ol>H0]@3o
l>H000h0oo3V00<000000?o`iP3ol>H0O`3ol>H00`000000oo3V0?o`iP0K0?o`iP030000003ol>H0
oo3V0;H0oo3V000>0?o`iP030000003ol>H0oo3V0800oo3V00<000000?o`iP3ol>H0603ol>H20000
0;T0oo3V000>0?o`iP030000003ol>H0oo3V0840oo3V0P00000G0?o`iP030000003ol>H0oo3V0;T0
oo3V000>0?o`iP030000003ol>H0oo3V08<0oo3V0P0000030?l00100oo3V0P00002l0?o`iP00103o
l>H3000000L0oo3V00<000000?o`iP3ol>H0Q03ol>H50?l000h0oo3V00<000000?o`iP3ol>H0_03o
l>H000<0oo3V00D000000?o`iP3ol>H0oo3V000000060?o`iP030000003ol>H0oo3V08@0oo3V1@3o
000<0?o`iP800000_`3ol>H000L0oo3V00<000000?o`iP3ol>H0103ol>H3000008@0oo3V1@3o0006
000000030?o`iP000000000000<00000`@3ol>H000L0oo3V00<000000?o`iP3ol>H0103ol>H00`00
0000oo3V0?o`iP250?o`iP<0o`001P3ol>H300000<D0oo3V00030?o`iP@000001`3ol>H00`000000
oo3V0?o`iP3o0?o`iUL0oo3V00030?o`iP030000003ol>H0oo3V00P0oo3V00<000000?o`iP3ol>H0
o`3ol>IG0?o`iP000`3ol>H5000000H0oo3V00<000000?o`iP3ol>H0o`3ol>IG0?o`iP003P3ol>H0
0`000000oo3V0?o`iP3o0?o`iUL0oo3V000>0?o`iP030000003ol>H0oo3V0?l0oo3VE`3ol>H00001
\
\>"],
  ImageRangeCache->{{{0, 358.625}, {257.188, 0}} -> {-0.297311, -0.281447, \
0.0210566, 0.0210566}}],

Cell["Equally spaced values along the bspline curve...", "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .12903 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0545315 0.0614439 0.0645161 0.0614439 [
[.05453 .05202 -3 -9 ]
[.05453 .05202 3 0 ]
[.20814 .05202 -9 -9 ]
[.20814 .05202 9 0 ]
[.36175 .05202 -3 -9 ]
[.36175 .05202 3 0 ]
[.51536 .05202 -9 -9 ]
[.51536 .05202 9 0 ]
[.66897 .05202 -6 -9 ]
[.66897 .05202 6 0 ]
[.82258 .05202 -12 -9 ]
[.82258 .05202 12 0 ]
[.97619 .05202 -6 -9 ]
[.97619 .05202 6 0 ]
[ 0 0 0 0 ]
[ 1 .12903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05453 .06452 m
.05453 .07077 L
s
[(0)] .05453 .05202 0 1 Mshowa
.20814 .06452 m
.20814 .07077 L
s
[(2.5)] .20814 .05202 0 1 Mshowa
.36175 .06452 m
.36175 .07077 L
s
[(5)] .36175 .05202 0 1 Mshowa
.51536 .06452 m
.51536 .07077 L
s
[(7.5)] .51536 .05202 0 1 Mshowa
.66897 .06452 m
.66897 .07077 L
s
[(10)] .66897 .05202 0 1 Mshowa
.82258 .06452 m
.82258 .07077 L
s
[(12.5)] .82258 .05202 0 1 Mshowa
.97619 .06452 m
.97619 .07077 L
s
[(15)] .97619 .05202 0 1 Mshowa
.125 Mabswid
.08525 .06452 m
.08525 .06827 L
s
.11598 .06452 m
.11598 .06827 L
s
.1467 .06452 m
.1467 .06827 L
s
.17742 .06452 m
.17742 .06827 L
s
.23886 .06452 m
.23886 .06827 L
s
.26959 .06452 m
.26959 .06827 L
s
.30031 .06452 m
.30031 .06827 L
s
.33103 .06452 m
.33103 .06827 L
s
.39247 .06452 m
.39247 .06827 L
s
.4232 .06452 m
.4232 .06827 L
s
.45392 .06452 m
.45392 .06827 L
s
.48464 .06452 m
.48464 .06827 L
s
.54608 .06452 m
.54608 .06827 L
s
.5768 .06452 m
.5768 .06827 L
s
.60753 .06452 m
.60753 .06827 L
s
.63825 .06452 m
.63825 .06827 L
s
.69969 .06452 m
.69969 .06827 L
s
.73041 .06452 m
.73041 .06827 L
s
.76114 .06452 m
.76114 .06827 L
s
.79186 .06452 m
.79186 .06827 L
s
.8533 .06452 m
.8533 .06827 L
s
.88402 .06452 m
.88402 .06827 L
s
.91475 .06452 m
.91475 .06827 L
s
.94547 .06452 m
.94547 .06827 L
s
.02381 .06452 m
.02381 .06827 L
s
.25 Mabswid
0 .06452 m
1 .06452 L
s
0 0 m
1 0 L
1 .12903 L
0 .12903 L
closepath
clip
newpath
.5 Mabswid
.02381 .06452 m
.97619 .06452 L
s
gsave
.94808 .06452 -67.1875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.375 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.750 moveto
(D) show
71.375 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05453 .06452 -67.1875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.375 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.750 moveto
(@) show
71.375 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.94808 .06452 -67.1875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.375 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.750 moveto
(D) show
71.375 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.94808 .06452 -67.1875 -23.4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.125 translate 1 -1 scale
63.000 13.125 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.125 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
71.375 13.125 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
4 Mabswid
.14389 .06452 Mdot
.23324 .06452 Mdot
.3226 .06452 Mdot
.41195 .06452 Mdot
.50131 .06452 Mdot
.59066 .06452 Mdot
.68002 .06452 Mdot
.76937 .06452 Mdot
.85873 .06452 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{359.625, 46.3125},
  ImageMargins->{{93, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005W0000;R000`400?l00000o`00003oo`3ol>IX
0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX
0?o`iP00o`3ol>IX0?o`iP00o`3ol>I>0?o`iPL000004`3ol>H00?l0oo3VC`3ol>H2000000<0oo3V
00<000000?o`iP3ol>H04@3ol>H00?l0oo3VC`3ol>H2000000<0oo3V00<000000?o`iP3ol>H04@3o
l>H001D0oo3V0P00000/0?o`iPD000000`3ol>H00`000000oo3V0?o`iP020?o`iP<00000;@3ol>H3
000002h0oo3V00<000000?o`iP3ol>H00`3ol>H00`000000oo3V0?o`iP020?o`iP<00000:P3ol>H3
000000@0oo3V0P00000W0?o`iP<000000P3ol>H5000000<0oo3V00<000000?o`iP3ol>H00P3ol>H3
00000200oo3V0P0000030?o`iP030000003ol>H00000008000000`3ol>H3000000T0oo3V000D0?o`
iP040000003ol>H0oo3V000002`0oo3V00@000000?o`iP3ol>H000001`3ol>H01@000000oo3V0?o`
iP3ol>H0000002/0oo3V00D000000?o`iP3ol>H0oo3V0000000]0?o`iP030000003ol>H0oo3V00L0
oo3V00D000000?o`iP3ol>H0oo3V0000000Z0?o`iP030000003ol>H0oo3V0080oo3V00@000000?o`
iP3ol>H000009`3ol>H00`000000oo3V0?o`iP020?o`iP040000003ol>H0oo3V000000L0oo3V00D0
00000?o`iP3ol>H0oo3V0000000O0?o`iP8000001P3ol>H01@000000oo3V0?o`iP3ol>H0000000<0
oo3V00<000000?o`iP3ol>H01P3ol>H001@0oo3V00@000000?o`iP3ol>H00000;@3ol>H00`000000
oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V02d0oo3V00<000000?o`iP3ol>H0;03ol>H00`000000
oo3V0?o`iP0:0?o`iP030000003ol>H0oo3V02P0oo3V00<000000?o`iP3ol>H00P3ol>H010000000
oo3V0?o`iP00000W0?o`iP030000003ol>H0oo3V00<0oo3V00<000000?o`iP3ol>H02`3ol>H00`00
0000oo3V0?o`iP0M0?o`iP8000001P3ol>H00`000000oo3V0?o`iP050?o`iP030000003ol>H0oo3V
00H0oo3V000D0?o`iP040000003ol>H0oo3V000002h0oo3V00<000000?o`iP3ol>H02P3ol>H00`00
0000oo3V0?o`iP0]0?o`iP030000003ol>H0oo3V02`0oo3V00<000000?o`iP3ol>H02P3ol>H00`00
0000oo3V0?o`iP0X0?o`iP030000003ol>H0oo3V0080oo3V00@000000?o`iP3ol>H000009`3ol>H0
0`000000oo3V0?o`iP040?o`iP030000003ol>H0oo3V00X0oo3V00<000000?o`iP3ol>H07@3ol>H2
000000H0oo3V00<000000?o`iP3ol>H01@3ol>H00`000000oo3V0?o`iP060?o`iP00503ol>H01000
0000oo3V0?o`iP00000[0?o`iP050000003ol>H0oo3V0?o`iP0000001`3ol>H4000002`0oo3V1000
000`0?o`iP030000003ol>H0oo3V00D0oo3V1000000[0?o`iP030000003ol>H0oo3V0080oo3V00@0
00000?o`iP3ol>H000009`3ol>H01@000000oo3V0?o`iP3ol>H0000000<0oo3V00<000000?o`iP3o
l>H01@3ol>H4000001l0oo3V100000050?o`iP040000003ol>H0oo3V0?o`iP@000002@3ol>H001@0
oo3V00@000000?o`iP3ol>H00000:`3ol>H01@000000oo3V0?o`iP3ol>H0000000L0oo3V00<00000
0?o`iP3ol>H0;@3ol>H00`000000oo3V0?o`iP0]0?o`iP050000003ol>H0oo3V0?o`iP0000001`3o
l>H00`000000oo3V0?o`iP0[0?o`iP800000103ol>H010000000oo3V0?o`iP00000V0?o`iP800000
0`3ol>H01@000000oo3V0?o`iP3ol>H0000000L0oo3V00<000000?o`iP3ol>H0:03ol>H2000000<0
oo3V00<000000?o`iP3ol>H02P3ol>H001D0oo3V0P00000]0?o`iP<00000203ol>H5000002/0oo3V
1@00000[0?o`iPD000001`3ol>H5000002X0oo3V00<000000?o`iP3ol>H00`3ol>H2000002P0oo3V
00<000000?o`iP3ol>H00P3ol>H3000000P0oo3V1@00000W0?o`iP040000003ol>H0oo3V0?o`iPD0
0000203ol>H00?l0oo3VJ03ol>H001D0oo3V0`00003o0?o`iSL0oo3V0`00000F0?o`iP005@3ol>H2
00000?l0oo3V>@3ol>H2000001H0oo3V000E0?o`iP800000o`3ol>Hi0?o`iP8000005P3ol>H001D0
oo3V0P00000N0?o`iP8000007P3ol>H2000001d0oo3V0P00000M0?o`iP8000007P3ol>H2000001d0
oo3V0P00000N0?o`iP8000007@3ol>H2000001d0oo3V0P00000M0?o`iP8000005P3ol>H001D0oo3V
0P00000M0?o`iP@00000703ol>H4000001/0oo3V1000000K0?o`iP@00000703ol>H4000001/0oo3V
1000000L0?o`iP@000006`3ol>H4000001/0oo3V1000000L0?o`iP8000005P3ol>H000<0oo3Vo`00
001Q000000@0oo3V000<0?o`iP030000003ol>H0oo3V00H0oo3V0P00000:0?o`iP030000003ol>H0
oo3V00P0oo3V00<000000?o`iP3ol>H01P3ol>H3000000X0oo3V00<000000?o`iP3ol>H01`3ol>H0
0`000000oo3V0?o`iP060?o`iP<000002P3ol>H00`000000oo3V0?o`iP080?o`iP030000003ol>H0
oo3V00@0oo3V0P0000000`3ol>H000000?o`iP090?o`iP030000003ol>H0oo3V00P0oo3V00<00000
0?o`iP3ol>H00`3ol>H2000000<0oo3V00<000000?o`iP3ol>H0203ol>H00`000000oo3V0?o`iP07
0?o`iP030000003ol>H0oo3V00<0oo3V0P0000030?o`iP030000003ol>H0oo3V00P0oo3V00<00000
0?o`iP3ol>H0203ol>H010000000oo3V0?o`iP3ol>H2000000D0oo3V00<000000?o`iP3ol>H01`3o
l>H00`000000oo3V0?o`iP080?o`iP040000003ol>H0oo3V0?o`iP8000001@3ol>H00`000000oo3V
0?o`iP080?o`iP030000003ol>H0oo3V00P0oo3V00@000000?o`iP00000000001P3ol>H00`000000
oo3V0?o`iP080?o`iP030000003ol>H0oo3V00P0oo3V0`0000080?o`iP030000003ol>H0oo3V00L0
oo3V00<000000?o`iP3ol>H0203ol>H2000000T0oo3V00<000000?o`iP3ol>H02P3ol>H001D0oo3V
0P00000e0?o`iP030000003ol>H0oo3V03<0oo3V00<000000?o`iP3ol>H0<`3ol>H00`000000oo3V
0?o`iP0c0?o`iP030000003ol>H0oo3V03<0oo3V00<000000?o`iP3ol>H0:03ol>H2000000T0oo3V
00<000000?o`iP3ol>H02P3ol>H001D0oo3V0P00003o0?o`iST0oo3V0P00000F0?o`iP005@3ol>H2
00000?l0oo3V>@3ol>H2000001H0oo3V000E0?o`iP800000o`3ol>Hi0?o`iP8000005P3ol>H001D0
oo3V0`00003o0?o`iSL0oo3V0`00000F0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX
0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX
0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX
0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00\
\>"],
  ImageRangeCache->{{{0, 358.625}, {45.3125, 0}} -> {-1.06015, -1.05001, \
0.0463445, 0.0463445}}],

Cell["\<\
that result from equally spaced arc length values along the length \
of the curve.\
\>", "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .15873 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.103175 0.793651 0.0793651 0.793651 [
[.10317 .06687 -3 -9 ]
[.10317 .06687 3 0 ]
[.2619 .06687 -9 -9 ]
[.2619 .06687 9 0 ]
[.42063 .06687 -9 -9 ]
[.42063 .06687 9 0 ]
[.57937 .06687 -9 -9 ]
[.57937 .06687 9 0 ]
[.7381 .06687 -9 -9 ]
[.7381 .06687 9 0 ]
[.89683 .06687 -3 -9 ]
[.89683 .06687 3 0 ]
[ 0 0 0 0 ]
[ 1 .15873 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .07937 m
.10317 .08562 L
s
[(0)] .10317 .06687 0 1 Mshowa
.2619 .07937 m
.2619 .08562 L
s
[(0.2)] .2619 .06687 0 1 Mshowa
.42063 .07937 m
.42063 .08562 L
s
[(0.4)] .42063 .06687 0 1 Mshowa
.57937 .07937 m
.57937 .08562 L
s
[(0.6)] .57937 .06687 0 1 Mshowa
.7381 .07937 m
.7381 .08562 L
s
[(0.8)] .7381 .06687 0 1 Mshowa
.89683 .07937 m
.89683 .08562 L
s
[(1)] .89683 .06687 0 1 Mshowa
.125 Mabswid
.14286 .07937 m
.14286 .08312 L
s
.18254 .07937 m
.18254 .08312 L
s
.22222 .07937 m
.22222 .08312 L
s
.30159 .07937 m
.30159 .08312 L
s
.34127 .07937 m
.34127 .08312 L
s
.38095 .07937 m
.38095 .08312 L
s
.46032 .07937 m
.46032 .08312 L
s
.5 .07937 m
.5 .08312 L
s
.53968 .07937 m
.53968 .08312 L
s
.61905 .07937 m
.61905 .08312 L
s
.65873 .07937 m
.65873 .08312 L
s
.69841 .07937 m
.69841 .08312 L
s
.77778 .07937 m
.77778 .08312 L
s
.81746 .07937 m
.81746 .08312 L
s
.85714 .07937 m
.85714 .08312 L
s
.06349 .07937 m
.06349 .08312 L
s
.02381 .07937 m
.02381 .08312 L
s
.93651 .07937 m
.93651 .08312 L
s
.97619 .07937 m
.97619 .08312 L
s
.25 Mabswid
0 .07937 m
1 .07937 L
s
0 0 m
1 0 L
1 .15873 L
0 .15873 L
closepath
clip
newpath
.5 Mabswid
.02381 .07937 m
.97619 .07937 L
s
gsave
.10317 .07937 -67.1875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.375 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.750 moveto
(@) show
71.375 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89683 .07937 -67.1875 -10.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.375 translate 1 -1 scale
63.000 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono-Bold
%%IncludeFont: Math2Mono-Bold
/Math2Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.750 moveto
(D) show
71.375 13.750 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 0 r
4 Mabswid
.10317 .07937 Mdot
.13102 .07937 Mdot
.16506 .07937 Mdot
.21103 .07937 Mdot
.29794 .07937 Mdot
.44325 .07937 Mdot
.53101 .07937 Mdot
.61668 .07937 Mdot
.74427 .07937 Mdot
.84713 .07937 Mdot
.89683 .07937 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{359.625, 57},
  ImageMargins->{{93, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005W0000>B000`400?l00000o`00003oo`3ol>IX
0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX
0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX
0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX
0?o`iP009P3ol>H200000300oo3V0P0000040?o`iP040000003ol>H0oo3V0?o`iPD00000:@3ol>H2
000000@0oo3V00<000000?o`iP3ol>H00`3ol>H3000002T0oo3V0P0000040?o`iP030000003ol>H0
oo3V0080oo3V0`00000Z0?o`iP800000103ol>H00`000000oo3V0?o`iP020?o`iP<00000;`3ol>H3
000002L0oo3V000U0?o`iP040000003ol>H0oo3V000002h0oo3V00@000000?o`iP3ol>H00000203o
l>H010000000oo3V0?o`iP00000X0?o`iP040000003ol>H0oo3V000000X0oo3V00<000000?o`iP3o
l>H09`3ol>H010000000oo3V0?o`iP0000070?o`iP050000003ol>H0oo3V0?o`iP000000:03ol>H0
10000000oo3V0?o`iP0000070?o`iP050000003ol>H0oo3V0?o`iP000000;`3ol>H00`000000oo3V
0?o`iP0V0?o`iP009@3ol>H010000000oo3V0?o`iP00000^0?o`iP040000003ol>H0oo3V000000T0
oo3V00<000000?o`iP3ol>H0:03ol>H010000000oo3V0?o`iP0000070?o`iPD00000:03ol>H01000
0000oo3V0?o`iP0000070?o`iP050000003ol>H0oo3V0?o`iP000000:03ol>H010000000oo3V0?o`
iP0000070?o`iP050000003ol>H0oo3V0?o`iP000000;`3ol>H00`000000oo3V0?o`iP0V0?o`iP00
9@3ol>H010000000oo3V0?o`iP00000^0?o`iP040000003ol>H0oo3V000000X0oo3V00<000000?o`
iP3ol>H09`3ol>H010000000oo3V0?o`iP0000070?o`iP040000003ol>H0oo3V000002T0oo3V00@0
00000?o`iP3ol>H000001`3ol>H4000002T0oo3V00@000000?o`iP3ol>H00000203ol>H300000300
oo3V00<000000?o`iP3ol>H09P3ol>H002D0oo3V00@000000?o`iP3ol>H00000;P3ol>H010000000
oo3V0?o`iP0000070?o`iP050000003ol>H0oo3V0?o`iP000000:03ol>H010000000oo3V0?o`iP00
00080?o`iP030000003ol>H0000002T0oo3V00@000000?o`iP3ol>H000001`3ol>H00`000000oo3V
0?o`iP0Z0?o`iP040000003ol>H0oo3V000000L0oo3V00D000000?o`iP3ol>H0oo3V0000000_0?o`
iP030000003ol>H0oo3V02H0oo3V000U0?o`iP040000003ol>H0oo3V000002h0oo3V00@000000?o`
iP3ol>H000001`3ol>H01@000000oo3V0?o`iP3ol>H0000002P0oo3V00@000000?o`iP3ol>H00000
2@3ol>H2000002T0oo3V00@000000?o`iP3ol>H00000203ol>H00`000000oo3V0?o`iP0Y0?o`iP04
0000003ol>H0oo3V000000L0oo3V00D000000?o`iP3ol>H0oo3V0000000^0?o`iP800000:03ol>H0
02H0oo3V0P00000`0?o`iP8000002@3ol>H3000002X0oo3V0P00000;0?o`iP030000003ol>H0oo3V
02P0oo3V0P00000:0?o`iP800000:P3ol>H2000000T0oo3V0`00000`0?o`iP030000003ol>H0oo3V
02H0oo3V000V0?o`iP<00000o`3ol>HE0?o`iP<000009`3ol>H002H0oo3V0P00003o0?o`iQL0oo3V
0P00000W0?o`iP009P3ol>H200000?l0oo3V5`3ol>H2000002L0oo3V000V0?o`iP800000o`3ol>HG
0?o`iP8000009`3ol>H002H0oo3V0P3o00080?o`iP80o`002P3ol>H20?l000h0oo3V0P3o000M0?o`
iP80o`00<@3ol>H20?l001d0oo3V0P3o000L0?o`iP80o`00:`3ol>H20?l002<0oo3V0P3o000?0?o`
iP80o`009`3ol>H00080oo3V8`0000040?l000H00000103o0008000000@0o`00300000040?l001/0
0000103o000_000000@0o`006`0000040?l001X00000103o000Y000000@0o`008@0000040?l000d0
0000103o000S000000<0oo3V000;0?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H0
2@3ol>H40?l000H0oo3V103o00020?o`iP030000003ol>H0oo3V00<0oo3V103o00040?o`iP030000
003ol>H0oo3V00D0oo3V103o00020?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H0
203ol>H40?l000d0oo3V00<000000?o`iP3ol>H02`3ol>H00`000000oo3V0?o`iP0;0?o`iP030000
003ol>H0oo3V00<0oo3V103o00040?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H0
1P3ol>H40?l000030?o`iP000000oo3V00`0oo3V00<000000?o`iP3ol>H0203ol>H40?l000d0oo3V
00<000000?o`iP3ol>H02`3ol>H00`000000oo3V0?o`iP0;0?o`iP@0o`002P3ol>H00`000000oo3V
0?o`iP0;0?o`iP030000003ol>H0oo3V00H0oo3V103o00000`3ol>H000000?o`iP0:0?o`iP@0o`00
303ol>H00`000000oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V00T0oo3V000;0?o`iP030000003o
l>H0oo3V00/0oo3V00<000000?o`iP3ol>H02P3ol>H20?l000P0oo3V0P3o00030?o`iP030000003o
l>H0oo3V00@0oo3V0P3o00050?o`iP030000003ol>H0oo3V00H0oo3V0P3o00030?o`iP030000003o
l>H0oo3V00/0oo3V00<000000?o`iP3ol>H02@3ol>H20?l000030000003ol>H0oo3V00/0oo3V00<0
00000?o`iP3ol>H02`3ol>H00`000000oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V00@0oo3V0P3o
00050?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H01`3ol>H20?l00080oo3V00<0
00000?o`iP3ol>H02`3ol>H00`000000oo3V0?o`iP090?o`iP80o`0000<000000?o`iP3ol>H02`3o
l>H00`000000oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V00/0oo3V00<000000?l0003o00002`3o
l>H00`000000oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V00L0oo3V0P3o00020?o`iP030000003o
l>H0oo3V00X0oo3V0P3o000=0?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H02@3o
l>H002H0oo3V0P00000g0?o`iP030000003ol>H0oo3V03D0oo3V00<000000?o`iP3ol>H0=@3ol>H0
0`000000oo3V0?o`iP0e0?o`iP030000003ol>H0oo3V03@0oo3V0P00000W0?o`iP009P3ol>H20000
0?l0oo3V5`3ol>H2000002L0oo3V000V0?o`iP800000o`3ol>HG0?o`iP8000009`3ol>H002H0oo3V
0`00003o0?o`iQD0oo3V0`00000W0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`
iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`
iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`
iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`
iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00o`3ol>IX0?o`iP00\
\>"],
  ImageRangeCache->{{{0, 358.625}, {56, 0}} -> {-0.140408, -0.100001, \
0.00357146, 0.00357146}}],

Cell["\<\
The parameter values that produce the equally spaced points on the \
curve.\
\>", "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Example",
    FontWeight->"Bold"],
  ":  The following code constructs an animation along the same curve as \
above, but this time the distance (along the path)  between the circles in \
successive frames is constant  and so the circle appears to move at constant \
speed."
}], "1ColumnBox",
  CellMargins->{{45, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\t\(gr\  = \ 
        Table[Show[{curve, 
              Graphics[{Circle[d\[LeftDoubleBracket]1\[RightDoubleBracket], 
                    0.5], Circle[d\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    0.5], Circle[d\[LeftDoubleBracket]3\[RightDoubleBracket], 
                    0.5], Circle[d\[LeftDoubleBracket]4\[RightDoubleBracket], 
                    0.5]}], \n\t\t\t\tGraphics[{Circle[
                    bspline[kt, ctrl, 
                      val\[LeftDoubleBracket]i\[RightDoubleBracket], 0], 
                    0.5]}]}, \ \tDisplayFunction \[Rule] Identity, 
            Axes \[Rule] False, 
            PlotRange -> {{\(-0.5\), 7.5}, {\(-0.5\), 6}}], {i, 1, 
            73}];\)\)}], "Input"],

Cell[BoxData[
    \(\(GLShow[gr, AnimateFrames \[Rule] True];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The Principles of Animation (TJ) 
        The Two Dimensional Bouncing Ball\
\>", "Subsection"],

Cell["\<\
According to Thomas and Johnston (TJ), reiterated by Lasseter (LA) \
in a somewhat different order (Lasseter left out Solid Drawing), the \
following are the principles of animation:\
\>", "Text"],

Cell["\<\
 1.\tSquash and Stretch
 2.\tAnticipation
 3.\tStaging
 4.\tStraight Ahead Action and Pose to Pose
 5.\tFollow Through and Overlapping Action
 6.\tSlow In and Slow Out
 7.\tArcs
 8.\tSecondary Action
 9.\tTiming
10.\tExaggeration
11.\tSolid Drawing
12\tAppeal\
\>", "ItemizedText",
  CellMargins->{{54.375, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Definitions and examples of each of these terms can be found in Thomas and \
Johnstone (TJ) and Lasseter (LA).  We demonstrate here how the above \
algorithms can be applied to two of these concepts:  Squash and Stretch, and \
Slow in and Slow out.  We use the standard animation test for beginning \
artists (TJ, p ",
  Cell[BoxData[
      \(50\  - \ 51\)]],
  " ), drawing a bouncing ball.  The demonstration here was suggested by the \
picture on p ",
  Cell[BoxData[
      \(51\)]],
  " of (TJ ), similar to the picture below.(see also Figure ",
  Cell[BoxData[
      \(2\)]],
  " of (LA))."
}], "Text",
  CellMargins->{{Inherited, 2.4375}, {Inherited, Inherited}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.166667 0.166667 0.166667 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.16667 .33333 .04167 0 365.73 arc
s
newpath
.19404 .39501 .04167 0 365.73 arc
s
newpath
.22823 .45313 .04167 0 365.73 arc
s
newpath
.27658 .49939 .04167 0 365.73 arc
s
newpath
.34061 .49589 .04167 0 365.73 arc
s
newpath
.3869 .44739 .04167 0 365.73 arc
s
newpath
.42017 .38872 .04167 0 365.73 arc
s
.48193 .34052 m
.4794 .34618 L
.4762 .35182 L
.4721 .35752 L
.46781 .36227 L
.46333 .36624 L
.45884 .36938 L
.45639 .3708 L
.45369 .37213 L
.45122 .37313 L
.44889 .37391 L
.44644 .37454 L
.44513 .3748 L
.44374 .37503 L
.44304 .37512 L
.44228 .3752 L
.44157 .37526 L
.44122 .37528 L
.4409 .3753 L
.44059 .37531 L
.44042 .37532 L
.44025 .37532 L
.43994 .37533 L
.43966 .37533 L
.43933 .37533 L
.43903 .37533 L
.43869 .37533 L
.43851 .37532 L
.43834 .37532 L
.43776 .37529 L
.43743 .37527 L
.43712 .37525 L
.43646 .37519 L
.43585 .37513 L
.43475 .37498 L
.43358 .37477 L
.43114 .37417 L
.42865 .37332 L
.42649 .37235 L
.42428 .37113 L
.42056 .36841 L
.41672 .3645 L
.41365 .36011 L
.41238 .35778 L
.41119 .35518 L
.40946 .35018 L
.4088 .34749 L
.40849 .34598 L
.40825 .34451 L
.40805 .34314 L
Mistroke
.40788 .34163 L
.40777 .34024 L
.40773 .33961 L
.40769 .33894 L
.40767 .33855 L
.40766 .33812 L
.40765 .33772 L
.40764 .33736 L
.40763 .33714 L
.40763 .33693 L
.40763 .33671 L
.40763 .33647 L
.40763 .33625 L
.40763 .33603 L
.40763 .33563 L
.40764 .33526 L
.40764 .33486 L
.40765 .33448 L
.40767 .33413 L
.4077 .33333 L
.40775 .33248 L
.40786 .33101 L
.408 .32964 L
.40843 .32653 L
.40907 .32316 L
.40984 .31999 L
.41172 .31416 L
.41433 .3081 L
.41725 .3028 L
.42098 .29736 L
.42489 .29276 L
.42925 .28861 L
.43365 .28526 L
.43873 .28229 L
.44349 .28027 L
.44599 .27949 L
.44737 .27915 L
.44866 .27888 L
.44984 .27868 L
.45092 .27853 L
.45213 .27841 L
.45275 .27836 L
.45307 .27834 L
.45341 .27833 L
.45376 .27831 L
.45407 .27831 L
.45437 .2783 L
.45469 .2783 L
.45498 .2783 L
.45524 .27831 L
Mistroke
.45553 .27831 L
.45584 .27832 L
.45618 .27834 L
.45653 .27836 L
.45719 .2784 L
.45782 .27846 L
.4584 .27853 L
.45956 .2787 L
.4606 .27889 L
.46288 .27945 L
.46523 .28025 L
.46732 .28116 L
.46967 .28244 L
.47176 .28384 L
.47537 .28696 L
.47883 .2911 L
.48166 .29582 L
.48369 .30061 L
.48456 .30333 L
.48521 .30594 L
.48577 .3089 L
.48599 .31042 L
.48618 .31212 L
.4863 .31363 L
.48635 .31439 L
.48637 .31483 L
.48639 .31523 L
.4864 .31558 L
.48641 .31596 L
.48642 .31635 L
.48642 .31673 L
.48643 .31708 L
.48643 .31746 L
.48643 .31778 L
.48642 .31813 L
.48642 .31834 L
.48641 .31857 L
.4864 .31899 L
.48639 .3194 L
.48638 .31977 L
.48634 .32063 L
.48628 .32155 L
.48613 .32323 L
.48596 .32476 L
.48548 .32798 L
.48488 .33093 L
.48303 .33752 L
.48193 .34052 L
Mfstroke
.4977 .27271 m
.49143 .28833 L
.48303 .3035 L
.47854 .30983 L
.47422 .31496 L
.46973 .31938 L
.46548 .32269 L
.46326 .32409 L
.46088 .32533 L
.45875 .32619 L
.45683 .32675 L
.45584 .32696 L
.45531 .32705 L
.4548 .32712 L
.45433 .32717 L
.45407 .32719 L
.45383 .3272 L
.4536 .32721 L
.4534 .32722 L
.45317 .32723 L
.45295 .32723 L
.45271 .32722 L
.45245 .32722 L
.45232 .32721 L
.45218 .3272 L
.45192 .32719 L
.45144 .32714 L
.451 .32708 L
.45049 .327 L
.44995 .32689 L
.44898 .32662 L
.4481 .32631 L
.4473 .32596 L
.44554 .32494 L
.44394 .32368 L
.44234 .32202 L
.44106 .3203 L
.43979 .31817 L
.43861 .31567 L
.43767 .3131 L
.43685 .3102 L
.43621 .30725 L
.43577 .30445 L
.43557 .3028 L
.43542 .30125 L
.43531 .29965 L
.43526 .29873 L
.43522 .29789 L
.43519 .29709 L
.43518 .29664 L
Mistroke
.43517 .29622 L
.43516 .29582 L
.43516 .29545 L
.43516 .29502 L
.43516 .29461 L
.43516 .29417 L
.43516 .29368 L
.43516 .29344 L
.43517 .29317 L
.43518 .2927 L
.4352 .29176 L
.43523 .2909 L
.43527 .2899 L
.43533 .28879 L
.43548 .28677 L
.43584 .28303 L
.43639 .27882 L
.43798 .27011 L
.44 .26196 L
.44272 .25321 L
.44954 .23666 L
.45755 .22257 L
.46606 .21162 L
.47058 .20722 L
.47539 .20357 L
.47771 .20219 L
.48018 .20102 L
.4813 .20059 L
.48247 .20022 L
.48355 .19994 L
.48453 .19975 L
.48501 .19968 L
.48554 .19961 L
.48578 .19959 L
.48603 .19957 L
.48626 .19956 L
.48648 .19954 L
.48672 .19954 L
.48698 .19953 L
.48721 .19953 L
.48745 .19953 L
.48771 .19954 L
.48796 .19955 L
.48822 .19957 L
.48851 .1996 L
.48897 .19965 L
.48946 .19973 L
.49034 .19991 L
.49119 .20015 L
.49195 .20042 L
Mistroke
.49364 .20122 L
.49513 .2022 L
.49667 .20353 L
.4982 .20525 L
.49951 .20714 L
.5008 .20949 L
.50186 .21197 L
.50272 .21449 L
.5035 .21747 L
.50408 .22048 L
.50449 .22335 L
.50466 .22502 L
.50479 .2266 L
.50488 .22824 L
.50492 .22917 L
.50493 .22961 L
.50495 .23003 L
.50495 .23041 L
.50496 .23084 L
.50497 .23126 L
.50497 .23172 L
.50497 .23212 L
.50497 .23256 L
.50497 .23297 L
.50496 .23335 L
.50496 .2338 L
.50495 .23428 L
.50492 .23516 L
.50488 .2362 L
.50484 .23716 L
.50471 .23927 L
.50454 .24129 L
.50412 .24518 L
.50352 .24938 L
.50206 .25705 L
.50003 .26515 L
.4977 .27271 L
Mfstroke
.41667 .16667 m
.41667 .16651 L
.41668 .16636 L
.41669 .16619 L
.41671 .16603 L
.41675 .16574 L
.41681 .16543 L
.4169 .16509 L
.41703 .16473 L
.41731 .16409 L
.41768 .16343 L
.41811 .16281 L
.41936 .16141 L
.42102 .16002 L
.42289 .15877 L
.42822 .15608 L
.43407 .15392 L
.44163 .1518 L
.44982 .15003 L
.45948 .14846 L
.46451 .14782 L
.47013 .14722 L
.47513 .14678 L
.48072 .1464 L
.48339 .14625 L
.48628 .14612 L
.48878 .14602 L
.49152 .14594 L
.49313 .1459 L
.49462 .14588 L
.49605 .14586 L
.49677 .14585 L
.49756 .14584 L
.49828 .14584 L
.49893 .14584 L
.49965 .14583 L
.50002 .14583 L
.50041 .14583 L
.50108 .14584 L
.5018 .14584 L
.50247 .14584 L
.50309 .14585 L
.50435 .14586 L
.50575 .14588 L
.50856 .14594 L
.51115 .14602 L
.51357 .14611 L
.51898 .14638 L
.52469 .14677 L
.52995 .14723 L
Mistroke
.53553 .14782 L
.54519 .14916 L
.55389 .15078 L
.56214 .15279 L
.56935 .15512 L
.57487 .15752 L
.57708 .15875 L
.57906 .16008 L
.58058 .16135 L
.58168 .16253 L
.58255 .16382 L
.58289 .16453 L
.58302 .16486 L
.58313 .16521 L
.5832 .16551 L
.58324 .16567 L
.58327 .16584 L
.58329 .16599 L
.58331 .16614 L
.58332 .16627 L
.58333 .16642 L
.58333 .16657 L
.58333 .16674 L
.58333 .1669 L
.58332 .16704 L
.5833 .16721 L
.58328 .1674 L
.58322 .16773 L
.58315 .16805 L
.58304 .1684 L
.5828 .16903 L
.5824 .16977 L
.58195 .17045 L
.58067 .1719 L
.57907 .17325 L
.57495 .17578 L
.56998 .17798 L
.5639 .18004 L
.55606 .18208 L
.54777 .18374 L
.53796 .18521 L
.52786 .1863 L
.52258 .18672 L
.51957 .18692 L
.5167 .18708 L
.51404 .1872 L
.51114 .18731 L
.50849 .18739 L
.50604 .18745 L
.50467 .18747 L
Mistroke
.50338 .18748 L
.50264 .18749 L
.50197 .18749 L
.5016 .1875 L
.50119 .1875 L
.50081 .1875 L
.50045 .1875 L
.50008 .1875 L
.49968 .1875 L
.4993 .1875 L
.49895 .1875 L
.49828 .1875 L
.49758 .18749 L
.49683 .18748 L
.49613 .18748 L
.49453 .18746 L
.49311 .18743 L
.49179 .1874 L
.48881 .18731 L
.4862 .18721 L
.48344 .18708 L
.47872 .18681 L
.47359 .18643 L
.46374 .18542 L
.45379 .184 L
.44504 .18233 L
.43688 .18027 L
.43034 .1781 L
.42532 .17591 L
.42294 .17459 L
.42102 .17331 L
.41958 .17213 L
.41836 .17085 L
.41763 .16982 L
.4173 .16923 L
.41706 .16868 L
.41689 .16818 L
.41677 .16771 L
.41673 .16746 L
.41671 .16732 L
.41669 .16718 L
.41668 .16704 L
.41667 .16691 L
.41667 .16679 L
.41667 .16667 L
Mfstroke
.49634 .23362 m
.49339 .22482 L
.49072 .21555 L
.48836 .20555 L
.48744 .2008 L
.48675 .19659 L
.48623 .19285 L
.4858 .18892 L
.48562 .18682 L
.48549 .18492 L
.4854 .18315 L
.48537 .18227 L
.48535 .18177 L
.48534 .18131 L
.48533 .18083 L
.48532 .1804 L
.48532 .17992 L
.48532 .17966 L
.48531 .17942 L
.48531 .17898 L
.48532 .17857 L
.48532 .17813 L
.48533 .17767 L
.48534 .17729 L
.48535 .17688 L
.48537 .17615 L
.48541 .17529 L
.48546 .17453 L
.48558 .17286 L
.48576 .17113 L
.48597 .16955 L
.48621 .16815 L
.48677 .16557 L
.48742 .16337 L
.48827 .16121 L
.48933 .15918 L
.49042 .15764 L
.49173 .15627 L
.49245 .1557 L
.49325 .15519 L
.49404 .15479 L
.49479 .15451 L
.49556 .1543 L
.49596 .15422 L
.49619 .15418 L
.49641 .15415 L
.49659 .15413 L
.49679 .15411 L
.49701 .1541 L
.49721 .15409 L
Mistroke
.49741 .15408 L
.49761 .15408 L
.49781 .15409 L
.49799 .15409 L
.49822 .15411 L
.49847 .15413 L
.49891 .15418 L
.4994 .15425 L
.49993 .15436 L
.50092 .15461 L
.50185 .15493 L
.50393 .15585 L
.50597 .15703 L
.50994 .16001 L
.51855 .16921 L
.52779 .1829 L
.53615 .19898 L
.54317 .21611 L
.54648 .22594 L
.54905 .23493 L
.55124 .24415 L
.55279 .25242 L
.5534 .25667 L
.55384 .26041 L
.55403 .26235 L
.55419 .26441 L
.55426 .26552 L
.55431 .26654 L
.55436 .26757 L
.55439 .26849 L
.5544 .26892 L
.55441 .26938 L
.55442 .26982 L
.55442 .27022 L
.55443 .27064 L
.55443 .2711 L
.55443 .27133 L
.55443 .27157 L
.55442 .27202 L
.55442 .2724 L
.55441 .27283 L
.5544 .27326 L
.55439 .27367 L
.55436 .27438 L
.55433 .27514 L
.55428 .27602 L
.55421 .27696 L
.55405 .27862 L
.55386 .28017 L
.55365 .28155 L
Mistroke
.55312 .2842 L
.5525 .28646 L
.55168 .2887 L
.55065 .29079 L
.54953 .29247 L
.54889 .29324 L
.54816 .29397 L
.54743 .29457 L
.54673 .29504 L
.54606 .29542 L
.54529 .29575 L
.54453 .29599 L
.5441 .2961 L
.54369 .29617 L
.54349 .2962 L
.5433 .29623 L
.54313 .29625 L
.54294 .29626 L
.54274 .29628 L
.54255 .29629 L
.54235 .29629 L
.54212 .29629 L
.54189 .29629 L
.54177 .29628 L
.54165 .29628 L
.54142 .29626 L
.54121 .29624 L
.54072 .29618 L
.54019 .2961 L
.53921 .29587 L
.53829 .29559 L
.53632 .29478 L
.53445 .29377 L
.53002 .29055 L
.52586 .28659 L
.52119 .28116 L
.51205 .26764 L
.50378 .2518 L
.49634 .23362 L
Mfstroke
.51107 .29553 m
.50857 .28875 L
.5065 .28151 L
.5057 .27796 L
.50501 .27419 L
.5047 .27204 L
.50446 .2701 L
.50428 .26827 L
.5042 .26728 L
.50413 .26636 L
.50408 .26549 L
.50405 .26471 L
.50402 .26384 L
.504 .26337 L
.504 .26292 L
.50399 .26254 L
.50399 .26214 L
.50399 .26177 L
.50399 .26143 L
.50399 .26103 L
.504 .2606 L
.504 .26019 L
.50401 .25982 L
.50404 .259 L
.50408 .25823 L
.50419 .25651 L
.50435 .25487 L
.50457 .25315 L
.50509 .25008 L
.50586 .24691 L
.50675 .24409 L
.50773 .24164 L
.51001 .23741 L
.51153 .2353 L
.51308 .23354 L
.51474 .23201 L
.51661 .23063 L
.5183 .22964 L
.52024 .22877 L
.52134 .22839 L
.5224 .22809 L
.52337 .22787 L
.52444 .22768 L
.525 .22761 L
.52563 .22755 L
.52594 .22752 L
.52628 .2275 L
.52645 .22749 L
.52661 .22749 L
.5269 .22748 L
Mistroke
.52718 .22747 L
.52748 .22747 L
.52776 .22747 L
.52802 .22748 L
.52832 .22749 L
.52849 .2275 L
.52865 .2275 L
.52924 .22754 L
.52983 .2276 L
.53036 .22766 L
.53157 .22784 L
.5327 .22806 L
.53378 .22832 L
.53622 .22907 L
.5389 .23014 L
.54385 .23281 L
.54907 .23657 L
.55804 .24552 L
.56229 .25104 L
.56649 .25757 L
.57003 .26417 L
.57335 .27174 L
.57594 .27919 L
.57778 .28617 L
.57855 .29002 L
.57912 .29361 L
.5795 .29679 L
.57965 .29857 L
.57976 .30019 L
.5798 .30104 L
.57982 .30181 L
.57984 .30223 L
.57985 .30269 L
.57986 .30313 L
.57986 .30353 L
.57986 .30389 L
.57986 .30424 L
.57986 .30461 L
.57986 .30501 L
.57985 .30541 L
.57984 .30583 L
.57982 .30657 L
.57978 .30739 L
.57973 .30825 L
.57961 .30978 L
.57943 .31157 L
.57921 .31317 L
.57867 .31615 L
.57803 .31878 L
.57718 .32152 L
Mistroke
.5761 .32423 L
.57501 .32645 L
.5737 .32864 L
.57097 .33209 L
.56928 .33369 L
.56729 .33518 L
.5653 .33633 L
.56334 .33717 L
.56228 .33752 L
.56111 .33784 L
.55998 .33807 L
.55943 .33815 L
.55892 .33822 L
.55841 .33828 L
.55794 .33831 L
.5577 .33833 L
.55742 .33835 L
.55714 .33836 L
.55686 .33836 L
.5566 .33837 L
.55631 .33837 L
.556 .33837 L
.55571 .33836 L
.55544 .33835 L
.5552 .33834 L
.55464 .3383 L
.55405 .33825 L
.55351 .33819 L
.5523 .33801 L
.55116 .33778 L
.55008 .33752 L
.54764 .33678 L
.54496 .3357 L
.53999 .33303 L
.53476 .32926 L
.52576 .32028 L
.5215 .31472 L
.5173 .30818 L
.51107 .29553 L
Mfstroke
newpath
.58115 .36687 .04167 0 365.73 arc
s
newpath
.61423 .41901 .04167 0 365.73 arc
s
newpath
.65827 .46192 .04167 0 365.73 arc
s
newpath
.71727 .47199 .04167 0 365.73 arc
s
newpath
.76771 .43756 .04167 0 365.73 arc
s
newpath
.80424 .38783 .04167 0 365.73 arc
s
newpath
.83333 .33333 .04167 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282, 188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000_1000`40O003h00OogoL6goL003oOm`K
Om`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000
ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`K
Om`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000
ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`K
Om`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000
ogoL6goL003oOm`KOm`008Qog0T008Uog000P7oL20002GoL2P00OgoL001kOm`5000KOm`4001kOm`0
07Mog0@000mog0@0015og08007Uog000MWoL00<007oLOm`047oL00<007oLOm`00WoL0P004GoL0P00
MgoL001eOm`00`00Omaog00@Om`20005Om`00`00Omaog00AOm`00`00Omaog01dOm`007Eog003001o
g7oL011og003001og7oL00Eog003001og7oL011og08007Eog000MGoL00<007oLOm`047oL00<007oL
Om`01WoL00<007oLOm`03goL00<007oLOm`0M7oL001eOm`2000AOm`00`00Omaog006Om`00`00Omao
g00>Om`2001fOm`007Mog0<000iog003001og7oL00Mog003001og7oL00Yog0<007Qog000NWoL0`00
2goL00<007oLOm`027oL00<007oLOm`01goL0P00NgoL001mOm`50006Om`00`00Omaog009Om`00`00
Om`00006001mOm`0089og1@008Aog000R7oL00<007oLOm`02WoL00<007oLOm`0PWoL0028Om`00`00
Omaog00:Om`00`00Omaog022Om`008Qog08000aog003001og7oL085og000QWoL1P002WoL00<007oL
Om`0PGoL0025Om`01`00Omaog7oL001og00000]og003001og7oL081og000PgoL0P0017oL00@007oL
Om`000Yog003001og7oL081og000PWoL00<007oLOm`017oL00D007oLOmaog00000Uog003001og7oL
081og000PWoL00<007oLOm`017oL00D007oLOmaog00000Yog003001og7oL07mog000PGoL00<007oL
Om`01GoL00D007oLOmaog00000Yog003001og7oL07mog000P7oL00<007oLOm`01goL00@007oLOm`0
00]og003001og7oL07iog000P7oL00<007oLOm`01goL00@007oLOm`000Aog0@000=og003001og7oL
07iog000OgoL00<007oLOm`027oL00@007oLOm`000=og080009og0<00003Om`007oL07mog000OgoL
00<007oLOm`02GoL00@007oL001og08000Mog0<007mog000OWoL00<007oLOm`02WoL00D007oL001o
g00000Yog003001og7oL07eog000OWoL00<007oLOm`02goL0`002goL0P00OWoL001mOm`00`00Omao
g00<Om`3000;Om`00`00Om`0001mOm`007eog003001og7oL00aog0<000]og003001og00007eog000
OGoL00<007oLOm`03GoL00<007oLOm`02goL00<007oL0000O7oL001lOm`00`00Omaog00>Om`00`00
Omaog00;Om`01000Omaog000NgoL001lOm`00`00Omaog00>Om`2000<Om`01@00Omaog7oL0000NWoL
001kOm`00`00Omaog00?Om`2000<Om`01@00Omaog7oL0000NWoL001kOm`00`00Omaog00>Om`3000<
Om`00`00Omaog002Om`00`00Omaog01gOm`007]og003001og7oL00iog0800003Om`007oL00Yog003
001og7oL009og003001og7oL07Mog000NgoL00<007oLOm`03GoL00<007oL00000WoL00<007oLOm`0
27oL00<007oLOm`00goL00<007oLOm`0MWoL001jOm`00`00Omaog00>Om`01000Omaog0000WoL00<0
07oLOm`01goL00<007oLOm`00goL00<007oLOm`0MWoL001jOm`00`00Om`000070007Om`01000Omao
g0000goL00<007oLOm`01WoL00<007oLOm`00goL00<007oLOm`0MWoL001jOm`20007Om`20005Om`0
1@00Omaog7oL00000goL00<007oLOm`01WoL00<007oLOm`00goL00<007oLOm`0MWoL001hOm`3000:
Om`00`00Omaog002Om`01@00Omaog7oL000017oL00<007oLOm`017oL0P001WoL00<007oLOm`0MGoL
000/Om`60016Om`00`00Om`0000;Om`01@00Omaog7oL00000goL00<007oLOm`00goL0P0017oL00<0
07oLOm`01GoL00<007oLOm`0@WoL1P00;GoL000ZOm`20006Om`20013Om`01000Omaog00037oL00<0
07oL00001GoL00<007oLOm`017oL1@001goL00<007oLOm`0@7oL0P001WoL0P00:goL000XOm`2000:
Om`20010Om`01@00Omaog7oL000037oL0P001WoL00<007oLOm`01GoL0P002GoL00<007oLOm`0?WoL
0P002WoL0P00:GoL000WOm`00`00Omaog00<Om`00`00Omaog00lOm`00`00Omaog002Om`00`00Omao
g00:Om`20007Om`00`00Omaog00?Om`00`00Omaog00mOm`00`00Omaog00<Om`00`00Omaog00VOm`0
02Iog003001og7oL00iog003001og7oL03]og003001og7oL009og003001og7oL00Yog08000Mog003
001og7oL00mog003001og7oL03aog003001og7oL00iog003001og7oL02Eog0009GoL00<007oLOm`0
47oL00<007oLOm`0>GoL00<007oLOm`00goL00<007oLOm`02GoL00<007oL000027oL00<007oLOm`0
3WoL00<007oLOm`0>goL00<007oLOm`047oL00<007oLOm`097oL000UOm`00`00Omaog00AOm`00`00
Omaog00hOm`00`00Omaog003Om`2000:Om`00`00Om`00008Om`00`00Omaog00>Om`00`00Omaog00k
Om`00`00Omaog00AOm`00`00Omaog00SOm`002Aog003001og7oL019og003001og7oL03Mog003001o
g7oL00Eog003001og7oL00Mog004001og7oL0009Om`00`00Omaog00=Om`00`00Omaog00jOm`00`00
Omaog00BOm`00`00Omaog00SOm`002Aog003001og7oL01=og003001og7oL03Iog003001og7oL00Eo
g003001og7oL00Eog08000=og003001og7oL00Qog003001og7oL00aog003001og7oL03Yog003001o
g7oL01=og003001og7oL029og0008goL00<007oLOm`057oL00<007oLOm`0=GoL00<007oLOm`01goL
00<007oLOm`00goL00<007oLOm`00goL00<007oLOm`02GoL00<007oLOm`02WoL0P00>goL00<007oL
Om`057oL00<007oLOm`08WoL000SOm`00`00Omaog00DOm`00`00Omaog00eOm`00`00Omaog008Om`5
0006Om`00`00Omaog00:Om`00`00Omaog006Om`:000fOm`00`00Omaog00DOm`00`00Omaog00ROm`0
02=og003001og7oL01Aog003001og7oL03Eog003001og7oL01=og003001og7oL00]og003001og7oL
00Aog005001og7oLOm`00006Om`2000dOm`00`00Omaog00DOm`00`00Omaog00ROm`002=og003001o
g7oL01Aog003001og7oL03Eog003001og7oL01=og003001og7oL00aog08000=og003001og7oL0080
00Uog003001og7oL035og003001og7oL01Aog003001og7oL029og0008goL00<007oLOm`057oL00<0
07oLOm`0=GoL00<007oLOm`04WoL00<007oLOm`03goL1`002goL00<007oLOm`0<7oL00<007oLOm`0
57oL00<007oLOm`08WoL000SOm`00`00Omaog00DOm`00`00Omaog00eOm`00`00Omaog00BOm`00`00
Omaog00?Om`00`00Omaog00@Om`00`00Omaog00_Om`00`00Omaog00DOm`00`00Omaog00ROm`002=o
g003001og7oL01Aog003001og7oL03Eog003001og7oL019og003001og7oL00mog003001og7oL011o
g003001og7oL02mog003001og7oL01Aog003001og7oL029og00097oL00<007oLOm`04WoL00<007oL
Om`0=GoL2P002goL00<007oLOm`03goL00<007oLOm`04WoL00<007oLOm`0;GoL2P003GoL00<007oL
Om`08goL000TOm`00`00Omaog00BOm`00`00Omaog00dOm`01000Omaog0001goL0P0027oL00<007oL
Om`047oL00<007oLOm`04WoL00<007oLOm`0:goL0P000WoL00<007oLOm`01GoL0P002goL00<007oL
Om`08goL000UOm`00`00Omaog009Om`;000cOm`01@00Omaog7oL00002GoL00<007oLOm`01GoL00<0
07oLOm`03goL00<007oLOm`057oL00<007oLOm`0:WoL00<007oLOm`00WoL00<007oLOm`01WoL00<0
07oLOm`027oL00<007oLOm`08goL000UOm`00`00Omaog008Om`00`00Omaog005Om`01@00Omaog7oL
0000<7oL0P0017oL00<007oLOm`027oL00<007oLOm`00goL00<007oLOm`047oL00<007oLOm`057oL
00<007oLOm`0:7oL0P001GoL00<007oLOm`01WoL00<007oLOm`01goL00<007oLOm`097oL000VOm`2
0007Om`00`00Omaog005Om`00`00Omaog003Om`00`00Omaog00/Om`00`00Omaog005Om`00`00Omao
g008Om`01@00Omaog7oL00004goL00<007oLOm`057oL00<007oLOm`09goL00<007oLOm`01WoL0P00
1goL00<007oLOm`01GoL00<007oLOm`09GoL000XOm`00`00Omaog003Om`00`00Omaog005Om`00`00
Omaog005Om`00`00Omaog00[Om`00`00Omaog006Om`00`00Omaog007Om`01000Om`0000057oL00<0
07oLOm`057oL00<007oLOm`09goL00<007oLOm`027oL00<007oLOm`01GoL00<007oLOm`00goL00<0
07oLOm`09WoL000YOm`01@00Omaog7oL00001WoL0P002GoL00<007oLOm`0:GoL00<007oLOm`027oL
00<007oLOm`01goL00<007oLOm`057oL00<007oLOm`057oL00<007oLOm`09WoL00<007oLOm`02WoL
00<007oLOm`01GoL00<007oLOm`00P00:GoL000ZOm`40004Om`2000;Om`00`00Omaog00YOm`00`00
Omaog009Om`30004Om`3000FOm`00`00Omaog00DOm`00`00Omaog00VOm`00`00Omaog00;Om`40003
Om`3000[Om`002aog003001og00000<000iog003001og7oL02Mog003001og7oL00aog0D000=og003
001og7oL01=og003001og7oL011og0D002Mog003001og7oL011og0D002aog000;7oL00<007oLOm`0
4GoL00<007oLOm`09goL00<007oLOm`057oL00<007oLOm`057oL00<007oLOm`037oL0`0017oL0`00
9GoL00<007oLOm`057oL00<007oLOm`0:WoL000[Om`00`00Omaog00COm`00`00Omaog00VOm`00`00
Omaog00DOm`00`00Omaog00DOm`00`00Omaog00:Om`20007Om`00`00Omaog002000SOm`00`00Omao
g00DOm`00`00Omaog00ZOm`002]og003001og7oL01=og003001og7oL02Iog003001og7oL01Aog003
001og7oL01Eog003001og7oL00Qog003001og7oL00Iog003001og7oL00=og003001og7oL021og003
001og7oL01Aog003001og7oL02Yog000:goL00<007oLOm`057oL00<007oLOm`09GoL00<007oLOm`0
57oL00<007oLOm`05GoL00<007oLOm`027oL00<007oLOm`01GoL00<007oLOm`01GoL00<007oLOm`0
7goL00<007oLOm`057oL00<007oLOm`0:WoL000[Om`00`00Omaog00DOm`00`00Omaog00UOm`00`00
Omaog00DOm`00`00Omaog00FOm`00`00Omaog006Om`00`00Omaog006Om`00`00Omaog006Om`00`00
Omaog00NOm`00`00Omaog00DOm`00`00Omaog00ZOm`002]og003001og7oL01Aog003001og7oL02Eo
g003001og7oL01Aog003001og7oL01Mog003001og7oL00Eog003001og7oL00Aog08000Yog003001o
g7oL01Uog0X0015og003001og7oL02Yog000:goL00<007oLOm`057oL00<007oLOm`09WoL00<007oL
Om`04goL00<007oLOm`067oL0P0017oL00<007oLOm`00goL0P0037oL00<007oLOm`05goL0P0017oL
00<007oLOm`00goL0P003goL00<007oLOm`0:WoL000[Om`00`00Omaog00DOm`00`00Omaog00UOm`5
000AOm`00`00Omaog00KOm`20002Om`01000Omaog7oL0P003goL00<007oLOm`05GoL00<007oLOm`0
17oL00<007oLOm`01GoL00<007oLOm`02goL00<007oLOm`0:goL000[Om`00`00Omaog00DOm`00`00
Omaog00SOm`200000goL001og002Om`3000>Om`00`00Omaog00MOm`6000AOm`00`00Omaog00EOm`0
0`00Omaog005Om`00`00Omaog005Om`00`00Omaog00:Om`00`00Omaog00[Om`002]og003001og7oL
00mog0P0025og08000Aog003001og7oL00=og08000]og003001og7oL01mog003001og7oL01=og003
001og7oL01Aog003001og7oL00Mog003001og7oL00Eog003001og7oL00Qog003001og7oL02aog000
;7oL00<007oLOm`02goL0`0017oL00@007oLOmaog08001iog003001og7oL00Eog003001og7oL00Ao
g003001og7oL00Qog003001og7oL01iog003001og7oL01Eog003001og7oL01=og003001og7oL00Qo
g003001og7oL00Aog003001og7oL00Qog003001og7oL02aog000;GoL00<007oLOm`02GoL00<007oL
Om`017oL00<007oLOm`017oL00<007oLOm`06WoL00<007oLOm`01goL00<007oLOm`017oL00<007oL
Om`01GoL0P008GoL00<007oLOm`04goL1P004GoL00<007oLOm`02WoL00<007oLOm`017oL00<007oL
Om`01GoL0P00;goL000^Om`00`00Omaog007Om`00`00Omaog004Om`00`00Omaog006Om`00`00Omao
g00HOm`00`00Omaog009Om`20005Om`00`00Omaog002Om`2000SOm`00`00Omaog00AOm`20002Om`0
1000Omaog7oL0P003goL00<007oLOm`02goL0P0017oL00<007oLOm`00goL0P00<GoL000^Om`00`00
Omaog006Om`00`00Omaog004Om`00`00Omaog008Om`00`00Omaog00GOm`00`00Omaog00;Om`20004
Om`01000Om`000009GoL00<007oLOm`03goL0P000goL00<007oLOm`017oL0P0037oL00<007oLOm`0
3WoL0P000goL00<007oLOm`00P00<goL000_Om`20005Om`00`00Omaog003Om`2000;Om`00`00Omao
g00FOm`00`00Omaog00>Om`6000WOm`00`00Omaog00>Om`00`00Omaog003Om`00`00Omaog006Om`0
0`00Omaog003Om`7000BOm`6000eOm`0035og0<0009og003001og7oL00<000iog003001og7oL01Eo
g003001og7oL019og003001og7oL02Mog003001og7oL00aog003001og7oL00Aog003001og7oL00Io
g004001og7oLOm`20005Om`4000DOm`00`00Omaog00dOm`003Aog0D0015og003001og7oL01Aog003
001og7oL01=og003001og7oL02Mog003001og7oL00]og003001og7oL00Eog003001og7oL00Mog0<0
00Mog005001og7oLOm`0000COm`00`00Omaog00dOm`003Eog003001og7oL01=og003001og7oL01=o
g003001og7oL01=og003001og7oL02Qog003001og7oL00Yog003001og7oL00Eog003001og7oL00Mo
g003001og00000Mog003001og7oL009og080015og003001og7oL03Aog000=7oL00<007oLOm`057oL
00<007oLOm`04goL00<007oLOm`057oL00<007oLOm`09goL00<007oLOm`02GoL00<007oLOm`017oL
0P002WoL00<007oL000027oL00<007oLOm`00goL00<007oLOm`03WoL00<007oLOm`0=7oL000dOm`0
0`00Omaog00DOm`00`00Omaog00COm`00`00Omaog00DOm`00`00Omaog00XOm`00`00Omaog008Om`0
0`00Omaog003Om`00`00Omaog009Om`01@00Omaog7oL00001goL00<007oLOm`00goL00<007oLOm`0
3WoL00<007oLOm`0=7oL000dOm`00`00Omaog00DOm`00`00Omaog00COm`00`00Omaog00DOm`00`00
Omaog00YOm`00`00Omaog006Om`00`00Omaog003Om`00`00Omaog009Om`00`00Omaog002Om`00`00
Omaog005Om`00`00Omaog004Om`00`00Omaog00=Om`00`00Omaog00dOm`003Aog003001og7oL01Ao
g003001og7oL00mog0P001=og003001og7oL02Yog08000Iog004001og7oLOm`2000;Om`00`00Omao
g003Om`00`00Omaog005Om`00`00Omaog004Om`00`00Omaog00<Om`00`00Omaog00eOm`003Aog003
001og7oL019og0X000Iog0@000Aog004001og7oLOm`2000AOm`00`00Omaog00/Om`500000goL001o
g002000=Om`00`00Omaog003Om`00`00Omaog006Om`00`00Omaog004Om`00`00Omaog00;Om`00`00
Omaog00eOm`003Aog003001og7oL011og080009og003001og7oL00Eog08000Aog003001og7oL00Eo
g003001og7oL00=og003001og7oL00eog003001og7oL039og0<000mog003001og7oL00=og003001o
g7oL00Mog003001og7oL00=og003001og7oL00Yog003001og7oL03Iog000=GoL00<007oLOm`03goL
00D007oLOmaog00000Uog004001og7oL0008Om`00`00Omaog003Om`00`00Omaog00=Om`00`00Omao
g00cOm`00`00Omaog00>Om`00`00Omaog003Om`00`00Omaog008Om`00`00Omaog003Om`00`00Omao
g008Om`00`00Omaog00gOm`003Eog003001og7oL00iog003001og7oL009og003001og7oL00Mog003
001og00000Yog003001og7oL00=og003001og7oL00aog003001og7oL03=og003001og7oL00eog003
001og7oL00Aog003001og7oL00Qog003001og7oL00=og003001og7oL00Iog08003Yog000=GoL00<0
07oLOm`03GoL00<007oLOm`00WoL00<007oLOm`02GoL00<007oLOm`02WoL00<007oLOm`00goL00<0
07oLOm`02GoL0P00=WoL00<007oLOm`03GoL00<007oLOm`017oL00<007oLOm`02GoL0P000goL00<0
07oLOm`017oL0P00?7oL000fOm`00`00Omaog00;Om`00`00Omaog002Om`00`00Omaog00:Om`2000<
Om`00`00Omaog003Om`00`00Omaog007Om`00`00Omaog00fOm`00`00Omaog00=Om`00`00Omaog003
Om`00`00Omaog00<Om`200000goL001og003Om`2000nOm`003Iog003001og7oL00]og003001og7oL
009og003001og7oL00Uog004001og7oL000<Om`00`00Omaog002Om`00`00Omaog007Om`00`00Omao
g00fOm`00`00Omaog00=Om`00`00Omaog003Om`00`00Omaog00>Om`60010Om`003Mog08000Yog004
001og7oLOm`2000<Om`01000Omaog0003GoL00D007oLOmaog00000Mog08003Yog003001og7oL00ao
g003001og7oL00=og003001og7oL00iog003001og7oL04=og000>GoL0P0027oL00@007oL000000eo
g003001og7oL009og003001og7oL00]og0D000Aog08003eog003001og7oL00aog005001og7oLOm`0
000AOm`00`00Omaog013Om`003]og08000Eog0<000mog003001og7oL009og003001og7oL00mog0D0
041og003001og7oL00]og004001og7oL000BOm`00`00Omaog013Om`003eog0H0015og003001og7oL
009og003001og7oL00mog003001og7oL04=og003001og7oL00]og080019og003001og7oL04Aog000
@WoL00<007oLOm`03goL00<007oLOm`00WoL00<007oLOm`03goL00<007oLOm`0A7oL0P002WoL0P00
4WoL00<007oLOm`0AGoL0012Om`00`00Omaog00?Om`00`00Omaog002Om`00`00Omaog00?Om`00`00
Omaog016Om`40004Om`20002Om`2000?Om`00`00Omaog016Om`0049og003001og7oL00mog003001o
g7oL009og003001og7oL00mog003001og7oL04Yog0@000Iog003001og7oL00]og003001og7oL04Mo
g000@WoL00<007oLOm`03goL00<007oLOm`00WoL00<007oLOm`03goL00<007oLOm`0EGoL00<007oL
Om`027oL0P00BWoL0012Om`00`00Omaog00?Om`00`00Omaog002Om`00`00Omaog00>Om`00`00Omao
g01GOm`500000goL00000002001<Om`0049og003001og7oL00mog005001og7oLOm`0000AOm`00`00
Omaog01LOm`00`00Omaog01>Om`0049og003001og7oL011og004001og7oL000@Om`00`00Omaog02^
Om`004=og003001og7oL011og080011og003001og7oL0:mog000A7oL00<007oLOm`03goL0P003goL
00<007oLOm`0/7oL0015Om`2000>Om`00`00Omaog002000;Om`2002cOm`004Mog08000Yog08000Eo
g0<000Iog0800;Eog000BGoL0P001WoL0P002WoL1P00]goL001;Om`60039Om`00?mog1]og000ogoL
6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`0
0?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL
6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`0
0?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL6goL003oOm`KOm`00?mog1]og000ogoL
6goL003oOm`KOm`00?mog1]og000ogoL6goL0000\
\>"],
  ImageRangeCache->{{{0, 281}, {187, 0}} -> {-0.00539266, -1.00002, \
0.0213907, 0.0213907}}],

Cell["Quoting from Lasseter: ", "Text"],

Cell["\<\
If the bottom drawing is flattened, it gives the appearance of \
bouncing.  Elongating the drawings before and after the bounce increases the \
sense of speed, makes it easier to follow and gives more snap to the \
action.\
\>", "IndentedText",
  CellMargins->{{Inherited, 13.625}, {Inherited, Inherited}}],

Cell["\<\
To produce an animation of a bouncing ball we can use our ability \
to find equally spaced points along a spline path to produce a constant speed \
traversal of the path:  each point corresponding to one frame of the action.  \
We can use those points to animate the ball along the chosen path.  We can \
then modify the picture in the frames close to the bounce point, again \
interpolating between the parametric values that control the picture (in this \
case the parameters are the major and minor axes of the ellipse used and the \
angle of rotation of the ellipse)  to produce a constant speed, squashed and \
stretched version of a constant speed bouncing ball.  Finally, by omitting \
some frames we can increase the apparent speed in some segments of the \
animation (or decrease the speed in the other segments, it all depends on \
your point of view), producing a slow in, slow out version of the squashed \
and stretched bouncing ball.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Pick a Path", "Subsubsection"],

Cell[TextData[{
  "We assume the ball bounces from left to right.  We assume the ball looses \
some energy when it bounces so the second high point is not as high as the \
first high point.  We only model one piece of the path.  We pick ",
  Cell[BoxData[
      \(5\)]],
  " key frame positions, centered at  ",
  Cell[BoxData[
      \(\((1, 1)\), \ \((2, 2)\), \ \((3, 0)\), \ \((4, 1.8)\), \)]],
  " and ",
  Cell[BoxData[
      \(\((5, 1)\)\)]],
  ", with ",
  Cell[BoxData[
      \(\((3, 0)\)\)]],
  " being the bounce point.  We sketch the lerp of these ",
  Cell[BoxData[
      \(5\)]],
  " points."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.181406 0.0566893 0.181406 [
[.20522 .04419 -3 -9 ]
[.20522 .04419 3 0 ]
[.38662 .04419 -3 -9 ]
[.38662 .04419 3 0 ]
[.56803 .04419 -3 -9 ]
[.56803 .04419 3 0 ]
[.74943 .04419 -3 -9 ]
[.74943 .04419 3 0 ]
[.93084 .04419 -3 -9 ]
[.93084 .04419 3 0 ]
[.01131 .14739 -18 -4.5 ]
[.01131 .14739 0 4.5 ]
[.01131 .2381 -6 -4.5 ]
[.01131 .2381 0 4.5 ]
[.01131 .3288 -18 -4.5 ]
[.01131 .3288 0 4.5 ]
[.01131 .4195 -6 -4.5 ]
[.01131 .4195 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20522 .05669 m
.20522 .06294 L
s
[(1)] .20522 .04419 0 1 Mshowa
.38662 .05669 m
.38662 .06294 L
s
[(2)] .38662 .04419 0 1 Mshowa
.56803 .05669 m
.56803 .06294 L
s
[(3)] .56803 .04419 0 1 Mshowa
.74943 .05669 m
.74943 .06294 L
s
[(4)] .74943 .04419 0 1 Mshowa
.93084 .05669 m
.93084 .06294 L
s
[(5)] .93084 .04419 0 1 Mshowa
.125 Mabswid
.06009 .05669 m
.06009 .06044 L
s
.09637 .05669 m
.09637 .06044 L
s
.13265 .05669 m
.13265 .06044 L
s
.16893 .05669 m
.16893 .06044 L
s
.2415 .05669 m
.2415 .06044 L
s
.27778 .05669 m
.27778 .06044 L
s
.31406 .05669 m
.31406 .06044 L
s
.35034 .05669 m
.35034 .06044 L
s
.4229 .05669 m
.4229 .06044 L
s
.45918 .05669 m
.45918 .06044 L
s
.49546 .05669 m
.49546 .06044 L
s
.53175 .05669 m
.53175 .06044 L
s
.60431 .05669 m
.60431 .06044 L
s
.64059 .05669 m
.64059 .06044 L
s
.67687 .05669 m
.67687 .06044 L
s
.71315 .05669 m
.71315 .06044 L
s
.78571 .05669 m
.78571 .06044 L
s
.822 .05669 m
.822 .06044 L
s
.85828 .05669 m
.85828 .06044 L
s
.89456 .05669 m
.89456 .06044 L
s
.96712 .05669 m
.96712 .06044 L
s
.25 Mabswid
0 .05669 m
1 .05669 L
s
.02381 .14739 m
.03006 .14739 L
s
[(0.5)] .01131 .14739 1 0 Mshowa
.02381 .2381 m
.03006 .2381 L
s
[(1)] .01131 .2381 1 0 Mshowa
.02381 .3288 m
.03006 .3288 L
s
[(1.5)] .01131 .3288 1 0 Mshowa
.02381 .4195 m
.03006 .4195 L
s
[(2)] .01131 .4195 1 0 Mshowa
.125 Mabswid
.02381 .07483 m
.02756 .07483 L
s
.02381 .09297 m
.02756 .09297 L
s
.02381 .11111 m
.02756 .11111 L
s
.02381 .12925 m
.02756 .12925 L
s
.02381 .16553 m
.02756 .16553 L
s
.02381 .18367 m
.02756 .18367 L
s
.02381 .20181 m
.02756 .20181 L
s
.02381 .21995 m
.02756 .21995 L
s
.02381 .25624 m
.02756 .25624 L
s
.02381 .27438 m
.02756 .27438 L
s
.02381 .29252 m
.02756 .29252 L
s
.02381 .31066 m
.02756 .31066 L
s
.02381 .34694 m
.02756 .34694 L
s
.02381 .36508 m
.02756 .36508 L
s
.02381 .38322 m
.02756 .38322 L
s
.02381 .40136 m
.02756 .40136 L
s
.02381 .03855 m
.02756 .03855 L
s
.02381 .02041 m
.02756 .02041 L
s
.02381 .00227 m
.02756 .00227 L
s
.02381 .43764 m
.02756 .43764 L
s
.02381 .45578 m
.02756 .45578 L
s
.02381 .47392 m
.02756 .47392 L
s
.25 Mabswid
.02381 0 m
.02381 .47619 L
s
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
.5 Mabswid
.20522 .2381 m
.38662 .4195 L
.56803 .05669 L
.74943 .38322 L
.93084 .2381 L
s
newpath
.20522 .2381 .04535 0 365.73 arc
s
newpath
.38662 .4195 .04535 0 365.73 arc
s
newpath
.56803 .05669 .04535 0 365.73 arc
s
newpath
.74943 .38322 .04535 0 365.73 arc
s
newpath
.93084 .2381 .04535 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{358.25, 170.5},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005V0000ZQ000`40O003h00OogoLIgoL003oOmaW
Om`00?mog6Mog0005WoL00<007oLOm`0ogoLCWoL000FOm`2003oOma?Om`001Iog003001og7oL0?mo
g4iog0005WoL00<007oLOm`0ogoLCWoL000FOm`00`00Omaog02dOm`8002AOm`001Iog003001og7oL
0;9og08000Qog0<008iog0005WoL00<007oLOm`0[goL0`003GoL0P00S7oL000FOm`2000jOm`3000j
Om`5000cOm`00`00Omaog005Om`30008Om`00`00Omaog00aOm`3000jOm`3000HOm`001Iog003001o
g7oL03Yog003001og7oL03Yog004001og7oL000bOm`00`00Omaog005Om`01@00Omaog7oL00001goL
00<007oLOm`0<WoL00<007oLOm`0>7oL00D007oLOmaog00001Mog0005WoL00<007oLOm`0>WoL00<0
07oLOm`0>goL00<007oLOm`0<GoL00<007oLOm`02WoL00<007oLOm`01WoL00<007oLOm`0;WoL1@00
?GoL00<007oLOm`05GoL000FOm`00`00Omaog00jOm`00`00Omaog00lOm`00`00Omaog00_Om`00`00
Omaog009Om`2000:Om`00`00Omaog00]Om`01000Omaog000?WoL00<007oLOm`05GoL000FOm`00`00
Omaog00jOm`00`00Omaog00iOm`01@00Omaog7oL0000<7oL00<007oLOm`02goL00<007oLOm`027oL
00<007oLOm`0;GoL00<007oL0000>WoL100067oL000FOm`00`00Omaog00iOm`2000kOm`01@00Omao
g7oL0000;goL00<007oLOm`027oL00D007oLOmaog00000]og003001og7oL02eog08003Yog003001o
g7oL01Uog0005WoL0P00>goL00<007oLOm`0>WoL0`00<7oL00<007oLOm`02GoL0`0037oL00<007oL
Om`0;WoL00<007oLOm`0>7oL1@005goL000FOm`00`00Omaog02ZOm`00`00Omaog00IOm`00`00Omao
g024Om`001Iog003001og7oL0:Uog003001og7oL01Yog003001og7oL08Aog0005WoL00<007oLOm`0
Z7oL00<007oLOm`077oL00<007oLOm`0PgoL000FOm`00`00Omaog02XOm`00`00Omaog00LOm`00`00
Omaog023Om`001Iog003001og7oL0:Qog003001og7oL01aog003001og7oL08=og0005WoL00<007oL
Om`0Z7oL00<007oLOm`077oL00<007oLOm`0PgoL000>Omco001I000001Iog003001og7oL00Uog003
001og7oL00Yog003001og7oL00Uog003001og7oL00Yog003001og7oL00Uog003001og7oL00Uog003
001og7oL00Yog003001og7oL00Uog003001og7oL00Yog003001og7oL00Uog003001og7oL00Yog003
001og7oL00Uog003001og7oL00Yog003001og7oL00Iog004001og7oL000<Om`00`00Omaog009Om`0
1000Omaog00027oL00<007oLOm`02WoL00<007oLOm`02GoL00<007oLOm`02WoL00<007oLOm`02GoL
00<007oLOm`02WoL00<007oLOm`02GoL00<007oLOm`02WoL00<007oLOm`02GoL00<007oLOm`02GoL
00<007oLOm`02WoL000FOm`00`00Omaog00kOm`00`00Omaog00kOm`00`00Omaog00/Om`00`00Omao
g00<Om`3000=Om`00`00Omaog00/Om`00`00Omaog00kOm`00`00Omaog00FOm`001Iog003001og7oL
0:Qog003001og7oL00aog003001og00000eog003001og7oL08=og0005WoL00<007oLOm`0ZGoL00<0
07oLOm`02WoL00D007oLOmaog00000aog003001og7oL08=og0005WoL00<007oLOm`0ZGoL00<007oL
Om`02WoL00D007oLOmaog00000]og003001og7oL08Aog0005WoL0P00ZWoL00<007oLOm`02GoL00<0
07oLOm`00goL00<007oLOm`027oL00<007oLOm`0Q7oL000FOm`00`00Omaog02ZOm`00`00Omaog008
Om`00`00Omaog004Om`00`00Omaog006Om`00`00Omaog025Om`001Iog003001og7oL0:Yog003001o
g7oL00Mog003001og7oL00Eog003001og7oL00Eog003001og7oL08Iog0005WoL00<007oLOm`0ZgoL
00<007oLOm`01WoL00<007oLOm`01WoL00<007oLOm`017oL00<007oLOm`0QWoL000FOm`00`00Omao
g02/Om`00`00Omaog004Om`00`00Omaog007Om`00`00Omaog003Om`00`00Omaog027Om`001Iog003
001og7oL0:eog003001og7oL00=og003001og7oL00Qog005001og7oLOm`0002:Om`001Iog0800:mo
g080009og003001og7oL00Uog004001og7oL002;Om`001Iog003001og7oL0;1og003001og00000ao
g08008aog0005WoL00<007oLOm`0/GoL0`0027oL1000SGoL000FOm`00`00Omaog02aOm`00`00Omao
g0080004Om`00`00Omaog02:Om`001Iog003001og7oL0;1og003001og7oL00iog003001og7oL08Uo
g0005WoL00<007oLOm`0/7oL00<007oLOm`03WoL00<007oLOm`0RGoL000FOm`2002`Om`00`00Omao
g00@Om`00`00Omaog028Om`001Iog003001og7oL0:mog003001og7oL011og003001og7oL08Qog000
5WoL00<007oLOm`0[WoL00<007oLOm`04WoL00<007oLOm`0QgoL000FOm`00`00Omaog02^Om`00`00
Omaog00BOm`00`00Omaog027Om`001Iog003001og7oL0:eog003001og7oL01Aog003001og7oL08Io
g0005WoL00<007oLOm`0[GoL00<007oLOm`057oL00<007oLOm`0QWoL000FOm`2002]Om`00`00Omao
g00FOm`00`00Omaog025Om`001Iog003001og7oL0:aog003001og7oL01Mog003001og7oL08Aog000
5WoL00<007oLOm`0ZgoL00<007oLOm`067oL00<007oLOm`0Q7oL000FOm`00`00Omaog02[Om`00`00
Omaog00IOm`00`00Omaog023Om`0009og08000Aog003001og7oL009og0<000Iog003001og7oL0:Yo
g003001og7oL01Yog003001og7oL08=og00000Eog000Omaog00000Mog005001og7oLOm`00005Om`0
0`00Omaog02ZOm`00`00Omaog00KOm`00`00Omaog022Om`00005Om`007oLOm`0000;Om`00`00Omao
g003Om`00`00Omaog02YOm`00`00Omaog00LOm`00`00Omaog022Om`00005Om`007oLOm`0000;Om`0
0`00Omaog003Om`3002YOm`00`00Omaog00MOm`00`00Omaog021Om`00005Om`007oLOm`00007Om`4
0006Om`00`00Omaog02XOm`00`00Omaog00NOm`00`00Omaog021Om`00005Om`007oLOm`00007Om`0
0`00Omaog007Om`00`00Omaog02WOm`00`00Omaog00POm`00`00Omaog020Om`0009og08000Qog0D0
00Eog003001og7oL0:Mog003001og7oL025og003001og7oL07mog0005WoL00<007oLOm`0YWoL00<0
07oLOm`08WoL00<007oLOm`0OgoL000FOm`00`00Omaog02VOm`00`00Omaog00SOm`00`00Omaog01n
Om`001Iog0800:Iog003001og7oL02Aog003001og7oL07iog0005WoL00<007oLOm`0YGoL00<007oL
Om`09GoL00<007oLOm`0OGoL000FOm`00`00Omaog02TOm`00`00Omaog00VOm`00`00Omaog01mOm`0
01Iog003001og7oL0:Aog003001og7oL02Mog003001og7oL07aog0005WoL00<007oLOm`0XgoL00<0
07oLOm`0:7oL00<007oLOm`0O7oL000FOm`00`00Omaog02SOm`00`00Omaog00YOm`00`00Omaog01k
Om`001Iog0800:=og003001og7oL02]og003001og7oL07Yog0005WoL00<007oLOm`0XWoL00<007oL
Om`0:goL00<007oLOm`0NWoL000FOm`00`00Omaog02QOm`00`00Omaog00]Om`00`00Omaog01iOm`0
01Iog003001og7oL03Uog0H0069og003001og7oL02eog003001og7oL05iog0H001Eog0005WoL00<0
07oLOm`0=GoL10001WoL0`00GWoL00<007oLOm`0;goL00<007oLOm`0FGoL10001WoL0`004WoL000F
Om`00`00Omaog00cOm`2000=Om`2001LOm`00`00Omaog00_Om`00`00Omaog01GOm`2000=Om`2000@
Om`001Iog08003=og003001og7oL00mog003001og7oL05Qog003001og7oL035og003001og7oL05Eo
g003001og7oL00mog003001og7oL00eog0005WoL00<007oLOm`0<GoL00<007oLOm`04GoL00<007oL
Om`0EgoL00<007oLOm`0<GoL00<007oLOm`0E7oL00<007oLOm`04GoL00<007oLOm`037oL000FOm`0
0`00Omaog00`Om`00`00Omaog00COm`00`00Omaog01EOm`00`00Omaog00cOm`00`00Omaog01BOm`0
0`00Omaog00COm`00`00Omaog00;Om`001Iog003001og7oL02mog003001og7oL01Eog003001og7oL
05Aog003001og7oL03Aog003001og7oL051og003001og7oL01Eog003001og7oL00Yog0005WoL00<0
07oLOm`0;goL00<007oLOm`05WoL00<007oLOm`0DWoL00<007oLOm`0=GoL00<007oLOm`0D7oL00<0
07oLOm`05WoL00<007oLOm`02GoL000FOm`00`00Omaog00^Om`00`00Omaog00HOm`00`00Omaog01A
Om`00`00Omaog00fOm`00`00Omaog01>Om`00`00Omaog00HOm`00`00Omaog008Om`001Iog003001o
g7oL02eog003001og7oL01Uog003001og7oL051og003001og7oL03Mog003001og7oL04eog003001o
g7oL01Uog003001og7oL00Qog0005WoL0P00;WoL00<007oLOm`06WoL00<007oLOm`0CgoL00<007oL
Om`0>7oL00<007oLOm`0C7oL00<007oLOm`06WoL00<007oLOm`01goL000FOm`00`00Omaog00/Om`0
0`00Omaog00KOm`00`00Omaog01>Om`00`00Omaog00iOm`00`00Omaog01;Om`00`00Omaog00KOm`0
0`00Omaog007Om`001Iog003001og7oL02aog003001og7oL01]og003001og7oL04iog003001og7oL
03Yog003001og7oL04Yog003001og7oL01]og003001og7oL00Mog0003GoL0`001WoL00<007oLOm`0
;7oL00<007oLOm`06goL00<007oLOm`0CGoL00<007oLOm`0>goL00<007oLOm`0BWoL00<007oLOm`0
6goL00<007oLOm`01goL000>Om`00`00Omaog005Om`00`00Omaog00/Om`00`00Omaog00LOm`00`00
Omaog01<Om`00`00Omaog00lOm`00`00Omaog019Om`00`00Omaog00LOm`00`00Omaog006Om`000io
g003001og7oL00Eog003001og7oL02]og003001og7oL01eog003001og7oL04]og003001og7oL03eo
g003001og7oL04Qog003001og7oL01eog003001og7oL00Iog0003WoL00<007oLOm`01GoL0`00:goL
00<007oLOm`03GoL00<007oLOm`03GoL00<007oLOm`0BgoL00<007oLOm`0?WoL00<007oLOm`0AgoL
00<007oLOm`037oL0P003goL00<007oLOm`01WoL000>Om`00`00Omaog005Om`00`00Omaog00[Om`0
0`00Omaog00>Om`00`00Omaog00<Om`00`00Omaog01:Om`00`00Omaog010Om`00`00Omaog016Om`0
0`00Omaog00;Om`00`00Omaog00?Om`00`00Omaog006Om`000eog08000Mog003001og7oL02aog003
001og7oL00iog003001og7oL00]og003001og7oL04Yog003001og7oL041og003001og7oL04Mog003
001og7oL00Uog003001og7oL011og003001og7oL00Iog0003WoL00<007oLOm`01GoL00<007oLOm`0
;7oL00<007oLOm`03goL00<007oLOm`02GoL00<007oLOm`0BWoL00<007oLOm`0@WoL00<007oLOm`0
AWoL00<007oLOm`027oL00<007oLOm`047oL00<007oLOm`01goL000FOm`00`00Omaog00/Om`00`00
Omaog00@Om`00`00Omaog008Om`00`00Omaog01:Om`00`00Omaog012Om`00`00Omaog016Om`00`00
Omaog006Om`2000COm`00`00Omaog007Om`001Iog003001og7oL02aog003001og7oL015og003001o
g7oL00Iog003001og7oL04Yog003001og7oL04Aog003001og7oL04Eog003001og7oL00Eog003001o
g7oL019og003001og7oL00Qog0005WoL0P00;GoL00<007oLOm`04WoL00<007oLOm`01GoL00<007oL
Om`0BWoL00<007oLOm`0A7oL00<007oLOm`0AGoL00<007oLOm`017oL00<007oLOm`04goL00<007oL
Om`027oL000FOm`00`00Omaog00]Om`00`00Omaog00BOm`00`00Omaog004Om`00`00Omaog019Om`0
0`00Omaog016Om`00`00Omaog015Om`00`00Omaog002Om`00`00Omaog00DOm`00`00Omaog008Om`0
01Iog003001og7oL02iog003001og7oL019og003001og7oL009og003001og7oL04Yog003001og7oL
04Iog003001og7oL04Iog004001og000000FOm`00`00Omaog009Om`001Iog003001og7oL02mog003
001og7oL019og005001og7oLOm`0001;Om`00`00Omaog018Om`00`00Omaog016Om`00`00Omaog00F
Om`00`00Omaog009Om`001Iog003001og7oL031og003001og7oL019og003001og00004aog003001o
g7oL04Uog003001og7oL04Aog003001og00001Iog003001og7oL00Yog0005WoL00<007oLOm`0<GoL
00<007oLOm`04GoL0P00C7oL00<007oLOm`0BWoL00<007oLOm`0@goL00D007oLOmaog00001=og080
00eog0005WoL0P00<goL0P0047oL00@007oLOm`004]og003001og7oL04]og003001og7oL041og080
00Eog080011og003001og7oL00eog0005WoL00<007oLOm`0=7oL00<007oLOm`02goL0P0017oL00<0
07oLOm`0AgoL00<007oLOm`0C7oL00<007oLOm`0?goL00<007oLOm`01goL00<007oLOm`02goL0P00
47oL000FOm`00`00Omaog00eOm`30008Om`20007Om`00`00Omaog016Om`00`00Omaog01=Om`00`00
Omaog00mOm`00`00Omaog009Om`30008Om`2000BOm`001Iog003001og7oL03Qog0P000Yog003001o
g7oL04Aog003001og7oL04iog003001og7oL03aog003001og7oL00eog0P001Aog0005WoL00<007oL
Om`0BgoL00<007oLOm`0@goL00<007oLOm`0CgoL00<007oLOm`0>WoL00<007oLOm`0:WoL000FOm`0
0`00Omaog01<Om`00`00Omaog011Om`00`00Omaog01@Om`00`00Omaog00hOm`2000]Om`001Iog080
04iog003001og7oL041og003001og7oL055og003001og7oL03Iog003001og7oL02eog0005WoL00<0
07oLOm`0CWoL00<007oLOm`0?WoL00<007oLOm`0DgoL00<007oLOm`0=7oL00<007oLOm`0;WoL000F
Om`00`00Omaog01?Om`00`00Omaog00mOm`00`00Omaog01COm`00`00Omaog00cOm`00`00Omaog00_
Om`001Iog003001og7oL051og003001og7oL03]og003001og7oL05Eog003001og7oL031og080039o
g0005WoL00<007oLOm`0DGoL00<007oLOm`0>WoL00<007oLOm`0EGoL00<007oLOm`0;goL00<007oL
Om`0<WoL000FOm`00`00Omaog01BOm`00`00Omaog00hOm`00`00Omaog01GOm`00`00Omaog00]Om`0
0`00Omaog00cOm`001Iog003001og7oL05=og003001og7oL03Mog003001og7oL05Mog003001og7oL
02aog003001og7oL03Aog0005WoL0P00EGoL00<007oLOm`0=GoL00<007oLOm`0FGoL00<007oLOm`0
:GoL0P00=goL000FOm`00`00Omaog01EOm`00`00Omaog00dOm`00`00Omaog01IOm`00`00Omaog00X
Om`00`00Omaog00gOm`001Iog003001og7oL05Iog003001og7oL039og003001og7oL05]og003001o
g7oL02Iog003001og7oL03Qog00000Aog000000000Aog003001og7oL009og0<000Iog003001og7oL
05Mog003001og7oL035og003001og7oL05aog003001og7oL02Aog003001og7oL03Uog0000WoL00<0
07oLOm`01goL00D007oLOmaog00000Eog003001og7oL05Qog003001og7oL02mog003001og7oL05eo
g003001og7oL029og08003aog0000WoL00<007oLOm`02goL00<007oLOm`00goL00<007oLOm`0FGoL
00<007oLOm`0;WoL00<007oLOm`0GWoL00<007oLOm`087oL00<007oLOm`0?7oL0002Om`00`00Omao
g00;Om`00`00Omaog003Om`3001JOm`00`00Omaog00/Om`00`00Omaog01OOm`00`00Omaog00OOm`0
0`00Omaog00mOm`0009og003001og7oL00Mog0@000Iog003001og7oL05]og003001og7oL02Yog003
001og7oL065og003001og7oL01eog003001og7oL03iog00000=og00000002GoL00<007oLOm`01goL
00<007oLOm`0G7oL00<007oLOm`0:GoL00<007oLOm`0HGoL00<007oLOm`06goL0P00@GoL0002Om`0
0`00Omaog007Om`50005Om`00`00Omaog01MOm`00`00Omaog00WOm`00`00Omaog01SOm`00`00Omao
g002Om`8000?Om`00`00Omaog011Om`001Iog003001og7oL05iog003001og7oL02Iog003001og7oL
06=og003001og7oL008000Qog0<000]og003001og7oL049og0005WoL00<007oLOm`0GgoL00<007oL
Om`097oL00<007oLOm`0I7oL0`003GoL0P0027oL00<007oLOm`0@goL000FOm`2001QOm`00`00Omao
g00SOm`00`00Omaog01SOm`01000Omaog0003goL00<007oLOm`00goL0P00AWoL000FOm`00`00Omao
g01QOm`00`00Omaog00QOm`00`00Omaog01SOm`01@00Omaog7oL000047oL00D007oLOmaog00004Qo
g0005WoL00<007oLOm`0HWoL00<007oLOm`087oL00<007oLOm`0HWoL00<007oLOm`00goL00<007oL
Om`03WoL00<007oL0000BGoL000FOm`00`00Omaog01SOm`00`00Omaog00NOm`00`00Omaog01ROm`0
0`00Omaog004Om`00`00Omaog00?Om`00`00Omaog018Om`001Iog003001og7oL06Aog003001og7oL
01eog003001og7oL069og003001og7oL00Eog003001og7oL00eog08004Yog0005WoL00<007oLOm`0
IGoL00<007oLOm`06goL00<007oLOm`0HWoL00<007oLOm`01WoL00<007oLOm`02goL0P000WoL00<0
07oLOm`0AgoL000FOm`2001WOm`00`00Omaog00JOm`00`00Omaog01ROm`00`00Omaog007Om`00`00
Omaog009Om`00`00Omaog002Om`00`00Omaog017Om`001Iog003001og7oL06Mog003001og7oL01Qo
g003001og7oL06=og003001og7oL00Mog003001og7oL00Qog003001og7oL00Aog003001og7oL04Io
g0005WoL00<007oLOm`0J7oL00<007oLOm`05goL00<007oLOm`0HWoL00<007oLOm`02GoL00<007oL
Om`01WoL00<007oLOm`01WoL00<007oLOm`0AGoL000FOm`00`00Omaog01YOm`00`00Omaog00<Om`4
0005Om`00`00Omaog01SOm`00`00Omaog00:Om`00`00Omaog003Om`20009Om`00`00Omaog015Om`0
01Iog003001og7oL06Yog003001og7oL00Mog0@000Aog0@00003Om`007oL06=og003001og7oL00]o
g003001og7oL009og003001og7oL00Uog003001og7oL04Eog0005WoL00<007oLOm`0JgoL00<007oL
Om`01GoL00<007oLOm`02WoL0P00I7oL00<007oLOm`037oL00@007oLOm`000aog003001og7oL04Eo
g0005WoL00<007oLOm`0K7oL00<007oLOm`00WoL0P003GoL00<007oL0000HgoL00<007oLOm`037oL
00<007oL00003GoL00<007oLOm`0AGoL000FOm`2001^Om`01000Om`000003WoL00D007oLOmaog000
069og003001og7oL00eog003001og7oL00aog003001og7oL04Eog0005WoL00<007oLOm`0KWoL0P00
3goL00<007oLOm`00WoL00<007oLOm`0GgoL00<007oLOm`077oL00<007oLOm`0AGoL000FOm`00`00
Omaog01^Om`2000>Om`00`00Omaog004Om`00`00Omaog01NOm`00`00Omaog00LOm`00`00Omaog015
Om`001Iog003001og7oL06eog004001og7oL000=Om`00`00Omaog004Om`00`00Omaog01NOm`00`00
Omaog00LOm`00`00Omaog015Om`001Iog003001og7oL06aog003001og7oL009og003001og7oL00Uo
g003001og7oL00Iog003001og7oL05iog003001og7oL01]og003001og7oL04Eog0005WoL00<007oL
Om`0JgoL00<007oLOm`017oL00<007oLOm`027oL00<007oLOm`01goL00<007oLOm`0GGoL00<007oL
Om`06WoL00<007oLOm`0AWoL000FOm`2001/Om`00`00Omaog005Om`00`00Omaog006Om`00`00Omao
g008Om`00`00Omaog01MOm`00`00Omaog00JOm`00`00Omaog016Om`001Iog003001og7oL06Yog003
001og7oL00Mog003001og7oL00Eog003001og7oL00Uog003001og7oL05eog003001og7oL01Uog003
001og7oL04Iog0005WoL00<007oLOm`0JWoL00<007oLOm`027oL00<007oLOm`00goL00<007oLOm`0
2WoL00<007oLOm`0GGoL00<007oLOm`067oL00<007oLOm`0AgoL000<Om`50005Om`00`00Omaog01Z
Om`00`00Omaog009Om`00`00Omaog002Om`00`00Omaog00;Om`00`00Omaog01MOm`00`00Omaog00G
Om`00`00Omaog017Om`000eog004001og7oL0005Om`00`00Omaog01ZOm`00`00Omaog00:Om`01000
Omaog0003WoL00<007oLOm`0GWoL0P005WoL00<007oLOm`0B7oL000>Om`00`00Omaog005Om`00`00
Omaog01ZOm`00`00Omaog00;Om`00`00Om`0000>Om`00`00Omaog01POm`00`00Omaog00AOm`2001;
Om`000mog003001og7oL00Aog0<006Yog003001og7oL00aog003001og7oL00eog003001og7oL065o
g003001og7oL00mog003001og7oL04]og00037oL00D007oLOmaog00000Eog003001og7oL06Yog003
001og7oL01aog003001og7oL069og003001og7oL00aog08004iog00037oL00D007oLOmaog00000Eo
g003001og7oL06Yog003001og7oL01aog003001og7oL06=og0<000Qog0<0051og0003GoL0`001WoL
00<007oLOm`0JWoL00<007oLOm`077oL00<007oLOm`0IWoL2000DgoL000FOm`00`00Omaog01[Om`0
0`00Omaog00KOm`00`00Omaog031Om`001Iog003001og7oL06]og003001og7oL01Yog003001og7oL
0<9og0005WoL0P00K7oL00<007oLOm`06WoL00<007oLOm`0`WoL000FOm`00`00Omaog01/Om`00`00
Omaog00IOm`00`00Omaog032Om`001Iog003001og7oL06aog003001og7oL01Qog003001og7oL0<=o
g0005WoL00<007oLOm`0K7oL00<007oLOm`05goL00<007oLOm`0a7oL000FOm`00`00Omaog01]Om`0
0`00Omaog00EOm`00`00Omaog035Om`001Iog003001og7oL06iog003001og7oL01=og003001og7oL
0<Iog0005WoL0P00L7oL00<007oLOm`04GoL00<007oLOm`0agoL000FOm`00`00Omaog01`Om`3000>
Om`2003:Om`001Iog003001og7oL07=og0<000Qog0<00<aog0005WoL00<007oLOm`0MWoL0`000WoL
0`00cgoL000FOm`00`00Omaog01iOm`2003BOm`001Iog003001og7oL0?mog4iog0005WoL00<007oL
Om`0ogoLCWoL000FOm`2003oOma?Om`00?mog6Mog000ogoLIgoL003oOmaWOm`00001\
\>"],
  ImageRangeCache->{{{0, 357.25}, {169.5, 0}} -> {-0.358109, -0.361549, \
0.0160655, 0.0160655}}],

Cell[TextData[{
  "Linearly interpolating the points ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\((1, 1)\), \ \((2, 2)\), \ \((3, 0)\), \ \((4, 1.8)\)\),
          FontSize->12], TraditionalForm]]],
  StyleBox[" ", "Output",
    FontSize->12],
  "and",
  StyleBox[" ", "Output",
    FontSize->12],
  Cell[BoxData[
      FormBox[
        StyleBox[\((5, 1)\),
          FontSize->12], TraditionalForm]]]
}], "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Since we want a sharp point at ",
  Cell[BoxData[
      \(\((3, 0)\)\)]],
  ", we model the path as two B\[EAcute]zier quadratics rather than one cubic \
bspline."
}], "Text"],

Cell["The Data", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[pos];\)\), "\n", 
    \(\(pos\  = \ {{1, 1}, {2, 2}, {3, 0}, {4, 1.8}, {5, 1}};\)\)}], "Input",
  CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell["The Knots", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[kt];\)\), "\n", 
    \(\(kt\  = \ {0.0, \ 0.0, \ 0.0, \ \ 1.0, \ 1.0, \ 1.0};\)\)}], "Input",
  CellMargins->{{54.625, Inherited}, {Inherited, Inherited}}],

Cell["The Unknown Control Points", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[ct];\)\), "\n", 
    \(\(ct\  = \ {{x1, y1}, {x2, y2}, {x3, y3}};\)\)}], "Input",
  CellMargins->{{54.625, Inherited}, {Inherited, Inherited}}],

Cell[TextData[StyleBox["Unknown spline function(s)",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[c];\)\), "\n", 
    \(\tc[t_]\ \  := \ \ bspline[kt, \ ct, t, 0]\)}], "Input",
  CellMargins->{{54, Inherited}, {Inherited, Inherited}}],

Cell[TextData[StyleBox["The Two Quadratic Splines\nOne",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(d\  = \ {pos\[LeftDoubleBracket]1\[RightDoubleBracket], 
        pos\[LeftDoubleBracket]2\[RightDoubleBracket], 
        pos\[LeftDoubleBracket]3\[RightDoubleBracket]}\)], "Input",
  CellMargins->{{54.625, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(Clear[ans]\), "\n", 
    \(\tans\  = \ Solve[{c[0]\ , c[0.5], c[1.0]} == d]\)}], "Input",
  CellMargins->{{54.625, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(ctrl1\  = \ 
      ct /. ans\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  CellMargins->{{54.625, Inherited}, {Inherited, Inherited}}],

Cell[TextData[StyleBox["Two",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[d];\)\), "\n", 
    \(\(d\  = \ {pos\[LeftDoubleBracket]3\[RightDoubleBracket], 
          pos\[LeftDoubleBracket]4\[RightDoubleBracket], 
          pos\[LeftDoubleBracket]5\[RightDoubleBracket]};\)\)}], "Input",
  CellMargins->{{54.625, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(Clear[ans]\), "\n", 
    \(\tans\  = \ Solve[{c[0]\ , c[0.5], c[1.0]} == d]\)}], "Input",
  CellMargins->{{54.625, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(ctrl2\  = \ 
      ct /. ans\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  CellMargins->{{54.625, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Plot the new trace curves and the original key frames to make sure \
we like what we have:\
\>", "Text"],

Cell[BoxData[
    \(curve1\  = 
      ParametricPlot[bspline[kt, \ ctrl1, \ x, 0], {x, 0, 1}, 
        DisplayFunction -> Identity]\)], "Input"],

Cell[BoxData[
    \(curve2\  = 
      ParametricPlot[bspline[kt, \ ctrl2, \ x, 0], {x, 0, 1}, 
        DisplayFunction -> Identity]\)], "Input"],

Cell[BoxData[
    \(Show[{curve1, \ curve2, 
        Graphics[{Table[
              Circle[pos\[LeftDoubleBracket]i\[RightDoubleBracket], 
                0.25], {i, 1, 5}]}]}, \ AspectRatio -> Automatic, 
      Axes -> True, \ DisplayFunction -> $DisplayFunction]\)], "Input"],

Cell["\<\
Since this looks good (or at least acceptable) we proceed to the \
next step.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Find the Pseudo-Arclength Parameterizations", "Subsubsection"],

Cell["\<\
We could combine the two curves into one piecewise polynomial, but \
nothing is gained since we actually want the sharp point at the place where \
they come together.  Further, it would make the next step harder to compute.  \
We do the arclength thing (see above) for each curve.\
\>", "Text"],

Cell["First the speed functions...", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\ \(Clear[v1, v2];\)\), "\n", 
    \(\(v1[t_]\  := \ 
        Module[{w\ }, w = bspline[kt, ctrl1, t, 1]; Sqrt[w . w]];\)\), "\n", 
    \(v2[t_]\  := \ 
      Module[{w\ }, w = bspline[kt, ctrl2, t, 1]; Sqrt[w . w]]\)}], "Input"],

Cell["Then the arclength functions...", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[s1, s2];\)\), "\n", 
    \(\(s1[t_]\  := \ NIntegrate[v1[x], \ {x, 0, t}];\)\), "\n", 
    \(\(s2[t_]\  := \ NIntegrate[v2[x], \ {x, 0, t}];\)\n\)}], "Input"],

Cell["\<\
The total length of each curve (note the right one is shorter than \
the left one)\
\>", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(len1\  = \ s1[1]\)], "Input"],

Cell[BoxData[
    \(len2\  = \ s2[1]\)], "Input"],

Cell["\<\
The equally spaced fractions (an arbitrary decision to have 20 \
frames per curve).\
\>", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[alf];\)\), "\n", 
    \(\(alf\  = \ Table[N[i/19], \ {i, 1, 18}];\)\)}], "Input"],

Cell["\<\
Find the t values for equally spaced points along the curves.  \
These take somewhere between 1 and 2 minutes each.\
\>", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[ans1, ans2];\)\), "\n", 
    \(\(ans1\  = 
        Table[FindRoot[
            s1[t] == alf\[LeftDoubleBracket]i\[RightDoubleBracket]*
                len1, \ {t, alf\[LeftDoubleBracket]i\[RightDoubleBracket], 
              alf\[LeftDoubleBracket]i\[RightDoubleBracket] + 0.01}], {i, 1, 
            18}];\)\), "\n", 
    \(\(ans2\  = 
        Table[FindRoot[
            s2[t] == alf\[LeftDoubleBracket]i\[RightDoubleBracket]*
                len2, \ {t, alf\[LeftDoubleBracket]i\[RightDoubleBracket], 
              alf\[LeftDoubleBracket]i\[RightDoubleBracket] + 0.01}], {i, 1, 
            18}];\)\)}], "Input"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(t\)]],
  " values for equally spaced points along the curves.  Note that the frame \
at the bottom of the bounce  (",
  Cell[BoxData[
      \(bspline[kt, \ ctrl1, \ \ 1, \ 0]\)]],
  " and ",
  Cell[BoxData[
      \(bspline[kt, \ ctrl2, \ \ 0, \ 0]\)]],
  StyleBox[")",
    FontFamily->"Courier"],
  "is not repeated."
}], "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(val1\  = 
        Union[{0}\ , 
          Table[t /. ans1\[LeftDoubleBracket]i, 1\[RightDoubleBracket], \ {i, 
              1, 18}], {1}];\)\)], "Input"],

Cell[BoxData[
    \(\(val2\  = \ 
        Union[Table[
            t /. ans2\[LeftDoubleBracket]i, 1\[RightDoubleBracket], \ {i, 1, 
              18}], {1}];\)\)], "Input"],

Cell["\<\
It will be useful to look again at what we've got so that we have \
some idea of what values of the parameters correspond to the action we are \
interested in.  Let's plot every other frame, along with labels:\
\>", "Text"],

Cell[BoxData[
    \(\(Show[
        Graphics[{Table[{Circle[
                  x\  = bspline[kt, ctrl1, 
                      val1\[LeftDoubleBracket]i\[RightDoubleBracket], 0], 
                  0.25], \[IndentingNewLine]\t\t\t\tHue[
                  0], \[IndentingNewLine]\t\t\t\tText[
                  StyleForm[
                    i, \[IndentingNewLine]FontFamily -> "\<Courier\>", 
                    FontSize -> 14], \ 
                  x + {0, 0.27}], \[IndentingNewLine]\t\t\t\tGrayLevel[
                  0]}, {i, 1, 20, 
                2}], \n\t\t\tTable[{Circle[
                  x\  = bspline[kt, ctrl2, 
                      val2\[LeftDoubleBracket]i\[RightDoubleBracket], 0], 
                  0.25], \[IndentingNewLine]\t\t\tHue[0], \n\t\t\t\tText[
                  StyleForm[i, FontFamily -> "\<Courier\>", 
                    FontSize -> 14], \ x + {0, 0.27}], GrayLevel[0]}, {i, 1, 
                19, 2}]\n\t\t\t\t}], \n\tAxes \[Rule] False, 
        PlotRange -> {{0, 6}, {\(-1\), 3}}];\)\)], "Input"],

Cell[TextData[{
  "From the plot above we make an arbitrary choice of frames ",
  Cell[BoxData[
      \(15 - 20\)]],
  " on the left curve and frames ",
  Cell[BoxData[
      \(1\  - \ 5\)]],
  " on the right curve (frames ",
  Cell[BoxData[
      \(15 - 25\)]],
  " in the overall scene ) for the squash and stretch."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Model the Squash and Stretch - Positioning the Ellipses", \
"Subsubsection"],

Cell[TextData[{
  "The circles in frames ",
  Cell[BoxData[
      \(15 - 19\)]],
  " and frames ",
  Cell[BoxData[
      \(21 - 25\)]],
  " will become ellipses.  The  major axes of these ellipses will be more or \
less vertical and their minor axes more or less horizontal and the length of \
the major axes will increase and the length of the minor axes will decrease \
in frames ",
  Cell[BoxData[
      \(15 - 19\)]],
  "  and the opposite will happen in frames ",
  Cell[BoxData[
      \(21 - 25\)]],
  ".  We might be tempted to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ellipse/circle primitive, but it turns out to be hard (not impossible) \
to rotate since the ",
  StyleBox["Shapes", "Input",
    FontWeight->"Plain"],
  " add-on package deals with three dimensional graphics."
}], "Text"],

Cell["\<\
We take the easy way out.  We do it by hand (sort of).  We know \
that \
\>", "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox["p",
              FontWeight->"Bold"], "\[RightVector]"], \((\[Theta])\)}], " ", 
        "=", " ", \((a\ cos\ \[Theta], \ b\ sin\ \[Theta])\)}]}]], "Text"],

Cell[TextData[{
  "is the parametric equation of an ellipse centered at the origin with axes \
parallel to the ",
  Cell[BoxData[
      \(X\)]],
  " and ",
  Cell[BoxData[
      \(Y\)]],
  " axis and the length of the ",
  Cell[BoxData[
      \(X\)]],
  "-parallel-axis is ",
  Cell[BoxData[
      \(2  a\)]],
  " and the length of the ",
  Cell[BoxData[
      \(Y\)]],
  "-parallel-axis ",
  Cell[BoxData[
      \(2  b\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "To keep the ellipses moving along the curve and stretching along the \
curve, we'll construct each ellipse so that the center of the ellipse is on \
the curve.  The major axis of the ellipse will be parallel to the derivative \
of the curve at this point on the curve.  We can compute these derivatives \
using ",
  Cell[BoxData[
      \(bspline\)]],
  " with the last input parameter equal to ",
  Cell[BoxData[
      \(1\)]],
  ".  For example, the derivative of the left hand curve at the ",
  Cell[BoxData[
      \(17\)]],
  "'th frame is"
}], "Text"],

Cell[TextData[{
  "bspline",
  StyleBox["[kt, ctrl1,  val1\[LeftDoubleBracket]17\[RightDoubleBracket], \
1].", "Input",
    FontWeight->"Plain"]
}], "ContentsText"],

Cell[TextData[{
  "If we let  ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["v",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " be the derivative vector above, then ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " = ",
  Cell[BoxData[
      StyleBox[
        FractionBox[
          OverscriptBox[
            StyleBox["v",
              FontFamily->"Courier"], "\[RightVector]"], 
          SqrtBox[
            StyleBox[\(v\&\[RightVector]\[CenterDot]v\&\[RightVector]\),
              FontFamily->"Courier"]]],
        FontWeight->"Bold"]]],
  "is the unit vector parallel to ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["v",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  ".  We need to find the rotation transformation that will rotate an ellipse \
so that one of the axes of the ellipse is parallel to ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  ".   Since ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " is a unit vector,  ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " ",
  Cell[BoxData[
      \(\(\(=\)\(\ \)\((cos\ \[Alpha], \ sin\ \ \[Alpha])\)\)\)]],
  " for some value of ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " where ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " is related to the angle through which we want to rotate the ellipse. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.5 0.47619 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -12 -9 ]
[.2619 .4875 12 0 ]
[.7381 .4875 -9 -9 ]
[.7381 .4875 9 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -24 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -18 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-1)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-0.5)] .2619 .4875 0 1 Mshowa
.7381 .5 m
.7381 .50625 L
s
[(0.5)] .7381 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(1)] .97619 .4875 0 1 Mshowa
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.21429 .5 m
.21429 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.40476 .5 m
.40476 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.59524 .5 m
.59524 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.78571 .5 m
.78571 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .02381 m
.50625 .02381 L
s
[(-1)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-0.5)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(0.5)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(1)] .4875 .97619 1 0 Mshowa
.125 Mabswid
.5 .07143 m
.50375 .07143 L
s
.5 .11905 m
.50375 .11905 L
s
.5 .16667 m
.50375 .16667 L
s
.5 .21429 m
.50375 .21429 L
s
.5 .30952 m
.50375 .30952 L
s
.5 .35714 m
.50375 .35714 L
s
.5 .40476 m
.50375 .40476 L
s
.5 .45238 m
.50375 .45238 L
s
.5 .54762 m
.50375 .54762 L
s
.5 .59524 m
.50375 .59524 L
s
.5 .64286 m
.50375 .64286 L
s
.5 .69048 m
.50375 .69048 L
s
.5 .78571 m
.50375 .78571 L
s
.5 .83333 m
.50375 .83333 L
s
.5 .88095 m
.50375 .88095 L
s
.5 .92857 m
.50375 .92857 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.5 Mabswid
newpath
.5 .5 .47619 0 365.73 arc
s
1 0 0 r
newpath
.5 .5 .35714 0 288.66 arc
s
gsave
.2619 .2619 -67.1875 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
  61.000000 16.000000 moveto
  558.000000 16.000000 lineto
  558.000000 4.000000 lineto
  61.000000 4.000000 lineto
  61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(a) show
71.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
newpath
matrix currentmatrix
0.0297619 0.0892857 scale
16.8 5.6 1 0 365.73 arc
setmatrix s
0 g
.5 .5 m
.65236 .04884 L
s
% Start of user PostScript
0 0 0.319955 -0.947433 MAarrowhead1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{286.5, 286.5},
  ImageMargins->{{73.5, 0}, {0, 0.625}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004N00017R000`400?l00000o`00003oSP3ol>H0
0`000000oo3V0?o`iP2=0?o`iP00SP3ol>H00`000000oo3V0?o`iP2=0?o`iP00SP3ol>H00`000000
oo3V0?o`iP2=0?o`iP00SP3ol>H00`000000oo3V0?o`iP2=0?o`iP00QP3ol>H3000000D0oo3V00<0
00000?o`iP3ol>H0S@3ol>H008L0oo3V00<000000?o`iP3ol>H0103ol>H00`000000oo3V0?o`iP2=
0?o`iP00O`3ol>H5000000<0oo3V00<000000?o`iP3ol>H0103ol>H00`000000oo3V0?o`iP2=0?o`
iP00P03ol>HN00000800oo3V001i0?o`iPL000001`3ol>H00`000000oo3V0?o`iP040?o`iP030000
003ol>H0oo3V00d0oo3V1P00001j0?o`iP00L`3ol>H6000000d0oo3V0P0000060?o`iP030000003o
l>H0oo3V01<0oo3V1`00001c0?o`iP00K`3ol>H4000001@0oo3V00<000000?o`iP3ol>H0103ol>H0
0`000000oo3V0?o`iP0J0?o`iP<00000L03ol>H006X0oo3V1@00000O0?o`iP030000003ol>H0oo3V
01d0oo3V1@00001[0?o`iP00I`3ol>H3000002@0oo3V00<000000?o`iP3ol>H08P3ol>H3000006P0
oo3V001T0?o`iP<000009`3ol>H00`000000oo3V0?o`iP0U0?o`iP@00000I03ol>H00640oo3V0`00
000Z0?o`iP030000003ol>H0oo3V02T0oo3V0`00001Q0?o`iP00G`3ol>H2000002d0oo3V00<00000
0?o`iP3ol>H0:@3ol>H010000000oo3V0?o`iP00001P0?o`iP00G03ol>H3000002l0oo3V00<00000
0?o`iP3ol>H0:03ol>H2000000<0oo3V1000001L0?o`iP00F@3ol>H300000380oo3V00<000000?o`
iP3ol>H09`3ol>H3000000L0oo3V0`00001I0?o`iP00E`3ol>H2000003D0oo3V00<000000?o`iP3o
l>H09`3ol>H3000000X0oo3V00<000000?o`iP3ol>H0EP3ol>H005H0oo3V00<000000?o`iP3ol>H0
=@3ol>H00`000000oo3V0?o`iP0V0?o`iP@000002`3ol>H2000005H0oo3V001C0?o`iP<00000>03o
l>H2000002H0oo3V1@00000=0?o`iP<00000D`3ol>H00540oo3V0P00000k0?o`iP030000003ol>H0
oo3V02D0oo3V1@00000@0?o`iP030000003ol>H0oo3V0500oo3V001?0?o`iP800000?@3ol>H00`00
0000oo3V0?o`iP0T0?o`iPD000004P3ol>H3000004l0oo3V001<0?o`iP<00000?`3ol>H00`000000
oo3V0?o`iP0S0?o`iPH000005@3ol>H2000004d0oo3V001;0?o`iP030000003ol>H0oo3V0400oo3V
00<000000?o`iP3ol>H08`3ol>H6000001L0oo3V00<000000?o`iP3ol>H0BP3ol>H004T0oo3V0P00
00130?o`iP030000003ol>H0oo3V0280oo3V1`00000H0?o`iP800000BP3ol>H004P0oo3V00<00000
0?o`iP3ol>H0@`3ol>H00`000000oo3V0?o`iP0Q0?o`iPP000006P3ol>H00`000000oo3V0?o`iP17
0?o`iP00A`3ol>H00`000000oo3V0?o`iP140?o`iP030000003ol>H0oo3V02<0oo3V1P00000K0?o`
iP800000A`3ol>H004H0oo3V00<000000?o`iP3ol>H0A@3ol>H00`000000oo3V0?o`iP0T0?o`iP03
0000003ol>H00000008000007@3ol>H00`000000oo3V0?o`iP140?o`iP00A03ol>H2000004P0oo3V
00<000000?o`iP3ol>H0903ol>H01@000000oo3V0?o`iP3ol>H0000001h0oo3V0`0000130?o`iP00
@@3ol>H3000004X0oo3V00<000000?o`iP3ol>H0903ol>H00`000000oo3V0?o`iP0S0?o`iP800000
@@3ol>H00400oo3V00<000000?o`iP3ol>H0B`3ol>H00`000000oo3V0?o`iP0S0?o`iP030000003o
l>H0oo3V02H0oo3V00<000000?o`iP3ol>H0?P3ol>H003h0oo3V0P00001>0?o`iP030000003ol>H0
oo3V02<0oo3V00<000000?o`iP3ol>H09`3ol>H00`000000oo3V0?o`iP0m0?o`iP00?@3ol>H00`00
0000oo3V0?o`iP1>0?o`iP030000003ol>H0oo3V02<0oo3V00<000000?o`iP3ol>H0:03ol>H00`00
0000oo3V0?o`iP0l0?o`iP00?03ol>H00`000000oo3V0?o`iP1?0?o`iP8000008`3ol>H00`000000
oo3V0?o`iP0Z0?o`iP800000?03ol>H003/0oo3V00<000000?o`iP3ol>H0D03ol>H00`000000oo3V
0?o`iP0R0?o`iP030000003ol>H0oo3V02`0oo3V00<000000?o`iP3ol>H0>@3ol>H003X0oo3V00<0
00000?o`iP3ol>H0D@3ol>H00`000000oo3V0?o`iP0R0?o`iP030000003ol>H0oo3V02d0oo3V00<0
00000?o`iP3ol>H0>03ol>H003T0oo3V00<000000?o`iP3ol>H0DP3ol>H00`000000oo3V0?o`iP0Q
0?o`iP030000003ol>H0oo3V02l0oo3V00<000000?o`iP3ol>H0=`3ol>H003P0oo3V00<000000?o`
iP3ol>H0D`3ol>H00`000000oo3V0?o`iP0Q0?o`iP030000003ol>H0oo3V0300oo3V00<000000?o`
iP3ol>H0=P3ol>H003H0oo3V0P00001F0?o`iP030000003ol>H0oo3V0240oo3V00<000000?o`iP3o
l>H0<@3ol>H00`000000oo3V0?o`iP0e0?o`iP00=@3ol>H00`000000oo3V0?o`iP1F0?o`iP030000
003ol>H0oo3V0200oo3V00<000000?o`iP3ol>H0<`3ol>H00`000000oo3V0?o`iP0d0?o`iP00=03o
l>H00`000000oo3V0?o`iP1;0?o`iQT0o`005P3ol>H00`000000oo3V0?o`iP0d0?o`iP800000=03o
l>H003<0oo3V00<000000?o`iP3ol>H0AP3ol>H60?l000`0oo3V00<000000?o`iP3ol>H02P3ol>H6
0?l00100oo3V00<000000?o`iP3ol>H0=P3ol>H00`000000oo3V0?o`iP0a0?o`iP00<@3ol>H20000
04@0oo3V1@3o000B0?o`iP030000003ol>H0oo3V0100oo3V1P3o00090?o`iP030000003ol>H0oo3V
03P0oo3V00<000000?o`iP3ol>H0<03ol>H00300oo3V00<000000?o`iP3ol>H0@03ol>H40?l001L0
oo3V00<000000?o`iP3ol>H05P3ol>H40?l000D0oo3V00<000000?o`iP3ol>H0>@3ol>H00`000000
oo3V0?o`iP0_0?o`iP00;`3ol>H00`000000oo3V0?o`iP0m0?o`iP@0o`006`3ol>H00`000000oo3V
0?o`iP0J0?o`iP80o`000`3ol>H00`000000oo3V0?o`iP0j0?o`iP030000003ol>H0oo3V02h0oo3V
000_0?o`iP030000003ol>H0oo3V03/0oo3V0P3o000O0?o`iP030000003ol>H0oo3V01`0oo3V0P3o
00000`000000oo3V0?o`iP0l0?o`iP030000003ol>H0oo3V02d0oo3V000^0?o`iP030000003ol>H0
oo3V03P0oo3V103o000Q0?o`iP030000003ol>H0oo3V01h0oo3V00<000000?o`iP3ol>H0?@3ol>H0
0`000000oo3V0?o`iP0/0?o`iP00;@3ol>H00`000000oo3V0?o`iP0g0?o`iP80o`009@3ol>H20000
01l0oo3V00<000000?o`iP3ol>H0?P3ol>H00`000000oo3V0?o`iP0[0?o`iP00;03ol>H00`000000
oo3V0?o`iP0f0?o`iP80o`009`3ol>H00`000000oo3V0?o`iP0M0?o`iP030000003ol>H0oo3V0400
oo3V00<000000?o`iP3ol>H0:P3ol>H002/0oo3V00<000000?o`iP3ol>H0=P3ol>H00`3o0000oo3V
0?o`iP0W0?o`iP030000003ol>H0oo3V01d0oo3V00<000000?o`iP3ol>H0@@3ol>H00`000000oo3V
0?o`iP0Y0?o`iP00:P3ol>H00`000000oo3V0?o`iP0c0?o`iP@0o`00:P3ol>H00`000000oo3V0?o`
iP0M0?o`iP030000003ol>H0oo3V0440oo3V00<000000?o`iP3ol>H0:@3ol>H002T0oo3V00<00000
0?o`iP3ol>H0<P3ol>H20?l002h0oo3V00<000000?o`iP3ol>H0703ol>H00`000000oo3V0?o`iP13
0?o`iP030000003ol>H0oo3V02P0oo3V000X0?o`iP030000003ol>H0oo3V0380oo3V00<0o`000?o`
iP3ol>H0;P3ol>H00`000000oo3V0?o`iP0L0?o`iP030000003ol>H0oo3V04@0oo3V00<000000?o`
iP3ol>H09`3ol>H002L0oo3V00<000000?o`iP3ol>H0<@3ol>H20?l00340oo3V00<000000?o`iP3o
l>H0703ol>H00`000000oo3V0?o`iP150?o`iP030000003ol>H0oo3V02H0oo3V000V0?o`iP030000
003ol>H0oo3V0300oo3V0P3o000c0?o`iP030000003ol>H0oo3V01/0oo3V00<000000?o`iP3ol>H0
A`3ol>H00`000000oo3V0?o`iP0U0?o`iP009P3ol>H00`000000oo3V0?o`iP0^0?o`iP80o`00=@3o
l>H00`000000oo3V0?o`iP0K0?o`iP030000003ol>H0oo3V04P0oo3V00<000000?o`iP3ol>H0903o
l>H002D0oo3V00<000000?o`iP3ol>H0;P3ol>H00`3o0000oo3V0?o`iP0e0?o`iP030000003ol>H0
oo3V01/0oo3V00<000000?o`iP3ol>H0B@3ol>H00`000000oo3V0?o`iP0S0?o`iP00903ol>H00`00
0000oo3V0?o`iP0_0?o`iP030?l0003ol>H0oo3V03D0oo3V00<000000?o`iP3ol>H06P3ol>H00`00
0000oo3V0?o`iP1;0?o`iP030000003ol>H0oo3V0280oo3V000T0?o`iP030000003ol>H0oo3V02d0
oo3V0P3o000h0?o`iP030000003ol>H0oo3V01X0oo3V00<000000?o`iP3ol>H0B`3ol>H00`000000
oo3V0?o`iP0R0?o`iP008`3ol>H00`000000oo3V0?o`iP0/0?o`iP80o`00>P3ol>H00`000000oo3V
0?o`iP0I0?o`iP030000003ol>H0oo3V04d0oo3V00<000000?o`iP3ol>H08@3ol>H00280oo3V00<0
00000?o`iP3ol>H0;03ol>H00`3o0000oo3V0?o`iP0j0?o`iP8000006P3ol>H00`000000oo3V0?o`
iP1>0?o`iP030000003ol>H0oo3V0200oo3V000Q0?o`iP030000003ol>H0oo3V02/0oo3V0P3o000m
0?o`iP030000003ol>H0oo3V01T0oo3V00<000000?o`iP3ol>H0C`3ol>H00`000000oo3V0?o`iP0O
0?o`iP00803ol>H00`000000oo3V0?o`iP0[0?o`iP030?l0003ol>H0oo3V03d0oo3V00<000000?o`
iP3ol>H0603ol>H00`000000oo3V0?o`iP1A0?o`iP030000003ol>H0oo3V01h0oo3V000P0?o`iP03
0000003ol>H0oo3V02/0oo3V00<0o`000?o`iP3ol>H0?@3ol>H00`000000oo3V0?o`iP0H0?o`iP03
0000003ol>H0oo3V0540oo3V00<000000?o`iP3ol>H07P3ol>H001l0oo3V00<000000?o`iP3ol>H0
:P3ol>H20?l00400oo3V00<000000?o`iP3ol>H0603ol>H00`000000oo3V0?o`iP1B0?o`iP030000
003ol>H0oo3V01d0oo3V000N0?o`iP030000003ol>H0oo3V02X0oo3V00<0o`000?o`iP3ol>H0@03o
l>H00`000000oo3V0?o`iP0G0?o`iP030000003ol>H0oo3V05@0oo3V00<000000?o`iP3ol>H0703o
l>H001h0oo3V00<000000?o`iP3ol>H0:@3ol>H00`3o0000oo3V0?o`iP110?o`iP030000003ol>H0
oo3V01L0oo3V00<000000?o`iP3ol>H0E03ol>H00`000000oo3V0?o`iP0L0?o`iP007@3ol>H00`00
0000oo3V0?o`iP0Y0?o`iP030?l0003ol>H0oo3V0480oo3V00<000000?o`iP3ol>H05`3ol>H00`00
0000oo3V0?o`iP1E0?o`iP030000003ol>H0oo3V01/0oo3V000L0?o`iP030000003ol>H0oo3V02T0
oo3V00<0o`000?o`iP3ol>H0@`3ol>H00`000000oo3V0?o`iP0F0?o`iP030000003ol>H0oo3V05H0
oo3V00<000000?o`iP3ol>H06`3ol>H001`0oo3V00<000000?o`iP3ol>H0:03ol>H00`3o0000oo3V
0?o`iP140?o`iP030000003ol>H0oo3V01H0oo3V00<000000?o`iP3ol>H0EP3ol>H00`000000oo3V
0?o`iP0K0?o`iP006`3ol>H00`000000oo3V0?o`iP0X0?o`iP030?l0003ol>H0oo3V04D0oo3V00<0
00000?o`iP3ol>H05P3ol>H00`000000oo3V0?o`iP1G0?o`iP030000003ol>H0oo3V01X0oo3V000J
0?o`iP030000003ol>H0oo3V02P0oo3V00<0o`000?o`iP3ol>H0<`3ol>H2000000@0oo3V00<00000
0?o`iP3ol>H00P3ol>H3000000D0oo3V00<000000?o`iP3ol>H05@3ol>H00`000000oo3V0?o`iP1I
0?o`iP030000003ol>H0oo3V01T0oo3V000J0?o`iP030000003ol>H0oo3V02L0oo3V00@0o`000?o`
iP3ol>H0ohn90P3o0000103oD4`0on3F0?mPG03o000/0?o`iP040000003ol>H0oo3V000000L0oo3V
00D000000?o`iP3ol>H0oo3V000000040?o`iP030000003ol>H0oo3V01D0oo3V00<000000?o`iP3o
l>H0F@3ol>H00`000000oo3V0?o`iP0I0?o`iP006@3ol>H00`000000oo3V0?o`iP0W0?o`iP0:0?l0
003ol>H0oo3V0?o`iP3o0000oinI0?o`iP3oOgX0obl]0?mPG2H0oo3V1@0000020?o`iP040000003o
l>H0oo3V000000/0oo3V00<000000?o`iP3ol>H00P3ol>H00`000000oo3V0?o`iP0E0?o`iP030000
003ol>H0oo3V05X0oo3V00<000000?o`iP3ol>H0603ol>H001T0oo3V00<000000?o`iP3ol>H09P3o
l>H00`3o0000oo3V0?o`iP020?o`iP060?l0003ol>H0oo3V0?o`iP3oOgX0obl];@3ol>H010000000
oo3V0?o`iP00000;0?o`iP030000003ol>H0oo3V0080oo3V0`00000D0?o`iP030000003ol>H0oo3V
05`0oo3V00<000000?o`iP3ol>H05`3ol>H001T0oo3V00<000000?o`iP3ol>H09@3ol>H00`3o0000
oo3V0?o`iP030?o`iP060?l?3`3o`;P0oo3V0?o`iP3oShT0obl];@3ol>H010000000oo3V0?o`iP00
00070?o`iP@000001@3ol>H00`000000oo3V0?o`iP0D0?o`iP030000003ol>H0oo3V05`0oo3V00<0
00000?o`iP3ol>H05`3ol>H001P0oo3V00<000000?o`iP3ol>H09@3ol>H00`3o0000oo3V0?o`iP04
0?o`iP070?n?R@3o7ah0om370?oPeP3o;bd0oe1<0?n_Z00/0?o`iP040000003ol>H0oo3V000000L0
oo3V00<000000?o`iP3ol>H01P3ol>H00`000000oo3V0?o`iP0D0?o`iP030000003ol>H0oo3V05d0
oo3V00<000000?o`iP3ol>H05P3ol>H001L0oo3V00<000000?o`iP3ol>H09P3ol>H00`3o0000oo3V
0?o`iP050?o`iP060?m`J`3o0000o`000?n?R@3o[jP0obl];@3ol>H2000000P0oo3V1@0000040?o`
iP030000003ol>H0oo3V01<0oo3V00<000000?o`iP3ol>H0G`3ol>H00`000000oo3V0?o`iP0E0?o`
iP005`3ol>H00`000000oo3V0?o`iP0U0?o`iP030?l0003ol>H0oo3V04`0oo3V00<000000?o`iP3o
l>H04`3ol>H00`000000oo3V0?o`iP1O0?o`iP030000003ol>H0oo3V01D0oo3V000F0?o`iP030000
003ol>H0oo3V02D0oo3V00<0o`000?o`iP3ol>H0C@3ol>H00`000000oo3V0?o`iP0C0?o`iP030000
003ol>H0oo3V0600oo3V00<000000?o`iP3ol>H0503ol>H001D0oo3V00<000000?o`iP3ol>H09@3o
l>H00`3o0000oo3V0?o`iP1>0?o`iP030000003ol>H0oo3V0180oo3V00<000000?o`iP3ol>H0H@3o
l>H00`000000oo3V0?o`iP0D0?o`iP005@3ol>H00`000000oo3V0?o`iP0T0?o`iP030?l0003ol>H0
oo3V04l0oo3V00<000000?o`iP3ol>H04P3ol>H00`000000oo3V0?o`iP1Q0?o`iP030000003ol>H0
oo3V01@0oo3V000D0?o`iP030000003ol>H0oo3V02D0oo3V00<0o`000?o`iP3ol>H0C`3ol>H00`00
0000oo3V0?o`iP0B0?o`iP030000003ol>H0oo3V0680oo3V00<000000?o`iP3ol>H04`3ol>H001@0
oo3V00<000000?o`iP3ol>H0903ol>H00`3o0000oo3V0?o`iP1@0?o`iP030000003ol>H0oo3V0140
oo3V00<000000?o`iP3ol>H0I03ol>H00`000000oo3V0?o`iP0B0?o`iP004`3ol>H00`000000oo3V
0?o`iP0T0?o`iP030?l0003ol>H0oo3V0540oo3V00<000000?o`iP3ol>H04@3ol>H00`000000oo3V
0?o`iP1T0?o`iP030000003ol>H0oo3V0180oo3V000C0?o`iP030000003ol>H0oo3V02@0oo3V00<0
o`000?o`iP3ol>H0D@3ol>H00`000000oo3V0?o`iP0A0?o`iP030000003ol>H0oo3V06@0oo3V00<0
00000?o`iP3ol>H04P3ol>H00180oo3V00<000000?o`iP3ol>H0903ol>H00`3o0000oo3V0?o`iP1B
0?o`iP030000003ol>H0oo3V0100oo3V00<000000?o`iP3ol>H0IP3ol>H00`000000oo3V0?o`iP0A
0?o`iP004P3ol>H00`000000oo3V0?o`iP0T0?o`iP030?l0003ol>H0oo3V0580oo3V0P00000A0?o`
iP030000003ol>H0oo3V06L0oo3V00<000000?o`iP3ol>H0403ol>H00180oo3V00<000000?o`iP3o
l>H08`3ol>H00`3o0000oo3V0?o`iP1C0?o`iP030000003ol>H0oo3V0100oo3V00<000000?o`iP3o
l>H0I`3ol>H00`000000oo3V0?o`iP0@0?o`iP004@3ol>H00`000000oo3V0?o`iP0S0?o`iP030?l0
003ol>H0oo3V05@0oo3V00<000000?o`iP3ol>H03`3ol>H00`000000oo3V0?o`iP1Y0?o`iP030000
003ol>H0oo3V00l0oo3V000@0?o`iP030000003ol>H0oo3V02@0oo3V00<0o`000?o`iP3ol>H0E03o
l>H00`000000oo3V0?o`iP0?0?o`iP030000003ol>H0oo3V06T0oo3V00<000000?o`iP3ol>H03`3o
l>H00100oo3V00<000000?o`iP3ol>H08`3ol>H00`3o0000oo3V0?o`iP1E0?o`iP030000003ol>H0
oo3V00l0oo3V00<000000?o`iP3ol>H0J@3ol>H00`000000oo3V0?o`iP0?0?o`iP00403ol>H00`00
0000oo3V0?o`iP0S0?o`iP030?l0003ol>H0oo3V05D0oo3V00<000000?o`iP3ol>H03P3ol>H00`00
0000oo3V0?o`iP1[0?o`iP030000003ol>H0oo3V00h0oo3V000@0?o`iP030000003ol>H0oo3V0280
oo3V00<0o`000?o`iP3ol>H0EP3ol>H00`000000oo3V0?o`iP0>0?o`iP030000003ol>H0oo3V06/0
oo3V00<000000?o`iP3ol>H03P3ol>H000l0oo3V00<000000?o`iP3ol>H08`3ol>H00`3o0000oo3V
0?o`iP1F0?o`iP030000003ol>H0oo3V00h0oo3V00<000000?o`iP3ol>H0J`3ol>H00`000000oo3V
0?o`iP0>0?o`iP003`3ol>H00`000000oo3V0?o`iP0R0?o`iP030?l0003ol>H0oo3V05L0oo3V00<0
00000?o`iP3ol>H03@3ol>H00`000000oo3V0?o`iP1]0?o`iP030000003ol>H0oo3V00d0oo3V000?
0?o`iP030000003ol>H0oo3V0240oo3V00<0o`000?o`iP3ol>H0F03ol>H00`000000oo3V0?o`iP0=
0?o`iP030000003ol>H0oo3V06d0oo3V00<000000?o`iP3ol>H03@3ol>H000h0oo3V00<000000?o`
iP3ol>H08P3ol>H00`3o0000oo3V0?o`iP1H0?o`iP030000003ol>H0oo3V00d0oo3V00<000000?o`
iP3ol>H0KP3ol>H00`000000oo3V0?o`iP0<0?o`iP003@3ol>H00`000000oo3V0?o`iP0R0?o`iP03
0?l0003ol>H0oo3V05T0oo3V00<000000?o`iP3ol>H0303ol>H00`000000oo3V0?o`iP1_0?o`iP03
0000003ol>H0oo3V00`0oo3V000=0?o`iP030000003ol>H0oo3V0280oo3V00<0o`000?o`iP3ol>H0
F@3ol>H00`000000oo3V0?o`iP0<0?o`iP030000003ol>H0oo3V06l0oo3V00<000000?o`iP3ol>H0
303ol>H000d0oo3V00<000000?o`iP3ol>H08@3ol>H00`3o0000oo3V0?o`iP1J0?o`iP030000003o
l>H0oo3V00/0oo3V00<000000?o`iP3ol>H0L@3ol>H00`000000oo3V0?o`iP0;0?o`iP003@3ol>H0
0`000000oo3V0?o`iP0Q0?o`iP030?l0003ol>H0oo3V05X0oo3V0P00000<0?o`iP030000003ol>H0
oo3V0740oo3V00<000000?o`iP3ol>H02`3ol>H000`0oo3V00<000000?o`iP3ol>H08@3ol>H00`3o
0000oo3V0?o`iP1K0?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H0L@3ol>H00`00
0000oo3V0?o`iP0;0?o`iP00303ol>H00`000000oo3V0?o`iP0Q0?o`iP030?l0003ol>H0oo3V05/0
oo3V00<000000?o`iP3ol>H02P3ol>H00`000000oo3V0?o`iP1c0?o`iP030000003ol>H0oo3V00X0
oo3V000<0?o`iP030000003ol>H0oo3V0240oo3V00<0o`000?o`iP3ol>H0F`3ol>H00`000000oo3V
0?o`iP0:0?o`iP030000003ol>H0oo3V07<0oo3V00<000000?o`iP3ol>H02P3ol>H000/0oo3V00<0
00000?o`iP3ol>H08P3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030000003ol>H0oo3V00X0oo3V00<0
00000?o`iP3ol>H0L`3ol>H00`000000oo3V0?o`iP0:0?o`iP002`3ol>H00`000000oo3V0?o`iP0Q
0?o`iP030?l0003ol>H0oo3V05`0oo3V00<000000?o`iP3ol>H02@3ol>H00`000000oo3V0?o`iP1d
0?o`iP030000003ol>H0oo3V00X0oo3V000;0?o`iP030000003ol>H0oo3V0240oo3V00<0o`000?o`
iP3ol>H0G03ol>H00`000000oo3V0?o`iP090?o`iP030000003ol>H0oo3V07D0oo3V00<000000?o`
iP3ol>H02@3ol>H000/0oo3V00<000000?o`iP3ol>H0803ol>H00`3o0000oo3V0?o`iP1M0?o`iP03
0000003ol>H0oo3V00T0oo3V00<000000?o`iP3ol>H0M@3ol>H00`000000oo3V0?o`iP090?o`iP00
2`3ol>H00`000000oo3V0?o`iP0P0?o`iP030?l0003ol>H0oo3V05d0oo3V00<000000?o`iP3ol>H0
203ol>H00`000000oo3V0?o`iP1f0?o`iP030000003ol>H0oo3V00T0oo3V000:0?o`iP030000003o
l>H0oo3V0240oo3V00<0o`000?o`iP3ol>H0G@3ol>H00`000000oo3V0?o`iP080?o`iP030000003o
l>H0oo3V07H0oo3V00<000000?o`iP3ol>H02@3ol>H000X0oo3V00<000000?o`iP3ol>H0803ol>H0
0`3o0000oo3V0?o`iP1N0?o`iP030000003ol>H0oo3V00P0oo3V00<000000?o`iP3ol>H0MP3ol>H0
0`000000oo3V0?o`iP090?o`iP002P3ol>H00`000000oo3V0?o`iP0P0?o`iP030?l0003ol>H0oo3V
05h0oo3V00<000000?o`iP3ol>H01`3ol>H00`000000oo3V0?o`iP1h0?o`iP030000003ol>H0oo3V
00P0oo3V00090?o`iP030000003ol>H0oo3V0200oo3V00<0o`000?o`iP3ol>H0G`3ol>H00`000000
oo3V0?o`iP070?o`iP030000003ol>H0oo3V07P0oo3V00<000000?o`iP3ol>H0203ol>H000T0oo3V
00<000000?o`iP3ol>H0803ol>H00`3o0000oo3V0?o`iP1O0?o`iP030000003ol>H0oo3V00L0oo3V
00<000000?o`iP3ol>H0N03ol>H00`000000oo3V0?o`iP080?o`iP002@3ol>H00`000000oo3V0?o`
iP0P0?o`iP030?l0003ol>H0oo3V05l0oo3V0P0000070?o`iP030000003ol>H0oo3V07X0oo3V00<0
00000?o`iP3ol>H01`3ol>H000T0oo3V00<000000?o`iP3ol>H0803ol>H00`3o0000oo3V0?o`iP1N
0?o`iP@0o`001P3ol>H00`000000oo3V0?o`iP1j0?o`iP030000003ol>H0oo3V00L0oo3V00090?o`
iP030000003ol>H0oo3V01l0oo3V00<0o`000?o`iP3ol>H0G`3ol>H01@3o000000000?o`iP3ol>H0
o`0000D0oo3V00<000000?o`iP3ol>H0NP3ol>H00`000000oo3V0?o`iP070?o`iP00203ol>H00`00
0000oo3V0?o`iP0P0?o`iP030?l0003ol>H0oo3V05h0oo3V00<0o`000?o`iP0000000P3ol>H00`3o
0000oo3V0?o`iP020?o`iP030000003ol>H0oo3V07/0oo3V00<000000?o`iP3ol>H01`3ol>H000P0
oo3V00<000000?o`iP3ol>H0803ol>H00`3o0000oo3V0?o`iP1M0?o`iP040?l0003ol>H0oo3V0000
00<0oo3V00D0o`000?o`iP3ol>H0oo3V0000001m0?o`iP030000003ol>H0oo3V00L0oo3V00080?o`
iP030000003ol>H0oo3V0200oo3V00<0o`000?o`iP3ol>H0G03ol>H01@3o0000oo3V0?o`iP3ol>H0
000000<0oo3V00D0o`000?o`iP3ol>H0oo3V0000001m0?o`iP030000003ol>H0oo3V00L0oo3V0008
0?o`iP030000003ol>H0oo3V01l0oo3V00<0o`000?o`iP3ol>H0G@3ol>H01@3o0000oo3V0?o`iP3o
l>H0000000@0oo3V00<0o`000?o`iP000000OP3ol>H00`000000oo3V0?o`iP070?o`iP00203ol>H0
0`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0oo3V05`0oo3V00<0o`000?o`iP3ol>H00P3ol>H0
0`000000oo3V0?o`iP030?o`iP030?l000000000oo3V07h0oo3V00<000000?o`iP3ol>H01P3ol>H0
00P0oo3V00<000000?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`iP1L0?o`iP030?l0003ol>H0oo3V
0080oo3V00<000000?o`iP3ol>H00`3ol>H00`3o000000000?o`iP1n0?o`iP030000003ol>H0oo3V
00H0oo3V00080?o`iP030000003ol>H0oo3V01l0oo3V00<0o`000?o`iP3ol>H0F`3ol>H00`3o0000
oo3V0?o`iP030?o`iP030000003ol>H0oo3V00<0oo3V00<000000?o`iP3ol>H0OP3ol>H00`000000
oo3V0?o`iP060?o`iP001`3ol>H00`000000oo3V0?o`iP0P0?o`iP030?l0003ol>H0oo3V05/0oo3V
00<0o`000?o`iP3ol>H00`3ol>H00`000000oo3V0?o`iP030?o`iP030000003o0000oo3V07h0oo3V
00<000000?o`iP3ol>H01P3ol>H000L0oo3V00<000000?o`iP3ol>H0803ol>H00`3o0000oo3V0?o`
iP1J0?o`iP030?l0003ol>H0oo3V00@0oo3V00<000000?o`iP3ol>H00`3ol>H00`000000o`000?o`
iP1n0?o`iP030000003ol>H0oo3V00H0oo3V00070?o`iP030000003ol>H0oo3V01l0oo3V00<0o`00
0?o`iP3ol>H0F`3ol>H00`3o0000oo3V0?o`iP040?o`iP030000003ol>H0oo3V0080oo3V00<00000
0?o`iP3o0000O`3ol>H00`000000oo3V0?o`iP060?o`iP001`3ol>H00`000000oo3V0?o`iP0O0?o`
iP030?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H0103ol>H2000000<0oo3V00<000000?o`
iP3o0000P03ol>H00`000000oo3V0?o`iP050?o`iP001`3ol>H00`000000oo3V0?o`iP0O0?o`iP03
0?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H0103ol>H00`000000oo3V0?o`iP020?o`iP04
0000003ol>H0oo3V0?l007l0oo3V00<000000?o`iP3ol>H01@3ol>H000L0oo3V0`00000O0?o`iP03
0?l0003ol>H0oo3V01X0oo3V0P0000040?o`iP030000003ol>H0oo3V0080oo3V0`00000c0?o`iP03
0?l0003ol>H0oo3V00@0oo3V00D000000?o`iP3ol>H0oo3V000000030?o`iP030?l0003ol>H0oo3V
0380oo3V0P0000040?o`iP030000003ol>H0oo3V0080oo3V0`00000k0?o`iP<000001`3ol>H000L0
oo3V0P00000P0?o`iP030?l0003ol>H0oo3V01T0oo3V00@000000?o`iP3ol>H000001`3ol>H01@00
0000oo3V0?o`iP3ol>H000000380oo3V00<0o`000?o`iP3ol>H0103ol>H01@000000oo3V0?o`iP3o
l>H0000000<0oo3V00<0o`000?o`iP3ol>H0<@3ol>H010000000oo3V0?o`iP0000070?o`iP050000
003ol>H0oo3V0?o`iP000000>`3ol>H2000000L0oo3V000500000080oo3V0P00000P0?o`iP030?l0
003ol>H0oo3V0180oo3V1@0000020?o`iP040000003ol>H0oo3V000000/0oo3V00<000000?o`iP3o
l>H0<03ol>H00`3o0000oo3V0?o`iP040?o`iP050000003ol>H0oo3V0?o`iP0000000`3ol>H00`3o
0000oo3V0?o`iP0a0?o`iP040000003ol>H0oo3V000000/0oo3V00<000000?o`iP3ol>H0>@3ol>H2
000000L0oo3V00070?o`iP800000803ol>H00`3o0000oo3V0?o`iP0I0?o`iP040000003ol>H0oo3V
000000/0oo3V00<000000?o`iP3ol>H0;`3ol>H00`3o0000oo3V0?o`iP050?o`iP040000003ol>H0
oo3V000000@0oo3V00<0o`000?o`iP3ol>H0<@3ol>H010000000oo3V0?o`iP00000;0?o`iP030000
003ol>H0oo3V03T0oo3V0P0000070?o`iP001`3ol>H200000200oo3V00<0o`000?o`iP3ol>H06@3o
l>H010000000oo3V0?o`iP0000070?o`iP@00000<P3ol>H00`3o0000oo3V0?o`iP050?o`iP040000
003ol>H0oo3V000000@0oo3V00<0o`000?o`iP3ol>H0<@3ol>H010000000oo3V0?o`iP0000070?o`
iP@00000?03ol>H2000000L0oo3V00060?o`iP<00000803ol>H00`3o0000oo3V0?o`iP0I0?o`iP04
0000003ol>H0oo3V000000L0oo3V00<000000?o`iP3ol>H0<`3ol>H00`3o0000oo3V0?o`iP050?o`
iP040000003ol>H0oo3V000000@0oo3V00<0o`000?o`iP3ol>H0<@3ol>H010000000oo3V0?o`iP00
00070?o`iP030000003ol>H0oo3V03`0oo3V0`0000070?o`iP001P3ol>H00`000000oo3V0000000P
0?o`iP030?l0003ol>H0oo3V01X0oo3V0P0000080?o`iPD00000<@3ol>H00`3o0000oo3V0?o`iP05
0?o`iP030000003ol>H0000000H0oo3V00<0o`000?o`iP3ol>H0<@3ol>H2000000P0oo3V1@00000k
0?o`iP8000001`3ol>H000H0oo3V00<000000?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`iP1K0?o`
iP030?l0003ol>H0oo3V00D0oo3V00<000000?o`iP0000001P3ol>H00`3o0000oo3V0?o`iP1l0?o`
iP030000003ol>H0oo3V00D0oo3V00060?o`iP030000003ol>H0oo3V01l0oo3V00<0o`000?o`iP3o
l>H0F`3ol>H00`3o0000oo3V0?o`iP050?o`iP030000003ol>H0000000H0oo3V00<0o`000?o`iP3o
l>H0O03ol>H00`000000oo3V0?o`iP050?o`iP001P3ol>H00`000000oo3V0?o`iP0O0?o`iP030?l0
003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H01@3ol>H2000000L0oo3V00<0o`000?o`iP3ol>H0
O03ol>H00`000000oo3V0?o`iP050?o`iP001P3ol>H00`000000oo3V0?o`iP0O0?o`iP030?l0003o
l>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H01@3ol>H2000000L0oo3V00<0o`000?o`iP3ol>H0O03o
l>H00`000000oo3V0?o`iP050?o`iP001P3ol>H00`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0
oo3V05/0oo3V00<0o`000?o`iP3ol>H01@3ol>H2000000L0oo3V00<0o`000?o`iP3ol>H0O03ol>H0
0`000000oo3V0?o`iP050?o`iP00:00000000`3o000000000000001K000000030?l0000000000000
00h0000000<0o`00000000000000FP0000000`3o000000000000000W000000001P3ol>H00`000000
oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V00X0oo3V00<000000?o`iP3ol>H0103ol>H00`3o0000
oo3V0?o`iP040?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H02P3ol>H00`000000
oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V00X0oo3V00<000000?o`iP3ol>H02`3ol>H00`000000
oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V0080oo3V00<0o`000?o`iP3ol>H01@3ol>H00`000000
oo3V0?o`iP060?o`iP030?l0003ol>H0oo3V0080oo3V00<000000?o`iP3ol>H02P3ol>H00`000000
oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H02P3ol>H00`000000
oo3V0?o`iP0;0?o`iP030000003ol>H0oo3V00X0oo3V00<000000?o`iP3ol>H0103ol>H00`3o0000
oo3V0?o`iP040?o`iP030000003ol>H0oo3V00/0oo3V00<000000?o`iP3ol>H02P3ol>H00`000000
oo3V0?o`iP050?o`iP001P3ol>H00`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0oo3V01l0oo3V
00<000000?o`iP3ol>H0>@3ol>H00`3o0000oo3V0?o`iP050?o`iP030000003ol>H0oo3V00H0oo3V
00<0o`000?o`iP3ol>H0>03ol>H00`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0oo3V01l0oo3V
00<000000?o`iP3ol>H01@3ol>H000H0oo3V00<000000?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`
iP1K0?o`iP030?l0003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01P3ol>H00`3o0000oo3V0?o`
iP1J0?o`iP030?l0003ol>H0oo3V01l0oo3V00<000000?o`iP3ol>H01@3ol>H000H0oo3V00<00000
0?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0oo3V00D0oo3V00<00000
0?o`iP3ol>H01P3ol>H00`3o0000oo3V0?o`iP1J0?o`iP030?l0003ol>H0oo3V01l0oo3V00<00000
0?o`iP3ol>H01@3ol>H000H0oo3V00<000000?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`iP1K0?o`
iP030?l0003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01P3ol>H00`3o0000oo3V0?o`iP1J0?o`
iP030?l0003ol>H0oo3V01l0oo3V00<000000?o`iP3ol>H01@3ol>H000H0oo3V00<000000?o`iP3o
l>H07`3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0oo3V00D0oo3V00<000000?o`iP3o
l>H01P3ol>H00`3o0000oo3V0?o`iP1J0?o`iP030?l0003ol>H0oo3V01l0oo3V00<000000?o`iP3o
l>H01@3ol>H000H0oo3V00<000000?o`iP3ol>H0803ol>H00`3o0000oo3V0?o`iP1J0?o`iP030?l0
003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01@3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030?l0
003ol>H0oo3V01l0oo3V00<000000?o`iP3ol>H01@3ol>H000L0oo3V00<000000?o`iP3ol>H07`3o
l>H00`3o0000oo3V0?o`iP1J0?o`iP030?l0003ol>H0oo3V00D0oo3V00<000000?o`iP3ol>H01@3o
l>H00`3o0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0oo3V01l0oo3V00<000000?o`iP3ol>H01@3o
l>H000L0oo3V00<000000?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`iP1J0?o`iP030?l0003ol>H0
oo3V00D0oo3V00<000000?o`iP3ol>H01@3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0
oo3V01l0oo3V00<000000?o`iP3ol>H01@3ol>H000L0oo3V00<000000?o`iP3ol>H07`3ol>H00`3o
0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0oo3V00@0oo3V00<000000?o`iP3ol>H01@3ol>H00`3o
0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0oo3V01l0oo3V00<000000?o`iP3ol>H01@3ol>H000L0
oo3V00<000000?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0oo3V00@0
oo3V00<000000?o`iP3ol>H01@3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0oo3V01l0
oo3V00<000000?o`iP3ol>H01@3ol>H000L0oo3V00<000000?o`iP3ol>H07`3ol>H00`3o0000oo3V
0?o`iP1K0?o`iP030?l0003ol>H0oo3V00@0oo3V00<000000?o`iP3ol>H01@3ol>H00`3o0000oo3V
0?o`iP1K0?o`iP030?l0003ol>H0oo3V01l0oo3V00<000000?o`iP3ol>H01@3ol>H000L0oo3V00<0
00000?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030?l0003ol>H0oo3V00@0oo3V0P00
00060?o`iP030?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H07`3ol>H00`000000oo3V0?o`
iP050?o`iP001`3ol>H00`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0oo3V05/0oo3V00<0o`00
0?o`iP3ol>H0103ol>H00`000000oo3V0?o`iP040?o`iP030?l0003ol>H0oo3V05/0oo3V00<0o`00
0?o`iP3ol>H0803ol>H00`000000oo3V0?o`iP050?o`iP001`3ol>H00`000000oo3V0?o`iP0O0?o`
iP030?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H0103ol>H00`000000oo3V0?o`iP040?o`
iP030?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H07`3ol>H00`000000oo3V0?o`iP060?o`
iP001`3ol>H00`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3o
l>H0103ol>H00`000000oo3V0?o`iP040?o`iP030?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3o
l>H07`3ol>H00`000000oo3V0?o`iP060?o`iP001`3ol>H00`000000oo3V0?o`iP0P0?o`iP030?l0
003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H00`3ol>H00`000000oo3V0?o`iP040?o`iP030?l0
003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H07`3ol>H00`000000oo3V0?o`iP060?o`iP00203o
l>H00`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H00`3o
l>H00`000000oo3V0?o`iP030?o`iP030?l0003ol>H0oo3V05`0oo3V00<0o`000?o`iP3ol>H07`3o
l>H00`000000oo3V0?o`iP060?o`iP00203ol>H00`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0
oo3V05`0oo3V00<0o`000?o`iP3ol>H00P3ol>H00`000000oo3V0?o`iP030?o`iP030?l0003ol>H0
oo3V05`0oo3V00<0o`000?o`iP3ol>H07`3ol>H00`000000oo3V0?o`iP060?o`iP00203ol>H00`00
0000oo3V0?o`iP0O0?o`iP030?l0003ol>H0oo3V05`0oo3V00<0o`000?o`iP3ol>H00P3ol>H00`00
0000oo3V0?o`iP030?o`iP030?l0003ol>H0oo3V05/0oo3V00<0o`000?o`iP3ol>H0803ol>H00`00
0000oo3V0?o`iP060?o`iP00203ol>H00`000000oo3V0?o`iP0P0?o`iP030?l0003ol>H0oo3V05/0
oo3V00<0o`000?o`iP3ol>H00P3ol>H00`000000oo3V0?o`iP020?o`iP030?l0003ol>H0oo3V05`0
oo3V00<0o`000?o`iP3ol>H0803ol>H00`000000oo3V0?o`iP060?o`iP00203ol>H00`000000oo3V
0?o`iP0P0?o`iP030?l0003ol>H0oo3V05`0oo3V00D0o`000?o`iP3ol>H0oo3V000000030?o`iP03
0?l0003ol>H0oo3V05d0oo3V00<0o`000?o`iP3ol>H07`3ol>H00`000000oo3V0?o`iP070?o`iP00
203ol>H00`000000oo3V0?o`iP0P0?o`iP030?l0003ol>H0oo3V05d0oo3V00@0o`000?o`iP3ol>H0
00000P3ol>H00`3o0000oo3V0?o`iP1N0?o`iP030?l0003ol>H0oo3V01l0oo3V00<000000?o`iP3o
l>H01`3ol>H000P0oo3V00<000000?o`iP3ol>H0803ol>H00`3o0000oo3V0?o`iP1M0?o`iP040?l0
003ol>H0oo3V00000080oo3V00<0o`000?o`iP3ol>H0G@3ol>H00`3o0000oo3V0?o`iP0P0?o`iP03
0000003ol>H0oo3V00L0oo3V00090?o`iP030000003ol>H0oo3V01l0oo3V00<0o`000?o`iP3ol>H0
GP3ol>H50?l00600oo3V00<0o`000?o`iP3ol>H0803ol>H00`000000oo3V0?o`iP070?o`iP002@3o
l>H00`000000oo3V0?o`iP0O0?o`iP030?l0003ol>H0oo3V0600oo3V00<000000?o`iP3ol>H0H03o
l>H00`3o0000oo3V0?o`iP0P0?o`iP030000003ol>H0oo3V00L0oo3V00090?o`iP030000003ol>H0
oo3V0200oo3V00<0o`000?o`iP3ol>H0G`3ol>H200000600oo3V00<0o`000?o`iP3ol>H08@3ol>H0
0`000000oo3V0?o`iP070?o`iP002@3ol>H00`000000oo3V0?o`iP0P0?o`iP030?l0003ol>H0oo3V
05l0oo3V00<000000?o`iP3ol>H0G`3ol>H00`3o0000oo3V0?o`iP0P0?o`iP030000003ol>H0oo3V
00P0oo3V00090?o`iP030000003ol>H0oo3V0200oo3V00<0o`000?o`iP3ol>H0G`3ol>H00`000000
oo3V0?o`iP1O0?o`iP030?l0003ol>H0oo3V0200oo3V00<000000?o`iP3ol>H0203ol>H000X0oo3V
00<000000?o`iP3ol>H07`3ol>H00`3o0000oo3V0?o`iP1O0?o`iP030000003ol>H0oo3V05l0oo3V
00<0o`000?o`iP3ol>H0803ol>H00`000000oo3V0?o`iP080?o`iP002P3ol>H00`000000oo3V0?o`
iP0P0?o`iP030?l0003ol>H0oo3V05h0oo3V00<000000?o`iP3ol>H0GP3ol>H00`3o0000oo3V0?o`
iP0Q0?o`iP030000003ol>H0oo3V00P0oo3V000:0?o`iP030000003ol>H0oo3V0200oo3V00<0o`00
0?o`iP3ol>H0GP3ol>H00`000000oo3V0?o`iP1N0?o`iP030?l0003ol>H0oo3V0200oo3V00<00000
0?o`iP3ol>H02@3ol>H000/0oo3V00<000000?o`iP3ol>H0803ol>H00`3o0000oo3V0?o`iP1M0?o`
iP030000003ol>H0oo3V05h0oo3V00<0o`000?o`iP3ol>H0803ol>H00`000000oo3V0?o`iP090?o`
iP002`3ol>H00`000000oo3V0?o`iP0P0?o`iP030?l0003ol>H0oo3V05d0oo3V00<000000?o`iP3o
l>H0GP3ol>H00`3o0000oo3V0?o`iP0P0?o`iP030000003ol>H0oo3V00T0oo3V000;0?o`iP030000
003ol>H0oo3V0200oo3V00<0o`000?o`iP3ol>H0G@3ol>H00`000000oo3V0?o`iP1M0?o`iP030?l0
003ol>H0oo3V0240oo3V00<000000?o`iP3ol>H02@3ol>H000/0oo3V00<000000?o`iP3ol>H08@3o
l>H00`3o0000oo3V0?o`iP1L0?o`iP030000003ol>H0oo3V05d0oo3V00<0o`000?o`iP3ol>H08@3o
l>H00`000000oo3V0?o`iP090?o`iP002`3ol>H00`000000oo3V0?o`iP0Q0?o`iP030?l0003ol>H0
oo3V05`0oo3V00<000000?o`iP3ol>H0G03ol>H00`3o0000oo3V0?o`iP0Q0?o`iP030000003ol>H0
oo3V00X0oo3V000<0?o`iP030000003ol>H0oo3V0240oo3V00<0o`000?o`iP3ol>H0F`3ol>H00`00
0000oo3V0?o`iP1L0?o`iP030?l0003ol>H0oo3V0240oo3V00<000000?o`iP3ol>H02P3ol>H000`0
oo3V00<000000?o`iP3ol>H08@3ol>H00`3o0000oo3V0?o`iP1K0?o`iP030000003ol>H0oo3V05/0
oo3V00<0o`000?o`iP3ol>H08P3ol>H00`000000oo3V0?o`iP0:0?o`iP00303ol>H00`000000oo3V
0?o`iP0R0?o`iP030?l0003ol>H0oo3V05X0oo3V00<000000?o`iP3ol>H0F`3ol>H00`3o0000oo3V
0?o`iP0Q0?o`iP030000003ol>H0oo3V00/0oo3V000=0?o`iP030000003ol>H0oo3V0240oo3V00<0
o`000?o`iP3ol>H0FP3ol>H2000005`0oo3V00<0o`000?o`iP3ol>H08@3ol>H00`000000oo3V0?o`
iP0;0?o`iP003@3ol>H00`000000oo3V0?o`iP0Q0?o`iP030?l0003ol>H0oo3V05X0oo3V00<00000
0?o`iP3ol>H0F`3ol>H00`3o0000oo3V0?o`iP0Q0?o`iP030000003ol>H0oo3V00/0oo3V000=0?o`
iP030000003ol>H0oo3V0240oo3V00<0o`000?o`iP3ol>H0FP3ol>H00`000000oo3V0?o`iP1J0?o`
iP030?l0003ol>H0oo3V0240oo3V00<000000?o`iP3ol>H0303ol>H000d0oo3V00<000000?o`iP3o
l>H08P3ol>H00`3o0000oo3V0?o`iP1I0?o`iP030000003ol>H0oo3V05T0oo3V00<0o`000?o`iP3o
l>H08P3ol>H00`000000oo3V0?o`iP0<0?o`iP003P3ol>H00`000000oo3V0?o`iP0R0?o`iP030?l0
003ol>H0oo3V05P0oo3V00<000000?o`iP3ol>H0F@3ol>H00`3o0000oo3V0?o`iP0R0?o`iP030000
003ol>H0oo3V00`0oo3V000>0?o`iP030000003ol>H0oo3V0280oo3V00<0o`000?o`iP3ol>H0F03o
l>H00`000000oo3V0?o`iP1H0?o`iP030?l0003ol>H0oo3V0280oo3V00<000000?o`iP3ol>H03@3o
l>H000h0oo3V00<000000?o`iP3ol>H08`3ol>H00`3o0000oo3V0?o`iP1G0?o`iP030000003ol>H0
oo3V05P0oo3V00<0o`000?o`iP3ol>H08P3ol>H00`000000oo3V0?o`iP0=0?o`iP003`3ol>H00`00
0000oo3V0?o`iP0R0?o`iP030?l0003ol>H0oo3V05L0oo3V00<000000?o`iP3ol>H0E`3ol>H00`3o
0000oo3V0?o`iP0R0?o`iP030000003ol>H0oo3V00h0oo3V000@0?o`iP030000003ol>H0oo3V0280
oo3V00<0o`000?o`iP3ol>H0EP3ol>H00`000000oo3V0?o`iP1G0?o`iP030?l0003ol>H0oo3V0280
oo3V00<000000?o`iP3ol>H03P3ol>H00100oo3V00<000000?o`iP3ol>H08P3ol>H00`3o0000oo3V
0?o`iP1F0?o`iP030000003ol>H0oo3V05H0oo3V00<0o`000?o`iP3ol>H08`3ol>H00`000000oo3V
0?o`iP0>0?o`iP00403ol>H00`000000oo3V0?o`iP0S0?o`iP030?l0003ol>H0oo3V05D0oo3V00<0
00000?o`iP3ol>H0E@3ol>H00`3o0000oo3V0?o`iP0S0?o`iP030000003ol>H0oo3V00l0oo3V000@
0?o`iP030000003ol>H0oo3V02<0oo3V00<0o`000?o`iP3ol>H0E@3ol>H00`000000oo3V0?o`iP1E
0?o`iP030?l0003ol>H0oo3V02<0oo3V00<000000?o`iP3ol>H03`3ol>H00140oo3V00<000000?o`
iP3ol>H08`3ol>H00`3o0000oo3V0?o`iP1D0?o`iP030000003ol>H0oo3V05@0oo3V00<0o`000?o`
iP3ol>H0903ol>H00`000000oo3V0?o`iP0?0?o`iP004P3ol>H00`000000oo3V0?o`iP0S0?o`iP03
0?l0003ol>H0oo3V05<0oo3V0P00001E0?o`iP030?l0003ol>H0oo3V02<0oo3V00<000000?o`iP3o
l>H0403ol>H00180oo3V00<000000?o`iP3ol>H08`3ol>H00`3o0000oo3V0?o`iP1C0?o`iP030000
003ol>H0oo3V05<0oo3V00<0o`000?o`iP3ol>H0903ol>H00`000000oo3V0?o`iP0@0?o`iP004P3o
l>H00`000000oo3V0?o`iP0T0?o`iP030?l0003ol>H0oo3V0580oo3V00<000000?o`iP3ol>H0D`3o
l>H00`3o0000oo3V0?o`iP0S0?o`iP030000003ol>H0oo3V0140oo3V000C0?o`iP030000003ol>H0
oo3V02<0oo3V00<0o`000?o`iP3ol>H0DP3ol>H00`000000oo3V0?o`iP1B0?o`iP030?l0003ol>H0
oo3V02<0oo3V00<000000?o`iP3ol>H04P3ol>H001<0oo3V00<000000?o`iP3ol>H0903ol>H00`3o
0000oo3V0?o`iP1A0?o`iP030000003ol>H0oo3V0540oo3V00<0o`000?o`iP3ol>H0903ol>H00`00
0000oo3V0?o`iP0B0?o`iP00503ol>H00`000000oo3V0?o`iP0T0?o`iP030?l0003ol>H0oo3V0500
oo3V00<000000?o`iP3ol>H0D@3ol>H00`3o0000oo3V0?o`iP0T0?o`iP030000003ol>H0oo3V0180
oo3V000E0?o`iP030000003ol>H0oo3V02@0oo3V00<0o`000?o`iP3ol>H0C`3ol>H00`000000oo3V
0?o`iP1?0?o`iP80o`009P3ol>H00`000000oo3V0?o`iP0C0?o`iP005@3ol>H00`000000oo3V0?o`
iP0U0?o`iP030?l0003ol>H0oo3V04h0oo3V00<000000?o`iP3ol>H0CP3ol>H00`3o0000oo3V0?o`
iP0V0?o`iP030000003ol>H0oo3V01<0oo3V000E0?o`iP030000003ol>H0oo3V02H0oo3V00<0o`00
0?o`iP3ol>H0C@3ol>H00`000000oo3V0?o`iP1>0?o`iP030?l0003ol>H0oo3V02D0oo3V00<00000
0?o`iP3ol>H0503ol>H001D0oo3V00<000000?o`iP3ol>H09P3ol>H00`3o0000oo3V0?o`iP1=0?o`
iP030000003ol>H0oo3V04d0oo3V00<0o`000?o`iP3ol>H09P3ol>H00`000000oo3V0?o`iP0D0?o`
iP005P3ol>H00`000000oo3V0?o`iP0V0?o`iP030?l0003ol>H0oo3V04`0oo3V00<000000?o`iP3o
l>H0C@3ol>H00`3o0000oo3V0?o`iP0U0?o`iP030000003ol>H0oo3V01D0oo3V000G0?o`iP030000
003ol>H0oo3V02D0oo3V00<0o`000?o`iP3ol>H0>@3ol>H2000000@0oo3V00<000000?o`iP3ol>H0
0P3ol>H3000000D0oo3V00<000000?o`iP3ol>H0C03ol>H00`3o0000oo3V0?o`iP0V0?o`iP030000
003ol>H0oo3V01D0oo3V000G0?o`iP030000003ol>H0oo3V02H0oo3V00<0o`000?o`iP3ol>H0=`3o
l>H010000000oo3V0?o`iP0000070?o`iP050000003ol>H0oo3V0?o`iP000000103ol>H00`000000
oo3V0?o`iP1;0?o`iP030?l0003ol>H0oo3V02L0oo3V00<000000?o`iP3ol>H05@3ol>H001P0oo3V
00<000000?o`iP3ol>H09P3ol>H00`3o0000oo3V0?o`iP0f0?o`iP040000003ol>H0oo3V000000/0
oo3V00<000000?o`iP3ol>H00P3ol>H00`000000oo3V0?o`iP1:0?o`iP030?l0003ol>H0oo3V02L0
oo3V00<000000?o`iP3ol>H05P3ol>H001T0oo3V00<000000?o`iP3ol>H09P3ol>H00`3o0000oo3V
0?o`iP0e0?o`iP040000003ol>H0oo3V000000/0oo3V00<000000?o`iP3ol>H00P3ol>H3000004T0
oo3V00<0o`000?o`iP3ol>H09`3ol>H00`000000oo3V0?o`iP0G0?o`iP006@3ol>H00`000000oo3V
0?o`iP0W0?o`iP80o`00=@3ol>H010000000oo3V0?o`iP0000070?o`iP@000001@3ol>H00`000000
oo3V0?o`iP180?o`iP030?l0003ol>H0oo3V02P0oo3V00<000000?o`iP3ol>H05`3ol>H001X0oo3V
00<000000?o`iP3ol>H0:03ol>H00`3o0000oo3V0?o`iP0b0?o`iP040000003ol>H0oo3V000000L0
oo3V00<000000?o`iP3ol>H01P3ol>H00`000000oo3V0?o`iP170?o`iP030?l0003ol>H0oo3V02P0
oo3V00<000000?o`iP3ol>H0603ol>H001X0oo3V00<000000?o`iP3ol>H0:@3ol>H00`3o0000oo3V
0?o`iP0b0?o`iP800000203ol>H5000000@0oo3V00<000000?o`iP3ol>H0AP3ol>H00`3o0000oo3V
0?o`iP0X0?o`iP030000003ol>H0oo3V01T0oo3V000K0?o`iP030000003ol>H0oo3V02T0oo3V00<0
o`000?o`iP3ol>H0A03ol>H00`000000oo3V0?o`iP150?o`iP030?l0003ol>H0oo3V02T0oo3V00<0
00000?o`iP3ol>H06@3ol>H001`0oo3V00<000000?o`iP3ol>H0:@3ol>H00`3o0000oo3V0?o`iP13
0?o`iP030000003ol>H0oo3V04@0oo3V00<0o`000?o`iP3ol>H0:@3ol>H00`000000oo3V0?o`iP0J
0?o`iP00703ol>H00`000000oo3V0?o`iP0Z0?o`iP030?l0003ol>H0oo3V0480oo3V00<000000?o`
iP3ol>H0@`3ol>H00`3o0000oo3V0?o`iP0Y0?o`iP030000003ol>H0oo3V01/0oo3V000M0?o`iP03
0000003ol>H0oo3V02X0oo3V00<0o`000?o`iP3ol>H0@@3ol>H00`000000oo3V0?o`iP110?o`iP80
o`00;03ol>H00`000000oo3V0?o`iP0K0?o`iP007P3ol>H00`000000oo3V0?o`iP0Z0?o`iP030?l0
003ol>H0oo3V0400oo3V00<000000?o`iP3ol>H0@03ol>H00`3o0000oo3V0?o`iP0[0?o`iP030000
003ol>H0oo3V01`0oo3V000N0?o`iP030000003ol>H0oo3V02/0oo3V00<0o`000?o`iP3ol>H0?`3o
l>H00`000000oo3V0?o`iP0o0?o`iP030?l0003ol>H0oo3V02`0oo3V00<000000?o`iP3ol>H0703o
l>H001l0oo3V00<000000?o`iP3ol>H0:`3ol>H20?l003l0oo3V00<000000?o`iP3ol>H0?`3ol>H0
0`3o0000oo3V0?o`iP0[0?o`iP030000003ol>H0oo3V01d0oo3V000P0?o`iP030000003ol>H0oo3V
02`0oo3V00<0o`000?o`iP3ol>H0?03ol>H00`000000oo3V0?o`iP0m0?o`iP80o`00;@3ol>H00`00
0000oo3V0?o`iP0N0?o`iP00803ol>H00`000000oo3V0?o`iP0/0?o`iP030?l0003ol>H0oo3V03`0
oo3V00<000000?o`iP3ol>H0?03ol>H00`3o0000oo3V0?o`iP0]0?o`iP030000003ol>H0oo3V01h0
oo3V000Q0?o`iP030000003ol>H0oo3V02`0oo3V0P3o000l0?o`iP800000>`3ol>H20?l002l0oo3V
00<000000?o`iP3ol>H07`3ol>H00280oo3V00<000000?o`iP3ol>H0;@3ol>H20?l003X0oo3V00<0
00000?o`iP3ol>H0>@3ol>H00`3o0000oo3V0?o`iP0^0?o`iP030000003ol>H0oo3V0200oo3V000R
0?o`iP030000003ol>H0oo3V02l0oo3V00<0o`000?o`iP3ol>H0=`3ol>H00`000000oo3V0?o`iP0h
0?o`iP030?l0003ol>H0oo3V02l0oo3V00<000000?o`iP3ol>H0803ol>H002<0oo3V00<000000?o`
iP3ol>H0;`3ol>H20?l003L0oo3V00<000000?o`iP3ol>H0=`3ol>H00`3o0000oo3V0?o`iP0_0?o`
iP030000003ol>H0oo3V0240oo3V000T0?o`iP030000003ol>H0oo3V0300oo3V0P3o000e0?o`iP03
0000003ol>H0oo3V03D0oo3V0P3o000`0?o`iP800000903ol>H002D0oo3V00<000000?o`iP3ol>H0
<@3ol>H00`3o0000oo3V0?o`iP0b0?o`iP030000003ol>H0oo3V03<0oo3V0P3o000a0?o`iP030000
003ol>H0oo3V02@0oo3V000V0?o`iP030000003ol>H0oo3V0340oo3V0P3o000b0?o`iP030000003o
l>H0oo3V0380oo3V00<0o`000?o`iP3ol>H0<03ol>H00`000000oo3V0?o`iP0U0?o`iP009P3ol>H0
0`000000oo3V0?o`iP0c0?o`iP80o`00<03ol>H00`000000oo3V0?o`iP0`0?o`iP80o`00<`3ol>H0
0`000000oo3V0?o`iP0U0?o`iP009`3ol>H00`000000oo3V0?o`iP0d0?o`iP80o`00;P3ol>H00`00
0000oo3V0?o`iP0^0?o`iP80o`00=03ol>H00`000000oo3V0?o`iP0V0?o`iP00:03ol>H2000003H0
oo3V00<0o`000?o`iP3ol>H0:`3ol>H00`000000oo3V0?o`iP0/0?o`iP80o`00=@3ol>H00`000000
oo3V0?o`iP0W0?o`iP00:P3ol>H00`000000oo3V0?o`iP0d0?o`iP80o`00:`3ol>H00`000000oo3V
0?o`iP0[0?o`iP030?l0003ol>H0oo3V03@0oo3V00<000000?o`iP3ol>H0:03ol>H002/0oo3V00<0
00000?o`iP3ol>H0=@3ol>H20?l002T0oo3V00<000000?o`iP3ol>H09`3ol>H40?l003H0oo3V00<0
00000?o`iP3ol>H0:@3ol>H002/0oo3V00<000000?o`iP3ol>H0=`3ol>H20?l002L0oo3V00<00000
0?o`iP3ol>H09@3ol>H20?l003X0oo3V00<000000?o`iP3ol>H0:@3ol>H002`0oo3V00<000000?o`
iP3ol>H0>03ol>H20?l002D0oo3V00<000000?o`iP3ol>H08`3ol>H20?l003/0oo3V00<000000?o`
iP3ol>H0:P3ol>H002d0oo3V00<000000?o`iP3ol>H0>@3ol>H30?l00280oo3V0P00000R0?o`iP80
o`00>`3ol>H2000002d0oo3V000^0?o`iP030000003ol>H0oo3V03/0oo3V0P3o000P0?o`iP030000
003ol>H0oo3V01d0oo3V103o000l0?o`iP030000003ol>H0oo3V02d0oo3V000_0?o`iP800000?@3o
l>H40?l001`0oo3V00<000000?o`iP3ol>H06P3ol>H30?l003l0oo3V00<000000?o`iP3ol>H0;P3o
l>H00340oo3V00<000000?o`iP3ol>H0?P3ol>H40?l001P0oo3V00<000000?o`iP3ol>H05P3ol>H4
0?l00440oo3V00<000000?o`iP3ol>H0;`3ol>H00380oo3V00<000000?o`iP3ol>H0@@3ol>H40?l0
01@0oo3V00<000000?o`iP3ol>H04P3ol>H40?l004@0oo3V00<000000?o`iP3ol>H0<03ol>H00380
oo3V00<000000?o`iP3ol>H0A@3ol>H60?l000h0oo3V00<000000?o`iP3ol>H03P3ol>H40?l004L0
oo3V00<000000?o`iP3ol>H0<@3ol>H003<0oo3V00<000000?o`iP3ol>H0BP3ol>H80?l000H0oo3V
00<000000?o`iP3ol>H0103ol>H:0?l004X0oo3V00<000000?o`iP3ol>H0<P3ol>H003@0oo3V0P00
001B0?o`iPd0o`00D`3ol>H00`000000oo3V0?o`iP0c0?o`iP00=P3ol>H00`000000oo3V0?o`iP1E
0?o`iP030000003ol>H0oo3V05H0oo3V00<000000?o`iP3ol>H0=03ol>H003L0oo3V00<000000?o`
iP3ol>H0E03ol>H00`000000oo3V0?o`iP1D0?o`iP800000=`3ol>H003P0oo3V00<000000?o`iP3o
l>H0D`3ol>H00`000000oo3V0?o`iP1C0?o`iP030000003ol>H0oo3V03L0oo3V000i0?o`iP800000
D`3ol>H00`000000oo3V0?o`iP1A0?o`iP800000>P3ol>H003/0oo3V00<000000?o`iP3ol>H0D03o
l>H00`000000oo3V0?o`iP1@0?o`iP030000003ol>H0oo3V03X0oo3V000l0?o`iP800000D03ol>H0
0`000000oo3V0?o`iP1?0?o`iP030000003ol>H0oo3V03/0oo3V000n0?o`iP030000003ol>H0oo3V
04d0oo3V0P00001?0?o`iP030000003ol>H0oo3V03`0oo3V000o0?o`iP800000C@3ol>H00`000000
oo3V0?o`iP1<0?o`iP800000?`3ol>H00440oo3V00<000000?o`iP3ol>H0BP3ol>H00`000000oo3V
0?o`iP1;0?o`iP030000003ol>H0oo3V03l0oo3V00120?o`iP030000003ol>H0oo3V04T0oo3V00<0
00000?o`iP3ol>H0B@3ol>H200000480oo3V00130?o`iP030000003ol>H0oo3V04P0oo3V00<00000
0?o`iP3ol>H0B03ol>H00`000000oo3V0?o`iP120?o`iP00A03ol>H2000004P0oo3V00<000000?o`
iP3ol>H0AP3ol>H2000004D0oo3V00160?o`iP030000003ol>H0oo3V04D0oo3V00<000000?o`iP3o
l>H0A@3ol>H00`000000oo3V0?o`iP150?o`iP00A`3ol>H3000004@0oo3V00<000000?o`iP3ol>H0
@`3ol>H2000004P0oo3V001:0?o`iP800000@P3ol>H00`000000oo3V0?o`iP100?o`iP<00000BP3o
l>H004`0oo3V00<000000?o`iP3ol>H0?`3ol>H00`000000oo3V0?o`iP0o0?o`iP030000003ol>H0
oo3V04/0oo3V001=0?o`iP800000?`3ol>H00`000000oo3V0?o`iP0m0?o`iP800000CP3ol>H004l0
oo3V00<000000?o`iP3ol>H0?03ol>H00`000000oo3V0?o`iP0l0?o`iP030000003ol>H0oo3V04h0
oo3V001@0?o`iP<00000>`3ol>H00`000000oo3V0?o`iP0i0?o`iP<00000D@3ol>H005<0oo3V0P00
000i0?o`iP800000>@3ol>H00`000000oo3V0?o`iP1B0?o`iP00E@3ol>H00`000000oo3V0?o`iP0f
0?o`iP030000003ol>H0oo3V03H0oo3V0P00001E0?o`iP00EP3ol>H3000003D0oo3V00<000000?o`
iP3ol>H0<`3ol>H3000005L0oo3V001I0?o`iP800000<`3ol>H00`000000oo3V0?o`iP0a0?o`iP80
0000FP3ol>H005/0oo3V0`00000`0?o`iP030000003ol>H0oo3V02h0oo3V0`00001L0?o`iP00GP3o
l>H3000002d0oo3V00<000000?o`iP3ol>H0;@3ol>H00`000000oo3V0?o`iP1M0?o`iP00H@3ol>H2
000002/0oo3V00<000000?o`iP3ol>H0:P3ol>H300000600oo3V001S0?o`iP<00000:03ol>H00`00
0000oo3V0?o`iP0V0?o`iP@00000H`3ol>H006H0oo3V0`00000U0?o`iP030000003ol>H0oo3V02<0
oo3V0`00001W0?o`iP00J@3ol>H500000200oo3V00<000000?o`iP3ol>H07P3ol>H5000006X0oo3V
001^0?o`iP@00000703ol>H00`000000oo3V0?o`iP0K0?o`iP<00000K`3ol>H00780oo3V1@00000?
0?o`iP<000001@3ol>H00`000000oo3V0?o`iP0F0?o`iPD00000LP3ol>H007L0oo3V1P00000:0?o`
iP030000003ol>H0oo3V00@0oo3V00<000000?o`iP3ol>H03`3ol>H7000007L0oo3V001m0?o`iP/0
00001P3ol>H00`000000oo3V0?o`iP050?o`iPX00000OP3ol>H008L0oo3V3`0000280?o`iP00Q`3o
l>H00`000000oo3V0?o`iP040?o`iP030000003ol>H0oo3V08d0oo3V00260?o`iP8000001P3ol>H0
0`000000oo3V0?o`iP2=0?o`iP00Q`3ol>H00`000000oo3V0?o`iP040?o`iP030000003ol>H0oo3V
08d0oo3V002>0?o`iP030000003ol>H0oo3V08d0oo3V002>0?o`iP030000003ol>H0oo3V08d0oo3V
002>0?o`iP030000003ol>H0oo3V08d0oo3V0000\
\>"],
  ImageRangeCache->{{{0, 285.5}, {285.5, 0}} -> {-1.05001, -1.05001, \
0.0073556, 0.0073556}}],

Cell[TextData[{
  "The angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " and the angle we want, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Alpha]", "-", 
          FormBox[\(\(3  \[Pi]\)\/\(\(2\)\(\ \)\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  StyleBox[".",
    FontSize->12]
}], "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The above picture shows a small elongated ellipse at the origin, one of \
the pictures of the bouncing ball.  The arrow in the picture is the unit \
tangent vector to the left hand curve for frame ",
  Cell[BoxData[
      \(17\)]],
  ", and the angle ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " referred to above is indicated.  Clearly the angle we want to rotate the \
little red ellipse through is ",
  Cell[BoxData[
      RowBox[{"\[Alpha]", " ", "-", " ", 
        StyleBox[\(\(3  \[Pi]\)\/2\),
          FontWeight->"Bold"]}]]],
  ".  Since \n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"cos", " ", 
          RowBox[{"(", 
            RowBox[{"\[Alpha]", " ", "-", " ", 
              StyleBox[\(\(3  \[Pi]\)\/2\),
                FontWeight->"Bold"]}], ")"}]}], " ", "=", 
        " ", \(\(-\ sin\)\(\ \)\(\[Alpha]\)\(\ \)\)}]]],
  "\nand \n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"sin", " ", 
          RowBox[{"(", 
            RowBox[{"\[Alpha]", " ", "-", " ", 
              StyleBox[\(\(3  \[Pi]\)\/2\),
                FontWeight->"Bold"]}], ")"}]}], " ", "=", 
        " ", \(cos\ \[Alpha]\)}]]],
  ", \nwe know that the cosine of our rotation angle is ",
  Cell[BoxData[
      RowBox[{"-", 
        SubscriptBox[
          OverscriptBox[
            StyleBox["n",
              FontWeight->"Bold"], "\[RightVector]"], "y"]}]]],
  "  and the sine of our rotation angle is ",
  Cell[BoxData[
      SubscriptBox[
        OverscriptBox[
          StyleBox["n",
            FontWeight->"Bold"], "\[RightVector]"], "x"]]],
  "."
}], "Text"],

Cell[TextData[{
  "Finally, we know that for any angle ",
  Cell[BoxData[
      \(\[CurlyPhi]\)]],
  " the matrix "
}], "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
            {\(cos\ \[CurlyPhi]\), \(\(-sin\)\ \[CurlyPhi]\)},
            {\(sin\ \[CurlyPhi]\), \(cos\ \[CurlyPhi]\)}
            }], "\[NegativeThinSpace]", ")"}]}]], "Text"],

Cell[TextData[{
  "is the rotation matrix for counterclockwise rotation of angle ",
  StyleBox["\[CurlyPhi]", "Output",
    FontSize->16],
  ".  Hence our rotation matrix will be "
}], "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        RowBox[{"(", "\[NegativeThinSpace] ", GridBox[{
              {
                RowBox[{"-", 
                  SubscriptBox[
                    OverscriptBox[
                      StyleBox["n",
                        FontWeight->"Bold"], "\[RightVector]"], "y"]}], 
                RowBox[{"-", 
                  SubscriptBox[
                    OverscriptBox[
                      StyleBox["n",
                        FontWeight->"Bold"], "\[RightVector]"], "x"]}]},
              {
                RowBox[{" ", 
                  SubscriptBox[
                    OverscriptBox[
                      StyleBox["n",
                        FontWeight->"Bold"], "\[RightVector]"], "x"]}], 
                RowBox[{"-", 
                  SubscriptBox[
                    OverscriptBox[
                      StyleBox["n",
                        FontWeight->"Bold"], "\[RightVector]"], "y"]}]}
              }], ")"}], "=", "  ", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(-n\[LeftDoubleBracket]2\[RightDoubleBracket]\), \(-n\
\[LeftDoubleBracket]1\[RightDoubleBracket]\)},
              {\(n\[LeftDoubleBracket]1\[RightDoubleBracket]\), \(-n\
\[LeftDoubleBracket]2\[RightDoubleBracket]\)}
              }], "\[NegativeThinSpace]", ")"}]}]}]], "Text"],

Cell[TextData[{
  "If we add the translation from the origin to the point ",
  Cell[BoxData[
      RowBox[{" ", Cell[TextData[Cell[BoxData[
            \(\((x\_0, \ y\_0)\)\)]]]]}]]],
  " along our curve we get"
}], "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox["p",
              FontWeight->"Bold"], "\[RightVector]"], \((\[Theta])\)}], " ", 
        "=", " ", 
        RowBox[{
          RowBox[{
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {\(-n\[LeftDoubleBracket]2\[RightDoubleBracket]\), \(-n\
\[LeftDoubleBracket]1\[RightDoubleBracket]\)},
                  {\(n\[LeftDoubleBracket]1\[RightDoubleBracket]\), \(-n\
\[LeftDoubleBracket]2\[RightDoubleBracket]\)}
                  }], "\[NegativeThinSpace]", ")"}], 
            "\[CenterDot]", \((a\ cos\ \[Theta], \ b\ sin\ \[Theta])\)}], "+",
           " ", \((x\_0, \ y\_0)\)}]}]}]], "Text"],

Cell[TextData[{
  "as the parametric equation of our ellipse.  The following procedure will \
plot the ellipse we want.  The input parameters for the procedure ",
  StyleBox["ellipse", "Input",
    FontWeight->"Plain"],
  " are\n\t    ",
  Cell[BoxData[
      \({x0, y0}\)]],
  "  \t  the center of the ellipse\n\t    ",
  StyleBox["{a, b}", "Input",
    FontWeight->"Plain"],
  "\t  \t  the lengths of the axes of the ellipse\n\t    ",
  StyleBox["{nx, ny}\t\t", "Input",
    FontWeight->"Plain"],
  "the vector ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["n",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " discussed above."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[ellipse];\)\), "\n", 
    \(ellipse[{x0_, y0_}, \ {a_, b_}, {nx_, 
          ny_}]\  := \[IndentingNewLine]ParametricPlot[\n\t\t{\(-ny\)\ a\ Cos[
                t]\  - nx\ b\ Sin[t]\  + x0, 
          nx\ a\ Cos[t] - ny\ b\ Sin[t] + y0}, \ {t, 0, 2  Pi}, 
        DisplayFunction -> Identity]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Model the Squash and Stretch - Squashing the Ellipses", "Subsubsection"],

Cell[TextData[{
  "We have modeled the ball with a circle of  radius ",
  Cell[BoxData[
      \(0.25\)]],
  ".  The first ellipse we draw will have major and minor axes close to ",
  Cell[BoxData[
      \(0.25\)]],
  ", and the last ellipse we draw will have major axis ",
  Cell[BoxData[
      \(0.5\)]],
  " and minor axis ",
  Cell[BoxData[
      \(0.125\)]],
  " (this is an arbitrary choice).  We construct the lerp between the two \
extremes :"
}], "Text"],

Cell[BoxData[
    StyleBox[\(axes[t_]\  := \ \((1 - t)\)*{0.25, 0.25}\  + \ 
          t*{0.125, 0.5}\),
      "Input"]], "Input"],

Cell[TextData[{
  "We'll start using ellipses to draw the ball at frame ",
  Cell[BoxData[
      \(14\)]],
  " and use ",
  StyleBox["axes[t]", "Input",
    FontWeight->"Plain"],
  " with a value of ",
  Cell[BoxData[
      \(t\  = \ 0\)]],
  ", and we'll complete our ellipse drawing at frame ",
  Cell[BoxData[
      \(19\)]],
  " and use ",
  StyleBox["axes[t]", "Input",
    FontWeight->"Plain"],
  " with a value of ",
  Cell[BoxData[
      \(t\  = \ 1\)]],
  ".  Clearly the corresponding values of ",
  Cell[BoxData[
      \(t\)]],
  " for the inbetween frames will be"
}], "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        TagBox[GridBox[{
              {"Frame", "14", "15", "16", "17", "18", "19"},
              {"t", "0", "0.2", "0.4", "0.6", "0.8", "1.0"}
              },
            ColumnWidths->3,
            ColumnAlignments->{Center},
            RowLines->True,
            ColumnLines->True],
          DisplayForm],
        FontFamily->"Courier"], TextForm]], "Text",
  CellMargins->{{57.3125, Inherited}, {Inherited, Inherited}}],

Cell["We'll look at the ellipses produced:", "Text"],

Cell[BoxData[
    \(\(LeftAx\  = \ Table[axes[i/5], {i, 0, 5}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
        Table[ellipse[i*{0.75, 0}, 
            LeftAx\[LeftDoubleBracket]i\[RightDoubleBracket], {0, 1}], {i, 1, 
            6}], \ AspectRatio -> Automatic, 
        DisplayFunction -> $DisplayFunction, Axes -> False];\)\)], "Input"],

Cell["\<\
Since that looks good, we'll do the other side of the bounce the \
same way:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        TagBox[GridBox[{
              {"Frame", "21", "22", "23", "24", "25", "26"},
              {"t", "1", "0.8", "0.6", "0.4", "0.2", "0.0"}
              },
            ColumnWidths->3,
            ColumnAlignments->{Center},
            RowLines->True,
            ColumnLines->True],
          DisplayForm],
        FontFamily->"Courier"], TextForm]], "Text",
  CellMargins->{{57.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(RightAx\  = \ Table[axes[i/5], {i, 5, 0, \(-1\)}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
        Table[ellipse[i*{0.75, 0}, 
            RightAx\[LeftDoubleBracket]i\[RightDoubleBracket], {0, 1}], {i, 
            1, 6}], \ AspectRatio -> Automatic, 
        DisplayFunction -> $DisplayFunction, Axes -> False];\)\)], "Input"],

Cell[TextData[{
  "One final observation.  The ellipse at the bottom of the bounce will have \
axes ",
  Cell[BoxData[
      \(\((0.5, \ 0.125)\)\)]],
  " and its ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " vector will be ",
  Cell[BoxData[
      \(\((0, 1)\)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Putting it all together--", "Subsubsection",
  FontWeight->"Bold"],

Cell["Make a table of all of the centers...", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(centers\  = 
        Join[\[IndentingNewLine]Table[
            bspline[kt, ctrl1, 
              val1\[LeftDoubleBracket]i\[RightDoubleBracket], 0], {i, 1, 
              20}], \[IndentingNewLine]Table[
            bspline[kt, ctrl2, 
              val2\[LeftDoubleBracket]i\[RightDoubleBracket], 0], {i, 1, 
              19}]];\)\)], "Input"],

Cell[TextData[{
  "Make a table of the vectors ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " for each side"
}], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(LeftN\  = 
        Table[\((x = 
                bspline[kt, ctrl1, 
                  val1\[LeftDoubleBracket]i\[RightDoubleBracket], 1])\)/
            Sqrt[x . x], {i, 14, 19}];\)\)], "Input"],

Cell[BoxData[
    \(\(RightN\  = 
        Table[\((x = 
                bspline[kt, ctrl2, 
                  val2\[LeftDoubleBracket]i\[RightDoubleBracket], 1])\)/
            Sqrt[x . x], {i, 1, 6}];\)\)], "Input"],

Cell["Plot Every Other Ellipse", "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(Show[{Graphics[
            Table[{Circle[centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  0.25]}, {i, 1, 13, 2}]], \n\t\t\tTable[
            ellipse[centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
              LeftAx\[LeftDoubleBracket]i - 13\[RightDoubleBracket], 
              LeftN\[LeftDoubleBracket]i - 13\[RightDoubleBracket]], {i, 15, 
              19, 2}], \n\t\tellipse[
            centers\[LeftDoubleBracket]20\[RightDoubleBracket], \ {0.5, 
              0.125}, {0, 1}], \n\t
          Table[ellipse[centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
              RightAx\[LeftDoubleBracket]i - 20\[RightDoubleBracket], 
              RightN\[LeftDoubleBracket]i - 20\[RightDoubleBracket]], {i, 22, 
              26, 2}], \n\t
          Graphics[\t
            Table[{Circle[centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  0.25]}, {i, 27, 39, 2}]]\n\t\t\n\t}, \n\t
        Axes \[Rule] False, PlotRange -> {{0, 6}, {\(-1\), 3}}];\)\)], "Input"],

Cell[TextData[{
  "After looking at the above picture for a period of time, we decide to \
eliminate Frame ",
  Cell[BoxData[
      \(19\)]],
  " since the stretch extends below the \"floor\", and eliminate Frame ",
  Cell[BoxData[
      \(26\)]],
  " because it is bunched up with Frame  ",
  Cell[BoxData[
      \(27\)]],
  ".  The resulting picture is the one that began this section.  The \
following produces the desired animation in 3D Explorer."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\t\(gr\  = \ 
        Join[Table[
            Show[Graphics[{Circle[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    0.25]}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 1, 14, 2}], \n\t\t\tTable[
            Show[ellipse[centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                LeftAx\[LeftDoubleBracket]i - 13\[RightDoubleBracket], 
                LeftN\[LeftDoubleBracket]i - 13\[RightDoubleBracket]], 
              Axes \[Rule] False, PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 15, 18, 2}], \n\t\t{Show[
              ellipse[centers\[LeftDoubleBracket]20\[RightDoubleBracket], \ \
{0.5, 0.125}, {0, 1}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity]}, \n\t
          Table[Show[
              ellipse[centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                RightAx\[LeftDoubleBracket]i - 20\[RightDoubleBracket], 
                RightN\[LeftDoubleBracket]i - 20\[RightDoubleBracket]], 
              Axes \[Rule] False, PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 22, 25, 2}], \n\t\t\t\n\t
          Table[Show[
              Graphics[{Circle[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    0.25]}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 27, 39, 2}]];\)\)}], "Input"],

Cell[BoxData[
    \(\(GLShow[gr, AnimateFrames \[Rule] True];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Model Slow In, Slow Out", "Subsubsection"],

Cell["\<\
Except for the two frames we removed, the motion for this animation \
is constant speed, although twice as fast as our original model (every other \
frame).  We can slow the animation down at any point in the path by adding \
back in some of the frames we took out.\
\>", "Text"],

Cell[TextData[{
  "Using Lasseter (LA) as our guide again, we slow the animation down at the \
top of the bounces by adding back in some frames.  Look again at the labeled \
version of the circles above.  We add back in frames ",
  Cell[BoxData[
      \(7\)]],
  ", and ",
  Cell[BoxData[
      \(9\)]],
  " on the left side of the bounce and frames ",
  Cell[BoxData[
      \(30, \ 32\)]],
  ", and ",
  Cell[BoxData[
      \(34\)]],
  " on the right side of the bounce."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\t\(gr\  = \ 
        Join[Table[
            Show[Graphics[{Circle[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    0.25]}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 1, 8, 2}], \n\t\tTable[
            Show[Graphics[{Circle[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    0.25]}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 9, 14, 1}], \n\t\t\tTable[
            Show[ellipse[centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                LeftAx\[LeftDoubleBracket]i - 13\[RightDoubleBracket], 
                LeftN\[LeftDoubleBracket]i - 13\[RightDoubleBracket]], 
              Axes \[Rule] False, PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 15, 18, 2}], \n\t\t{Show[
              ellipse[centers\[LeftDoubleBracket]20\[RightDoubleBracket], \ \
{0.5, 0.125}, {0, 1}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity]}, \n\t
          Table[Show[
              ellipse[centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                RightAx\[LeftDoubleBracket]i - 20\[RightDoubleBracket], 
                RightN\[LeftDoubleBracket]i - 20\[RightDoubleBracket]], 
              Axes \[Rule] False, PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 22, 25, 2}], \n\t
          Table[Show[
              Graphics[{Circle[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    0.25]}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 27, 29, 2}], \t
          Table[Show[
              Graphics[{Circle[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    0.25]}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 30, 34, 1}], \t
          Table[Show[
              Graphics[{Circle[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    0.25]}], Axes \[Rule] False, 
              PlotRange -> {{0, 6}, {\(-1\), 3}}, 
              DisplayFunction -> Identity], {i, 35, 39, 
              2}]\n\t];\)\)}], "Input"],

Cell[BoxData[
    \(\(GLShow[gr, AnimateFrames \[Rule] True];\)\)], "Input"],

Cell[TextData[{
  "The previous discussion was primarily ",
  Cell[BoxData[
      \(2\)]],
  " dimensional.  While it is true that the three dimensional case is an \
obvious generalization, let's work through it anyway."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The Three Dimensional Bouncing Ball", "Subsection"],

Cell[TextData[{
  "We'll model the ball taking its first arc in the ",
  Cell[BoxData[
      \(YZ\)]],
  " plane.  After the ball hits, assuming some spin on the ball, the bounce \
will go off at a ",
  Cell[BoxData[
      \(45  \[Degree]\)]],
  "  angle.  Hence, the second set of circles/ellipses will be along the line \
from ",
  Cell[BoxData[
      \(\((3, 0, 0)\)\)]],
  " to ",
  Cell[BoxData[
      \(\((4, 1, 0)\)\)]],
  "."
}], "Text"],

Cell["\<\
The real problem in three dimensions will be modeling the spheres \
and ellipses (actually ellipsoids in three dimensions), but that won't be too \
bad since we already have a hint from dealing with the parametric equations \
of the ellipses in two dimensions. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Ellipsoids", "Subsubsection"],

Cell["\<\
A parametric equation of an ellipsoid centered at the origin \
is\
\>", "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox["p",
              FontWeight->"Bold"], "\[RightVector]"], \((u, v)\)}], " ", "=", 
        " ", \((a\ cos\ u\ cos\ v, \ b\ sin\ u\ cos\ v, \ 
          c\ sin\ v)\)}]}]], "Text"],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(0\  \[LessEqual] \ u\  \[LessEqual] \ 2  \[Pi]\)]],
  "  and ",
  Cell[BoxData[
      \(\(-\ \(\[Pi]\/2\)\)\  \[LessEqual] \ v\  \[LessEqual] \ \[Pi]\/2\)]],
  ".  If  ",
  Cell[BoxData[
      \(a\  = \ \(b\  = \ c\)\)]],
  " then the ellipsoid is a sphere with radius ",
  Cell[BoxData[
      \(a\)]],
  "."
}], "Text"],

Cell[TextData[{
  "We'll need to rotate the ellipse so that the major axis is parallel to the \
derivative vector of the curve at the point on the curve where we locate the \
center of the ellipse. In this case we'll assume that the major axis of the \
ellipse is along the ",
  Cell[BoxData[
      \(X\)]],
  " axis.  If ",
  Cell[BoxData[
      \(\((p, q, r)\)\)]],
  " is a vector on the unit sphere, that is if  ",
  Cell[BoxData[
      \(p\^2\  + \ q\^2\  + \ r\^2\  = \ 1\)]],
  " , then a rotation around the origin that takes the vector ",
  Cell[BoxData[
      \(\((1, 0, 0)\)\)]],
  " to the vector ",
  Cell[BoxData[
      \(\((p, q, r)\)\)]],
  " is given by the matrix"
}], "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {
                "p", \(\(-q\)\/\@\(p\^2 + q\^2\)\), \(\(-pr\)\/\@\(p\^2 + \
q\^2\)\)},
              {
                "q", \(p\/\@\(p\^2 + q\^2\)\), \(\(-qr\)\/\@\(p\^2 + \
q\^2\)\)},
              {"r", "0", \(\@\(p\^2 + q\^2\)\)}
              }], "\[NegativeThinSpace]", ")"}], "."}]}]], "Text"],

Cell[TextData[{
  "(First rotate around the ",
  Cell[BoxData[
      \(Y\)]],
  " axis so that ",
  Cell[BoxData[
      \(\((1, 0, 0)\)\  \[RightArrow] \ \((\@\(p\^2 + \ q\^2\), \ 0, \ 
          r)\)\)]],
  " then around the ",
  Cell[BoxData[
      \(Z\)]],
  " axis so that ",
  Cell[BoxData[
      \(\((1, 0, 0)\)\)]],
  " lines up with ",
  Cell[BoxData[
      \(\((p\/\@\(p\^2 + \ q\^2\), \ q\/\@\(p\^2 + \ q\^2\), \ 0)\)\)]],
  ".  For alternate rotation matrices that produce the same results, see the \
next section on Quaternions.  Also see (MH) and references contained there.)"
}], "Text"],

Cell["\<\
We define the general purpose parametric ellipse for this animation \
as follows:\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[ellipsoid];\)\), "\n", 
    \(\t\(ellipsoid\ [{x0_, y0_, z0_}, {a_, b_, c_}, {p_, q_, r_}]\)[u_, 
        v_]\ \  := 
      Module[{sq}, \n\t\tsq\  = \ 
          Sqrt[p^2 + 
              q^2]; \n\t\tReturn[{\(1\/sq\) \((p\ *sq*\ Cos[u]*\ Cos[v]*a - 
                    q\ *Cos[v]*b*\ Sin[u] - p\ *r\ *c\ *Sin[v])\) + 
              x0, \(1\/sq\) \((q\ *sq\ *Cos[u]*Cos[v]\ *a + 
                    p\ *Cos[v]*b\ *Sin[u] - q\ *r\ *c*Sin[v])\) + y0, 
            r\ *Cos[u]*\ Cos[v]\ *a + sq\ *c\ *Sin[v] + z0}]]\)}], "Input"],

Cell[TextData[{
  "where the input parameters are\n\t\t",
  Cell[BoxData[Cell["{x0,y0,z0}"]]],
  "\t  the center of the ellipsoid\n\t\t",
  Cell[BoxData[Cell["{a, b, c}"]]],
  "\t\t  the lengths of the major axes of the ellipsoid\t\n\t\t",
  Cell[BoxData[Cell["{p,q,r}"]]],
  "\t\t  the vector determining the rotation of the\n\t\t\t\t     \t\t   \
ellipsoid\nYou should have no trouble explaining the above procedure to \
yourself (or anyone else who happens to ask).  We'll use ",
  StyleBox["ellipsoid", "Input",
    FontWeight->"Plain"],
  " to draw both the ellipses and the spheres."
}], "Text"],

Cell["\<\
One last modeling difference.  At the point of contact,  the \
splatted ball is (arbitrarily) chosen to be circular, stretched.  The \
remainder of this section is mostly computation that mimics the computation \
above for the two dimensional case.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pick a Path", "Subsubsection"],

Cell["The Data", "Text",
  CellMargins->{{36, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[pos];\)\), "\n", 
    \(\(pos\  = 
        N[\ {{1, 0, 1}, {2, 0, 2}, {3, 0, 0}, {3 + Sqrt[2]/2, \ Sqrt[2]/2, 
              1.8}, {3 + Sqrt[2], \ Sqrt[2], 1}}];\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["The Knots", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[kt];\)\), "\n", 
    \(\(kt\  = \ {0.0, \ 0.0, \ 0.0, \ \ 1.0, \ 1.0, \ 1.0};\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["The Unknown Control Points", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[ct];\)\), "\n", 
    \(\(ct\  = \ {{x1, y1, z1}, {x2, y2, z2}, {x3, y3, z3}};\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[TextData[StyleBox["Unknown spline function(s)",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[c];\)\), "\n", 
    \(\t\(c[t_]\ \  := \ \ bspline[kt, \ ct, t, 0];\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[TextData[StyleBox["The Two Quadratic Splines",
  FontWeight->"Bold"]], "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[ans1, ans2];\)\), "\n", 
    \(\t\(ans1\  = 
        Solve[{c[0]\ , c[0.5], 
              c[1.0]} == {pos\[LeftDoubleBracket]1\[RightDoubleBracket], 
              pos\[LeftDoubleBracket]2\[RightDoubleBracket], 
              pos\[LeftDoubleBracket]3\[RightDoubleBracket]\ }];\)\)}], \
"Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\t\)\(ans2\  = 
        Solve[{c[0]\ , c[0.5], 
              c[1.0]} == {pos\[LeftDoubleBracket]3\[RightDoubleBracket], 
              pos\[LeftDoubleBracket]4\[RightDoubleBracket], 
              pos\[LeftDoubleBracket]5\[RightDoubleBracket]\ }];\)\)\)], \
"Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(ctrl1\  = \ 
        ct /. ans1\[LeftDoubleBracket]1\[RightDoubleBracket];\)\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(ctrl2\  = \ 
        ct /. ans2\[LeftDoubleBracket]1\[RightDoubleBracket];\)\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Plot the new trace curves and the original key frames to make sure \
we like what we have.  Use low resolution spheres here.  This is just for \
prototyping.\
\>", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(curve1\  = 
      ParametricPlot3D[bspline[kt, \ ctrl1, \ x, 0], {x, 0, 1}, 
        DisplayFunction -> Identity]\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(curve2\  = 
      ParametricPlot3D[bspline[kt, \ ctrl2, x, 0], {x, 0, 1}, 
        DisplayFunction -> Identity]\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(Show[{curve1, \ curve2, 
        Table[ParametricPlot3D[\(ellipsoid[
                pos\[LeftDoubleBracket]i\[RightDoubleBracket], \ {0.25, 0.25, 
                  0.25}, {1, 0, 0}]\)[u, v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, 
              Pi/2}, PlotPoints -> {10, 10}, 
            DisplayFunction -> Identity], {i, 1, 5}]}, 
      AspectRatio -> Automatic, \ Axes -> True, 
      DisplayFunction -> $DisplayFunction]\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Now the arclength stuff ", "Subsubsection"],

Cell["First the speed functions...", "Text",
  CellMargins->{{17.375, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\ \(Clear[v1, v2];\)\), "\n", 
    \(\(v1[t_]\  := \ 
        Module[{w\ }, w = bspline[kt, ctrl1, t, 1]; Sqrt[w . w]];\)\), "\n", 
    \(v2[t_]\  := \ 
      Module[{w\ }, w = bspline[kt, ctrl2, t, 1]; Sqrt[w . w]]\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["Then the arclength functions...", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[s1, s2];\)\), "\n", 
    \(\(s1[t_]\  := \ NIntegrate[v1[x], \ {x, 0, t}];\)\), "\n", 
    \(\(s2[t_]\  := \ NIntegrate[v2[x], \ {x, 0, t}];\)\n\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["\<\
The total length of each curve (note the right one is shorter than \
the left one)\
\>", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(len1\  = \ s1[1]\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(len2\  = \ s2[1]\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["\<\
The equally spaced fractions (an arbitrary decision to have 20 \
frames per curve).\
\>", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[{
    \(\(Clear[alf];\)\), "\n", 
    \(\(alf\  = \ Table[N[i/19], \ {i, 1, 18}];\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[val1, val2];\)\), "\[IndentingNewLine]", 
    \(\(val1\  = \ \(val2\  = \ 
          Table[0, {i, 1, 20}]\);\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, \ 
        i <= 18, \ \(i++\), \[IndentingNewLine]val1\[LeftDoubleBracket]
            i + 1\[RightDoubleBracket]\  = \ 
          t /. \(FindRoot[
                s1[t] == alf\[LeftDoubleBracket]i\[RightDoubleBracket]*
                    len1, \ {t, 
                  val1\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  val1\[LeftDoubleBracket]i\[RightDoubleBracket] + 
                    0.01}]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \n
        val2\[LeftDoubleBracket]i + 1\[RightDoubleBracket]\  = \ 
          t /. \(FindRoot[
                s2[t] == alf\[LeftDoubleBracket]i\[RightDoubleBracket]*
                    len2, \ {t, 
                  val2\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  val2\[LeftDoubleBracket]i\[RightDoubleBracket] + 
                    0.01}]\)\[LeftDoubleBracket]1\[RightDoubleBracket];\
\[IndentingNewLine]];\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(val1\[LeftDoubleBracket]20\[RightDoubleBracket]\  = \ 
        1.0;\)\), "\[IndentingNewLine]", 
    \(\(val2\[LeftDoubleBracket]20\[RightDoubleBracket]\  = \ 
        2.0;\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["\<\
It will be useful to look again at what we've got so that we have \
some idea as to what values of the parameters correspond to the action we are \
interested in.  Let's plot every other frame, along with labels.  Again we \
choose a small number of polygons to display each ellipse since we are still \
at the testing stage.\
\>", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(centers\  = 
        Join[Table[
            bspline[kt, ctrl1, 
              val1\[LeftDoubleBracket]i\[RightDoubleBracket], 0], {i, 1, 
              20}], Table[
            bspline[kt, ctrl2, 
              val2\[LeftDoubleBracket]i\[RightDoubleBracket], 0], {i, 1, 
              19}]];\)\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(Show[{curve1, \ curve2, 
        Table[ParametricPlot3D[\(ellipsoid[
                centers\[LeftDoubleBracket]i\[RightDoubleBracket], \ {0.25, 
                  0.25, 0.25}, {1, 0, 0}]\)[u, v], {u, 0, 
              2*Pi}, {v, \(-Pi\)/2, Pi/2}, PlotPoints -> {7, 7}, 
            DisplayFunction -> Identity], {i, 1, 39, 2}], \n\t
        Graphics3D[{Hue[0], 
            Table[\n\t\t\t\t\tText[StyleForm[i, FontSize -> 14], 
                centers\[LeftDoubleBracket]i\[RightDoubleBracket] + {0, 0, 
                    0.25}], {i, 1, 39, 2}]\n\t\t\t\t\n\t\t\t\t}]}, 
      AspectRatio -> Automatic, \ Axes -> True, 
      DisplayFunction -> $DisplayFunction]\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Now the stretch", "Subsubsection",
  CellMargins->{{18.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[TextData[{
  "We will stretch the ellipsoid from a sphere with radius ",
  Cell[BoxData[
      \(0.25\)]],
  " ",
  Cell[BoxData[
      \(\((a\  = \ \(b\  = \ \(c\  = \ 0.25\)\))\)\)]],
  "to an ellipsoid whose major axis is ",
  Cell[BoxData[
      \(0.5\)]],
  " and whose other two axes are ",
  Cell[BoxData[
      \(0.125\ \((a\  = \ 0.5, \ b\  = \ \(c\  = \ 0.125\))\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[axes];\)\), "\n", 
    \(axes[t_]\  := \((1 - t)\)*{0.25, 0.25, 0.25}\  + \ 
        t*{0.5, 0.125, 0.125}\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Clear[LeftAx];\)\), "\n", 
    \(\(LeftAx\  = \ Table[axes[i/5], {i, 0, 5}];\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(RightAx\  = \ Table[axes[i/5], {i, 5, 0, \(-1\)}];\)\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Make a table of the derivative or direction vectors for each side\
\
\>", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(\(LeftN\  = 
        Table[\((x = 
                bspline[kt, ctrl1, 
                  val1\[LeftDoubleBracket]i\[RightDoubleBracket], 1])\)/
            Sqrt[x . x], {i, 14, 19}];\)\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(RightN\  = 
        Table[\((x = 
                bspline[kt, ctrl2, 
                  val2\[LeftDoubleBracket]i\[RightDoubleBracket], 1])\)/
            Sqrt[x . x], {i, 1, 6}];\)\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["Final Check", "Text",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell[BoxData[
    \(Show[{Table[
          ParametricPlot3D[\(ellipsoid[
                centers\[LeftDoubleBracket]i\[RightDoubleBracket], \ {0.25, 
                  0.25, 0.25}, {1, 0, 0}]\)[u, v], {u, 0, 
              2*Pi}, {v, \(-Pi\)/2, Pi/2}, PlotPoints -> {7, 7}, 
            DisplayFunction -> Identity], {i, 1, 14, 2}], 
        Table[ParametricPlot3D[\(ellipsoid[
                centers\[LeftDoubleBracket]
                  i\[RightDoubleBracket], \ \ LeftAx\[LeftDoubleBracket]
                  i - 14\[RightDoubleBracket], 
                LeftN\[LeftDoubleBracket]i - 14\[RightDoubleBracket]]\)[u, 
              v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, PlotPoints -> {7, 7}, 
            DisplayFunction -> Identity], {i, 15, 18, 2}], 
        ParametricPlot3D[\(ellipsoid[
              centers\[LeftDoubleBracket]20\[RightDoubleBracket], \ {0.35, 
                0.35, 0.125}, {Sqrt[1]/2, Sqrt[2]/2, 0}]\)[u, v], {u, 0, 
            2*Pi}, {v, \(-Pi\)/2, Pi/2}, PlotPoints -> {7, 7}, 
          DisplayFunction -> Identity], 
        Table[ParametricPlot3D[\(ellipsoid[
                centers\[LeftDoubleBracket]i\[RightDoubleBracket], 
                RightAx\[LeftDoubleBracket]i - 20\[RightDoubleBracket], 
                RightN\[LeftDoubleBracket]i - 20\[RightDoubleBracket]]\)[u, 
              v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, PlotPoints -> {7, 7}, 
            DisplayFunction -> Identity], {i, 22, 25, 2}], 
        Table[ParametricPlot3D[\(ellipsoid[
                centers\[LeftDoubleBracket]i\[RightDoubleBracket], \ {0.25, 
                  0.25, 0.25}, {1, 0, 0}]\)[u, v], {u, 0, 
              2*Pi}, {v, \(-Pi\)/2, Pi/2}, PlotPoints -> {7, 7}, 
            DisplayFunction -> Identity], {i, 27, 39, 
            2}]\n\t\t\t\t\n\t\t\t\t}, \ AspectRatio -> Automatic, \ 
      Axes -> True, \ DisplayFunction -> $DisplayFunction]\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["The Animation", "Subsubsection",
  CellMargins->{{18.6875, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"],

Cell["Watch this from several different viewpoints.", "Text"],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\t\(gr\  = \ 
        Join[\[IndentingNewLine]Table[
            Show[ParametricPlot3D[\(ellipsoid[
                    centers\[LeftDoubleBracket]
                      i\[RightDoubleBracket], \ {0.25, 0.25, 0.25}, {1, 0, 
                      0}]\)[u, v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, 
                DisplayFunction -> Identity, 
                PlotRange -> {{0, 5.5}, {\(-0.5\), 2}, {0, 2.5}}, 
                Axes -> False]], {i, 1, 8, 2}], \n\ \ \ \ \ \ \ \ \ Table[
            Show[ParametricPlot3D[\(ellipsoid[
                    centers\[LeftDoubleBracket]
                      i\[RightDoubleBracket], \ {0.25, 0.25, 0.25}, {1, 0, 
                      0}]\)[u, v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, 
                DisplayFunction -> Identity, 
                PlotRange -> {{0, 5.5}, {\(-0.5\), 2}, {0, 2.5}}, \ 
                Axes -> False]], {i, 9, 14, 1}], \n\ \ \ \ \ \ \ \ Table[
            Show[ParametricPlot3D[\(ellipsoid[
                    centers\[LeftDoubleBracket]
                      i\[RightDoubleBracket], \ \ LeftAx\[LeftDoubleBracket]
                      i - 13\[RightDoubleBracket], 
                    LeftN\[LeftDoubleBracket]i - 13\[RightDoubleBracket]]\)[
                  u, v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, 
                DisplayFunction -> Identity, 
                PlotRange -> {{0, 5.5}, {\(-0.5\), 2}, {0, 2.5}}, \ 
                Axes -> False]], {i, 15, 18, 
              2}], \n\ \ \ \ \ \ \ {ParametricPlot3D[\(ellipsoid[
                  centers\[LeftDoubleBracket]20\[RightDoubleBracket], \ {0.5, 
                    0.125, 0.125}, {1, 0, 0}]\)[u, v], {u, 0, 
                2*Pi}, {v, \(-Pi\)/2, Pi/2}, DisplayFunction -> Identity, 
              PlotRange -> {{0, 5.5}, {\(-0.5\), 2}, {0, 2.5}}, \ 
              Axes -> False]}, \n\t
          Table[Show[
              ParametricPlot3D[\(ellipsoid[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], \ 
                    RightAx\[LeftDoubleBracket]i - 20\[RightDoubleBracket], 
                    RightN\[LeftDoubleBracket]i - 20\[RightDoubleBracket]]\)[
                  u, v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, 
                DisplayFunction -> Identity, 
                PlotRange -> {{0, 5.5}, {\(-0.5\), 2}, {0, 2.5}}, \ 
                Axes -> False]], {i, 22, 25, 2}], \n\t
          Table[Show[
              ParametricPlot3D[\(ellipsoid[
                    centers\[LeftDoubleBracket]
                      i\[RightDoubleBracket], \ {0.25, 0.25, 0.25}, {1, 0, 
                      0}]\)[u, v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, 
                DisplayFunction -> Identity, 
                PlotRange -> {{0, 5.5}, {\(-0.5\), 2}, {0, 2.5}}, \ 
                Axes -> False]], {i, 27, 29, 2}], \t\[IndentingNewLine]Table[
            Show[ParametricPlot3D[\(ellipsoid[
                    centers\[LeftDoubleBracket]i\[RightDoubleBracket], \ \
{0.25, 0.25, 0.25}, {1, 0, 0}]\)[u, v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, 
                DisplayFunction -> Identity, 
                PlotRange -> {{0, 5.5}, {\(-0.5\), 2}, {0, 2.5}}, \ 
                Axes -> False]], {i, 30, 34, 2}], \t\[IndentingNewLine]Table[
            Show[ParametricPlot3D[\(ellipsoid[
                    centers\[LeftDoubleBracket]
                      i\[RightDoubleBracket], \ {0.25, 0.25, 0.25}, {1, 0, 
                      0}]\)[u, v], {u, 0, 2*Pi}, {v, \(-Pi\)/2, Pi/2}, 
                DisplayFunction -> Identity, 
                PlotRange -> {{0, 5.5}, {\(-0.5\), 2}, {0, 2.5}}, \ 
                Axes -> False]], {i, 35, 39, 2}]\n\t];\)\)}], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Again, your patience (as well as your memory), is required \
here.\
\>", "Text"],

Cell[BoxData[
    \(\(GLShow[gr, AnimateFrames \[Rule] True];\)\)], "Input",
  CellMargins->{{44.6875, Inherited}, {Inherited, Inherited}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rotation - Key Frames 2", "Subsubtitle"],

Cell[TextData[{
  "For this discussion we assume that we have an object living in its own \
coordinate system.  We discuss rotating the object around the center of the \
object's coordinate system. We call the result of such a rotation an ",
  StyleBox["orientation of the object.",
    FontWeight->"Bold"],
  "  An orientation of an object can be specified by giving the world \
positions of the three standard basis vectors that define the object's \
coordinate system."
}], "Text"],

Cell[TextData[{
  "From a strictly algebraic point of view a rotation is a linear \
transformation whose transformation matrix is orthogonal and is positive \
definite.  That is, if ",
  Cell[BoxData[
      \(r\)]],
  " is the transformation and ",
  Cell[BoxData[
      StyleBox[\(M\_\(3\[Times]3\)\),
        "Text",
        FontFamily->"Courier"]]],
  " is the transformation matrix, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{Cell["\tr(x,y,z)"], " ", "="}]}], TraditionalForm]]],
  StyleBox[" ", "Output"],
  StyleBox[Cell[BoxData[
      RowBox[{
        StyleBox["M",
          FontFamily->"Courier"], "\[CenterDot]", 
        RowBox[{"(", "\[NegativeThinSpace]", 
          StyleBox[GridBox[{
                {"x"},
                {"y"},
                {"z"}
                }],
            FontFamily->"Courier"], "\[NegativeThinSpace]", ")"}]}]], 
    "Output"], "Output"],
  " , "
}], "Text"],

Cell[TextData[{
  "then the inverse of ",
  Cell[BoxData[
      \(M\)]],
  " is the transpose of ",
  Cell[BoxData[
      \(M\)]],
  ", ",
  Cell[BoxData[
      \(M\^\(-1\) = \ M\^T\)]],
  ", and all eigenvalues of ",
  Cell[BoxData[
      \(M\)]],
  " are positive.  The collection of all such matrices is denoted ",
  Cell[BoxData[
      \(SO \((3)\)\)]],
  ", (special orthogonal matrices of dimension ",
  Cell[BoxData[
      \(3\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "This matrix formulation allows us to represent any rotation; simply find \
the matrix ",
  Cell[BoxData[
      \(M\)]],
  ".   We know we can find the matrix ",
  Cell[BoxData[
      \(M\)]],
  " if we can find the image of the three basis vectors ",
  Cell[BoxData[
      \(\((1, 0, 0)\), \ \((0, 1, 0)\)\)]],
  ", and ",
  Cell[BoxData[
      \(\((0, 0, 1)\)\)]],
  " ( see the discussion of linear transformations in the introductory \
chapters on three dimensional graphics), but we need a little more geometry \
to be able to do that."
}], "Text"],

Cell[CellGroupData[{

Cell["Rotations, Euler's Theorem, and Euler Angles", "Sub3title"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00362 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0338805 1.14081 -1.11022e-16 1.14081 [
[ 0 0 0 0 ]
[ 1 1.00362 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00362 L
0 1.00362 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4241 .45441 m
.41568 .97029 L
s
.4241 .45441 m
.92681 .36798 L
s
.4241 .45441 m
.13759 .24039 L
s
.42309 .72093 m
.41755 .72087 L
s
.4286 .72087 m
.42309 .72093 L
s
.41755 .72087 m
.41203 .72069 L
s
.43406 .72068 m
.4286 .72087 L
s
.41203 .72069 m
.40656 .72038 L
s
.43942 .72037 m
.43406 .72068 L
s
.40656 .72038 m
.40118 .71994 L
s
.44465 .71993 m
.43942 .72037 L
s
.40118 .71994 m
.39592 .71939 L
s
.44972 .71937 m
.44465 .71993 L
s
.39592 .71939 m
.39083 .71872 L
s
.45459 .7187 m
.44972 .71937 L
s
.39083 .71872 m
.38593 .71794 L
s
.45922 .71792 m
.45459 .7187 L
s
.38593 .71794 m
.38126 .71706 L
s
.46359 .71703 m
.45922 .71792 L
s
.38126 .71706 m
.37685 .71607 L
s
.46766 .71604 m
.46359 .71703 L
s
.37685 .71607 m
.37273 .71498 L
s
.47141 .71495 m
.46766 .71604 L
s
.6869 .41472 m
.68605 .40921 L
s
.6876 .42023 m
.6869 .41472 L
s
.68605 .40921 m
.68505 .40372 L
s
.68813 .42568 m
.6876 .42023 L
s
.68505 .40372 m
.6839 .3983 L
s
.6885 .43105 m
.68813 .42568 L
s
.6839 .3983 m
.68261 .39297 L
s
.6887 .4363 m
.6885 .43105 L
s
.37273 .71498 m
.36894 .71381 L
s
.47481 .71378 m
.47141 .71495 L
s
.68261 .39297 m
.6812 .38778 L
s
.68873 .44139 m
.6887 .4363 L
s
.6812 .38778 m
.67966 .38276 L
s
.68858 .4463 m
.68873 .44139 L
s
.36894 .71381 m
.36549 .71256 L
s
.47782 .71252 m
.47481 .71378 L
s
.67966 .38276 m
.67802 .37794 L
s
.68827 .45098 m
.68858 .4463 L
s
.67802 .37794 m
.67628 .37336 L
s
.36549 .71256 m
.36243 .71124 L
s
.48044 .7112 m
.47782 .71252 L
s
.68779 .4554 m
.68827 .45098 L
s
.67628 .37336 m
.67444 .36905 L
s
.68715 .45954 m
.68779 .4554 L
s
.36243 .71124 m
.35976 .70985 L
s
.48264 .70981 m
.48044 .7112 L
s
.67444 .36905 m
.67254 .36504 L
s
.68634 .46335 m
.68715 .45954 L
s
.67254 .36504 m
.67057 .36135 L
s
.35976 .70985 m
.35751 .7084 L
s
.4844 .70836 m
.48264 .70981 L
s
.68537 .46683 m
.68634 .46335 L
s
.67057 .36135 m
.66855 .35802 L
s
.35751 .7084 m
.3557 .70692 L
s
.4857 .70687 m
.4844 .70836 L
s
.68426 .46993 m
.68537 .46683 L
s
.66855 .35802 m
.6665 .35507 L
s
.683 .47264 m
.68426 .46993 L
s
.3557 .70692 m
.35434 .7054 L
s
.48654 .70535 m
.4857 .70687 L
s
.6665 .35507 m
.66442 .35252 L
s
.6816 .47494 m
.683 .47264 L
s
.35434 .7054 m
.35345 .70385 L
s
.4869 .70381 m
.48654 .70535 L
s
.66442 .35252 m
.66234 .3504 L
s
.68007 .4768 m
.6816 .47494 L
s
.35345 .70385 m
.35304 .70229 L
s
.48679 .70225 m
.4869 .70381 L
s
.66234 .3504 m
.66026 .34872 L
s
.67843 .47822 m
.68007 .4768 L
s
.35304 .70229 m
.35311 .70073 L
s
.48619 .70069 m
.48679 .70225 L
s
.66026 .34872 m
.6582 .34749 L
s
.67668 .47917 m
.67843 .47822 L
s
.35311 .70073 m
.35366 .69918 L
s
.6582 .34749 m
.65619 .34672 L
s
.4851 .69914 m
.48619 .70069 L
s
.67483 .47965 m
.67668 .47917 L
s
.65619 .34672 m
.65422 .34644 L
s
.35366 .69918 m
.3547 .69766 L
s
.48354 .69761 m
.4851 .69914 L
s
.6729 .47965 m
.67483 .47965 L
s
.65422 .34644 m
.65232 .34663 L
s
.3547 .69766 m
.35622 .69616 L
s
.48152 .69612 m
.48354 .69761 L
s
.6709 .47917 m
.6729 .47965 L
s
.35622 .69616 m
.35821 .69471 L
s
.65232 .34663 m
.6505 .3473 L
s
.47903 .69467 m
.48152 .69612 L
s
.66885 .47821 m
.6709 .47917 L
s
.35821 .69471 m
.36066 .69331 L
s
.47611 .69328 m
.47903 .69467 L
s
.6505 .3473 m
.64877 .34846 L
s
.66676 .47677 m
.66885 .47821 L
s
.36066 .69331 m
.36355 .69198 L
s
.47276 .69195 m
.47611 .69328 L
s
.64877 .34846 m
.64715 .35009 L
s
.66464 .47486 m
.66676 .47677 L
s
.36355 .69198 m
.36687 .69073 L
s
.46901 .6907 m
.47276 .69195 L
s
.64715 .35009 m
.64565 .35218 L
s
.66251 .47249 m
.66464 .47486 L
s
.36687 .69073 m
.37059 .68956 L
s
.4649 .68953 m
.46901 .6907 L
s
.64565 .35218 m
.64428 .35473 L
s
.37059 .68956 m
.37469 .68849 L
s
.46044 .68846 m
.4649 .68953 L
s
.66039 .46969 m
.66251 .47249 L
s
.41568 .97029 m
.41727 .90241 L
s
.41727 .90241 m
.40319 .90103 L
s
.43102 .90116 m
.41727 .90241 L
s
.64428 .35473 m
.64306 .35771 L
s
.37469 .68849 m
.37913 .68752 L
s
.45567 .6875 m
.46044 .68846 L
s
.6583 .46645 m
.66039 .46969 L
s
.37913 .68752 m
.38388 .68667 L
s
.45062 .68664 m
.45567 .6875 L
s
.64306 .35771 m
.64199 .36111 L
s
.41568 .97029 m
.43102 .90116 L
s
.43421 .89819 m
.43102 .90116 L
s
.41568 .97029 m
.40319 .90103 L
s
.40319 .90103 m
.3993 .89804 L
s
.65624 .46281 m
.6583 .46645 L
s
.38388 .68667 m
.38892 .68593 L
s
.44534 .68591 m
.45062 .68664 L
s
.64199 .36111 m
.64108 .3649 L
s
.38892 .68593 m
.39419 .68532 L
s
.43986 .6853 m
.44534 .68591 L
s
.65423 .4588 m
.65624 .46281 L
s
.39419 .68532 m
.39966 .68484 L
s
.43423 .68482 m
.43986 .6853 L
s
.64108 .3649 m
.64034 .36906 L
s
.39966 .68484 m
.40528 .68449 L
s
.42848 .68448 m
.43423 .68482 L
s
.40528 .68449 m
.41103 .68428 L
s
.42267 .68427 m
.42848 .68448 L
s
.6523 .45444 m
.65423 .4588 L
s
.41103 .68428 m
.41684 .68421 L
s
.41684 .68421 m
.42267 .68427 L
s
.64034 .36906 m
.63977 .37356 L
s
.65045 .44976 m
.6523 .45444 L
s
.63977 .37356 m
.63939 .37836 L
s
.41568 .97029 m
.43421 .89819 L
s
.42427 .89573 m
.43421 .89819 L
s
.41568 .97029 m
.3993 .89804 L
s
.3993 .89804 m
.40866 .89566 L
s
.64869 .4448 m
.65045 .44976 L
s
.63939 .37836 m
.63919 .38342 L
s
.64706 .43959 m
.64869 .4448 L
s
.63919 .38342 m
.63918 .38871 L
s
.64554 .43418 m
.64706 .43959 L
s
.63918 .38871 m
.63935 .39419 L
s
.64417 .42861 m
.64554 .43418 L
s
.63935 .39419 m
.63971 .39982 L
s
.64295 .42291 m
.64417 .42861 L
s
.63971 .39982 m
.64026 .40555 L
s
.64188 .41714 m
.64295 .42291 L
s
.64026 .40555 m
.64098 .41134 L
s
.92681 .36798 m
.86086 .37883 L
s
.86086 .37883 m
.86154 .3932 L
s
.85679 .3654 m
.86086 .37883 L
s
.64098 .41134 m
.64188 .41714 L
s
.41568 .97029 m
.42427 .89573 L
s
.40866 .89566 m
.42427 .89573 L
s
.41568 .97029 m
.40866 .89566 L
s
.92681 .36798 m
.86154 .3932 L
s
.86154 .3932 m
.85832 .3978 L
s
.92681 .36798 m
.85679 .3654 L
s
.85236 .36294 m
.85679 .3654 L
s
.92681 .36798 m
.85832 .3978 L
s
.85832 .3978 m
.85357 .38904 L
s
.92681 .36798 m
.85236 .36294 L
s
.8509 .37345 m
.85236 .36294 L
s
.92681 .36798 m
.85357 .38904 L
s
.85357 .38904 m
.8509 .37345 L
s
.24927 .32711 m
.25284 .32235 L
s
.24603 .33208 m
.24927 .32711 L
s
.25284 .32235 m
.2567 .31785 L
s
.24314 .33724 m
.24603 .33208 L
s
.2567 .31785 m
.26085 .31364 L
s
.92681 .36798 m
.8509 .37345 L
s
.24062 .34256 m
.24314 .33724 L
s
.26085 .31364 m
.26524 .30973 L
s
.23848 .34798 m
.24062 .34256 L
s
.26524 .30973 m
.26985 .30617 L
s
.23675 .35349 m
.23848 .34798 L
s
.26985 .30617 m
.27465 .30298 L
s
.23543 .35904 m
.23675 .35349 L
s
.27465 .30298 m
.2796 .30018 L
s
.23454 .36458 m
.23543 .35904 L
s
.2796 .30018 m
.28466 .29778 L
s
.23408 .37009 m
.23454 .36458 L
s
.28466 .29778 m
.28981 .29582 L
s
.23405 .37553 m
.23408 .37009 L
s
.28981 .29582 m
.29501 .29429 L
s
.23447 .38085 m
.23405 .37553 L
s
.29501 .29429 m
.30022 .29322 L
s
.23531 .38601 m
.23447 .38085 L
s
.30022 .29322 m
.30541 .29261 L
s
.23659 .39099 m
.23531 .38601 L
s
.30541 .29261 m
.31054 .29247 L
s
.2383 .39575 m
.23659 .39099 L
s
.31054 .29247 m
.31556 .2928 L
s
.24041 .40025 m
.2383 .39575 L
s
.31556 .2928 m
.32046 .2936 L
s
.24292 .40446 m
.24041 .40025 L
s
.32046 .2936 m
.32518 .29486 L
s
.24582 .40834 m
.24292 .40446 L
s
.32518 .29486 m
.32971 .29659 L
s
.24908 .41188 m
.24582 .40834 L
s
.32971 .29659 m
.33399 .29876 L
s
.25268 .41503 m
.24908 .41188 L
s
.33399 .29876 m
.33801 .30137 L
s
.2566 .41779 m
.25268 .41503 L
s
.33801 .30137 m
.34173 .30439 L
s
.26081 .42012 m
.2566 .41779 L
s
.34173 .30439 m
.34513 .30781 L
s
.26527 .42201 m
.26081 .42012 L
s
.34513 .30781 m
.34817 .3116 L
s
.26997 .42344 m
.26527 .42201 L
s
.34817 .3116 m
.35084 .31574 L
s
.27486 .42441 m
.26997 .42344 L
s
.35084 .31574 m
.35311 .3202 L
s
.27991 .42489 m
.27486 .42441 L
s
.35311 .3202 m
.35497 .32494 L
s
.28509 .4249 m
.27991 .42489 L
s
.35497 .32494 m
.3564 .32994 L
s
.29035 .42441 m
.28509 .4249 L
s
.3564 .32994 m
.35739 .33515 L
s
.29565 .42345 m
.29035 .42441 L
s
.35739 .33515 m
.35792 .34054 L
s
.30097 .42201 m
.29565 .42345 L
s
.35792 .34054 m
.358 .34607 L
s
.30625 .4201 m
.30097 .42201 L
s
.358 .34607 m
.35763 .3517 L
s
.31146 .41773 m
.30625 .4201 L
s
.35763 .3517 m
.3568 .35738 L
s
.31657 .41493 m
.31146 .41773 L
s
.3568 .35738 m
.35552 .36308 L
s
.32152 .41171 m
.31657 .41493 L
s
.35552 .36308 m
.35379 .36875 L
s
.32628 .4081 m
.32152 .41171 L
s
.35379 .36875 m
.35164 .37434 L
s
.33083 .40412 m
.32628 .4081 L
s
.35164 .37434 m
.34908 .37982 L
s
.33512 .3998 m
.33083 .40412 L
s
.34908 .37982 m
.34612 .38515 L
s
.33911 .39518 m
.33512 .3998 L
s
.34612 .38515 m
.34279 .39028 L
s
.34279 .39028 m
.33911 .39518 L
s
.13759 .24039 m
.16704 .26896 L
s
.16704 .26896 m
.17907 .25674 L
s
.16618 .28461 m
.16704 .26896 L
s
.13759 .24039 m
.17907 .25674 L
s
.17907 .25674 m
.1933 .25709 L
s
.13759 .24039 m
.16618 .28461 L
s
.17719 .29197 m
.16618 .28461 L
s
.13759 .24039 m
.1933 .25709 L
s
.1933 .25709 m
.19902 .26984 L
s
.13759 .24039 m
.17719 .29197 L
s
.19185 .28541 m
.17719 .29197 L
s
.13759 .24039 m
.19902 .26984 L
s
.19902 .26984 m
.19185 .28541 L
s
.13759 .24039 m
.19185 .28541 L
s
gsave
.39631 .33865 -70.7188 -10.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.375 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.375000 moveto
 558.000000 16.375000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.375000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
71.375000 15.375000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.937500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
78.437500 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
gsave
.62336 .37351 -70.7188 -11.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.3125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.312500 moveto
 558.000000 18.312500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.312500 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
71.375000 15.375000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.937500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
78.437500 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
gsave
.3695 .67525 -70.7188 -10.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.375 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.375000 moveto
 558.000000 16.375000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.375000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
71.375000 15.375000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.937500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
78.437500 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{274.875, 275.875},
  ImageMargins->{{172.625, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004B00014a000`40O003h00OogoL4goL003oOm`C
Om`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000
ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`C
Om`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000
ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`C
Om`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000
ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`C
Om`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000
ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`C
Om`00?mog1=og000ogoL4goL003oOm`COm`002Eog0<00>Yog0009GoL1P00igoL000VOm`8003TOm`0
02Mog0X00>5og0009goL1@0000=og00000001@00gWoL000XOm`00`00Om`000020002Om`6003MOm`0
02Qog0800003Om`0000000D0009og003001og7oL0=]og000:GoL0P0000=og000Om`00P000WoL0P00
00=og000Om`0fgoL000ZOm`200000goL001og0020003Om`2003LOm`002Yog0800004Om`007oLOm`3
0003Om`00`00Omaog03IOm`002]og0<000=og003001og000009og003001og7oL0=Uog000:goL00<0
07oL000017oL00@007oL00000=aog000;7oL0P001GoL00@007oL00000=]og000;GoL0P0017oL0P00
0WoL00<007oLOm`0f7oL000_Om`01000Om`000001GoL00<007oLOm`0egoL000`Om`00`00Omaog006
Om`2000EOm`:002hOm`003]og003001og7oL00mog0<000Yog0800;Iog000?7oL00<007oLOm`03GoL
00<007oLOm`03GoL00<007oLOm`0/goL000mOm`2000:Om`3000AOm`00`00Omaog02bOm`003mog003
001og7oL00Iog003001og7oL01=og003001og7oL0;5og000@7oL00<007oLOm`01GoL00<007oLOm`0
57oL00<007oLOm`0/7oL0011Om`20004Om`00`00Omaog00FOm`00`00Omaog02_Om`004=og004001o
g7oL000IOm`00`00Omaog02_Om`004Aog08001Yog003001og7oL00Yog0800003Om`000000:1og000
A7oL0`006WoL00<007oLOm`02WoL00<007oL0000XGoL0014Om`01000Omaog0006GoL00H007oLOmao
g7>J6:D200000bU9LiYog003Om`00`00Omaog02POm`004=og003001og7oL009og003001og7oL01Io
g00;001og7oLOm`YBEZdOmacVT7^46=cVP02Om`00`00Om`0002QOm`0049og003001og7oL00Aog080
01Iog005001og7oLOm`00004Om`00d7^>Leog00200000goL0000002POm`0045og003001og7oL00Mo
g003001og7oL01Aog004001og7oL0005Om`00a1SOmaog02TOm`0045og003001og7oL00Qog08001Ao
g004001og7oL46<6002VOm`0045og003001og7oL00Yog003001og7oL015og005001og7oLBS11kP04
Om`00`00Omaog013Om`4001MOm`0041og003001og7oL00aog003001og7oL00mog003001og7oL009o
g0066:E1kW>JOma1kQRUA7oL0P000goL00<007oLOm`0FWoL0010Om`00`00Omaog00=Om`2000?Om`0
0`00Omaog002Om`01W>J>Ld000006:ES5Smog0<0009og003001og7oL00=og003001og7oL05Uog000
@7oL00<007oLOm`03goL00<007oLOm`037oL00<007oLOm`0B7oL00D007oLOmaog00000Iog003001o
g7oL05Qog000@7oL00<007oLOm`047oL00<007oLOm`02goL00<007oLOm`0BGoL00<007oL00001goL
00<007oLOm`0;goL2`007WoL0010Om`00`00Omaog00AOm`2000;Om`00`00Omaog019Om`00`00Om`0
0008Om`00`00Omaog00^Om`E000DOm`0041og003001og7oL01=og003001og7oL00Mog003001og7oL
045og006LiXHY@00000YBG>J0WoL00@007oL000000Qog003001og7oL02iog08000=og0h001Iog000
@7oL00<007oLOm`057oL00<007oLOm`01WoL00<007oLOm`0@GoL00XYBEZdOmacVT7^46=cVWoL001o
g08000Uog003001og7oL02eog0/00003Om`0000000<001Qog000@7oL00<007oLOm`05GoL0P001WoL
00<007oLOm`0@GoL00<007oLOm`00WoL00E1kSW=000007oL008000Uog003001og7oL02eog0H0009o
g0L001Yog000@7oL00<007oLOm`05goL00<007oLOm`00WoL00<007oLOm`0@WoL00<007oLOm`00goL
00<@HgoLOm`00WoL00<007oLOm`027oL00<007oLOm`09WoL1`0000Aog000Omaog0P001aog000@7oL
00<007oLOm`067oL00@007oLOm`004Eog00346<0000000@000Aog003001og7oL00Qog003001og7oL
025og0D000Iog003001og00000800004Om`00000Om`2000NOm`0041og003001og7oL01Uog0<004Eo
g003BS11kWoL00=og003001og7oL009og003001og7oL00Qog003001og7oL01]og0H000]og0H00003
Om`00000021og000@7oL00<007oLOm`06WoL0P00AWoL00HHYD7^LiYog47^6:D4Om`00`00Omaog008
Om`00`00Omaog00EOm`6000AOm`00`00Om`00002Om`2000ROm`0045og003001og7oL01Qog004001o
g7oL0015Om`01W>J>Ld000006:ES5PAog003001og7oL00Qog003001og7oL00mog0H001Qog0@002Ao
g000@GoL00<007oLOm`05goL00<007oLOm`00WoL0P00CGoL00<007oLOm`02GoL00<007oLOm`02GoL
1@007goL00<007oLOm`097oL0012Om`00`00Omaog00EOm`00`00Omaog005Om`00`00Omaog01:Om`0
0`00Omaog009Om`00`00Omaog003Om`6001;Om`004=og003001og7oL01=og003001og7oL00Mog003
001og7oL04Uog003001og7oL00Uog0H0055og000A7oL00<007oLOm`047oL0P002goL0P00BGoL00<0
07oLOm`017oL1P00EWoL0015Om`00`00Omaog00>Om`00`00Omaog00=Om`00`00Omaog016Om`70006
Om`00`00Omaog01COm`004Iog003001og7oL00]og080015og003001og7oL041og0H000aog003001o
g7oL05=og000AgoL0P0027oL0`0057oL0P00>goL1@001WoL00<007oLOm`02GoL00<007oLOm`0DgoL
0019Om`8000IOm`00`00Omaog00bOm`6000;Om`00`00Omaog009Om`00`00Omaog01COm`006]og003
001og7oL02]og0H0015og003001og7oL00Uog003001og7oL05=og000K7oL0P009GoL1P005goL00<0
07oLOm`02GoL00<007oLOm`0DgoL001^Om`00`00Omaog00MOm`5000MOm`00`00Omaog009Om`00`00
Omaog01COm`006mog003001og7oL01Iog0H002=og003001og7oL00Qog003001og7oL05=og000L7oL
0P0047oL1P00:GoL00<007oLOm`027oL00<007oLOm`0DgoL001bOm`00`00Omaog008Om`5000_Om`0
0`00Omaog008Om`00`00Omaog01COm`007=og004001og7oLOm`6000eOm`00`00Omaog007Om`00`00
Omaog01COm`007Aog0<003]og003001og7oL00Mog003001og7oL05=og000M7oL00<007oLOm`0?7oL
00<007oLOm`01WoL00<007oLOm`0DgoL001dOm`00`00Omaog00lOm`00`00Omaog006Om`00`00Omao
g01COm`007Aog003001og7oL03eog003001og7oL00Aog003001og7oL05Aog000M7oL00<007oLOm`0
?GoL00<007oLOm`017oL00<007oLOm`0E7oL001dOm`00`00Omaog00nOm`00`00Omaog003Om`00`00
Omaog01DOm`007Aog003001og7oL03mog005001og7oLOm`0001GOm`007Aog003001og7oL041og0<0
05Qog000M7oL00<007oLOm`0VgoL001dOm`00`00Omaog02KOm`007Aog003001og7oL09]og000M7oL
00<007oLOm`0VgoL001dOm`00`00Omaog02KOm`007Aog003001og7oL09]og000M7oL00<007oLOm`0
VgoL001dOm`00`00Omaog02KOm`007Aog003001og7oL09]og000M7oL00<007oLOm`0VgoL001dOm`0
0`00Omaog02KOm`007Aog003001og7oL09]og000M7oL00<007oLOm`0VgoL001dOm`00`00Omaog02K
Om`007Aog003001og7oL09]og000M7oL00<007oLOm`0VgoL001cOm`00`00Omaog02LOm`007=og003
001og7oL09aog000LgoL00<007oLOm`0W7oL001cOm`00`00Omaog02LOm`007=og003001og7oL09ao
g000LgoL00<007oLOm`0W7oL001cOm`00`00Omaog02LOm`007=og003001og7oL09aog000LgoL00<0
07oLOm`0W7oL001cOm`00`00Omaog02LOm`007=og003001og7oL09aog000LgoL00<007oLOm`0W7oL
001cOm`00`00Omaog02LOm`007=og003001og7oL09aog000LgoL00<007oLOm`0W7oL001cOm`00`00
Omaog02LOm`007=og003001og7oL09aog000LgoL00<007oLOm`0W7oL001cOm`00`00Omaog02LOm`0
07=og003001og7oL09aog000LgoL00<007oLOm`0W7oL001cOm`00`00Omaog02LOm`007=og003001o
g7oL09aog000LgoL00<007oLOm`0W7oL001cOm`00`00Omaog02LOm`007=og003001og7oL09aog000
LgoL00<007oLOm`0W7oL001cOm`00`00Omaog02LOm`007=og003001og7oL09aog000LgoL00<007oL
Om`0W7oL001cOm`00`00Omaog02LOm`007=og003001og7oL09aog000IGoL1@002GoL00<007oLOm`0
W7oL001VOm`01000Omaog0002GoL00<007oLOm`0W7oL001WOm`00`00Omaog009Om`00`00Omaog02L
Om`005iog008LiXHY@00000YBG>JOm`0009og003001og7oL00Qog003001og7oL09aog000GWoL00LY
BEZdOmacVT7^46=cVP050009Om`00`00Omaog02LOm`005iog003001og7oL009og003@NhicGoL00eo
g003001og7oL09aog000GWoL00<007oLOm`00goL00<@HgoLOm`037oL00<007oLOm`0W7oL001NOm`0
0a1S000000040005Om`A002GOm`005iog003BS11kWoL00=og0H000Uog003001og7oL00Eog0D0099o
g000GgoL00@HYD7^LiYog08000iog003001og7oL00Yog0<008mog000GgoL00IcVSW=000001RUHaH>
Om`00`00Omaog00=Om`00`00Omaog02<Om`0061og080015og003001og7oL00iog003001og7oL08]o
g000H7oL00<007oLOm`047oL00<007oLOm`03goL00<007oLOm`0RWoL001QOm`00`00Omaog00?Om`0
0`00Omaog00?Om`00`00Omaog02:Om`0065og0<000mog003001og7oL00eog08008eog000I7oL0`00
2goL00<007oLOm`037oL0P00SgoL001WOm`50006Om`00`00Omaog007Om`5002AOm`006aog10009Io
g000LWoL00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0079og003001og7oL09eog000LWoL00<0
07oLOm`0WGoL001bOm`00`00Omaog02MOm`0079og003001og7oL09eog000LWoL00<007oLOm`0WGoL
001bOm`00`00Omaog02MOm`0079og003001og7oL09eog000LWoL00<007oLOm`0WGoL001bOm`00`00
Omaog02MOm`0079og003001og7oL09eog000LWoL00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0
079og003001og7oL09eog000LWoL00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0079og003001o
g7oL09eog000LWoL00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0079og003001og7oL09eog000
LWoL00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0079og003001og7oL09eog000LWoL00<007oL
Om`0WGoL001bOm`00`00Omaog02MOm`0079og003001og7oL09eog000LWoL00<007oLOm`0WGoL001b
Om`00`00Omaog02MOm`0079og003001og7oL09eog000LWoL00<007oLOm`0WGoL001bOm`00`00Omao
g02MOm`0079og003001og7oL09eog000LWoL00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0079o
g003001og7oL09eog000LWoL00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0079og003001og7oL
09eog000LWoL00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0079og003001og7oL09eog000LWoL
00<007oLOm`0WGoL001bOm`00`00Omaog02MOm`0075og003001og7oL09iog000LGoL00<007oLOm`0
WWoL001aOm`00`00Omaog02NOm`006iog0P009aog000KGoL1@000WoL0`00VgoL001]Om`300000goL
0000000200000goL001og02JOm`006eog0<00007Om`00000Om`007oL0000VgoL001^Om`200001WoL
00000000Om`009aog000KWoL0P0000Iog000000007oL002LOm`006iog0H00003Om`007oL09]og000
KWoL1P0000=og000Om`0VgoL001^Om`7002MOm`006mog0H009eog000KgoL1P00WGoL001_Om`5002N
Om`006mog0D009iog000KgoL1@00WWoL001`Om`4002NOm`0071og0<009mog000L7oL0`00WgoL001`
Om`3002OOm`0071og0<009mog000LGoL00<007oLOm`0WWoL001aOm`00`00Omaog02NOm`00?mog1=o
g000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003oOm`COm`00?mog1=og000ogoL4goL003o
Om`COm`00001\
\>"],
  ImageRangeCache->{{{0, 273.875}, {274.875, 0}} -> {0.0296943, -1.81176*^-5, \
0.00320065, 0.00320065}}],

Cell["Euler Angles", "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Euler's Theorem (or one of Euler's theorems) says that for any given \
rotation there is a vector ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["v",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " and an angle ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " such that the rotation is equivalent to rotating around the vector ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["v",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " through the angle ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  ".  Any such transformation can be decomposed further so that it is written \
as a sequence of rotations about the coordinate axes.  The angles \
corresponding to the three axes are called the Euler angles of the rotation.  \
This decomposition is not unique and is dependent on the order in which the \
rotations are to be accomplished.  Converting from Euler angles to \
transformation matrices is easy; converting from transformations to Euler \
angles is ill defined due to the trigonometric equations involved and the \
need to specify the order of the rotations.  Euler angles are subject to a \
loss of degrees of freedom known as gimble lock.  Euler angles do not behave \
well under composition. Further, interpolating between rotations defined by \
Euler angles is totally unsatisfactory (see (SH85)).  We won't use Euler \
angles."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quaternions", "Sub3title"],

Cell[TextData[{
  "An alternative to Euler angles for representing rotations is the algebra \
of quaternions, discovered by Sir William Hamilton (",
  Cell[BoxData[
      \(1805 - 1865\)]],
  ").  In this section we spend some time looking at the arithmetic of \
quaternions, and then how they can be used to represent rotations."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition:",
    FontWeight->"Bold"],
  "  A quaternion is a pair ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"a", ",", " ", 
          OverscriptBox[
            StyleBox["u",
              FontWeight->"Bold"], "\[RightVector]"]}], ")"}]]],
  " where ",
  Cell[BoxData[
      \(a\)]],
  " is a real number and  ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["u",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " is a vector or a point in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ".  The collection of all quaternions is denoted ",
  Cell[BoxData[Cell["\[DoubleStruckCapitalH]"]]],
  " in honor of Hamilton."
}], "ContentsText"],

Cell[TextData[{
  "You can also think of a quaternion as an ordered quadruple of real numbers \
[ Hamilton's original formulation was ",
  Cell[BoxData[
      RowBox[{"a", " ", "+", " ", 
        StyleBox[
          RowBox[{"b", 
            StyleBox["i",
              FontWeight->"Bold"]}]], " ", "+", 
        StyleBox[
          RowBox[{"c", 
            StyleBox["j",
              FontWeight->"Bold"]}]], " ", "+", " ", 
        StyleBox[
          RowBox[{"d", 
            StyleBox["k",
              FontWeight->"Bold"]}]]}]]],
  " where ",
  Cell[BoxData[
      RowBox[{
        StyleBox["i",
          FontWeight->"Bold"], ",", " ", 
        StyleBox["j",
          FontWeight->"Bold"]}]]],
  ", and ",
  Cell[BoxData[
      StyleBox["k",
        FontWeight->"Bold"]]],
  " had special multiplication properties (like ",
  Cell[BoxData[
      StyleBox["i",
        FontWeight->"Bold"]]],
  " has in the complex number system).  We'll stick with the current \
formulation.]  Quaternions can be added and multiplied.   The definitions \
are:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"a", ",", " ", 
          OverscriptBox[
            StyleBox["u",
              FontWeight->"Bold"], "\[RightVector]"]}], ")"}]]],
  StyleBox[" ", "Output"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"+", " ", 
          RowBox[{"(", 
            RowBox[{"b", ",", " ", 
              OverscriptBox[
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], " ", "=",
         " ", 
        RowBox[{"(", 
          RowBox[{\(a + b\), ",", " ", 
            RowBox[{
              OverscriptBox[
                StyleBox["u",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"], " ", "+", " ", 
              OverscriptBox[
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}], " "}]]],
  " \n\t\t\t\t[if you consider quaternions as 4-tuples, just add \
coordinate-wise]"
}], "ContentsText"],

Cell[TextData[Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"(", 
          RowBox[{"a", ",", " ", 
            OverscriptBox[
              StyleBox["u",
                FontFamily->"Courier",
                FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
        "\[CenterDot]", " ", 
        RowBox[{"(", 
          RowBox[{"b", ",", " ", 
            OverscriptBox[
              StyleBox["v",
                FontFamily->"Courier",
                FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], " ", "=", 
      " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(a\[CenterDot]b\), " ", "-", " ", 
            RowBox[{
              OverscriptBox[
                StyleBox["u",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"], "\[CenterDot]", 
              OverscriptBox[
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"]}]}], ",", " ", 
          RowBox[{
            RowBox[{"a", 
              OverscriptBox[
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"]}], " ", "+", " ", 
            RowBox[{"b", 
              OverscriptBox[
                StyleBox["u",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"]}], " ", "+", " ", 
            RowBox[{
              OverscriptBox[
                StyleBox["u",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"], "\[Cross]", 
              OverscriptBox[
                StyleBox["v",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"]}]}]}], 
        ")"}]}]]]], "ContentsText"],

Cell[TextData[{
  "It is possible to define a new data type in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and overload the + and \[CenterDot] operators.  We'll skip this in favor \
of some simple procedures:"
}], "Text"],

Cell[BoxData[
    \(add[{a_, u_}, {b_, v_}]\  := \ {a + b, \ u + v}\)], "Input"],

Cell[BoxData[
    \(mult[{a_, u_}, {b_, v_}]\  := \ {a\ b\  - \ u . v, \ 
        a\ v\  + \ b\ u\  + \ Cross[u, v]}\)], "Input"],

Cell[TextData[{
  "Compute the following by hand.  Check your answers with the two \
mathematica functions above.\n\t(1)\t",
  Cell[BoxData[
      \(TraditionalForm\`\((1, \ \((2, \ \(-3\), \ 
            4)\))\)\  + \ \((\(-3\), \ \((2.1, \ 4, \ 5)\))\)\)]],
  "\n\t(2)\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-7.2\), \ \((\(-4\), \ 0, \ 
            2)\))\)\  + \ \((7.2, \ \((4, \ 0, \ \(-2\))\))\)\)]],
  "\n\t(3)\t",
  Cell[BoxData[
      \(TraditionalForm\`\((2, \ \((2, 3, 
            4)\))\)\[CenterDot]\((\(-3\), \ \((1, \ 4, \ \(-2\))\))\)\)]],
  "\n\t(4)\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\((3, \ \((1, \(-1\), 3)\))\), "\[CenterDot]", " ", 
          FormBox[
            RowBox[{"(", 
              RowBox[{\(3\/20\), ",", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[\(\(-1\)\/20\),
                      "TraditionalForm"], ",", \(1\/20\), ",", 
                    " ", \(\(-3\)\/20\)}], ")"}]}], ")"}],
            "TraditionalForm"]}], TraditionalForm]]]
}], "1ColumnBox"],

Cell["\<\
Here are some obvious and not so obvious arithmetic facts that you \
can check out using the above definitions:\
\>", "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox[
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"a", ",", " ", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
                "+", " ", 
                RowBox[{"(", 
                  RowBox[{"b", ",", " ", 
                    OverscriptBox[
                      StyleBox["v",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], 
              " ", "=", " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"b", ",", " ", 
                    OverscriptBox[
                      StyleBox["v",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
                "+", " ", 
                RowBox[{"(", 
                  RowBox[{"a", ",", " ", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}]}],
            FontSize->14], 
          StyleBox[\(\[Bullet]\ addition\ is\ commutative\),
            FontSize->14]},
        {
          StyleBox[
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"a", ",", " ", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
                "+", " ", 
                RowBox[{"[", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"b", ",", " ", 
                        OverscriptBox[
                          StyleBox["v",
                            FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                    "+", " ", 
                    RowBox[{"(", 
                      RowBox[{"c", ",", " ", 
                        OverscriptBox[
                          StyleBox["w",
                            FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}],
                   "]"}]}], " ", "=", " ", "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"[", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"a", ",", " ", 
                        OverscriptBox[
                          StyleBox["u",
                            FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                    " ", "+", " ", 
                    RowBox[{"(", 
                      RowBox[{"b", ",", " ", 
                        OverscriptBox[
                          StyleBox["v",
                            FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}],
                   "]"}], " ", "+", " ", 
                RowBox[{"(", 
                  RowBox[{"c", ",", " ", 
                    OverscriptBox[
                      StyleBox["w",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}]}],
            FontSize->14], 
          StyleBox[\(\[Bullet]\ addition\ is\ associative\),
            FontSize->14]},
        {
          StyleBox[
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"0", ",", " ", 
                    OverscriptBox[
                      StyleBox["0",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
                "+", " ", 
                RowBox[{"(", 
                  RowBox[{"a", ",", " ", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], 
              " ", "=", " ", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"a", ",", " ", 
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                  " ", "+", 
                  RowBox[{"(", 
                    RowBox[{"0", ",", " ", 
                      OverscriptBox[
                        StyleBox["0",
                          FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], 
                " ", "=", " ", 
                RowBox[{"(", 
                  RowBox[{"a", ",", " ", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}]}],
            FontSize->14], 
          StyleBox[
            RowBox[{"\[Bullet]", " ", 
              RowBox[{"(", 
                RowBox[{"0", ",", " ", 
                  OverscriptBox[
                    StyleBox["0",
                      FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
              "is", " ", "the", " ", "additive", " ", "identity"}],
            FontSize->14]},
        {
          StyleBox[
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"a", ",", " ", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
                "+", " ", 
                RowBox[{"(", 
                  RowBox[{\(-a\), ",", " ", 
                    RowBox[{"-", 
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}]}],
               " ", "=", " ", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{\(-a\), ",", " ", 
                      RowBox[{"-", 
                        OverscriptBox[
                          StyleBox["u",
                            FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}],
                   " ", "+", " ", 
                  RowBox[{"(", 
                    RowBox[{"a", ",", " ", 
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], 
                " ", "=", " ", 
                RowBox[{"(", 
                  RowBox[{"0", ",", " ", 
                    OverscriptBox[
                      StyleBox["0",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}]}],
            FontSize->14], 
          StyleBox[
            RowBox[{
              RowBox[{"\[Bullet]", "  ", "every", " ", "element", " ", 
                RowBox[{"(", 
                  RowBox[{"a", ",", " ", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                "has", " ", "an", " ", "additive", " ", "inverse"}], ",", " ",
               
              RowBox[{"(", 
                RowBox[{\(-a\), ",", " ", 
                  RowBox[{"-", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}]}],
            FontSize->14]}
        },
      RowLines->True,
      ColumnLines->True]]]], "2ColumnBox"],

Cell["\t\t\t\t\t\t\t\t\tAddition Facts", "Caption"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"a", ",", 
                  OverscriptBox[
                    StyleBox["u",
                      FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
              "\[CenterDot]", 
              RowBox[{"[", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"b", ",", 
                      OverscriptBox[
                        StyleBox["v",
                          FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                  "\[CenterDot]", 
                  RowBox[{"(", 
                    RowBox[{"c", ",", 
                      OverscriptBox[
                        StyleBox["w",
                          FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], 
                "]"}]}], " ", "=", "  ", 
            RowBox[{
              RowBox[{"[", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"a", ",", 
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                  " ", "\[CenterDot]", 
                  RowBox[{"(", 
                    RowBox[{"b", ",", 
                      OverscriptBox[
                        StyleBox["v",
                          FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], 
                "]"}], "\[CenterDot]", 
              RowBox[{"(", 
                RowBox[{"c", ",", 
                  OverscriptBox[
                    StyleBox["w",
                      FontWeight->"Bold"], "\[RightVector]"]}], 
                ")"}]}]}], \(\[Bullet]multiplication\ is\ associative\)},
        {
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", ",", 
                  OverscriptBox[
                    StyleBox["0",
                      FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
              "\[CenterDot]", 
              RowBox[{"(", 
                RowBox[{"a", ",", 
                  OverscriptBox[
                    StyleBox["u",
                      FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], " ", 
            "=", " ", 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"a", ",", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                "\[CenterDot]", 
                RowBox[{"(", 
                  RowBox[{"1", ",", 
                    OverscriptBox[
                      StyleBox["0",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], 
              " ", "=", " ", 
              RowBox[{"(", 
                RowBox[{"a", ",", 
                  OverscriptBox[
                    StyleBox["u",
                      FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}]}], 
          RowBox[{"\[Bullet]", 
            RowBox[{"(", 
              RowBox[{"1", ",", 
                OverscriptBox[
                  StyleBox["0",
                    FontWeight->"Bold"], "\[RightVector]"]}], ")"}], " ", 
            "is", " ", "the", " ", "multiplicative", " ", "identity"}]},
        {
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"a", ",", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                "\[CenterDot]", 
                FractionBox["1", 
                  RowBox[{\(a\^2\), "+", " ", 
                    RowBox[{
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"], 
                      "\[CenterDot]", 
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"]}]}]]}], 
              RowBox[{"(", 
                RowBox[{"a", ",", 
                  RowBox[{"-", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}]}], 
            "=", 
            RowBox[{
              RowBox[{
                FractionBox["1", 
                  RowBox[{\(a\^2\), "+", " ", 
                    RowBox[{
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"], 
                      "\[CenterDot]", 
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"]}]}]], 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"a", ",", 
                      RowBox[{"-", 
                        OverscriptBox[
                          StyleBox["u",
                            FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}],
                   "\[CenterDot]", 
                  RowBox[{"(", 
                    RowBox[{"a", ",", 
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}]}],
               " ", "=", " ", 
              RowBox[{"(", 
                RowBox[{"1", ",", 
                  OverscriptBox[
                    StyleBox["0",
                      FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}]}], 
          RowBox[{
            RowBox[{"\[Bullet]", " ", "every", " ", "element", " ", 
              RowBox[{"(", 
                RowBox[{"a", ",", 
                  OverscriptBox[
                    StyleBox["u",
                      FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], ",", 
            " ", 
            RowBox[{"except", " ", 
              RowBox[{"(", 
                RowBox[{"0", ",", 
                  OverscriptBox[
                    StyleBox["0",
                      FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}], ",", 
            " ", \(has\ a\ multiplicative\ inverse\), ",", " ", 
            RowBox[{
              FractionBox["1", 
                RowBox[{\(a\^2\), "+", " ", 
                  RowBox[{
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"], 
                    "\[CenterDot]", 
                    OverscriptBox[
                      StyleBox["u",
                        FontWeight->"Bold"], "\[RightVector]"]}]}]], 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"a", ",", 
                    RowBox[{"-", 
                      OverscriptBox[
                        StyleBox["u",
                          FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}], 
                "."}]}]}]}
        },
      RowLines->True,
      ColumnLines->True]]]], "2ColumnBox"],

Cell["\t\t\t\t\t\t\t\t\tMultiplication Facts", "Caption"],

Cell[TextData[{
  "Notice the lack of a commutative property of multiplication.  In general, \
",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{Cell[TextData[Cell[BoxData[
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"a", ",", " ", 
                        OverscriptBox[
                          StyleBox["u",
                            FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                    "\[CenterDot]", 
                    RowBox[{"(", 
                      RowBox[{"b", ",", " ", 
                        OverscriptBox[
                          StyleBox["v",
                            FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}],
                   " ", "\[NotEqual]", " ", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"b", ",", " ", 
                        OverscriptBox[
                          StyleBox["v",
                            FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
                    "\[CenterDot]", 
                    RowBox[{"(", 
                      RowBox[{"a", ",", " ", 
                        OverscriptBox[
                          StyleBox["u",
                            FontWeight->"Bold"], "\[RightVector]"]}], 
                      ")"}]}]}]]]]], "  "}],
          "Output"], TextForm]]],
  "(this is good since we already know that rotations do not commute)."
}], "Text"],

Cell[TextData[{
  "For our convenience, we define the function ",
  Cell[BoxData[
      \(inv\)]],
  " to compute the inverse of a quaternion."
}], "Text"],

Cell[BoxData[
    \(inv[q_]\  := \ 
      Module[{w}, \n\t\tw\  = \ 
          q\[LeftDoubleBracket]1\[RightDoubleBracket]^2 + 
            q\[LeftDoubleBracket]2\[RightDoubleBracket] . 
              q\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\tIf[w == 0, \ 
          Return["\<inv[(0,(0,0,0))] is undefined\>"]]; \n\t\t\tReturn[{q\
\[LeftDoubleBracket]1\[RightDoubleBracket], \(-q\[LeftDoubleBracket]2\
\[RightDoubleBracket]\)}/w]]\)], "Input"],

Cell[TextData[{
  "Now that we know a little about the arithmetic of quaternions, we can use \
them to define rotations as follows (due to Arthur Cayley, ",
  Cell[BoxData[
      \(1821 - 1895\)]],
  "):"
}], "Text"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Q",
            FontSlant->"Plain"], " ", "="}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"a", ",", " ", 
          OverscriptBox[
            StyleBox["u",
              FontWeight->"Bold"], "\[RightVector]"]}], ")"}]]],
  "be a unit quaternion,  i.e. \n\t",
  Cell[BoxData[
      \(\(\(a\^2\  + \ u\_x\%2\  + \ u\_y\%2\  + \ 
          u\_z\%2\)\(\ \)\(=\)\(\ \)\(1\)\(\ \)\)\)]],
  ".\nDefine ",
  Cell[BoxData[
      \(\(R\_Q\) : \ \[DoubleStruckCapitalR]\^3 \[RightArrow] \
\[DoubleStruckCapitalR]\^3\)]],
  " by\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(R\_Q\), 
          RowBox[{"(", 
            OverscriptBox[
              StyleBox["v",
                FontWeight->"Bold"], "\[RightVector]"], ")"}]}], " ", "=", 
        " ", 
        OverscriptBox[
          StyleBox["w",
            FontWeight->"Bold"], "\[RightVector]"]}]]],
  " where ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", ",", 
          OverscriptBox[
            StyleBox["w",
              FontWeight->"Bold"], "\[RightVector]"]}], ")"}]]],
  "= ",
  Cell[BoxData[
      \(\(\(Q\^\(-1\)\)\(\[CenterDot]\)\)\)]],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", ",", 
            OverscriptBox[
              StyleBox["v",
                FontWeight->"Bold"], "\[RightVector]"]}], ")"}], 
        "\[CenterDot]", \(\(Q\)\(.\)\)}]]]
}], "ContentsText"],

Cell[TextData[{
  "We will denote the set of unit quaternions by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalH]\_1\)]],
  "."
}], "Text"],

Cell["An example.", "1ColumnBox",
  CellMargins->{{22, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      FormBox[
        StyleBox["Q",
          FontSlant->"Plain"], TraditionalForm]]],
  StyleBox[" = ", "Output"],
  StyleBox[Cell[BoxData[
      \(\((\@3\/2, \ \((1\/\(2 \@ 3\), \ 1\/\(2 \@ 3\), 
          1\/\(2 \@ 3\))\))\)\)], "Output"], "Output"],
  ", then ",
  StyleBox[Cell[BoxData[
      \(a\^2\  + \ u\_x\%2\  + \ u\_y\%2\  + \ u\_z\%2\)], "Output"], 
    "Output"],
  StyleBox[" ", "Output"],
  Cell[BoxData[
      \(TraditionalForm\` = \)]],
  StyleBox[" ", "Output"],
  StyleBox[Cell[BoxData[
      \(3\/4\  + \ 1\/12 + \ 1\/12 + \ 1\/12\)], "Output",
    CellMargins->{{29, Inherited}, {Inherited, Inherited}}], "Output"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(\ \)\(1\)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["Q",
          FontSlant->"Plain"], TraditionalForm]]],
  "  is a unit quaternion.\n\nLet ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox["x",
              FontSlant->"Plain"], ",", " ", 
            StyleBox["y",
              FontSlant->"Plain"], ",", " ", 
            StyleBox["z",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  " be any point in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^3\)]],
  ".  Compute the product\n\n\t\t\t",
  StyleBox["Q", "Output",
    FontFamily->"Courier"],
  StyleBox[Cell[BoxData[
      \(\^\(-1\)\)], "Output",
    GeneratedCell->False,
    CellAutoOverwrite->False], "Output"],
  StyleBox["\[CenterDot] (0,", "Output"],
  StyleBox[Cell[BoxData[
      \(\((x, y, z)\)\)], "Output"], "Output"],
  StyleBox[") \[CenterDot]", "Output"],
  StyleBox[" Q\n", "Output",
    FontFamily->"Courier"],
  StyleBox["\n",
    FontFamily->"Courier"],
  "We'll use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ...",
  StyleBox["\t\t\t",
    FontFamily->"Courier"]
}], "1ColumnBox",
  CellMargins->{{22.625, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(Q\  = \ {\@3\/2, \ \(-{1\/\(2 \@ 3\), \ 1\/\(2 \@ 3\), 
              1\/\(2 \@ 3\)}\)};\)\)], "Input"],

Cell[BoxData[
    \(Together[mult[mult[inv[Q], {0, {x, y, z}}], \ Q]]\)], "Input"],

Cell[" ", "Text"],

Cell[TextData[{
  "Then, taking the vector part of the answer, we have the transformation\n\n\
\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["f",
              FontSlant->"Plain"], "(", 
            RowBox[{
              StyleBox["x",
                FontSlant->"Plain"], 
              StyleBox[",",
                "Output",
                FontSlant->"Italic"], 
              StyleBox["y",
                "Output",
                FontSlant->"Plain"], 
              StyleBox[",",
                "Output",
                FontSlant->"Italic"], 
              StyleBox["z",
                "Output",
                FontSlant->"Plain"]}], ")"}], " ", "="}], TraditionalForm]]],
  StyleBox[" ", "Output"],
  StyleBox[Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{\(1\/3\), " ", 
            StyleBox[\((2\ x - y + 2\ z)\),
              FontFamily->"Courier"]}], 
          StyleBox[",",
            FontFamily->"Courier"], 
          RowBox[{\(1\/3\), 
            StyleBox[" ",
              FontFamily->"Courier"], 
            StyleBox[\((2\ x + 2\ y - z)\),
              FontFamily->"Courier"]}], ",", 
          RowBox[{\(1\/3\), 
            StyleBox[" ",
              FontFamily->"Courier"], 
            StyleBox[\((\(-x\) + 2\ y + 2\ z)\),
              FontFamily->"Courier"]}]}], "}"}]], "Output"], "Output"]
}], "1ColumnBox",
  CellMargins->{{55.3125, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Clearly the matrix for this transformation is \n",
  Cell[BoxData[
      RowBox[{"mm", " ", "=", " ", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(2\/3\), \(-\(1\/3\)\), \(2\/3\)},
              {\(2\/3\), \(2\/3\), \(-\(1\/3\)\)},
              {\(-\(1\/3\)\), \(2\/3\), \(2\/3\)}
              }], "\[NegativeThinSpace]", ")"}]}]]],
  "\nand it is easily checked that ",
  Cell[BoxData[Cell["mm"]]],
  " is an element of ",
  Cell[BoxData[
      StyleBox[\(SO \((3)\)\),
        FontSize->14]]],
  ".  As a matter of fact this matrix produces a rotation of ",
  Cell[BoxData[
      StyleBox["60",
        FontSize->14]]],
  " degrees around the vector ",
  Cell[BoxData[
      \(\((1, 1, 1)\)\)],
    FontSize->14],
  StyleBox[".",
    FontSize->14]
}], "Note",
  CellMargins->{{55, Inherited}, {Inherited, Inherited}},
  Background->GrayLevel[0.8]],

Cell[TextData[{
  "You should be able to determine the relationship between multiplication in \
of unit quaternions and composition of rotations.  Compare ",
  Cell[BoxData[
      \(R\_\(Q\_1\)\[SmallCircle]R\_\(Q\_2\)\)]],
  " and ",
  Cell[BoxData[
      \(R\_\(\(Q\_1\) Q\_2\)\)]],
  ".  Is ",
  Cell[BoxData[
      \(Q\_1\[CenterDot]Q\_2\)]],
  " a unit quaternion?"
}], "Text"],

Cell["\<\
Proof of the following result is beyond the scope of the discussion \
here, but this is the basic relationship between quaternions and rotations.\
\
\>", "Text"],

Cell[TextData[{
  StyleBox["Theorem:  ",
    FontWeight->"Bold"],
  "(Cayley) For a unit quaternion ",
  Cell[BoxData[
      RowBox[{"Q", " ", "=", " ", 
        RowBox[{"(", 
          RowBox[{"a", ",", " ", 
            OverscriptBox[
              StyleBox["u",
                FontWeight->"Bold"], "\[RightVector]"]}], ")"}]}]]],
  ", the function ",
  Cell[BoxData[
      \(R\_Q\)]],
  " defined above defines a rotation around the vector ",
  Cell[BoxData[
      OverscriptBox[
        StyleBox["u",
          FontWeight->"Bold"], "\[RightVector]"]]],
  " through an angle ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " where ",
  Cell[BoxData[
      \(cos\ \[Alpha]\/2\  = \ a\)]],
  "."
}], "ContentsText"],

Cell["A direct result of the above theorem is the following:", "Text"],

Cell[TextData[{
  "The unit quaternion that produces a rotation around the vector ",
  Cell[BoxData[
      RowBox[{
        OverscriptBox[
          StyleBox["u",
            FontWeight->"Bold"], "\[RightVector]"], " ", "=", 
        " ", \((u\_x, \ u\_y, \ u\_z)\)}]]],
  "through an angle \[Alpha] is ",
  Cell[BoxData[
      RowBox[{"Q", " ", "=", " ", 
        RowBox[{"(", 
          RowBox[{\(cos\ \[Alpha]\/2\), ",", 
            RowBox[{"sin", " ", \(\[Alpha]\/2\), 
              FractionBox[
                OverscriptBox[
                  StyleBox["u",
                    FontSize->10,
                    FontWeight->"Bold"], "\[RightVector]"], 
                RowBox[{"\[LeftDoubleBracketingBar]", 
                  OverscriptBox[
                    StyleBox["u",
                      FontSize->10,
                      FontWeight->"Bold"], "\[RightVector]"], 
                  "\[RightDoubleBracketingBar]"}]]}]}], ")"}], " "}]]],
  ".  The unit quaternion ",
  Cell[BoxData[
      \(\(-Q\)\)]],
  " will produce this same rotation."
}], "ContentsText"],

Cell["\<\
We now look at converting back and forth between the matrix \
representation and the quaternion representation of a rotation.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Quaternions to Rotation Matrices and Back", "Subsection"],

Cell[TextData[{
  "We know from previous work that if ",
  StyleBox[Cell[BoxData[
      StyleBox[\(L\  : \[DoubleStruckCapitalR]\^3\  \[Rule] \ \
\[DoubleStruckCapitalR]\^3\),
        FontFamily->"Courier"]], "Output"], "Output"],
  "is a linear transformation, then the matrix for ",
  Cell[BoxData[
      \(L\)]],
  "  with respect to the standard basis of ",
  Cell[BoxData[
      \(\(\(\ \)\(\[DoubleStruckCapitalR]\^3\)\)\)]],
  " is the matrix whose columns are ",
  Cell[BoxData[
      RowBox[{"L", "\[CenterDot]", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {"1"},
              {"0"},
              {"0"}
              }], "\[NegativeThinSpace]", ")"}]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{"L", "\[CenterDot]", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {"0"},
              {"1"},
              {"0"}
              }], "\[NegativeThinSpace]", ")"}]}]]],
  ", and ",
  Cell[BoxData[
      RowBox[{"L", "\[CenterDot]", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {"0"},
              {"0"},
              {"1"}
              }], "\[NegativeThinSpace]", ")"}]}]]],
  ".  Therefore it should be fairly easy to compute the matrix representation \
of the quaternion based function ",
  Cell[BoxData[
      \(R\_Q\)]],
  ". (Note:  the inverse of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{"a", ",", " ", 
            OverscriptBox[
              StyleBox["u",
                FontFamily->"Courier",
                FontWeight->"Bold"], "\[RightVector]"]}], ")"}], TextForm]]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{"a", ",", " ", 
            RowBox[{"-", 
              OverscriptBox[
                StyleBox["u",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}], 
        TextForm]]],
  " if ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{"a", ",", " ", 
            OverscriptBox[
              StyleBox["u",
                FontFamily->"Courier",
                FontWeight->"Bold"], "\[RightVector]"]}], ")"}], TextForm]]],
  " is in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalH]\_1\)]],
  ")."
}], "Text"],

Cell[BoxData[
    \(Simplify[
      mult[mult[{a, \(-{x, y, z}\)}, {0, {1, 0, 0}}], {a, {x, y, 
              z}}] /. {a^2 + x^2 \[Rule] 1 - y^2 - z^2}]\)], "Input"],

Cell[BoxData[
    \(Simplify[
      mult[mult[{a, \(-{x, y, z}\)}, {0, {0, 1, 0}}], {a, {x, y, 
              z}}] /. {a^2 + y^2 \[Rule] 1 - x^2 - z^2}]\)], "Input"],

Cell[BoxData[
    \(Simplify[
      mult[mult[{a, \(-{x, y, z}\)}, {0, {0, 0, 1}}], {a, {x, y, 
              z}}] /. {a^2 + z^2 -> 1 - x^2 - y^2}]\)], "Input"],

Cell[TextData[{
  "The results of the above cells, along with the fact that ",
  Cell[BoxData[
      \(a\^2 + x\^2 + y\^2 + z\^2\)]],
  " = 1,  produces the following (non-homogeneous version) of the rotation \
matrix for the function ",
  Cell[BoxData[
      \(R\_Q\)]],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{"(", GridBox[{
            {\(1 - 2  y\^2 - 2  z\^2\), \(2  x\ y\  + \ 
                2\ a\ z\), \(\(-2\) a\ y\  + 2\ x\ z\)},
            {\(2\ x\ y\  - \ 2\ a\ z\), \(1 - 2  x\^2 - 
                2  z\^2\), \(2  a\ x\  + \ 2  y\ z\)},
            {\(2\ a\ y\  + \ 2\ x\ z\), \(\(-2\)\ a\ x\  + \ 2\ y\ z\), \(1 - 
                2  x\^2 - 2  y\^2\)}
            }], ")"}]}]], "Text"],

Cell[TextData[{
  "The procedure ",
  StyleBox["mat",
    FontWeight->"Bold"],
  " in this cell will convert a unit quaternion to a non-homogeneous ",
  Cell[BoxData[
      FormBox[
        StyleBox[\((3\[Times]3)\),
          FontSize->12], TraditionalForm]]],
  StyleBox[" ", "Output"],
  "rotation matrix."
}], "1ColumnBox",
  CellMargins->{{37.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(Clear[mat]\), "\n", 
    \(\t\(\(mat\ [q_]\  := \ 
      Module[{a, x, y, z, eps}, \n\t\teps\ \  = \ 
          0.0000001; \n\t\t{a, {x, y, z}}\  = \ q; \n\t\tIf[
          Abs[{a, x, y, z} . {a, x, y, z}]\  - 1\  > \ eps, \ 
          Return["\<Not a unit quaternion\>"]]; \n\t\tReturn[{{\(-\((2\ y\^2)\
\)\) - 2\ z\^2 + 1, 2\ x\ y + 2\ a\ z, 
              2\ x\ z - 2\ a\ y}, {2\ x\ y - 2\ a\ z, \(-\((2\ x\^2)\)\) - 
                2\ z\^2 + 1, 2\ a\ x + 2\ y\ z}, {2\ a\ y + 2\ x\ z, 
              2\ y\ z - 2\ a\ x, \(-\((2\ x\^2)\)\) - 2\ y\^2 + 
                1}}]]\)\(\n\)\(\t\t\)\)\)}], "Input"],

Cell[TextData[{
  "Converting from a rotation matrix to the quaternion form (remember there \
are two choices) can be accomplished using the following algorithm from ",
  "(SH85)",
  ".  Given the matrix ",
  Cell[BoxData[
      \(N\)]],
  " in ",
  Cell[BoxData[
      \(SO \((3)\)\)]],
  " we want to find the ",
  Cell[BoxData[
      \(4\)]],
  " values ",
  Cell[BoxData[
      \(a, \ x, \ y, \ z\)]],
  " so that "
}], "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      StyleBox[
        RowBox[{Cell["N"], Cell[TextData[Cell[BoxData[
              RowBox[{"     ", 
                RowBox[{"=", 
                  RowBox[{
                    RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                          {\(n\_11\), \(n\_12\), \(n\_13\)},
                          {\(n\_21\), \(n\_22\), \(n\_23\)},
                          {\(n\_31\), \(n\_32\), \(n\_33\)}
                          }], "\[NegativeThinSpace]", ")"}], " ", "\n", 
                    "     ", "=", " ", 
                    RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                          {\(1 - 2  y\^2 - 2  z\^2\), \(2  x\ y\  + \ 
                              2\ a\ z\), \(\(-2\) a\ y\  + 2\ x\ z\)},
                          {\(2\ x\ y\  - \ 2\ a\ z\), \(1 - 2  x\^2 - 
                              2  z\^2\), \(2  a\ x\  + \ 2  y\ z\)},
                          {\(2\ a\ y\  + \ 
                              2\ x\ z\), \(\(-2\)\ a\ x\  + \ \(\(2\)\(\ \
\)\(y\)\(\ \)\(z\)\(\ \)\)\), \(1 - 2  x\^2 - 2  y\^2\)}
                          }], "\[NegativeThinSpace]", ")"}]}]}]}]]]]]}],
        "Output"]}]], "Text"],

Cell[TextData[{
  "which looks like an overdetermined system (",
  Cell[BoxData[
      \(9\)]],
  " equations and only ",
  Cell[BoxData[
      \(4\)]],
  " variables), but its not because ",
  Cell[BoxData[
      \(N\)]],
  " in ",
  Cell[BoxData[
      \(SO \((3)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Shoemake's procedure for converting from a rotation matrix to a \
quaternion, here called ",
  StyleBox["quat",
    FontWeight->"Bold"],
  "."
}], "1ColumnBox",
  CellMargins->{{37.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(Clear[quat]\), "\n", 
    \(\tquat[n_]\  := \ 
      Module[{a, x, y, z, \ eps}, \n\t\teps\  = \ 
          0.0000001; \n\t\ta\  = \ \((1.0 + 
                n\[LeftDoubleBracket]1, 1\[RightDoubleBracket] + 
                n\[LeftDoubleBracket]2, 2\[RightDoubleBracket] + 
                n\[LeftDoubleBracket]3, 3\[RightDoubleBracket])\)/
            4.0; \n\t\tIf[
          a\  > eps, \n\t\t\ta\  = \ 
            Sqrt[a]; \n\t\t\tx\  = \ \(\((n\[LeftDoubleBracket]2, 
                      3\[RightDoubleBracket] - 
                    n\[LeftDoubleBracket]3, 2\[RightDoubleBracket])\)/4.0\)/
              a; \n\t\t\ty\  = \ \(\((n\[LeftDoubleBracket]3, 
                      1\[RightDoubleBracket] - 
                    n\[LeftDoubleBracket]1, 3\[RightDoubleBracket])\)/4.0\)/
              a; \n\t\t\tz\  = \ \(\((n\[LeftDoubleBracket]1, 
                      2\[RightDoubleBracket] - 
                    n\[LeftDoubleBracket]2, 1\[RightDoubleBracket])\)/4.0\)/
              a; \n\t\t\tReturn[{a, {x, y, z}}]]; \n\t\ta\  = \ 
          0; \n\t\tx\  = \ \(-\((n\[LeftDoubleBracket]2, 
                    2\[RightDoubleBracket] + 
                  n\[LeftDoubleBracket]3, 3\[RightDoubleBracket])\)\)/
            2.0; \n\t\tIf[\ 
          x\  > \ eps, \n\t\t\tx\  = \ 
            Sqrt[x]; \n\t\t\ty\  = \ \(n\[LeftDoubleBracket]1, 
                  2\[RightDoubleBracket]/2.0\)/
              x; \n\t\t\tz\  = \ \(n\[LeftDoubleBracket]1, 
                  3\[RightDoubleBracket]/2.0\)/
              x; \n\t\t\tReturn[{a, {x, y, z}}]]; \n\t\tx\  = \ 
          0.0; \n\t\ty\  = \ \((1.0 - 
                n\[LeftDoubleBracket]3, 3\[RightDoubleBracket])\)/
            2.0; \n\t\tIf[
          y\  > \ eps, \n\t\t\ty\  = \ 
            Sqrt[y]; \n\t\t\tz\  = \ \(n\[LeftDoubleBracket]2, 
                  3\[RightDoubleBracket]/2.0\)/
              y; \n\t\t\tReturn[{a, {x, y, z}}]]; \n\t\ty = 0.0; \ \ z\  = \ 
          1.0; \n\t\t\t\t\tReturn[{a, {x, y, z}}]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Great Arc Interpolation of Quaternion's (Slerping)", "Subsection"],

Cell[TextData[{
  "Suppose that in frame ",
  Cell[BoxData[
      \(1\)]],
  " of an animation sequence an object has orientation represented by the \
quaternion ",
  Cell[BoxData[
      \(Q\_1\)]],
  " and in the last frame of the sequence the same object has orientation \
represented by the quaternion ",
  Cell[BoxData[
      \(Q\_2\)]],
  "and that you have to supply the orientations for the object in the \
inbetween frames.  How would you do it?"
}], "Text"],

Cell[TextData[{
  "A most reasonable suggestion, due originally to Shoemake ",
  "(SH85)",
  ", is to choose the inbetween orientations by choosing quaternions along \
the shortest path between ",
  Cell[BoxData[
      \(Q\_1\)]],
  " and ",
  Cell[BoxData[
      \(Q\_2\)]],
  StyleBox["on the unit sphere in ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["\[DoubleStruckCapitalR]",
            FontWeight->"Bold"], "4"], TraditionalForm]]],
  ".  We can actually picture this situation by considering the plane in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^4\)]],
  "determined by the origin (the center of the unit sphere) and the points ",
  Cell[BoxData[
      \(Q\_1\)]],
  " and ",
  Cell[BoxData[
      \(Q\_2\)]],
  " and the intersection of that plane with the unit sphere in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^4\)]],
  ", which will be a circle."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00238 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.478571 0.238095 [
[ 0 0 0 0 ]
[ 1 1.00238 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00238 L
0 1.00238 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .47857 .47619 0 365.73 arc
s
5 Mabswid
.93994 .29634 Mdot
.61396 .94092 Mdot
.5 Mabswid
.5 .47857 m
.93994 .29634 L
s
% Start of user PostScript
0 0 1.84776 -0.765367 MAarrowhead1
% End of user PostScript
.5 .47857 m
.61396 .94092 L
s
% Start of user PostScript
0 0 0.478631 1.94188 MAarrowhead1
% End of user PostScript
gsave
.61905 .55714 -67.1875 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
71.375000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
gsave
.93994 .29634 -61 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 558.000000 16.562500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Q) show
71.375000 15.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.937500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
78.437500 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.61396 .94092 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 558.000000 16.562500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Q) show
71.375000 15.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.937500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
78.437500 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{278.25, 278.875},
  ImageMargins->{{199.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004F00015Q000`40O003h00OPgoL3`00Q7oL001i
Om`:000?Om`:001jOm`007=og0H002=og0L007=og000KWoL1@00<7oL1@00KWoL001YOm`5000jOm`4
001ZOm`006Iog0<004=og0<006Mog000HgoL0`00BGoL1000HgoL001POm`3001@Om`3001POm`005ao
g0@005Iog0<005eog000FGoL0`00GGoL0`00FWoL001HOm`00`00Omaog01QOm`00`00Omaog01GOm`0
05Eog0<006Eog0<005Iog000DgoL0P00JgoL0`00DgoL001@Om`3001`Om`2001AOm`004mog003001o
g7oL07=og003001og7oL04iog000CGoL0P00MgoL0`00CGoL001:Om`3001lOm`2001;Om`004Uog003
001og7oL07mog003001og7oL04Qog000AgoL0P00PgoL0P00B7oL0016Om`00`00Omaog025Om`00`00
Omaog015Om`004Aog08008Uog0<004Aog000@WoL0P00SWoL0P00@WoL0011Om`00`00Omaog02@Om`0
0`00Omaog00oOm`003mog08009Aog003001og7oL03iog000?WoL00<007oLOm`0UGoL00<007oLOm`0
?GoL000lOm`2002IOm`2000mOm`003]og003001og7oL09]og003001og7oL03Yog000>WoL00<007oL
Om`0WGoL00<007oLOm`0>GoL000iOm`00`00Omaog02OOm`00`00Omaog00hOm`003Mog0800:=og080
03Qog000=WoL00<007oLOm`0YGoL00<007oLOm`0=GoL000eOm`00`00Omaog02WOm`00`00Omaog00d
Om`003Aog003001og7oL0:Uog003001og7oL03=og000<goL00<007oLOm`0ZgoL00<007oLOm`0<WoL
000bOm`00`00Omaog02]Om`00`00Omaog00aOm`0035og003001og7oL0:mog003001og7oL031og000
<7oL00<007oLOm`0/GoL00<007oLOm`0;goL000_Om`00`00Omaog02cOm`00`00Omaog00^Om`002io
g003001og7oL0;Eog08002iog000;GoL00<007oLOm`0^7oL00<007oLOm`0:goL000[Om`2002lOm`0
0`00Omaog00ZOm`002Yog003001og7oL0;aog003001og7oL02Yog000:GoL00<007oLOm`0_WoL00<0
07oLOm`0:GoL000YOm`00`00Omaog02oOm`00`00Omaog00XOm`002Qog003001og7oL0<5og003001o
g7oL02Mog0009goL00<007oLOm`0`goL00<007oLOm`09WoL000VOm`00`00Omaog035Om`00`00Omao
g00UOm`002Eog003001og7oL0<Mog003001og7oL02Aog0009GoL00<007oLOm`0agoL00<007oLOm`0
97oL000TOm`00`00Omaog039Om`00`00Omaog00SOm`002=og003001og7oL0<]og003001og7oL029o
g0008goL00<007oLOm`0bgoL00<007oLOm`08WoL000ROm`00`00Omaog03=Om`00`00Omaog00QOm`0
025og003001og7oL0<mog003001og7oL021og00087oL00<007oLOm`0dGoL00<007oLOm`07goL000O
Om`00`00Omaog03COm`00`00Omaog00NOm`001mog003001og7oL0==og003001og7oL01iog0007WoL
00<007oLOm`0eGoL00<007oLOm`07GoL000MOm`00`00Omaog03GOm`00`00Omaog00LOm`001eog003
001og7oL0=Mog003001og7oL01aog00077oL00<007oLOm`0fGoL00<007oLOm`06goL000KOm`00`00
Omaog03KOm`00`00Omaog00JOm`001Yog003001og7oL0=eog003001og7oL01Uog0006GoL00<007oL
Om`0ggoL00<007oLOm`067oL000IOm`00`00Omaog03OOm`00`00Omaog00HOm`001Qog003001og7oL
0>5og003001og7oL01Mog00067oL00<007oLOm`0hGoL00<007oLOm`05goL000HOm`00`00Omaog03Q
Om`00`00Omaog00GOm`001Mog003001og7oL0>=og003001og7oL01Iog0005WoL00<007oLOm`0iGoL
00<007oLOm`05GoL000FOm`00`00Omaog03UOm`00`00Omaog007Om`00`00Omaog0020009Om`001Eo
g003001og7oL0>Mog003001og7oL00Iog0<0009og003001og000008000Aog0005GoL00<007oLOm`0
j7oL00<007oLOm`01WoL00<007oLOm`017oL00<007oLOm`00goL000EOm`00`00Omaog03XOm`00`00
Omaog006Om`30004Om`00`00Omaog003Om`001Aog003001og7oL0>Yog003001og7oL00Aog005001o
g7oLOm`00003Om`00`00Omaog003Om`001=og003001og7oL0>]og003001og7oL00=og003001og7oL
00=og004001og7oL0005Om`001=og003001og7oL0>]og003001og7oL00=og003001og7oL00=og004
001og0000005Om`0019og003001og7oL0>eog003001og7oL009og003001og7oL00=og004001og7oL
0005Om`0019og003001og7oL0>eog003001og7oL009og003001og7oL00=og003001og7oL00Iog000
4WoL00<007oLOm`0kGoL00<007oLOm`00goL00D007oLOmaog00000Uog0004GoL00<007oLOm`0kgoL
0`000goL0`002WoL000@Om`00`00Omaog03_Om`5000?Om`0011og003001og7oL0>iog0H000mog000
47oL00<007oLOm`0igoL3@003goL000?Om`00`00Omaog03TOm`<000017oL0000000047oL000?Om`0
0`00Omaog03TOm`;0004Om`00`00Omaog00>Om`000mog003001og7oL0>Eog0P000Mog003001og7oL
00eog0003WoL00<007oLOm`0iWoL1`0027oL00<007oLOm`03GoL000>Om`00`00Omaog03SOm`30000
0goL00000002000:Om`00`00Omaog00=Om`000iog003001og7oL0>5og08000Aog0<000aog003001o
g7oL00aog0003GoL00<007oLOm`0ggoL0`001goL00<007oLOm`02goL00<007oLOm`037oL000=Om`0
0`00Omaog03MOm`2000HOm`00`00Omaog00<Om`000aog003001og7oL0=]og0<001]og003001og7oL
00]og00037oL00<007oLOm`0fGoL0P007WoL00<007oLOm`02goL000<Om`00`00Omaog03FOm`3000P
Om`00`00Omaog00;Om`000aog003001og7oL0=Aog08002Aog003001og7oL00Yog00037oL00<007oL
Om`0dWoL0P009WoL00<007oLOm`02WoL000;Om`00`00Omaog03@Om`3000XOm`00`00Omaog00:Om`0
00]og003001og7oL0<iog08002aog003001og7oL00Uog0002goL00<007oLOm`0bgoL0`00;WoL00<0
07oLOm`02GoL000:Om`00`00Omaog03:Om`2000aOm`00`00Omaog009Om`000Yog003001og7oL0<Mo
g0<003=og003001og7oL00Uog0002WoL00<007oLOm`0aGoL0P00=WoL00<007oLOm`02GoL0009Om`0
0`00Omaog034Om`2000iOm`00`00Omaog008Om`000Uog003001og7oL0<5og0<003]og003001og7oL
00Qog0002GoL00<007oLOm`0_goL0P00?WoL00<007oLOm`027oL0009Om`00`00Omaog02lOm`30011
Om`00`00Omaog007Om`000Uog003001og7oL0;Yog08004Aog003001og7oL00Mog00027oL00<007oL
Om`0^7oL0`00AWoL00<007oLOm`01goL0008Om`00`00Omaog02fOm`20019Om`00`00Omaog007Om`0
00Qog003001og7oL0;=og0<004]og003001og7oL00Mog00027oL00<007oLOm`0/GoL0P00CWoL00<0
07oLOm`01goL0008Om`00`00Omaog02_Om`2001@Om`00`00Omaog007Om`000Qog003001og7oL0:ao
g0<005=og003001og7oL00Iog0001goL00<007oLOm`0ZgoL0P00EWoL00<007oLOm`01WoL0007Om`0
0`00Omaog02XOm`3001HOm`00`00Omaog006Om`000Mog003001og7oL0:Iog08005]og003001og7oL
00Iog0001goL00<007oLOm`0XgoL0`00GGoL00<007oLOm`01WoL0007Om`00`00Omaog02QOm`2001P
Om`00`00Omaog006Om`000Mog003001og7oL09iog0<0069og003001og7oL00Iog0001goL00<007oL
Om`0W7oL0P00IGoL00<007oLOm`01WoL0007Om`00`00Omaog02JOm`2001XOm`00`00Omaog005Om`0
00Iog003001og7oL09Qog0<006Yog003001og7oL00Eog0001WoL00<007oLOm`0UWoL0P00KGoL00<0
07oLOm`01GoL0006Om`00`00Omaog02COm`3001_Om`00`00Omaog005Om`000Iog003001og7oL095o
g080079og003001og7oL00Eog0001WoL00<007oLOm`0SWoL0`00M7oL00<007oLOm`01GoL0006Om`0
0`00Omaog02<Om`2001gOm`00`00Omaog005Om`000Iog003001og7oL08Yog08007Uog003001og7oL
00Eog0001WoL00<007oLOm`0QgoL0`00NgoL00<007oLOm`01GoL0006Om`00`00Omaog025Om`2001n
Om`00`00Omaog005Om`000Iog003001og7oL089og0<0081og003001og7oL00Eog0001WoL00<007oL
Om`0PGoL00<007oLOm`0PGoL00<007oLOm`01GoL0006Om`00`00Omaog021Om`00`00Omaog021Om`0
0`00Omaog005Om`000Iog003001og7oL085og003001og7oL085og003001og7oL00Eog0001WoL00<0
07oLOm`0PWoL00<007oLOm`0P7oL00<007oLOm`01GoL0006Om`00`00Omaog022Om`00`00Omaog020
Om`00`00Omaog005Om`000Iog003001og7oL089og003001og7oL081og003001og7oL00Eog0001WoL
00<007oLOm`0PWoL00<007oLOm`0P7oL00<007oLOm`01GoL0006Om`00`00Omaog023Om`00`00Omao
g01oOm`00`00Omaog005Om`000Iog003001og7oL08=og003001og7oL07mog003001og7oL00Eog000
1WoL00<007oLOm`0PgoL00<007oLOm`0OgoL00<007oLOm`01GoL0006Om`00`00Omaog023Om`00`00
Omaog01oOm`00`00Omaog005Om`000Iog003001og7oL08Aog003001og7oL07iog003001og7oL00Eo
g0001goL00<007oLOm`0PgoL00<007oLOm`0OWoL00<007oLOm`01GoL0007Om`00`00Omaog023Om`0
0`00Omaog01mOm`00`00Omaog006Om`000Mog003001og7oL08=og003001og7oL07eog003001og7oL
00Iog0001goL00<007oLOm`0Q7oL00<007oLOm`0O7oL00<007oLOm`01WoL0007Om`00`00Omaog024
Om`00`00Omaog01lOm`00`00Omaog006Om`000Mog003001og7oL08Aog003001og7oL07aog003001o
g7oL00Iog0001goL00<007oLOm`0Q7oL00<007oLOm`0O7oL00<007oLOm`01WoL0007Om`00`00Omao
g025Om`00`00Omaog01kOm`00`00Omaog006Om`000Qog003001og7oL08Aog003001og7oL01Mog0@0
061og003001og7oL00Iog00027oL00<007oLOm`0Q7oL00<007oLOm`05WoL00<007oLOm`00WoL00<0
07oLOm`0GGoL00<007oLOm`01WoL0008Om`00`00Omaog024Om`00`00Omaog00FOm`00`00Omaog003
Om`00`00Omaog01KOm`00`00Omaog007Om`000Qog003001og7oL08Eog003001og7oL01Eog003001o
g7oL00=og003001og7oL05]og003001og7oL00Mog00027oL00<007oLOm`0QGoL00<007oLOm`05GoL
1`00GGoL00<007oLOm`01goL0008Om`00`00Omaog025Om`00`00Omaog00EOm`00`00Omaog003Om`0
0`00Omaog01KOm`00`00Omaog007Om`000Uog003001og7oL08Aog003001og7oL01Iog003001og7oL
009og003001og7oL05]og003001og7oL00Mog0002GoL00<007oLOm`0QGoL00<007oLOm`05WoL1000
GWoL00<007oLOm`01goL0009Om`00`00Omaog025Om`00`00Omaog01gOm`00`00Omaog008Om`000Uo
g003001og7oL08Eog003001og7oL07Mog003001og7oL00Qog0002GoL00<007oLOm`0QGoL00<007oL
Om`0MgoL00<007oLOm`027oL000:Om`00`00Omaog025Om`00`00Omaog01eOm`00`00Omaog009Om`0
00Yog003001og7oL08Eog003001og7oL07Eog003001og7oL00Uog0002WoL00<007oLOm`0QGoL00<0
07oLOm`0MGoL00<007oLOm`02GoL000;Om`00`00Omaog024Om`00`00Omaog01eOm`00`00Omaog009
Om`000]og003001og7oL08Eog003001og7oL07Aog003001og7oL00Uog0002goL00<007oLOm`0QGoL
00<007oLOm`0LgoL00<007oLOm`02WoL000;Om`00`00Omaog025Om`00`00Omaog01cOm`00`00Omao
g00:Om`000aog003001og7oL08Aog003001og7oL07=og003001og7oL00Yog00037oL00<007oLOm`0
QGoL00<007oLOm`0LGoL00<007oLOm`02goL000<Om`00`00Omaog025Om`00`00Omaog01aOm`00`00
Omaog00;Om`000aog003001og7oL08Eog003001og7oL075og003001og7oL00]og0003GoL00<007oL
Om`0Q7oL00<007oLOm`0L7oL00<007oLOm`037oL000=Om`00`00Omaog025Om`00`00Omaog01_Om`0
0`00Omaog00<Om`000iog003001og7oL08Aog003001og7oL06mog003001og7oL00aog0003WoL00<0
07oLOm`0Q7oL00<007oLOm`0KWoL00<007oLOm`03GoL000>Om`00`00Omaog024Om`00`00Omaog01^
Om`00`00Omaog00=Om`000mog003001og7oL08Aog003001og7oL06eog003001og7oL00eog0003goL
00<007oLOm`0Q7oL00<007oLOm`0KGoL00<007oLOm`03GoL000?Om`00`00Omaog024Om`00`00Omao
g01/Om`00`00Omaog00>Om`0011og003001og7oL08=og003001og7oL06]og003001og7oL00mog000
47oL00<007oLOm`0Q7oL00<007oLOm`0JWoL00<007oLOm`03goL000@Om`00`00Omaog024Om`00`00
Omaog01ZOm`00`00Omaog00?Om`0011og003001og7oL08Aog003001og7oL06Yog003001og7oL00mo
g0004GoL00<007oLOm`0PgoL00<007oLOm`0JGoL00<007oLOm`047oL000BOm`00`00Omaog023Om`0
0`00Omaog01WOm`00`00Omaog00AOm`0019og003001og7oL08=og003001og7oL06Mog003001og7oL
015og0004goL00<007oLOm`0PWoL00<007oLOm`0IWoL00<007oLOm`04WoL000COm`00`00Omaog022
Om`00`00Omaog01VOm`00`00Omaog00BOm`001Aog003001og7oL089og003001og7oL06Eog003001o
g7oL019og0005GoL00<007oLOm`0PGoL00<007oLOm`0I7oL00<007oLOm`04goL000EOm`00`00Omao
g021Om`00`00Omaog01TOm`00`00Omaog00COm`001Iog003001og7oL081og003001og7oL06=og003
001og7oL01Aog0005WoL00<007oLOm`0PGoL00<007oLOm`0HGoL00<007oLOm`05GoL000FOm`00`00
Omaog021Om`00`00Omaog01QOm`00`00Omaog00EOm`001Mog003001og7oL081og003001og7oL061o
g003001og7oL01Iog00067oL00<007oLOm`0OgoL00<007oLOm`0GgoL00<007oLOm`05goL000HOm`0
0`00Omaog020Om`00`00Omaog01NOm`00`00Omaog00GOm`001Uog003001og7oL07mog003001og7oL
05eog003001og7oL01Qog0006GoL00<007oLOm`0OgoL00<007oLOm`0GGoL00<007oLOm`067oL000I
Om`00`00Omaog01oOm`00`00Omaog01MOm`00`00Omaog00HOm`001Yog003001og7oL07mog003001o
g7oL05]og003001og7oL01Uog0006goL00<007oLOm`0OWoL00<007oLOm`0FWoL00<007oLOm`06WoL
000KOm`00`00Omaog01nOm`00`00Omaog01JOm`00`00Omaog00JOm`001aog003001og7oL07eog003
001og7oL05Uog003001og7oL01]og0007GoL00<007oLOm`0OGoL00<007oLOm`0EgoL00<007oLOm`0
77oL000NOm`00`00Omaog01lOm`00`00Omaog01FOm`00`00Omaog00MOm`001mog003001og7oL07]o
g003001og7oL05Eog003001og7oL01iog0007goL00<007oLOm`0NgoL00<007oLOm`0EGoL00<007oL
Om`07WoL000POm`00`00Omaog01kOm`00`00Omaog01COm`00`00Omaog00OOm`0025og003001og7oL
07Yog003001og7oL059og003001og7oL021og0008GoL00<007oLOm`0NWoL00<007oLOm`0DWoL00<0
07oLOm`087oL000ROm`00`00Omaog01iOm`00`00Omaog01AOm`00`00Omaog00QOm`002=og003001o
g7oL07Uog003001og7oL04mog003001og7oL029og00097oL00<007oLOm`0N7oL00<007oLOm`0CWoL
00<007oLOm`08goL000UOm`00`00Omaog01gOm`00`00Omaog01=Om`00`00Omaog00TOm`002Eog003
001og7oL07Mog003001og7oL04eog003001og7oL02Aog0009WoL00<007oLOm`0MgoL00<007oLOm`0
BgoL00<007oLOm`09GoL000WOm`00`00Omaog01fOm`00`00Omaog01:Om`00`00Omaog00VOm`002Qo
g003001og7oL07Eog003001og7oL04Uog003001og7oL02Mog000:GoL0P00MGoL00<007oLOm`0B7oL
00<007oLOm`0:7oL000[Om`00`00Omaog01cOm`00`00Omaog016Om`00`00Omaog00YOm`002aog003
001og7oL079og003001og7oL04Eog003001og7oL02Yog000;7oL00<007oLOm`0LWoL00<007oLOm`0
A7oL00<007oLOm`0:goL000]Om`00`00Omaog01aOm`00`00Omaog013Om`00`00Omaog00/Om`002io
g003001og7oL075og003001og7oL045og003001og7oL02eog000;goL00<007oLOm`0L7oL00<007oL
Om`0@7oL00<007oLOm`0;WoL000`Om`2001`Om`00`00Omaog00nOm`2000aOm`0039og003001og7oL
06eog003001og7oL03eog003001og7oL035og000<goL00<007oLOm`0KGoL00<007oLOm`0>goL00<0
07oLOm`0<WoL000dOm`00`00Omaog01/Om`00`00Omaog00jOm`00`00Omaog00cOm`003Eog08006ao
g003001og7oL03Qog08003Iog000=goL00<007oLOm`0JGoL00<007oLOm`0=goL00<007oLOm`0=WoL
000hOm`00`00Omaog01YOm`00`00Omaog00eOm`00`00Omaog00gOm`003Qog003001og7oL06Uog003
001og7oL03Eog003001og7oL03Mog000>GoL00<007oLOm`0J7oL00<007oLOm`0=7oL00<007oLOm`0
>7oL000jOm`3001WOm`00`00Omaog00bOm`2000kOm`003eog08006Iog003001og7oL02iog0<003eo
g000?goL00<007oLOm`0HgoL00<007oLOm`0;GoL00<007oLOm`0?WoL0010Om`00`00Omaog01ROm`0
0`00Omaog00/Om`00`00Omaog00oOm`0045og003001og7oL065og003001og7oL02]og003001og7oL
041og000@WoL0P00HWoL00<007oLOm`0:7oL0P00@goL0014Om`00`00Omaog01OOm`00`00Omaog00W
Om`00`00Omaog013Om`004Eog08005mog003001og7oL02Eog08004Iog000AgoL00<007oLOm`0G7oL
00<007oL00000P008WoL00<007oLOm`0AWoL0018Om`3001JOm`6000POm`20019Om`004]og08005Io
g0P001eog0<004]og000CGoL00<007oLOm`0DgoL200077oL00<007oLOm`0C7oL001>Om`3001COm`7
000JOm`2001?Om`0055og080055og0L001Mog0<0055og000DgoL00<007oLOm`0CgoL1P005WoL00<0
07oLOm`0DWoL001DOm`3001?Om`5000DOm`2001EOm`005Mog003001og7oL04aog0D0019og08005Mo
g000F7oL0`00C7oL10003goL0`00FGoL001KOm`40018Om`4000<Om`3001LOm`005mog0<004Iog0<0
00Uog0<005mog000HWoL0`00A7oL0`0017oL1000HWoL001UOm`30010Om`8001VOm`006Qog0<003eo
g0D006Uog000JgoL1@00=GoL2000JGoL001`Om`5000[Om`50004Om`30002Om`00`00Omaog0020000
0goL00000003001MOm`007Eog0P001]og0P000iog0<0009og003001og000009og003001og7oL05]o
g000OGoL6`005goL00<007oLOm`017oL00<007oLOm`0GGoL002_Om`30005Om`00`00Omaog01LOm`0
0:iog007001og7oLOm`007oL00000goL00<007oLOm`0FgoL002]Om`00`00Omaog003Om`20003Om`0
0`00Omaog01KOm`00:eog003001og7oL00=og003001og000008005iog000[GoL00<007oLOm`00goL
00<007oLOm`0H7oL002]Om`00`00Omaog003Om`00`00Omaog01POm`00:iog005001og7oLOm`0001S
Om`00:mog0<006Aog000ogoL5goL003oOm`GOm`00?mog1Mog000ogoL5goL003oOm`GOm`00001\
\>"],
  ImageRangeCache->{{{0, 277.25}, {277.875, 0}} -> {-2.10029, -2.01002, \
0.0151508, 0.0151508}}],

Cell[TextData[{
  "The arc of the sphere in ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[DoubleStruckCapitalR]\^4\),
          FontSize->12], TraditionalForm]]],
  " that contains the quaternions ",
  Cell[BoxData[
      StyleBox[\(Q\_1\),
        "Output",
        FontSize->12]]],
  "and ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox["Q", 
          StyleBox["2",
            "Output",
            FontSize->12]],
        "Output",
        FontSize->12]]],
  "."
}], "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "The arc from ",
  Cell[BoxData[
      \(Q\_1\)]],
  "to ",
  Cell[BoxData[
      \(Q\_2\)]],
  " has length ",
  Cell[BoxData[
      \(\[Theta]r\  = \ \[Theta]\)]],
  ", (this is a unit circle), where ",
  Cell[BoxData[
      \(cos\ \[Theta]\  = \ Q\_1\[CenterDot]Q\_2\)]],
  "(dot product of vectors in ",
  Cell[BoxData[
      \(\[DoubleStruckCapitalR]\^4\)]],
  ").  We want the parameter ",
  Cell[BoxData[
      \(u\)]],
  " in ",
  Cell[BoxData[
      RowBox[{\([0, 1]\), Cell[""]}]]],
  " to correspond to the point on the arc which is \"u\" of the way from ",
  Cell[BoxData[
      \(Q\_1\)]],
  " to ",
  Cell[BoxData[
      \(Q\_2\)]],
  ".  That is, we want ",
  Cell[BoxData[
      \(q \((u)\)\)]],
  " to divide the arc into two segments of length ",
  Cell[BoxData[
      \(u\[Theta]\)]],
  " and ",
  Cell[BoxData[
      \(\((1 - u)\) \[Theta]\)]],
  " as in the sketch below."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93348 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.445676 0.221729 0.445676 0.221729 [
[ 0 0 0 0 ]
[ 1 .93348 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .93348 L
0 .93348 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.44568 .44568 .44346 0 365.73 arc
s
5 Mabswid
.85538 .27597 Mdot
.5518 .87625 Mdot
.5 Mabswid
.44568 .44568 m
.85538 .27597 L
s
% Start of user PostScript
0 0 1.84776 -0.765367 MAarrowhead1
% End of user PostScript
.44568 .44568 m
.5518 .87625 L
s
% Start of user PostScript
0 0 0.478631 1.94188 MAarrowhead1
% End of user PostScript
gsave
.90391 .61294 -67.1875 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(q) show
71.375000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
gsave
.85538 .27597 -61 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 558.000000 16.562500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Q) show
71.375000 15.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.937500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
78.437500 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5518 .87625 -61 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 558.000000 16.562500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Q) show
71.375000 15.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.937500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
78.437500 13.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
gsave
.8794 .53809 -61 -17.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.500000 moveto
 558.000000 17.500000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.500000 lineto
closepath
clip newpath
63.000000 13.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(q) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
71.375000 13.750000 moveto
(H) show
79.750000 13.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(u) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
88.125000 13.750000 moveto
(L) show
96.500000 13.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
5 Mabswid
.8794 .53809 Mdot
.5 Mabswid
.44568 .44568 m
.8794 .53809 L
s
% Start of user PostScript
0 0 1.95609 0.416808 MAarrowhead1
% End of user PostScript
gsave
.8652 .40723 -81.75 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(u) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(q) show
79.750000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
gsave
.74826 .73881 -115.25 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.625000 moveto
 558.000000 17.625000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.625000 lineto
closepath
clip newpath
63.000000 14.062500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
63.000000 14.062500 moveto
(H) show
71.375000 14.062500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(1) show
79.750000 14.062500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
88.125000 14.062500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(u) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
96.500000 14.062500 moveto
(L) show
104.875000 14.062500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(q) show
113.250000 14.062500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{278.25, 278.875},
  ImageMargins->{{199.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004F00015Q000`40O003h00OogoL5goL003oOm`G
Om`00?mog1Mog000ogoL5goL003oOm`GOm`00?mog1Mog000ogoL5goL003oOm`GOm`00?mog1Mog000
ogoL5goL001^Om`K002=Om`006Mog0L001]og0L008Iog000HWoL1@00:GoL1P00P7oL001OOm`3000d
Om`3001mOm`005Uog0H003Yog0H007Mog000EWoL0`00AWoL0`00M7oL001COm`3001<Om`3001aOm`0
051og0<0059og0<006iog000CGoL0`00F7oL0`00JgoL001;Om`2001NOm`2001YOm`004Yog003001o
g7oL061og003001og7oL06Iog000B7oL0P00I7oL0P00IWoL0015Om`3001XOm`3001SOm`0049og0<0
06iog080065og000@GoL00<007oLOm`0LGoL00<007oLOm`0GWoL000oOm`2001eOm`3001MOm`003eo
g08007Yog003001og7oL05Yog000?7oL00<007oLOm`0NgoL00<007oLOm`0FGoL000jOm`2001oOm`3
001HOm`003Qog08008Aog003001og7oL05Eog000=goL00<007oLOm`0QGoL00<007oLOm`0E7oL000e
Om`20029Om`2001DOm`003Aog003001og7oL08]og003001og7oL055og000<goL00<007oLOm`0SGoL
00<007oLOm`0D7oL000bOm`00`00Omaog02?Om`00`00Omaog01?Om`0031og08009=og08004mog000
;goL00<007oLOm`0UGoL00<007oLOm`0C7oL000^Om`00`00Omaog02GOm`00`00Omaog01;Om`002eo
g003001og7oL09Uog003001og7oL04Yog000;7oL00<007oLOm`0VgoL00<007oLOm`0BGoL000[Om`0
0`00Omaog02MOm`00`00Omaog018Om`002Uog0800:5og08004Qog000:7oL00<007oLOm`0XgoL00<0
07oLOm`0AGoL000WOm`00`00Omaog02UOm`00`00Omaog014Om`002Iog003001og7oL0:Mog003001o
g7oL04=og0009GoL00<007oLOm`0ZGoL00<007oLOm`0@WoL000TOm`00`00Omaog02[Om`00`00Omao
g011Om`002=og003001og7oL0:eog003001og7oL041og0008WoL00<007oLOm`0[goL00<007oLOm`0
?goL000QOm`00`00Omaog02aOm`00`00Omaog00nOm`0021og003001og7oL0;=og003001og7oL03eo
g0007goL00<007oLOm`0]GoL00<007oLOm`0?7oL000OOm`00`00Omaog02eOm`00`00Omaog00lOm`0
01iog003001og7oL0;Mog003001og7oL03]og0007GoL00<007oLOm`0^GoL00<007oLOm`0>WoL000L
Om`00`00Omaog02kOm`00`00Omaog00iOm`001]og003001og7oL0;eog003001og7oL03Qog0006WoL
00<007oLOm`0_WoL00<007oLOm`0>7oL000IOm`00`00Omaog030Om`00`00Omaog00gOm`001Uog003
001og7oL0<5og003001og7oL03Iog00067oL00<007oLOm`0`goL00<007oLOm`0=GoL000GOm`00`00
Omaog035Om`00`00Omaog00dOm`001Iog003001og7oL0<Mog003001og7oL03=og0005GoL00<007oL
Om`0bGoL00<007oLOm`0<WoL000EOm`00`00Omaog039Om`00`00Omaog00bOm`001Aog003001og7oL
0<]og003001og7oL035og00057oL00<007oLOm`0bgoL00<007oLOm`0<GoL000DOm`00`00Omaog03;
Om`00`00Omaog00aOm`001=og003001og7oL0<eog003001og7oL031og0004WoL00<007oLOm`0cgoL
00<007oLOm`0;goL000BOm`00`00Omaog03@Om`00`00Omaog00^Om`0015og003001og7oL0=9og003
001og7oL02eog0004GoL00<007oLOm`0dWoL00<007oLOm`0;GoL000@Om`00`00Omaog03DOm`00`00
Omaog00/Om`000mog003001og7oL0=Eog003001og7oL00Mog00646=J]7>J>Ld004X`7goL000?Om`0
0`00Omaog03EOm`00`00Omaog007Om`01aRU224003W=Om`HYGoL00<001]og0003WoL00<007oLOm`0
egoL00<007oLOm`01WoL00=[F247Om`01GoL00<007oLOm`06WoL000>Om`00`00Omaog03GOm`00`00
Omaog006Om`01E9b000000PQDW800goL00<007oLOm`06WoL000=Om`00`00Omaog03IOm`00`00Omao
g004Om`01e9b225J]7oLF[@88E9b009og003001og7oL01Yog00037oL00<007oLOm`0fgoL00<007oL
Om`00goL00<HYE9bOm`00WoL00EBLQ1SOmaog00001aog00037oL00<007oLOm`0fgoL00<007oLOm`0
0goL00<007oLOm`00goL00@007oL000001aog0002goL00<007oLOm`0gGoL00<007oLOm`00WoL00<0
07oLOm`00goL00@007oLOm`001aog0002goL00<007oLOm`0gGoL00<007oLOm`00WoL00<Q1e9bOm`0
0WoL00=BLR47Om`07WoL000;Om`00`00Omaog03MOm`00`00Omaog002Om`01eZd225J]7oLF[@88EZd
01mog0002WoL00<007oLOm`0ggoL0`000WoL00EBLPPQ00088E9b021og0002WoL00<007oLOm`0gWoL
1@009WoL000:Om`00`00Omaog03LOm`7000VOm`000Uog003001og7oL0=Iog0h002Iog0002GoL00<0
07oLOm`0dWoL3@0000Aog000000002Mog0002GoL00<007oLOm`0dWoL2`001GoL00<007oLOm`09GoL
0008Om`00`00Omaog03DOm`90007Om`00`00Omaog00TOm`000Qog003001og7oL0=Aog0L000Uog003
001og7oL02Aog00027oL00<007oLOm`0dWoL20002WoL00<007oLOm`097oL0007Om`00`00Omaog03A
Om`20003Om`3000=Om`00`00Omaog00SOm`000Mog003001og7oL0<iog0<000Iog003001og7oL00ao
g003001og7oL02=og0001goL00<007oLOm`0c7oL0P0067oL00<007oLOm`08goL0006Om`00`00Omao
g03;Om`2000KOm`00`00Omaog00ROm`000Iog003001og7oL0<Qog0<001eog003001og7oL029og000
1GoL00<007oLOm`0agoL0P0087oL00<007oLOm`08WoL0005Om`00`00Omaog034Om`3000ROm`00`00
Omaog00ROm`000Eog003001og7oL0<9og08002Eog003001og7oL029og00017oL00<007oLOm`0`7oL
0`00:7oL00<007oLOm`08GoL0004Om`00`00Omaog02nOm`2000[Om`00`00Omaog00QOm`000Aog003
001og7oL0;aog08002eog003001og7oL025og0000goL00<007oLOm`0^WoL0`00<7oL00<007oLOm`0
87oL0003Om`00`00Omaog02hOm`2000cOm`00`00Omaog00POm`000=og003001og7oL0;Eog0<003Eo
g003001og7oL021og0000goL00<007oLOm`0/goL0P00>GoL00<007oLOm`07goL0003Om`00`00Omao
g02`Om`3000kOm`00`00Omaog00OOm`000=og003001og7oL0:iog08003iog003001og7oL01mog000
0WoL00<007oLOm`0[GoL0P00@7oL00<007oLOm`07goL0002Om`00`00Omaog02ZOm`30012Om`00`00
Omaog00OOm`0009og003001og7oL0:Qog08004Eog003001og7oL01mog0000WoL00<007oLOm`0YGoL
0`00B7oL00<007oLOm`07WoL00000goL001og02UOm`2001;Om`00`00Omaog00NOm`00003Om`007oL
0:9og0<004eog003001og7oL01iog00000=og000Om`0X7oL0P00D7oL00<007oLOm`07WoL00000goL
001og02NOm`2001BOm`00`00Omaog00NOm`00003Om`007oL09]og0<005Aog003001og7oL01iog000
00=og000Om`0VGoL0P00EgoL00<007oLOm`07WoL00000goL001og02FOm`30013Om`02Gh`O01l07g=
O01l8GoLOiYlY@02O0000ge9OiYog008Om`00`00Omaog00NOm`00003Om`007oL09Aog08004Iog005
O01nLWoLONil0002Om`01ge9O[Aog7nJONilHgnJ00Qog003001og7oL01iog00000=og000Om`0TGoL
0`00B7oL00El07oLOmaog7`0009og003O01og7oL009og003ONimcGoL00Qog003001og7oL01eog000
00=og000Om`0SgoL0P00BgoL00El07oLOmaog7`0009og003O01og7oL00=og003O6=og7oL00Mog003
001og7oL01eog00000<007oLOm`0SGoL0P00CGoL00El07oLOmaog7`0009og003O6=l07`000Al00Uo
g003001og7oL01eog00000<007oLOm`0RWoL0`00CWoL00Al8G`0Omaog09l009og003OS1mkWoL00=o
g003O01og7oL00Mog003001og7oL01eog00000<007oLOm`0R7oL0P00FWoL00IlYGg^OiYog7g^O:D9
Om`00`00Omaog00MOm`00003001og7oL08Eog0<005aog006OiYmcG`0O01lYGlF2GoL00<007oLOm`0
7GoL00000`00Omaog023Om`2001^Om`00`00Omaog00MOm`00003001og7oL081og0<0071og003001o
g7oL01eog00000<007oLOm`0OWoL0P00LgoL00<007oLOm`07GoL00000`00Omaog01lOm`2001eOm`0
0`00Omaog00MOm`00003001og7oL07Uog0<007Mog003001og7oL01eog00000<007oLOm`0N7oL0g`0
N7oL00<007oLOm`07GoL00000`00Omaog01hOm`00`00Omaog005O01cOm`00`00Omaog00MOm`00003
001og7oL07Qog003001og7oL00Eog0El06iog003001og7oL01eog00000<007oLOm`0NGoL00<007oL
Om`02GoL1G`0JGoL00<007oLOm`07GoL00000`00Omaog01iOm`00`00Omaog00>Om`5O01TOm`00`00
Omaog00MOm`00003001og7oL07Uog003001og7oL01=og0Al061og003001og7oL01eog00000<007oL
Om`0NGoL00<007oLOm`05goL1G`0FgoL00<007oLOm`07GoL00000`00Omaog01jOm`00`00Omaog00K
Om`5O01FOm`00`00Omaog00MOm`00003001og7oL07Yog003001og7oL021og0El055og003001og7oL
01eog00000<007oLOm`0NWoL00<007oLOm`09GoL1G`0C7oL00<007oLOm`07GoL00000goL001og01j
Om`00`00Omaog00ZOm`4O018Om`00`00Omaog00MOm`00003Om`007oL07]og003001og7oL02eog0El
049og08001mog00000=og000Om`0NgoL00<007oLOm`0<WoL1G`0?GoL00<007oLOm`07WoL00000goL
001og01kOm`00`00Omaog00gOm`5O00hOm`00`00Omaog00NOm`00003Om`007oL07]og003001og7oL
03aog0El03=og004001og7oLOm`3O0000g`QOmaog004Om`00gjdO:Eog009Om`00gbUO[Aog004Om`0
0003Om`007oL07aog003001og7oL041og0Al02mog003001og7oL00=og003O01og7oL00Eog003O25n
]7oL00Uog003O[AlHgoL00Aog00000=og000Om`0O7oL00<007oLOm`0A7oL1G`0:WoL00<007oLOm`0
0goL00=l07oLOm`017oL00=n]7bUOm`02goL00=lYGjdOm`00goL00000goL001og01lOm`00`00Omao
g019Om`5O00UOm`00`00OiYmB@02O0000gg=O01og005Om`00ge9OS1og003Om`01Wh`O01l07g=O01l
8@9og003OS1mBGoL00=og00000=og000Om`0O7oL00<007oLOm`0CWoL1G`087oL00L007e9OLeog7nJ
ODUl0006Om`00g`QOaIog003Om`01G`0OW9og7g^O0000goL00=oF7`QOm`00goL00000goL001og01m
Om`00`00Omaog01BOm`5O00<Om`2O00=Om`00`00O01og002Om`00gnJO01og005Om`00g`0Omaog003
Om`01G`0Omaog7oLO00017oL00=l07oLOm`00WoL0002Om`00`00Omaog01kOm`00`00Omaog01GOm`4
O008Om`4O00:Om`00`00Omal0003Om`00gnJO01og005Om`00g`0Omaog003Om`01G`0Omaog7oLO000
17oL00=l07oLOm`00WoL0002Om`00`00Omaog01kOm`00`00Omaog01KOm`5O003Om`6O008Om`02000
OmamRgg=OmaoVWe9O006Om`00g`QOaIog003Om`01G`0Omaog7oLO0000goL00=oF7`QOm`00goL0002
Om`00`00Omaog01kOm`00`00Omaog01POm`<O005Om`01000OmaoVWe90W`000=mcG`0O2401GoL00=m
BGg^Om`00WoL00Al8G`0Omaog09l00=og003OS1mBGoL00=og0000WoL00<007oLOm`0NgoL00<007oL
Om`0HWoL37`000Aog7`0O01l00eog003O[Al8GoL00]og003O6=n]7oL00=og0000goL00<007oLOm`0
NgoL00<007oLOm`0HGoL4G`03GoL00=lYGjdOm`02GoL00=n]7aSOm`017oL0003Om`00`00Omaog01k
Om`00`00Omaog01QOm`AO00=Om`00gjdO:Eog009Om`00gbUO[Aog004Om`000=og003001og7oL07]o
g003001og7oL065og0Ml00Eog0El021og0000goL00<007oLOm`0NgoL00<007oLOm`0KWoL0g`08GoL
0003Om`00`00Omaog01lOm`00`00Omaog01^Om`00`00Omaog00POm`000Aog003001og7oL07]og003
001og7oL06eog003001og7oL025og00017oL00<007oLOm`0NgoL00<007oLOm`0KGoL00<007oLOm`0
8GoL0004Om`00`00Omaog01kOm`00`00Omaog01]Om`00`00Omaog00QOm`000Eog003001og7oL07]o
g003001og7oL06]og003001og7oL029og0001GoL00<007oLOm`0NgoL00<007oLOm`0JgoL00<007oL
Om`08WoL0005Om`00`00Omaog01kOm`00`00Omaog01[Om`00`00Omaog00ROm`000Iog003001og7oL
07Yog003001og7oL06]og003001og7oL029og0001WoL00<007oLOm`0NgoL00<007oLOm`0JWoL00<0
07oLOm`08WoL0006Om`00`00Omaog01kOm`00`00Omaog01ZOm`00`00Omaog00ROm`000Mog003001o
g7oL07Yog003001og7oL06Uog003001og7oL02=og0001goL00<007oLOm`0NWoL00<007oLOm`0JGoL
00<007oLOm`08goL0007Om`00`00Omaog01kOm`00`00Omaog01XOm`00`00Omaog00SOm`000Qog003
001og7oL07Yog003001og7oL06Mog003001og7oL02Aog00027oL00<007oLOm`0NWoL00<007oLOm`0
IgoL00<007oLOm`097oL0008Om`00`00Omaog01jOm`00`00Omaog01WOm`00`00Omaog00TOm`000Uo
g003001og7oL07Yog003001og7oL06Eog003001og7oL00Iog006LiXHY@00000YBG>J6GoL0009Om`0
0`00Omaog01jOm`00`00Omaog01UOm`00`00Omaog006Om`01bU9F[Aog7>J@Nh@Hg>J01Qog0002GoL
00<007oLOm`0NWoL00<007oLOm`0I7oL00<007oLOm`01goL00<007oLOm`00WoL00=1kSW=Om`05goL
000:Om`00`00Omaog01iOm`00`00Omaog01SOm`00`00Omaog008Om`00`00Omaog003Om`00a1SOmao
g00FOm`000Yog003001og7oL07Yog003001og7oL069og003001og7oL00Qog00346<0000000@001Qo
g0002goL00<007oLOm`0NGoL00<007oLOm`0HGoL00<007oLOm`02GoL00=:<47^Om`00goL00<007oL
Om`05WoL000;Om`00`00Omaog01iOm`00`00Omaog01QOm`00`00Omaog00:Om`01QRU@NicVWoL@NhH
YAQog0002goL00<007oLOm`0NGoL00<007oLOm`0HGoL00<007oLOm`02WoL00IcVSW=000001RUHaHH
Om`000aog003001og7oL07Uog003001og7oL05mog003001og7oL02Uog00037oL00<007oLOm`0NGoL
00<007oLOm`0GgoL00<007oLOm`0:GoL000<Om`00`00Omaog01iOm`00`00Omaog01OOm`00`00Omao
g00YOm`000eog003001og7oL07Qog003001og7oL05iog003001og7oL02Yog0003WoL00<007oLOm`0
N7oL00<007oLOm`0G7oL00<007oLOm`0:goL000>Om`00`00Omaog01hOm`00`00Omaog01LOm`00`00
Omaog00[Om`000mog003001og7oL07Mog003001og7oL05]og003001og7oL02aog0003goL00<007oL
Om`0MgoL00<007oLOm`0FgoL00<007oLOm`0;7oL000@Om`00`00Omaog01gOm`00`00Omaog01JOm`0
0`00Omaog00/Om`0015og003001og7oL07Iog003001og7oL05Uog003001og7oL02eog0004GoL00<0
07oLOm`0MWoL00<007oLOm`0FGoL00<007oLOm`0;GoL000BOm`00`00Omaog01eOm`00`00Omaog01H
Om`00`00Omaog00^Om`0019og003001og7oL07Eog003001og7oL05Mog003001og7oL02mog0004goL
00<007oLOm`0MGoL00<007oLOm`0EGoL00<007oLOm`0<7oL000DOm`00`00Omaog01dOm`00`00Omao
g01DOm`00`00Omaog00aOm`001Aog003001og7oL07Aog003001og7oL05Aog003001og7oL035og000
5GoL00<007oLOm`0LgoL00<007oLOm`0DgoL00<007oLOm`0<WoL000EOm`00`00Omaog01dOm`00`00
Omaog01BOm`00`00Omaog00bOm`001Iog003001og7oL07=og003001og7oL055og003001og7oL03=o
g0005goL00<007oLOm`0LWoL00<007oLOm`0D7oL00<007oLOm`0=7oL000GOm`00`00Omaog01bOm`0
0`00Omaog01@Om`00`00Omaog00dOm`001Qog003001og7oL079og003001og7oL04iog003001og7oL
03Eog0006GoL00<007oLOm`0LGoL00<007oLOm`0CGoL00<007oLOm`0=WoL000JOm`00`00Omaog01`
Om`00`00Omaog01<Om`00`00Omaog00gOm`001]og003001og7oL06mog003001og7oL011og003O[Al
YGoL01Yog003O:En]7oL01]og003001og7oL03Qog0006goL00<007oLOm`0L7oL00<007oLOm`03goL
00=l8GjdOm`06WoL00=n]7aSOm`06goL00<007oLOm`0>7oL000LOm`00`00Omaog01_Om`00`00Omao
g00>Om`00gjdO:Eog00LOm`00gbUO[Aog00IOm`00`00Omaog00iOm`001eog003001og7oL06iog003
001og7oL00iog003ODUn<7oL00=og0Al0003O25og7oL00Yog006OS1l07`0OLel07`Q0WoL00=n<7e9
Om`01GoL00IoVWbUO01l07e9OiX=Om`00`00Omaog00jOm`001iog003001og7oL06eog003001og7oL
00iog003O25o5WoL00Eog003O01og7oL00aog005O01nLWoLONil0003Om`00gmHO25og005Om`01ge9
O[Aog7nJONilHgnJ00]og003001og7oL03]og0007goL00<007oLOm`0KGoL00<007oLOm`03GoL00=l
07oLOm`01GoL00=l07oLOm`00WoL1W`017oL00El07oLOmaog7`000Aog003O01og7oL00Aog003O01o
g7oL009og003ONimcGoL00Uog003001og7oL03aog00087oL00<007oLOm`0K7oL00<007oLOm`03GoL
00=l07oLOm`01GoL00=l07oLOm`037oL00El07oLOmaog7`000Aog003O01og7oL00Aog003O01og7oL
00=og003O6=og7oL00Mog003001og7oL03eog0008GoL00<007oLOm`0JgoL00<007oLOm`03GoL00=l
8GlFOm`01GoL00=l07oLOm`037oL00El07oLOmaog7`000=og003OeQl8GoL00Eog003O6=l07`000Al
00Qog003001og7oL03iog0008GoL00<007oLOm`0JgoL00<007oLOm`03GoL00=mBGg^Om`01GoL00=l
07oLOm`02goL00Al8G`0Omaog09l00=og003OS1mBGoL00Eog003OS1mkWoL00=og003O01og7oL00Io
g003001og7oL03iog0008WoL00<007oLOm`0JgoL00<007oLOm`037oL00=n]7`QOm`01GoL00=l07oL
Om`057oL00=lHgjdOm`01WoL00IlYGg^OiYog7g^O:D7Om`00`00Omaog00oOm`002=og003001og7oL
06Yog003001og7oL00eog003O:En]7oL009og003O01m1g`001Eog003O[AlHgoL00Mog006OiYmcG`0
O01lYGlF1WoL00<007oLOm`0@7oL000TOm`00`00Omaog01YOm`00`00Omaog00=Om`00gjdO:Eog002
Om`00glFODUl000EOm`00gbUO[Aog00BOm`00`00Omaog011Om`002Eog003001og7oL06Qog003001o
g7oL03iog003001og7oL049og0009WoL00<007oLOm`0J7oL00<007oLOm`0?7oL00<007oLOm`0@goL
000WOm`2001XOm`00`00Omaog00jOm`20016Om`002Uog003001og7oL06Eog003001og7oL03Uog003
001og7oL04Iog000:WoL00<007oLOm`0I7oL00<007oLOm`0>7oL00<007oLOm`0AgoL000[Om`00`00
Omaog01TOm`00`00Omaog00fOm`00`00Omaog018Om`002aog003001og7oL06=og003001og7oL03Eo
g003001og7oL04Uog000;GoL00<007oLOm`0HWoL00<007oLOm`0=7oL00<007oLOm`0BWoL000^Om`2
001ROm`00`00Omaog00bOm`2001=Om`0031og003001og7oL061og003001og7oL031og003001og7oL
04eog000<GoL00<007oLOm`0GgoL00<007oLOm`0;goL00<007oLOm`0CWoL000bOm`00`00Omaog01N
Om`00`00Omaog00^Om`00`00Omaog01?Om`003=og0<005eog003001og7oL02aog080059og000=WoL
00<007oLOm`0FWoL00<007oLOm`0:WoL0P00E7oL000gOm`00`00Omaog01JOm`00`00Omaog00XOm`0
0`00Omaog01DOm`003Qog08005Yog003001og7oL02Iog08005Mog000>WoL00<007oLOm`0EgoL00<0
07oLOm`09GoL00<007oLOm`0EgoL000kOm`3001FOm`5000QOm`2001JOm`003iog003001og7oL055o
g0L001mog08005aog000?goL00<007oLOm`0D7oL1`007WoL00<007oLOm`0G7oL0010Om`3001@Om`6
000LOm`2001OOm`004=og0<004eog0H001Uog0<0065og000AWoL00<007oLOm`0BgoL1@005goL0P00
I7oL0017Om`00`00Omaog01:Om`5000FOm`00`00Omaog01TOm`004Qog0<004Yog0@001Aog08006Mo
g000BgoL0`00AgoL10004GoL0`00JGoL001>Om`30014Om`4000>Om`3001/Om`0055og0<0049og0<0
00]og0<006mog000E7oL0`00?goL0`0027oL0`00LWoL001GOm`3000mOm`30004Om`3001eOm`005Yo
g0<003Uog0P007Qog000GGoL0`00=WoL1@00NgoL001POm`6000/Om`900001goL46=J]7>J>Ld004X`
07Aog000IWoL10008goL1@001GoL0`000WoL00LHY@PQ000icGoL6:Eog005001^Om`006Yog0/000eo
g0/000mog003JePQ1goL00Eog004001og7oL001^Om`007Eog0d001Yog005DW800000225BLP04Om`0
0`00Omaog01^Om`009]og007DW888EZdOmaJ]0PQDW8017oL00<007oLOm`0KGoL002KOm`00aRUDW9o
g002Om`0159b46=og0000goL00<007oLOm`0K7oL002KOm`00`00Omaog003Om`00`00Om`00003Om`0
0`00Omaog01/Om`009]og003001og7oL00=og003001og7oL00<006mog000VgoL00<Q1e9bOm`00WoL
00=BLR47Om`0LgoL002KOm`01eZd225J]7oLF[@88EZd07Aog000W7oL00EBLPPQ00088E9b07Eog000
ogoL5goL003oOm`GOm`00?mog1Mog000ogoL5goL003oOm`GOm`00?mog1Mog000ogoL5goL003oOm`G
Om`00?mog1Mog000ogoL5goL003oOm`GOm`00?mog1Mog000ogoL5goL003oOm`GOm`00001\
\>"],
  ImageRangeCache->{{{0, 277.25}, {277.875, 0}} -> {-2.01003, -2.16511, \
0.0162671, 0.0162671}}],

Cell[TextData[{
  "In the above picture, ",
  Cell[BoxData[
      \(u\[Theta]\)]],
  " and ",
  Cell[BoxData[
      \(\((1 - u)\) \[Theta]\)]],
  " represent the lengths of the arcs indicated.  A little vector \
manipulation and the Law of Sines reveals that the appropriate expression for \
",
  Cell[BoxData[
      \(q \((u)\)\)]],
  " is "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(q \((u)\)\  = \ \(\(sin \((\[Theta] - 
                      u\[Theta])\)\)\/\(sin\ \[Theta]\)\) 
            Q\_1\  + \ \(\(sin\ u\[Theta]\)\/\(sin\ \[Theta]\)\) Q\_2\)]]
}], "Text"],

Cell[TextData[{
  "Shoemake called this process ",
  StyleBox["slerping",
    FontWeight->"Bold"],
  " (spherical linear interpolating) since it uses the spherical analog of a \
straight line (the shortest distance between two points on a sphere is the \
arc determined by the intersection of the sphere and the plane containing the \
two points and the center of the sphere)."
}], "Text"],

Cell[TextData[{
  "Lets look at an example.  Let ",
  Cell[BoxData[
      \(Q\_1\)]],
  " be the identity quaternion ",
  Cell[BoxData[
      \(\((1, \((0, 0, 0)\))\)\)]],
  StyleBox[" ", "Output",
    FontSize->16],
  "representing the standard orientation in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^3\)]],
  "and let  ",
  Cell[BoxData[
      \(Q\_2\)]],
  " be the red orientation in the sketch below."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.65153 .69659 m .65612 .70482 L .66477 .73412 L closepath p 0 0 0 r
F P
0 g
s
.64126 .69564 m .65153 .69659 L .66477 .73412 L closepath p 0 0 0 r
F P
0 g
s
.6313 .70248 m .64126 .69564 L .66477 .73412 L closepath p 0 0 0 r
F P
0 g
s
.62743 .71312 m .6313 .70248 L .66477 .73412 L closepath p 0 0 0 r
F P
0 g
s
.63192 .7214 m .62743 .71312 L .66477 .73412 L closepath p 0 0 0 r
F P
0 g
s
.64222 .72243 m .63192 .7214 L .66477 .73412 L closepath p 0 0 0 r
F P
0 g
s
.65227 .71555 m .64222 .72243 L .66477 .73412 L closepath p 0 0 0 r
F P
0 g
s
.65612 .70482 m .65227 .71555 L .66477 .73412 L closepath p 0 0 0 r
F P
0 g
s
.005 w
.52632 .58304 m
.64949 .71745 L
s
.5 Mabswid
.54178 .38811 m .53397 .39442 L .52632 .34495 L closepath p .455 0 0 r
F P
0 g
s
.54057 .37997 m .54178 .38811 L .52632 .34495 L closepath p 0 0 0 r
F P
0 g
s
.53095 .37477 m .54057 .37997 L .52632 .34495 L closepath p .854 0 0 r
F P
0 g
s
.52174 .39526 m .51214 .39015 L .52632 .34495 L closepath p .842 0 0 r
F P
0 g
s
.53397 .39442 m .52174 .39526 L .52632 .34495 L closepath p .681 0 0 r
F P
0 g
s
.51858 .37562 m .53095 .37477 L .52632 .34495 L closepath p .622 0 0 r
F P
0 g
s
.51214 .39015 m .5108 .38202 L .52632 .34495 L closepath p .993 0 0 r
F P
0 g
s
.5108 .38202 m .51858 .37562 L .52632 .34495 L closepath p .128 0 0 r
F P
0 g
s
1 0 0 r
.005 w
.52632 .37509 m
.52632 .58304 L
s
.5 Mabswid
.31258 .64991 m .31455 .66189 L .25961 .66843 L closepath p .664 0 0 r
F P
0 g
s
.30653 .64013 m .31258 .64991 L .25961 .66843 L closepath p .713 0 0 r
F P
0 g
s
.29988 .63824 m .30653 .64013 L .25961 .66843 L closepath p .76 0 0 r
F P
0 g
s
.29849 .65756 m .29652 .64544 L .25961 .66843 L closepath p .494 0 0 r
F P
0 g
s
.31455 .66189 m .31128 .66916 L .25961 .66843 L closepath p .578 0 0 r
F P
0 g
s
.30463 .66741 m .29849 .65756 L .25961 .66843 L closepath p .545 0 0 r
F P
0 g
s
.31128 .66916 m .30463 .66741 L .25961 .66843 L closepath p .239 0 0 r
F P
0 g
s
.29652 .64544 m .29988 .63824 L .25961 .66843 L closepath p .142 0 0 r
F P
0 g
s
1 0 0 r
.005 w
.29824 .65606 m
.52632 .58304 L
s
.5 Mabswid
.77182 .50274 m .7664 .49167 L .82351 .48789 L closepath p 0 0 0 r
F P
0 g
s
.77473 .51558 m .77182 .50274 L .82351 .48789 L closepath p 0 0 0 r
F P
0 g
s
.77345 .5228 m .77473 .51558 L .82351 .48789 L closepath p 0 0 0 r
F P
0 g
s
.7664 .49167 m .7616 .48881 L .82351 .48789 L closepath p 0 0 0 r
F P
0 g
s
.76867 .52009 m .77345 .5228 L .82351 .48789 L closepath p 0 0 0 r
F P
0 g
s
.7616 .48881 m .76025 .49593 L .82351 .48789 L closepath p 0 0 0 r
F P
0 g
s
.76318 .50894 m .76867 .52009 L .82351 .48789 L closepath p 0 0 0 r
F P
0 g
s
.005 w
.52632 .58304 m
.79538 .4969 L
s
.5 Mabswid
.76025 .49593 m .76318 .50894 L .82351 .48789 L closepath p 0 0 0 r
F P
0 g
s
.52107 .819 m .53509 .81826 L .52632 .86433 L closepath p 0 0 0 r
F P
0 g
s
.51007 .81448 m .52107 .819 L .52632 .86433 L closepath p 0 0 0 r
F P
0 g
s
.53509 .81826 m .54404 .81268 L .52632 .86433 L closepath p 0 0 0 r
F P
0 g
s
.50852 .80729 m .51007 .81448 L .52632 .86433 L closepath p 0 0 0 r
F P
0 g
s
.54404 .81268 m .54266 .80547 L .52632 .86433 L closepath p 0 0 0 r
F P
0 g
s
.51744 .80163 m .50852 .80729 L .52632 .86433 L closepath p 0 0 0 r
F P
0 g
s
.54266 .80547 m .53163 .80087 L .52632 .86433 L closepath p 0 0 0 r
F P
0 g
s
.53163 .80087 m .51744 .80163 L .52632 .86433 L closepath p 0 0 0 r
F P
0 g
s
.005 w
.52632 .58304 m
.52632 .80115 L
s
.5 Mabswid
.37947 .42854 m .37427 .44039 L .35716 .39846 L closepath p .973 0 0 r
F P
0 g
s
.39098 .42027 m .37947 .42854 L .35716 .39846 L closepath p .795 0 0 r
F P
0 g
s
.40216 .42037 m .39098 .42027 L .35716 .39846 L closepath p .332 0 0 r
F P
0 g
s
.37427 .44039 m .37845 .44895 L .35716 .39846 L closepath p 0 0 0 r
F P
0 g
s
.40647 .42886 m .40216 .42037 L .35716 .39846 L closepath p .844 0 0 r
F P
0 g
s
.37845 .44895 m .38965 .44916 L .35716 .39846 L closepath p .484 0 0 r
F P
0 g
s
.4013 .44081 m .40647 .42886 L .35716 .39846 L closepath p .867 0 0 r
F P
0 g
s
.38965 .44916 m .4013 .44081 L .35716 .39846 L closepath p .745 0 0 r
F P
0 g
s
1 0 0 r
.005 w
.39808 .44312 m
.52632 .58304 L
s
0 g
gsave
.82351 .48789 -61 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
71.375000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.66477 .73412 -61 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
71.375000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.52632 .86433 -61 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
71.375000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 0 r
gsave
.25961 .66843 -73.375 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(X) show
71.375000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.52632 .34495 -73.375 -10.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Y) show
71.375000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.35716 .39846 -61 -16.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.125000 moveto
 558.000000 16.125000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.125000 lineto
closepath
clip newpath
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Z) show
71.375000 13.125000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.25, 288},
  ImageMargins->{{196.625, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000181000`40O003h00OogoL2WoL003oOm`:
Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000
ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:
Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000
ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:
Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000
ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:
Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000
ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:
Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000
ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:
Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000
ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000PWoL1G`0PWoL0024
Om`00g`0Omaog022Om`008Aog003O01og7oL00Aog003001og7oL07]og000Q7oL00=l07oLOm`017oL
00<007oLOm`0NgoL0023Om`00g`0Omal0004Om`3001lOm`008=og003O01og7`000Aog0<007aog000
PWoL00El07oLOmaog7`0009og0@007aog000PGoL0g`000Eog7`0O01l07oL00800003C000000007]o
g000HGoL1W`08GoL00@00100001<008007]og000HGoL00=l07oLOm`00WoL00=l07oLOm`07goL0P00
0T`00P00NgoL001ROm`01G`0Omaog7oLO00087oL100000Al0000000007Yog000HgoL00=l07oLOm`0
8GoL0P0000IX0000O00003P0001jOm`006Aog003O01og7oL01mog009001l0000J00007`0000h0000
07Yog000HGoL00El07oLOmaog7`0021og0800008J00005@0O01D0000>00007Uog000HGoL00=l07oL
Om`00WoL00=l07oLOm`07WoL0`0000=D07`0E0000P00NWoL001QOm`6O00ROm`200000g`00000001k
Om`005iog08002]og003O01og7oL07]og000GWoL00@005`0000002Uog003O01og7oL07]og000GgoL
00<005`000000P009goL00=l07oLOm`0NgoL001OOm`200000e`000000002000UOm`00g`0Omaog01k
Om`005mog080009L0003001/0000008002=og003O01og7oL07]og000H7oL0P000U`000<006`00000
0`008GoL00=l07oLOm`0NgoL001POm`20003G0000`00K01/0003000POm`00g`0Omaog01kOm`0061o
g0<000=L0005001/06`0K000000POm`00g`0Omaog01kOm`0065og003000l000000=L0005001/06`0
K000000OOm`00g`0Omaog01kOm`0065og0<000AL0004001/06`0000OOm`00g`0Omaog01kOm`0065o
g0800003?00005`000=L0080021og003O01og7oL07]og000HWoL0`0015`00P0087oL00=l07oLOm`0
NgoL001SOm`01000?00005`00P0000=l07oLOm`07goL00=l07oLOm`0NgoL001TOm`30002Om`00g`0
Omaog00OOm`00g`0Omaog01kOm`006Yog003O01og7oL01iog003O01og7oL07]og000JgoL00=l07oL
Om`07GoL00=l07oLOm`0CWoL0`0000Aog000000002Iog000K7oL00=l07oLOm`077oL00=l07oLOm`0
CgoL00D007oLOmaog00002Mog000KGoL00=l07oLOm`06goL00=l07oLOm`0D7oL00<007oL0000:7oL
001^Om`00g`0Omaog00JOm`00g`0Omaog01AOm`00`00Omaog00WOm`006mog003O01og7oL01Uog003
O01og7oL055og003001og7oL02Mog000L7oL00=l07oLOm`067oL00=l07oLOm`0D7oL00<007oL0000
:7oL001aOm`00g`0Omaog00GOm`00g`0Omaog01?Om`01@00Omaog7oL00009goL001bOm`00g`0Omao
g00FOm`00g`0Omaog01>Om`3000017oL000000009WoL001cOm`00g`0Omaog00EOm`00g`0Omaog01k
Om`007Aog003O01og7oL01Aog003O01og7oL03]og14002mog000M7oL00=l07oLOm`057oL00=l07oL
Om`0>goL3`00<GoL001eOm`00g`0Omaog00COm`00g`0Omaog00jOm`?000bOm`007Iog003O01og7oL
019og003O01og7oL03Yog0d003Aog000MgoL00=l07oLOm`04GoL00=l07oLOm`0>goL2`00=GoL001h
Om`00g`0Omaog00@Om`00g`0Omaog00iOm`;000gOm`007Uog003O01og7oL00mog003O01og7oL03Io
g0<0009og0P003Qog000NWoL00=l07oLOm`03WoL00=l07oLOm`0<goL0`001WoL1P00>GoL001kOm`0
0g`0Omaog00=Om`00g`0Omaog00`Om`3000:Om`3000kOm`007aog003O01og7oL00aog003O01og7oL
02eog0<000iog003001og7oL03Yog000OGoL00=l07oLOm`02goL00=l07oLOm`0:WoL0`00CWoL001n
Om`00g`0Omaog00:Om`00g`0Omaog00WOm`3001AOm`007mog003O01og7oL00Uog003O01og7oL02Ao
g0<005Aog000P7oL00=l07oLOm`027oL00=l07oLOm`087oL1000EgoL0020Om`00g`0Omaog008Om`0
0g`0Omaog00MOm`3001KOm`0085og003O01og7oL00Mog003O01og7oL01Yog0<005iog000PWoL00=l
07oLOm`01WoL00=l07oLOm`05goL0`00HGoL0023Om`00g`0Omaog005Om`00g`0Omaog00DOm`3001T
Om`008Aog003O01og7oL00Aog003O01og7oL015og0<006Mog000QGoL00=l07oLOm`00goL00=l07oL
Om`03WoL0`00JWoL0026Om`00g`0Omaog002Om`00g`0Omaog00;Om`3001]Om`008Mog005O01og7oL
Omal000:Om`3001`Om`008Qog004O01og7oLO007Om`3001cOm`008Uog003O01og7`000Aog0<007Io
g000RWoL0W`000Aog000000007Uog000RGoL0g`000<007oLOm`0NWoL0026Om`3O002Om`00`00Omao
g01kOm`008=og0=l00Eog08007aog000P7oL0g`027oL00<007oL0000NgoL001mOm`3O00;Om`01000
Omaog000NWoL001iOm`4O00>Om`01@00Omaog7oL0000NGoL001fOm`3O00BOm`00`00Omaog002Om`0
0`00Omaog01fOm`007=og0=l01Eog003001og7oL00=og003001og7oL07Eog000L7oL0g`067oL00<0
07oLOm`017oL00<007oLOm`0M7oL001/Om`4O00KOm`00`00Omaog005Om`00`00Omaog01cOm`006Uo
g0=l01mog003001og7oL00Iog003001og7oL079og000IWoL0g`08WoL00<007oLOm`01goL00<007oL
Om`0LGoL001SOm`3O00UOm`00`00Omaog008Om`00`00Omaog01`Om`0061og0=l02Qog003001og7oL
00Qog003001og7oL071og000>goL0g`000Aog7`0O01l00aog0<000]og0Al02]og003001og7oL00Uo
g003001og7oL06mog000?7oL00El07oLOmaog7`000aog003000@0000008000Mog0=l02mog003001o
g7oL00Yog003001og7oL06iog000?GoL00=l07oLO00037oL100000=H0000Om`00goL0g`0<WoL00<0
07oLOm`02goL00<007oLOm`0KGoL000nOm`00g`0Omaog009Om`3000013`0001H05P00P000g`0=GoL
00<007oLOm`037oL00<007oLOm`0K7oL000nOm`00g`0Omaog008Om`20003?0020003O00hOm`00`00
Omaog00=Om`00`00Omaog01[Om`003eog003O01og7`000Mog0<0008l0080009l00=D0003001og7oL
03Eog003001og7oL00iog003001og7oL06Yog000?7oL00El07oLOmaog7`000Eog0800004?0000000
0002A006000gOm`00`00Omaog00?Om`00`00Omaog01YOm`003]og0=l0004Omal07`0O003Om`40006
A0001@00B01804P00000=goL00<007oLOm`047oL00<007oLOm`0J7oL0014Om`?000hOm`00`00Omao
g00AOm`00`00Omaog01WOm`008]og003001og7oL019og003001og7oL06Iog000RgoL00<007oLOm`0
4WoL00<007oLOm`0IWoL002;Om`00`00Omaog00COm`00`00Omaog01UOm`008]og003001og7oL01Ao
g003001og7oL06Aog000RgoL00<007oLOm`05GoL00<007oLOm`0HgoL002;Om`00`00Omaog00FOm`0
0`00Omaog01ROm`008]og003001og7oL01Mog003001og7oL00@005eog000RgoL00<007oLOm`067oL
1`00G7oL002;Om`00`00Omaog00HOm`70006Om`5001AOm`008]og003001og7oL01Qog0P000Mog003
001og7oL055og000RgoL00<007oLOm`05goL2@001goL00<007oLOm`0DGoL002;Om`00`00Omaog00G
Om`90007Om`00`00Omaog01AOm`008]og003001og7oL01Mog0X000Eog003001og000059og000RgoL
00<007oLOm`067oL2@001GoL00<007oL0000DWoL002;Om`00`00Omaog00JOm`70004Om`01@00Omao
g7oL0000DGoL002;Om`00`00Omaog00LOm`50003Om`3000017oL00000000D7oL002;Om`00`00Omao
g00OOm`3001IOm`008]og003001og7oL025og003001og7oL05Mog000RgoL00<007oLOm`0NgoL002;
Om`00`00Omaog01kOm`008]og003001og7oL07]og000RgoL00<007oLOm`0NgoL002;Om`00`00Omao
g01kOm`008]og003001og7oL07]og000RgoL00<007oLOm`0NgoL002;Om`00`00Omaog01kOm`008]o
g003001og7oL07]og000RgoL00<007oLOm`0NgoL002;Om`00`00Omaog01kOm`008]og003001og7oL
07]og000RgoL00<007oLOm`0NgoL002;Om`00`00Omaog01kOm`008]og003001og7oL07]og000RgoL
00<007oLOm`0NgoL0028Om`7001jOm`008Mog0T007Uog000QWoL2P00NGoL0026Om`:001iOm`008Io
g0X007Uog000QWoL2P00NGoL0027Om`8001jOm`008Mog0P007Yog000QgoL2000NWoL0028Om`6001k
Om`008Qog0H007]og000RGoL1@00NgoL0029Om`5001kOm`008Uog0@007aog000RWoL0`00O7oL002:
Om`300000goL00000004001eOm`008Yog080009og003001og7oL009og003001og7oL07=og000RgoL
00D007oLOmaog00000=og003001og7oL07=og000T7oL00<007oLOm`0MWoL002AOm`00`00Omaog01e
Om`008iog005001og7oLOm`0001fOm`008iog003001og7oL009og003001og7oL07=og000SWoL1P00
MGoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`0
0?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL
2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`0
0?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL
2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`0
0?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL
2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`00?mog0Yog000ogoL2WoL003oOm`:Om`0
0?mog0Yog000\
\>"],
  ImageRangeCache->{{{0, 264.25}, {287, 0}} -> {0.0486402, -0.000258806, \
0.00324535, 0.00324535}}],

Cell[TextData[{
  "Orientations of 3 space represented by the quaternions ",
  Cell[BoxData[
      StyleBox[\(Q\_1\),
        "Output",
        FontSize->12]]],
  "and ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox["Q", 
          StyleBox["2",
            FontSize->12]],
        "Output",
        FontSize->12]]],
  "."
}], "Caption",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "We can recover ",
  Cell[BoxData[
      \(Q\_2\)]],
  " by noting that the matrix for rotating the ",
  Cell[BoxData[
      \(X\)]],
  StyleBox[", ", "Input",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(Y\)]],
  ", and ",
  Cell[BoxData[
      \(Z\)]],
  " unit vectors to the new positions is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{"N", " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(-1\), "0", "0"},
              {"0", "0", \(-1\)},
              {"0", \(-1\), "0"}
              }], ")"}]}]}]]]], "Text"],

Cell[TextData[{
  "and computing ",
  Cell[BoxData[
      \(quat[N]\)]],
  " using the function ",
  Cell[BoxData[
      \(quat\)]],
  " above."
}], "Text"],

Cell[BoxData[{
    \(q1\  = \ {1, {0, 0, 0}}\), "\n", 
    \(q2\  = \ 
      quat[{{\(-1\), 0, 0}, {0, 0, \(-1\)}, {0, \(-1\), 0}}]\)}], "Input"],

Cell[TextData[{
  "We define the slerp function (noting the limitation implied by choosing",
  StyleBox[" ", "Output"],
  Cell[BoxData[
      \(\[Theta]\  = \ ArcCos[\ Q\_1\[CenterDot]Q\_2]\)]],
  ")"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[slerp];\)\), "\n", 
    \(slerp[q1_, \ q2_, \ u_]\  := \ 
      Module[{th, costh}, \n\t\tcosth\  = \ 
          Flatten[q1] . Flatten[q2]; \n\t\tth\  = \ 
          ArcCos[costh]; \n\t\tReturn[\ 
          Sin[th - u*th]/Sin[th]*q1\  + Sin[u*th]/Sin[th]*q2]]\)}], "Input"],

Cell["Here are two functions to draw axes.", "Text"],

Cell[BoxData[
    \(axes[m_, col_]\  := \ {Vector[{m, 0, 0}, \ VectorColor -> col], \ 
        Vector[{0, m, 0}, \ VectorColor -> col], 
        Vector[{0, 0, m}, \ VectorColor -> col]}\)], "Input"],

Cell[TextData[{
  StyleBox["trans", "Input",
    FontWeight->"Plain"],
  " draws the axes after they have been rotated by using the input quaternion \
",
  Cell[BoxData[
      \(q\)]],
  "."
}], "Text",
  CellMargins->{{15, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(trans[r_, q_, \ col_]\  := \ 
      Module[{mm}, \n\t\tmm\  = \ 
          mat[q]; \n\t\tReturn[{Vector[\ mm . {r, 0, 0}, \ 
              VectorColor -> col], \ 
            Vector[\ mm . {0, r, 0}, \ VectorColor -> col], 
            Vector[\ mm . {0, 0, r}, \ VectorColor -> col]}]]\)], "Input"],

Cell[TextData[{
  "These two frames will construct an animation illustrating the smooth \
transition from the orientation of quaternion ",
  Cell[BoxData[
      \(Q\_1\)]],
  " to the orientation of the quaternion ",
  Cell[BoxData[
      \(Q\_2\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\(gr = 
        Table[Show[{axes[2, GrayLevel[0]], \ trans[2, q2, Hue[0]], 
              trans[2, \ slerp[q1, q2, t], Hue[0.25]]}, \ PlotRange -> All, \ 
            AspectRatio -> Automatic, \ DisplayFunction -> Identity], {t, 0, 
            1, 1/15}];\)\)}], "Input"],

Cell[BoxData[
    \(\(GLShow[gr, \ AnimateFrames -> True];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Quaternions, Slerping, and the Tumbling Cube - An Example", \
"Subsubsection"],

Cell[TextData[{
  "In the first section of this chapter we mentioned an example of a cube \
sliding down a circular ramp.  We expand on this example a bit.  We want to \
animate the following situation.  The cube tumbles through space, its \
position at time t is determined by the circular ramp and its orientation at \
time t is determined by the slerp between the two orientations determined by \
",
  Cell[BoxData[
      \(Q\_1\)]],
  "  and ",
  Cell[BoxData[
      \(Q\_2\)]],
  " above."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(box3\)]],
  " is a low-level procedure to create the box.  The input parameter is ",
  Cell[BoxData[
      \(t\)]],
  " in ",
  Cell[BoxData[
      \(\([0, 1]\)\)]],
  " and the output is a set of ",
  Cell[BoxData[
      \(6\)]],
  " polygons that form a cube centered at the point on the ramp with the \
orientation described above.  The ramp is the intersection of the cylinder \
around the ",
  Cell[BoxData[
      \(z\)]],
  " axis  with radius ",
  Cell[BoxData[
      \(3.5\)]],
  "  and the plane ",
  Cell[BoxData[
      \(z\  = \ \(4 - x\)\/8\)]],
  ".\nThe parametric equation of that intersection is"
}], "Text"],

Cell[BoxData[
    RowBox[{"\t", 
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox["c",
              FontWeight->"Bold"], "\[RightVector]"], \((t)\)}], " ", "=", 
        " ", \((3.5\ cos\ t, \ 
          3.5\ sin\ t, \ \(4 - 3.5\ cos\ t\)\/8)\)}]}]], "Text"],

Cell[TextData[{
  "The procedure ",
  Cell[BoxData[
      \(box3\)]],
  " assumes the definition of ",
  Cell[BoxData[
      \(q1, \ q2\)]],
  ", and ",
  Cell[BoxData[
      \(slerp\)]],
  " above.  It applies the rotation determined by the input parameter ",
  Cell[BoxData[
      \(t\)]],
  " and the ",
  Cell[BoxData[
      \(slerp\)]],
  " of ",
  Cell[BoxData[
      \(q1\)]],
  " and ",
  Cell[BoxData[
      \(q2\)]],
  " to the three half-unit vectors and uses these rotated vectors to draw the \
cube."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[box3];\)\), "\n", 
    \(box3[t_]\  := \ 
      Module[{ang, pos, q, m, a, b, c}, \n\t\tang\  = \ 
          Pi - t*Pi; \n\t\tpos\  = \ {3.5*Cos[ang], \ 
            3.5*Sin[ang], \ \((4 - 3.5  Cos[ang])\)/8}; \n\t\tq\  = \ 
          slerp[q1, q2, t]; \n\t\tm\  = \ mat\ [q]; \n\t\ta\  = \ 
          m . {1/2, 0, 0}; \n\t\tb\  = \ m . {0, 1/2, 0}; \n\t\tc = 
          m . {0, 0, 
              1/2}; \n\t\tReturn[{\n\t\t\t\tPolygon[{\(-a\) + \(-b\) - c + 
                  pos, a - b - c + pos, 
                a - b + c + pos, \(-a\) - b + c + pos}], 
            Polygon[{a - b - c + pos, a + b - c + pos, a + b + c + pos, 
                a - b + c + pos}], \n\t\t\t\tPolygon[{a + b - c + 
                  pos, \(-a\) + b - c + pos, \(-a\) + b + c + pos, 
                a + b + c + pos}], \n\t\t\t\tPolygon[{\(-a\) - b - c + 
                  pos, \(-a\) - b + c + pos, \(-a\) + b + c + pos, \(-a\) + 
                  b - c + pos}], \n\t\t\t\tPolygon[{\(-a\) - b - c + 
                  pos, \(-a\) + b - c + pos, a + b - c + pos, 
                a - b - c + pos}], \n\t\t\t\tPolygon[{\(-a\) - b + c + pos, 
                a - b + c + pos, 
                a + b + c + pos, \(-a\) + b + c + 
                  pos}]}]]\n\t\t\t\t\)}], "Input"],

Cell["\<\
The following two frames produce the tumbling cube animation.\
\>", \
"Text"],

Cell[BoxData[{
    \(\(Clear[gr];\)\), "\n", 
    \(\(gr = 
        Table[Show[Graphics3D[box3[t]], \ 
            PlotRange -> {{\(-4\), 4}, {\(-1\), 5}, {\(-2\), 4}}, \ 
            AspectRatio -> Automatic, \ DisplayFunction -> Identity], {t, 0, 
            1, 1/30}];\)\)}], "Input"],

Cell[BoxData[
    \(\(GLShow[gr, \ AnimateFrames -> True];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "More complex key framing and interpolations (",
  StyleBox["squad", "Input",
    FontWeight->"Plain"],
  ")"
}], "Subsection"],

Cell[TextData[{
  "Slerping allows us to interpolate between two orientations.  By modifying \
the definition of the arc ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " in the definition of the ",
  Cell[BoxData[
      \(slerp\)]],
  " procedure to include one or more complete  circumnavigations of the great \
arc determined by ",
  Cell[BoxData[
      \(Q\_1\)]],
  " and ",
  Cell[BoxData[
      \(Q\_2\)]],
  "many \"tumbles\" of an object can be interpolated between two given \
orientations.  "
}], "Text"],

Cell[TextData[{
  "But suppose there are three or four or more keyframe positions and \
orientations to be interpolated.  For position, we can create a spline curve \
between the key positions as in the first part of this chapter.  If all we \
have is ",
  Cell[BoxData[
      \(slerp\)]],
  ", we could ",
  StyleBox["piecewise slerp",
    FontWeight->"Bold"],
  " between the orientations in the keyframes.  This would produce the \
rotational analog of the sharp corner change of direction we observed for \
lerping earlier.  It would be more useful to construct some sort of \
\"spherical spline\" which interpolates the orientations.  Constructing \
splines in non-Euclidean spaces (the sphere in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^4\)]],
  ") is a subject of current research in mathematics.  Several recent papers \
discuss techniques for constructing splines in spaces like ",
  StyleBox["SO(3)", "Input",
    FontWeight->"Plain"],
  " and the sphere in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^4\)]],
  " and how to apply these techniques to interpolating rotations.  In his \
original paper (SH85) Shoemake presented an analog of Catmull-Rom splines  \
for interpolating several key quaternions.  In a subsequent paper (SH87) \
Shoemake introduced the procedure ",
  StyleBox["squad ",
    FontWeight->"Bold"],
  " which is a spherical analog of a cubic B\[EAcute]zier curve.  While \
subsequent work has shown this procedure to lack some of the properties of \
cubic splines in Euclidean space, the curves created are continuous and the \
derivatives are continuous at the points where the pieces come together.  We \
present a bare-bones discussion of this technique here.  Readers interested \
in more sophisticated techniques should consult some of the references below \
[(BA), (KKS), (RB) ].  A development of",
  Cell[BoxData[
      \(\(\(\ \)\(squad\)\(\ \)\)\)]],
  "can be found in Watt and Watt (WW).  "
}], "Text"],

Cell[CellGroupData[{

Cell["Some more Quaternion Functions", "Subsubsection"],

Cell["We define the logarithm function for unit quaternions. ", "Text"],

Cell[TextData[{
  StyleBox["Definition:",
    FontWeight->"Bold"],
  "  Suppose ",
  Cell[BoxData[
      \(Q\)]],
  " is a unit quaternion, ",
  Cell[BoxData[
      \(Q\)]],
  " in",
  Cell[BoxData[
      RowBox[{" ", 
        FormBox[
          StyleBox[\(\[DoubleStruckCapitalH]\_1\),
            FontSize->14],
          "TraditionalForm"]}]]],
  ".  Then ",
  Cell[BoxData[
      RowBox[{"Q", " ", "=", " ", 
        StyleBox[
          RowBox[{"(", 
            RowBox[{\(cos\ \[Theta]\), ",", " ", 
              RowBox[{"sin", " ", "\[Theta]", " ", 
                OverscriptBox[
                  StyleBox["v",
                    FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}],
          FontFamily->"Courier",
          FontSize->14]}]]],
  ",  where",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{"|", 
            OverscriptBox[
              StyleBox["v",
                FontWeight->"Bold"], "\[RightVector]"], "|"}], " ", "=", " ", 
          "1"}]}]]],
  ".  Define\n\t",
  Cell[BoxData[
      RowBox[{\(log \((Q)\)\), " ", "=", " ", 
        RowBox[{"(", 
          StyleBox[
            RowBox[{"0", ",", " ", 
              RowBox[{"\[Theta]", 
                OverscriptBox[
                  StyleBox["v",
                    FontWeight->"Bold"], "\[RightVector]"]}]}],
            FontFamily->"Courier",
            FontSize->14], ")"}]}]]]
}], "ContentsText"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code for the quaternion",
  StyleBox[" ", "Output"],
  StyleBox["log", "Input",
    FontWeight->"Plain"],
  StyleBox[" ", "Output"],
  "function."
}], "1ColumnBox",
  CellMargins->{{37.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(qlog[q_]\  := \ 
      Module[{th}, \n\t\tth\  = \ 
          ArcCos[q\[LeftDoubleBracket]1\[RightDoubleBracket]]; \n\t\tIf\ [
          th\  == 0\ , \ Return[{0, {0, 0, 0}}]]; \n\t\tv\  = \ 
          q\[LeftDoubleBracket]2\[RightDoubleBracket]/
            Sin[th]; \n\t\tReturn[{0, th*v}]]\)], "Input"],

Cell["\<\
We define the exponential function for pure quaternions (scalar \
part = 0)\
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition:",
    FontWeight->"Bold"],
  "  Suppose ",
  Cell[BoxData[
      \(Q\)]],
  " is a pure quaternion,  (ie the ",
  Cell[BoxData[
      \(a\)]],
  " part is ",
  Cell[BoxData[
      RowBox[{"0", ",", " ", 
        RowBox[{"Q", " ", "=", " ", 
          RowBox[{"(", 
            StyleBox[
              RowBox[{"0", ",", " ", 
                RowBox[{"\[Theta]", 
                  OverscriptBox[
                    StyleBox["v",
                      FontWeight->"Bold"], "\[RightVector]"]}]}],
              FontFamily->"Courier",
              FontSize->14], ")"}]}]}]]],
  ").  Define\n\t",
  Cell[BoxData[
      RowBox[{\(exp \((Q)\)\), " ", "=", " ", 
        StyleBox[
          RowBox[{"(", 
            RowBox[{\(cos\ \[Theta]\), ",", " ", 
              RowBox[{"sin", " ", "\[Theta]", " ", 
                OverscriptBox[
                  StyleBox["v",
                    FontWeight->"Bold"], "\[RightVector]"]}]}], ")"}],
          FontFamily->"Courier"]}]]],
  "."
}], "ContentsText"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code for the quaternion ",
  StyleBox["exp", "Input",
    FontWeight->"Plain"],
  " function."
}], "1ColumnBox",
  CellMargins->{{37.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(qexp[q_]\  := \ 
      Module[{th, v}, \n\t\tIf[
          q\[LeftDoubleBracket]1\[RightDoubleBracket] != 0.0, \ 
          Return["\<Error: not a pure quaternion\>"]]; \n\t\tv\  = \ 
          q\[LeftDoubleBracket]2\[RightDoubleBracket]; \n\t\tth\  = \ 
          Sqrt[v . v]; \n\t\tIf[th == 0.0, \ 
          Return[{1, {0, 0, 0}}]]; \n\t\tReturn[{Cos[th], \ 
            Sin[th] v/th}]]\)], "Input"],

Cell[TextData[{
  "Although not immediately obvious, we state (without proof) the following \
relationship between ",
  Cell[BoxData[
      \(\(\(slerp\) \((q1, q2, u)\)\(\ \)\)\)]],
  "and the ",
  StyleBox["log", "Input",
    FontWeight->"Plain"],
  " and ",
  StyleBox["exp", "Input",
    FontWeight->"Plain"],
  " functions."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem:",
    FontWeight->"Bold"],
  "  Suppose ",
  Cell[BoxData[
      \(Q\_1\)]],
  " and ",
  Cell[BoxData[
      \(Q\_2\)]],
  "  are unit quaternions,  ",
  Cell[BoxData[
      \(Q\_1\)]],
  " and ",
  Cell[BoxData[
      \(Q\_2\)]],
  "  in ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalH]\_1\)]],
  ".  Then\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"slerp", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{" ", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["Q",
                        FontSize->16], "1"],
                    "Output"], ",", 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["Q",
                        FontSize->16], 
                      StyleBox["2",
                        FontSize->12]],
                    "Output"]}]}], ",", "u"}], ")"}]}], " ", "=", " ", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["Q",
                FontSize->16], "1"],
            "Output"], " ", "exp", 
          RowBox[{"(", " ", 
            RowBox[{"u", " ", "log", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[
                      SubscriptBox[
                        StyleBox["Q",
                          FontSize->16], "1"],
                      "Output"], \(-1\)], 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["Q",
                        FontSize->16], "2"],
                    "Output"]}], ")"}]}], ")"}]}]}]]]
}], "ContentsText"],

Cell["\<\
This more or less says that the quaternion analog of linear \
combinations involves combinations using the multiplication operator.\
\>", \
"Text"],

Cell["\<\
As explained in an early paper by W. Boehm (B\[ODoubleDot]hm), \
(BO), by computing two new control points it is possible to write a cubic B\
\[EAcute]zier function as a lerp of two lerps rather than the usual \
deCasteljau algorithm which involves a lerp of two lerps each of which is a \
lerp of two lerps.  You can easily check that the cubic B\[EAcute]zier \
curve\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox["c",
              FontWeight->"Bold"], "\[RightVector]"], \((t)\)}], " ", "=", 
        " ", 
        RowBox[{\(\[Sum]\+\(i = 0\)\%3\), 
          RowBox[{
            SubscriptBox[
              OverscriptBox[
                StyleBox["a",
                  FontWeight->"Bold"], "\[RightVector]"], "i"], 
            " ", \(B\_i\%3\), \((t)\)}]}]}]]],
  "where ",
  Cell[BoxData[
      RowBox[{\(\(B\_i\%3\) \((t)\)\), " ", "=", " ", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {"3"},
              {"i"}
              }], "\[NegativeThinSpace]", ")"}]}]]],
  Cell[BoxData[
      \(\((1 - t)\)\^\(3 - i\)\ t\^i\)]]
}], "Text"],

Cell["can also be expressed as ", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox["c",
              FontWeight->"Bold"], "\[RightVector]"], \((t)\)}], " ", "=", 
        " ", 
        RowBox[{
          RowBox[{
            OverscriptBox[
              StyleBox["A",
                FontWeight->"Bold"], "\[RightVector]"], " ", \((1 - v)\)}], 
          " ", "+", " ", 
          RowBox[{
            OverscriptBox[
              StyleBox["B",
                FontWeight->"Bold"], "\[RightVector]"], "v"}]}]}]]],
  " where ",
  Cell[BoxData[
      \(\(\(v\  = \ 2  t \((1 - t)\)\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            OverscriptBox[
              StyleBox["A",
                FontWeight->"Bold"], "\[RightVector]"], "  ", "=", " ", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["a",
                      FontWeight->"Bold"], "\[RightVector]"], 
                  "0"], \((1 - t)\)}], " ", "+", " ", 
              RowBox[{
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["a",
                      FontWeight->"Bold"], "\[RightVector]"], "3"], "t"}]}]}],
           ",", " ", 
          RowBox[{
            OverscriptBox[
              StyleBox["B",
                FontWeight->"Bold"], "\[RightVector]"], " ", "=", " ", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["S",
                      FontWeight->"Bold"], "\[RightVector]"], 
                  "1"], \((1 - t)\)}], " ", "+", " ", 
              RowBox[{
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["S",
                      FontWeight->"Bold"], "\[RightVector]"], "2"], 
                "t"}]}]}]}]}]]],
  ", and "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          SubscriptBox[
            OverscriptBox[
              StyleBox["S",
                FontWeight->"Bold"], "\[RightVector]"], "1"], "  ", "=", " ", 
          
          FractionBox[
            RowBox[{
              RowBox[{"3", 
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["a",
                      FontSize->10,
                      FontWeight->"Bold"], "\[RightVector]"], "1"]}], " ", 
              "-", " ", 
              SubscriptBox[
                OverscriptBox[
                  StyleBox["a",
                    FontSize->10,
                    FontWeight->"Bold"], "\[RightVector]"], "3"]}], "2"], 
          " "}]}]]],
  " and ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          SubscriptBox[
            OverscriptBox[
              StyleBox["S",
                FontWeight->"Bold"], "\[RightVector]"], "2"], "  ", "=", " ", 
          
          FractionBox[
            RowBox[{
              RowBox[{"3", 
                SubscriptBox[
                  OverscriptBox[
                    StyleBox["a",
                      FontSize->10,
                      FontWeight->"Bold"], "\[RightVector]"], "2"]}], " ", 
              "-", " ", 
              SubscriptBox[
                OverscriptBox[
                  StyleBox["a",
                    FontSize->10,
                    FontWeight->"Bold"], "\[RightVector]"], "0"]}], "2"], 
          " "}]}]]]
}], "Text"],

Cell["\<\
Incorporating the above representation for cubic B\[EAcute]zier \
curves along with computations that will match up the derivatives at the \
keyframe values, produces the following definition\
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition (Shoemake):",
    FontWeight->"Bold"],
  "  Suppose ",
  Cell[BoxData[
      \({Q\_i}\_\(i = 1\)\%n\)]],
  "  are unit quaternions, ",
  Cell[BoxData[
      \({Q\_i}\_\(i = 1\)\%n\)]],
  " \[Subset] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalH]\_1\)]],
  ".  Define\n\t",
  StyleBox[Cell[BoxData[
      RowBox[{
        StyleBox[\(S\_i\),
          FontFamily->"Courier"], 
        StyleBox[" ",
          FontFamily->"Courier"], "=", " ", 
        RowBox[{
          StyleBox[\(Q\_i\),
            FontFamily->"Courier"], 
          StyleBox["exp",
            FontFamily->"Courier"], 
          RowBox[{"(", 
            FractionBox[
              
              StyleBox[\(log \((\(Q\_i\%\(-1\)\) Q\_\(i + 1\))\)\  + \ 
                  log \((\(Q\_i\%\(-1\)\) Q\_\(i - 1\))\)\),
                FontFamily->"Courier"], 
              StyleBox["4",
                FontFamily->"Courier"]], ")"}]}]}]], "Output"], "Output"],
  ",",
  StyleBox[" ", "Output"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["i",
              FontSlant->"Plain"], " ", "=", " ", "1"}], ",", "2"}], 
        TraditionalForm]]],
  ".\nand use these values to define\n\t",
  Cell[BoxData[
      \(squad \((Q\_i, \ 
            Q\_\(i + 1\), \ \(\(\ \)\(S\_i\)\), \(\(\ \)\(S\_\(i + 1\)\)\), \ 
            u)\)\  = \ \ \t\ \ \ slerp \((slerp \((Q\_i, \ Q\_\(i + 1\), 
                u)\), \ slerp \((\(\(\ \)\(S\_i\)\), \(\(\ \)\(S\_\(i + 
                      1\)\)\), \ u)\), \ 2  u \((1 - u)\))\)\)]]
}], "ContentsText"],

Cell[TextData[{
  "You may notice that ",
  Cell[BoxData[
      \(S\_1\)]],
  Cell[BoxData[
      StyleBox[Cell[""],
        "Output"]]],
  " and ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["S",
          FontFamily->"Courier",
          FontSize->16], "n"]]],
  " are not defined in the above sequence.   If we have no other alternative, \
 we will set",
  StyleBox[" ", "Output"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox["S",
              FontSize->16], "1"],
          "Output"], "  ", "=", " ", 
        SubscriptBox[
          StyleBox["Q",
            FontFamily->"Courier"], "1"]}]]],
  " and",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["S",
                FontSize->16], 
              StyleBox["n",
                "Output"]],
            "Output"], "  ", "=", " ", 
          SubscriptBox[
            StyleBox["Q",
              FontFamily->"Courier"], "n"]}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code for the quaternion ",
  StyleBox["squad", "Input",
    FontWeight->"Plain"],
  " function."
}], "1ColumnBox",
  CellMargins->{{20.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(squad[b1_, b2_, s1_, s2_, t_]\  := \ 
      slerp[slerp[b1, b2, t], \ slerp[s1, s2, t], \ 
        2*t*\((1 - t)\)]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "An ",
  StyleBox["squad", "Input",
    FontWeight->"Plain"],
  " Example"
}], "Subsubsection"],

Cell[TextData[{
  "The following animation of rotating a block letter \"F\" whose initial \
position is ",
  Cell[BoxData[
      \(\((0, 0, 4)\)\)]],
  "  around a sphere is suggested by a similar illustrations using a block \
\"R\" in Watt and Watt (Fig ",
  Cell[BoxData[
      \(15.25\)]],
  ", p ",
  Cell[BoxData[
      \(267\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "This is the code to draw the F.  It lives at ",
  Cell[BoxData[
      FormBox[
        StyleBox[\((0, 0, 4)\),
          FontSize->12], TraditionalForm]]],
  ", the top of the sphere with radius ",
  Cell[BoxData[
      FormBox[
        StyleBox["4",
          FontSize->12], TraditionalForm]]],
  "."
}], "1ColumnBox"],

Cell[BoxData[{
    \(\(Clear[box4];\)\), "\n", 
    \(box4[orig_, \ l_, w_, h_]\  := \ 
      Module[{a, b, c, 
          pos}, \n\ \ \ \ a\  = {l/2, 0, 0}; \n\t\tb\  = {0, w/2, 
            0}; \n\t\tc = {0, 0, h/2}; \n\t\tpos\  = \ 
          orig\  + {l/2, w/2, 
              h/2}; \n\t\tReturn[{Polygon[{\(-a\) + \(-b\) - c + pos, 
                a - b - c + pos, a - b + c + pos, \(-a\) - b + c + pos}], 
            Polygon[{a - b - c + pos, a + b - c + pos, a + b + c + pos, 
                a - b + c + pos}], 
            Polygon[{a + b - c + pos, \(-a\) + b - c + pos, \(-a\) + b + c + 
                  pos, a + b + c + pos}], 
            Polygon[{\(-a\) - b - c + pos, \(-a\) - b + c + pos, \(-a\) + b + 
                  c + pos, \(-a\) + b - c + 
                  pos}], \n\t\t\t\tPolygon[{\(-a\) - b - c + pos, \(-a\) + 
                  b - c + pos, a + b - c + pos, 
                a - b - c + pos}], \n\t\t\t\tPolygon[{\(-a\) - b + c + pos, 
                a - b + c + pos, 
                a + b + c + pos, \(-a\) + b + c + pos}]}]]\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[ef];\)\), "\n", 
    \(ef\  = \ 
      Show[Graphics3D[{box4[{0, 0, 4}, \ 0.5, 0.5, 2], \ 
            box4[{0.5, 0, \ 4.75}, 0.5, 0.5, 0.5], \ 
            box4[{0.5, 0, 5.5}, \ 0.75, 0.5, 0.5]}]]\)}], "Input"],

Cell["\<\
We use four key frames with a repeating loop structure so that the \
key frames are \
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(Q\_0\ \ \ Q\_1\ \ \ Q\_2\ \ \ Q\_3\ \ \ Q\_4\ \ \ Q\_5\)]]
}], "Text"],

Cell[TextData[{
  "where",
  StyleBox[" ", "Output"],
  StyleBox[Cell[BoxData[
      StyleBox[\(Q\_0\),
        FontFamily->"Courier"]], "Output"], "Output"],
  StyleBox[" = ", "Output"],
  StyleBox[Cell[BoxData[
      StyleBox[\(Q\_4\),
        FontFamily->"Courier"]], "Output"], "Output"],
  StyleBox[" ", "Output"],
  "and ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox["Q", 
          StyleBox["5",
            FontFamily->"Courier"]],
        FontFamily->"Courier"]]],
  " = ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox["Q", 
          StyleBox["1",
            FontFamily->"Courier"]],
        FontFamily->"Courier"]]],
  ", allowing us to compute ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[\(S\_1\),
          FontFamily->"Courier"]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{"  ", 
        SubscriptBox[
          StyleBox["S",
            FontFamily->"Courier"], "2"]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{" ", 
        SubscriptBox[
          StyleBox["S",
            FontFamily->"Courier"], "3"]}]]],
  ", and ",
  Cell[BoxData[
      RowBox[{"  ", 
        SubscriptBox[
          StyleBox["S",
            FontFamily->"Courier"], "4"]}]]],
  ".  For ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["1",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  " and ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["2",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  " we choose the two quaternions we defined above, "
}], "Text"],

Cell[TextData[{
  "     ",
  Cell[BoxData[
      \(Q\_1\  = \ \((1, \((0, 0, 0)\))\)\)]],
  " and ",
  Cell[BoxData[
      \(Q\_2\  = \ \((0.5, \ \((0.5, \ 0.5, \ 0.5)\))\)\)]]
}], "Text"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["3",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  " and ",
  Cell[BoxData[
      StyleBox[
        SubscriptBox["Q", 
          StyleBox["4",
            FontFamily->"Courier"]],
        FontFamily->"Courier"]]],
  ", we make the following choice of  axes and angles:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["3",
              FontFamily->"Courier",
              FontWeight->"Bold"]],
          FontFamily->"Courier",
          FontWeight->"Bold"], ":"}], TextForm]], "Text"],

Cell[TextData[{
  "Choose the axis of rotation to be ",
  Cell[BoxData[
      \(\((\(-1\), \ 1, \ 0)\)\)]],
  " and the angle ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " to be ",
  Cell[BoxData[
      \(\(2  \[Pi]\)\/3\)]],
  ". ",
  Cell[BoxData[
      FormBox[
        StyleBox[Cell[TextData[Cell[BoxData[
              StyleBox[Cell[""],
                "Output",
                FontFamily->"Courier"]]]]],
          "Output",
          FontFamily->"Courier"], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
    RowBox[{"      ", 
      StyleBox[Cell[TextData[Cell[BoxData[
            StyleBox[Cell[TextData[Cell[BoxData[
                  StyleBox[
                    RowBox[{Cell[TextData[Cell[BoxData[
                          \(Q\_3\)]]]], " ", "=", Cell[TextData[Cell[BoxData[
                          \(\(\(\ \)\((cos  \[Pi]\/3, \ 
                            sin\ \(\[Pi]\/3\) \((\(-1\), 1, 
                                  0)\)/\@2)\)\)\)]]]]}],
                    "Text"]]]]],
              "Text"]]]]],
        "Output"]}]], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["4",
              FontFamily->"Courier",
              FontWeight->"Bold"]],
          FontFamily->"Courier",
          FontWeight->"Bold"], ":"}], TextForm]], "Text"],

Cell[TextData[{
  "Choose the axis of rotation to be ",
  Cell[BoxData[
      \(\((\(-0.8\), \ \(-1.0\), \ 0)\)\)]],
  " and the angle ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " to be ",
  Cell[BoxData[
      \(\(5  \[Pi]\)\/9\)]],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["      ",
        "Output"], 
      StyleBox[
        RowBox[{Cell[TextData[Cell[BoxData[
              \(Q\_4\)]]]], " ", Cell[TextData[Cell[BoxData[
              \(\(\(=\)\(\ \)\((cos \( 5  \[Pi]\)\/18, \ 
                  sin\ \(\(5  \[Pi]\)\/8\) 
                    5 \((\(-0.8\), \(-1\), 0)\)/\@41)\)\)\)]]]]}],
        "Text"]}]], "Text"],

Cell["\<\
This code will create a picture of the sphere and the key frame \
positions of the block letter F, along with a 3D Explorer version that you \
can manipulate to get the complete picture.\
\>", "1ColumnBox"],

Cell[BoxData[{
    \(Clear[Q1, Q2, Q3, Q4]\), "\n", 
    \(\(Q1\  = \ {1, {0, 0, 0}};\)\), "\n", 
    \(\(Q2\  = \ {0.5, {0.5, 0.5, 0.5}};\)\), "\n", 
    \(\(Q3\  = \ {Cos[Pi/3], \ 
          Sin[Pi/3] {\(-1.0\), 1.0, 0}/Sqrt[2]};\)\), "\n", 
    \(\(Q4\  = \ {Cos[5  Pi/18], \ 
          Sin[5  Pi/18] 5 {\(-0.8\), \(-1.0\), 0}/Sqrt[41. ]};\)\)}], "Input"],

Cell[BoxData[
    \(\(sp\  = \ 
        ParametricPlot3D[
          4 {Cos[u] Cos[v], \ Sin[u] Cos[v], Sin[v]}, {u, 0, 
            2  Pi}, {v, \(-Pi\)/2, Pi/2}, \ 
          DisplayFunction -> Identity];\)\)], "Input"],

Cell[TextData[{
  "This code for ",
  Cell[BoxData[
      \(ApplyMatrix\)]],
  " is from (TWJ), pp ",
  Cell[BoxData[
      \(419 - 420\)]],
  ".  If ",
  Cell[BoxData[
      \(m\)]],
  " is a ",
  Cell[BoxData[
      \(3\ x\ 3\)]],
  " matrix, then the result of ",
  Cell[BoxData[
      \(ApplyMatrix[m]\)]],
  " is a pattern matching rule that replaces individual points ",
  Cell[BoxData[
      \(\((x, y, z)\)\)]],
  " with",
  Cell[BoxData[
      \(\(\(\ \)\(m . \((x, y, z)\)\)\)\)]],
  "."
}], "1ColumnBox"],

Cell[BoxData[
    \(ApplyMatrix\  = \ \(({x_?NumberQ, \ y_?NumberQ, \ 
              z_?NumberQ} :> \ # . {x, y, z})\) &\)], "Input"],

Cell[BoxData[
    \(Show[{Graphics3D[EdgeForm[]], sp, \ ef /. ApplyMatrix[mat[Q1]], \ 
        ef /. ApplyMatrix[mat[Q2]], \ ef /. ApplyMatrix[mat[Q3]], \ 
        ef /. ApplyMatrix[mat[Q4]]}, 
      DisplayFunction -> $DisplayFunction]\)], "Input"],

Cell[BoxData[
    \(\(GLShow[%, \ LockLights -> True, \ ShadeModel -> Smooth];\)\)], "Input"],

Cell[TextData[{
  "There are ",
  StyleBox["4", "Output",
    FontSize->16],
  " squad segments to be created:  from ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["1",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  "to ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["2",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  ", from ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["2",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  "to ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["3",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  ", from ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["3",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  "to ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["4",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  " and from ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["4",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  "to ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["Q", 
            StyleBox["1",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  ", so we will need quaternions ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[\(S\_1\),
          FontFamily->"Courier"]}]]],
  "and ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["S", 
            StyleBox["2",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["S", 
            StyleBox["2",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  "and ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["S", 
            StyleBox["3",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  ", ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["S", 
            StyleBox["3",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  "and ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          SubscriptBox["S", 
            StyleBox["4",
              FontFamily->"Courier"]],
          FontFamily->"Courier"]}]]],
  ", and ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[\(S\_4\),
          FontFamily->"Courier"], 
        StyleBox[" ",
          FontFamily->"Courier"]}]]],
  "and ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[\(S\_1\),
          FontFamily->"Courier"]}]]],
  "."
}], "Text"],

Cell[BoxData[
    \(\(S1\  = \ 
        mult[Q1, 
          qexp[\(-\((qlog[mult[inv[Q1], Q2]] + qlog[mult[inv[Q1], Q4]])\)\)/
              4.0]];\)\)], "Input"],

Cell[BoxData[
    \(\(S2\  = \ 
        mult[Q2, 
          qexp[\(-\((qlog[mult[inv[Q2], Q3]] + qlog[mult[inv[Q2], Q1]])\)\)/
              4.0]];\)\)], "Input"],

Cell[BoxData[
    \(\(S3\  = \ 
        mult[Q3, 
          qexp[\(-\((qlog[mult[inv[Q3], Q4]] + qlog[mult[inv[Q3], Q2]])\)\)/
              4.0]];\)\)], "Input"],

Cell[BoxData[
    \(\(S4\  = \ 
        mult[Q4, 
          qexp[\(-\((qlog[mult[inv[Q4], Q1]] + qlog[mult[inv[Q4], Q3]])\)\)/
              4.0]];\)\)], "Input"],

Cell["The following four functions are the B\[EAcute]zier segments:", "Text"],

Cell[BoxData[
    \(Clear[f1, f2, f3, f4]\)], "Input"],

Cell[BoxData[{
    \(\(f1[t_]\  := \ squad[Q1, Q2, S1, S2, t];\)\), "\n", 
    \(\(f2[t_]\  := \ squad[Q2, Q3, S2, S3, t];\)\), "\n", 
    \(\(f3[t_]\  := \ squad[Q3, Q4, S3, S4, t];\)\), "\n", 
    \(\(f4[t_]\  := \ squad[Q4, Q1, S4, S1, t];\)\)}], "Input"],

Cell[TextData[{
  "and the following code constructs the animation.  If your computer doesn't \
have enough memory for ",
  Cell[BoxData[
      \(96\)]],
  " frames, or you don't have the patience to wait for 3D Explorer to set up \
the animation for ",
  Cell[BoxData[
      \(96\)]],
  " frames (it takes ",
  StyleBox["several minutes",
    FontSize->16],
  "), you can cut down on the number of frames in the obvious way."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[Gr];\)\), "\n", 
    \(\(Gr\  = \ 
        Join[\n\t\tTable[
            Show[{Graphics3D[EdgeForm[]], sp, \ ef /. ApplyMatrix[mat[Q1]], \ 
                ef /. ApplyMatrix[mat[Q2]], \ ef /. ApplyMatrix[mat[Q3]], \ 
                ef /. ApplyMatrix[mat[Q4]], \ ef /. ApplyMatrix[mat[f1[t]]]}, 
              DisplayFunction -> Identity, \ Boxed -> False], {t, 0, 1, 
              1/24}], \t\n\t\tTable[
            Show[{Graphics3D[EdgeForm[]], sp, \ ef /. ApplyMatrix[mat[Q1]], \ 
                ef /. ApplyMatrix[mat[Q2]], \ ef /. ApplyMatrix[mat[Q3]], \ 
                ef /. ApplyMatrix[mat[Q4]], \ ef /. ApplyMatrix[mat[f2[t]]]}, 
              DisplayFunction -> Identity, \ Boxed -> False], {t, 0, 1, 
              1/24}], \t\n\t\tTable[
            Show[{Graphics3D[EdgeForm[]], sp, \ ef /. ApplyMatrix[mat[Q1]], \ 
                ef /. ApplyMatrix[mat[Q2]], \ ef /. ApplyMatrix[mat[Q3]], \ 
                ef /. ApplyMatrix[mat[Q4]], \ ef /. ApplyMatrix[mat[f3[t]]]}, 
              DisplayFunction -> Identity, \ Boxed -> False], {t, 0, 1, 
              1/24}], \t\n\t\tTable[
            Show[{Graphics3D[EdgeForm[]], sp, \ ef /. ApplyMatrix[mat[Q1]], \ 
                ef /. ApplyMatrix[mat[Q2]], \ ef /. ApplyMatrix[mat[Q3]], \ 
                ef /. ApplyMatrix[mat[Q4]], \ ef /. ApplyMatrix[mat[f4[t]]]}, 
              DisplayFunction -> Identity, \ Boxed -> False], {t, 0, 1, 
              1/24}]];\)\)}], "Input"],

Cell[BoxData[
    \(\(GLShow[Gr, \ AnimateFrames -> True, \ LockLights -> True, \ 
        ShadeModel -> Smooth];\)\)], "Input"],

Cell[TextData[{
  "Be sure to rotate the 3D Explorer window to check out that the transition \
at each of the key frames is smooth.  You should also be able to trace the \
path traveled by the \"F\" by plotting what happens to the point ",
  Cell[BoxData[
      \(\((0, 0, 4)\)\)]],
  " under the ",
  Cell[BoxData[
      \(4\)]],
  " transformations."
}], "Text"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Referencetitle"],

Cell[TextData[{
  "(BA) Barr, A.H., Currin, B., Gabriel, S., Hughes, J.F.,",
  StyleBox[" ",
    FontSlant->"Italic"],
  "Smooth Interpolation of Orientations with Angular Velocity Constraints \
using Quaternions, ",
  StyleBox["SIGGRAPH Conference Proceedings",
    FontSlant->"Italic"],
  ", 1992, pp 313-320"
}], "ReferenceEntry"],

Cell[TextData[{
  "(Bo) B\[ODoubleDot]hm, W., On Cubics: A Survey, ",
  StyleBox["Computer Graphics and Image Processing, 19,",
    FontSlant->"Italic"],
  " 1982, pp 201-206"
}], "ReferenceEntry"],

Cell[TextData[{
  "(dB) de Boor Carl,",
  StyleBox[" A Practical Guide to Splines",
    FontSlant->"Italic"],
  ", Springer-Verlag, 1978"
}], "ReferenceEntry"],

Cell[TextData[{
  "(KKS) Kim, Myoung-Jun, Kim, Myung-Soo, Shin, Sung Yong,",
  StyleBox[" A General Construction Scheme for Unit Quaternion Curves with \
Simple High Order Derivatives",
    FontSlant->"Italic"],
  ", SIGGRAPH Conference Proceedings, 1995, pp 369-376"
}], "ReferenceEntry"],

Cell[TextData[{
  "(LA) Lasseter, John, Principles of Traditional Animation Applied to 3D \
Computer Animation, ",
  StyleBox["SIGGRAPH Conference Proceedings",
    FontSlant->"Italic"],
  ", 1987"
}], "ReferenceEntry"],

Cell[TextData[{
  "(MH) M\[ODoubleDot]ller, Tomas, Hughes, J.F., Efficiently Building a \
Matrix to Rotate One Vector to Another, ",
  StyleBox["Journal of Graphics Tools",
    FontSlant->"Italic"],
  ", 4(4), pp 1-4, 1999"
}], "ReferenceEntry"],

Cell[TextData[{
  "(RAL) Ralston, A, Rabinowitz, P., ",
  StyleBox["A First Course in Numerical Analysis",
    FontSlant->"Italic"],
  ", McGraw-Hill, 1978"
}], "ReferenceEntry"],

Cell[TextData[{
  "(RB) Ramamoorthi, Ravi, Barr, A.H., Fast Construction of Accurate \
Quaternion Splines,  ",
  StyleBox["SIGGRAPH Conference Proceedings",
    FontSlant->"Italic"],
  ", 1997, pp 287-292 "
}], "ReferenceEntry"],

Cell[TextData[{
  "(SH85) Shoemake,K., Animating Rotation with Quaternion Curves, ",
  StyleBox["SIGGRAPH Conference Proceedings",
    FontSlant->"Italic"],
  ", 1985, pp 245-254"
}], "ReferenceEntry"],

Cell[TextData[{
  "(SH87) Shoemake,K., Quaternion Calculus and Fast Animation,",
  StyleBox[" SIGGRAPH Course Notes #10",
    FontSlant->"Italic"],
  ", 1987"
}], "ReferenceEntry"],

Cell[TextData[{
  "(TJ) Thomas, F., Johnston, O., ",
  StyleBox["The Illusion of Life:  Disney Animation",
    FontSlant->"Italic"],
  ", (Revised Edition)  Hyperion, 1995"
}], "ReferenceEntry"],

Cell[TextData[{
  "(WW) Watt, Alan, Watt, Mark, ",
  StyleBox["Advanced Animation and Rendering Techniques, Theory and Practice",
    
    FontSlant->"Italic"],
  ", Addison-Wesley and ACM Press, 1992"
}], "ReferenceEntry"],

Cell[TextData[{
  "(TWJ)\tTom Wickham-Jones,  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Graphics",
    FontSlant->"Italic"],
  ", TELOS, Springer-Verlag, 1994"
}], "ReferenceEntry"],

Cell["\[Copyright] 2000 Louis J. Nachman, All Rights Reserved", "Text"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{750, 727},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
ShowCellTags->True,
SpellingOptions->{"AlwaysStop"->{}},
SpellingDictionaries->{"CorrectWords"->{
  "Nachman", "betweening", "Lasseter", "homepage", "com", "Disney", 
    "Pinocchio", "storyboarding", "pixar", "funstuff", "perp", "orig", "dir", 
    "lerping", "th ", "bspline", "B\[EAcute]zier", "Bspline", "interv", 
    "bval", "bcoef", "jderiv", "ilo", "imk", "jc", "jcmin", "jcmax", "jj", 
    "kmj", "nmi", "aj", "fkmj", "bvalue", "Interpolant", "ans", "ctrl", "du", 
    "bsplines", "arclength", "alf", "lerp", "pos", "Arclength", 
    "Parameterizations", "Xax", "Yax", "nx", "inbetween", "dv", "splatted", 
    "prototyping", "mult", "quat", "Slerping", "Shoemake", "slerping", 
    "slerp", "th", "costh", "ang", "qlog", "qexp", "Boehm", 
    "B\[ODoubleDot]hm", "lerps", "Casteljau", "lerps.", "ef", "sp", "pp", 
    "inv"}},
SingleLetterItalics->False,
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
The following notebook is copyright 1999-2000 by Math \
Everywhere,Inc.and may not be reproduced, copied, or distributed, in whole or \
in part, through any means electronic or otherwise, without written consent \
of the copyright holder.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScriptMinSize->12,
    FontSize->18],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[RawData["Cell[\"Notebook Options\", \"Section\"]"], "Section"],
  
  Cell[RawData["\<\
Cell[\"\\<\\
The options defined for the style below will be used \\
at the Notebook level.\\
\\>\", \"Text\"]\
\>"], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    CellGrouping->Automatic,
    ShowClosedCellArea->False,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.940002, 0.900008]],
  
  Cell[RawData["\<\
Cell[StyleData[\"Notebook\", \"Printout\"],
  Background->GrayLevel[1]]\
\>"],
    Background->GrayLevel[1]],
  
  Cell[RawData["\<\
Cell[StyleData[\"Notebook\", \"Presentation\"],
  Background->GrayLevel[1]]\
\>"],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{1, 1}, {1, 5}},
    ShowCellBracket->True,
    CellMargins->{{24, 24}, {12, 5}},
    CellGroupingRules->{"TitleGrouping", 105},
    PageBreakBelow->False,
    CellFrameMargins->{{15, Inherited}, {Inherited, Inherited}},
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Left,
    LineSpacing->{1.1, 1},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}, {"Sub3title", 0}, {
        "Sub4title", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.925002, 0.869993, 0.790005]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, Inherited}, {60, Inherited}},
    TextAlignment->Center,
    FontSize->24,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.294118, 0.521569, 0.0941176]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, Inherited}, {0, 0}},
    TextAlignment->Center,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellFrame->{{0, 0}, {2, 0}},
    ShowCellBracket->False,
    ShowClosedCellArea->False,
    CellMargins->{{6, Inherited}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Left,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}, {"Sub3title", 0}, {"Sub4title", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellFrame->False,
    CellMargins->{{24, Inherited}, {6, Inherited}}],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{14, Inherited}, {2, 2}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[GraySquare]",
    ShowCellBracket->True,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{22, Inherited}, {Inherited, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    LineSpacing->{1.5, 1},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{24, Inherited}, {Inherited, 20}},
    LineSpacing->{1.5, 0},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{14, Inherited}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"",
    ShowCellBracket->True,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{19, Inherited}, {Inherited, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    LineSpacing->{1.5, 1},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.392187, 0]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{24, Inherited}, {Inherited, 15}}],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{14, Inherited}, {2, 5}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[EmptySquare]",
    ShowClosedCellArea->True,
    CellMargins->{{18, Inherited}, {Inherited, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    LineSpacing->{1.5, 1},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.689998, 0.0899977, 0.119997]],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{24, Inherited}, {Inherited, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{14, Inherited}, {2, 3}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    ShowClosedCellArea->True,
    CellMargins->{{15, 10}, {Inherited, Inherited}},
    DefaultFormatType->DefaultTextFormatType,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    LineSpacing->{1.5, 1},
    LimitsPositioningTokens->{},
    FontFamily->"Times",
    FontSize->16,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    LineSpacing->{2, 0},
    FontSize->16,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{14, Inherited}, {3, 1}},
    PageBreakWithin->True,
    GroupPageBreakWithin->True,
    LineSpacing->{1, 2},
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.300008]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.600015],
    FontSize->16,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.800015],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{45, Inherited}, {20, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{30, Inherited}, {2, 2}},
    PageBreakWithin->True,
    GroupPageBreakWithin->True,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1.5, 0},
    FormatType->StandardForm,
    FontFamily->"Courier",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{45, Inherited}, {20, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{30, Inherited}, {2, 2}},
    PageBreakWithin->True,
    GroupPageBreakWithin->True,
    LineSpacing->{1, 0},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{30, Inherited}, {2, 2}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{30, Inherited}, {2, 2}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{45, Inherited}, {0, 8}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->False,
    CellAutoOverwrite->False,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.700008, 0.500008, 0.500008],
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Note", "Presentation"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{15, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    AnimationDisplayTime->0.2,
    StyleMenuListing->None,
    FontSize->14],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{30, Inherited}, {0, 0}},
    CellFrameMargins->False,
    ImageSize->{Inherited, 150},
    ImageMargins->{{45, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Special Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrefaceTitle"],
    CellFrame->{{1, 1}, {1, 5}},
    ShowCellBracket->False,
    CellMargins->{{24, 24}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 110},
    PageBreakBelow->False,
    CellFrameMargins->{{15, Inherited}, {Inherited, Inherited}},
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Center,
    LineSpacing->{1.4, 1},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.392187, 0]],
  
  Cell[StyleData["PrefaceTitle", "Presentation"],
    CellMargins->{{24, Inherited}, {60, Inherited}},
    TextAlignment->Center,
    FontSize->38,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.596078, 0.65098, 0.0196078]],
  
  Cell[StyleData["PrefaceTitle", "Printout"],
    CellMargins->{{0, Inherited}, {0, Inherited}},
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellFrame->True,
    CellDingbat->"\[FilledSquare]",
    ShowClosedCellArea->False,
    CellMargins->{{6, Inherited}, {6, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Left,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Sub3title", 0}, {"Sub4title", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellFrame->True,
    CellMargins->{{24, Inherited}, {6, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{14, Inherited}, {2, 2}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sub3title"],
    CellFrame->True,
    ShowClosedCellArea->False,
    CellMargins->{{6, Inherited}, {6, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Center,
    CounterIncrements->"Sub3title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Sub4title", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["Sub3title", "Presentation"],
    CellFrame->True,
    CellMargins->{{24, Inherited}, {6, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Sub3title", "Printout"],
    CellMargins->{{14, Inherited}, {2, 2}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sub4title"],
    CellFrame->True,
    ShowClosedCellArea->False,
    CellMargins->{{6, Inherited}, {6, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Center,
    CounterIncrements->"Sub4title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["Sub4title", "Presentation"],
    CellFrame->True,
    CellMargins->{{24, Inherited}, {6, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Sub4title", "Printout"],
    CellMargins->{{14, Inherited}, {2, 2}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Referencetitle"],
    CellFrame->{{1, 0}, {0, 1}},
    ShowCellBracket->True,
    ShowClosedCellArea->False,
    CellMargins->{{6, Inherited}, {6, Inherited}},
    CellGroupingRules->{"TitleGrouping", 15},
    PageBreakBelow->False,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Left,
    CounterIncrements->"Referencetitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Referencetitle", "Presentation"],
    CellMargins->{{24, Inherited}, {6, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Referencetitle", "Printout"],
    CellMargins->{{14, Inherited}, {2, 2}},
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Special Body Text and Index", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsText"],
    CellMargins->{{50, 10}, {5, 5}},
    FontFamily->"Times",
    FontSize->16],
  
  Cell[StyleData["ContentsText", "Presentation"]],
  
  Cell[StyleData["ContentsText", "Printout"],
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceEntry"],
    ShowCellBracket->False,
    CellMargins->{{50, 10}, {5, 5}},
    FontFamily->"Courier",
    FontSize->16],
  
  Cell[StyleData["ReferenceEntry", "Presentation"]],
  
  Cell[StyleData["ReferenceEntry", "Printout"],
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[StyleData["IndexEntry"],
    ShowCellBracket->False,
    CellMargins->{{15, 5}, {0, 5}},
    PageBreakBelow->False,
    DefaultFormatType->DefaultTextFormatType,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    ParagraphIndent->-40,
    StyleMenuListing->None,
    FontSize->16],
  
  Cell[StyleData["IndexSubEntry"],
    ShowCellBracket->False,
    CellMargins->{{45, 5}, {0, 0}},
    DefaultFormatType->DefaultTextFormatType,
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    ParagraphIndent->-40,
    StyleMenuListing->None,
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text",
    FontSize->16],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{20, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    FontFamily->"Times",
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {3, 3}}},
    GridBoxOptions->{ColumnSpacings->2,
    ColumnWidths->0.49,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    ColumnWidths->0.49,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TwoColumnBox"],
    CellFrame->True,
    CellMargins->{{15, 10}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    FontFamily->"Times",
    FontSize->16,
    FontColor->RGBColor[0, 0, 0.500008],
    Background->RGBColor[1, 0.940002, 0.900008],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1,
    ColumnWidths->{0.09, 0.9},
    ColumnAlignments->{Left}}],
  
  Cell[RawData["\<\
Cell[StyleData[\"2ColumnBox\", \"Printout\"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]]\
\>"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for License Agreement", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LicenseHeading"],
    ShowCellBracket->True,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 24}, {-1, 2}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.4, 0.300008, 0.6]],
  
  Cell[StyleData["LicenseHeading", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["LicenseHeading", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LicenseText"],
    CellFrame->True,
    ShowCellBracket->False,
    CellMargins->{{24, 24}, {5, -1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->RGBColor[1, 0.537743, 0.509071]],
  
  Cell[StyleData["LicenseText", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["LicenseText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CounterIncrements->"NumberedEquation"],
  
  Cell[StyleData["NumberedEquation", "Presentation"]],
  
  Cell[StyleData["NumberedEquation", "Printout"]],
  
  Cell[StyleData["NumberedEquation", "TwoColumn"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{24, Inherited}, {20, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedFigure", "TwoColumn"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{24, Inherited}, {20, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedTable", "TwoColumn"],
    CellMargins->{{14, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->14,
    FontColor->RGBColor[0, 0.392187, 0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "TwoColumn"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MEIHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.650004, 0.680003, 0.0800031],
    Background->RGBColor[0, 0.392187, 0],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->"Come visit us!"}],
  
  Cell[StyleData["MEIHyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MEIHyperlink", "TwoColumn"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "TwoColumn"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "TwoColumn"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "TwoColumn"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCell"],
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Left,
    ScriptLevel->1,
    LimitsPositioningTokens->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["InlineCell", "Presentation"],
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Left,
    ScriptLevel->1,
    LimitsPositioningTokens->{},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->16,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["InlineCell", "Printout"],
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Left,
    ScriptLevel->1,
    LimitsPositioningTokens->{},
    StyleMenuListing->None,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InlineCell", "TwoColumn"],
    DefaultInlineFormatType->DefaultInputInlineFormatType,
    TextAlignment->Left,
    ScriptLevel->1,
    LimitsPositioningTokens->{},
    StyleMenuListing->None,
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?mooh<<H`Ui0fL5:0?l0080004/0B`000000]P2:001
0000I00000000`<3000002L?00400@00000000000000060801T1T000000@0000
00000000004000@ji^000000009@DTiD\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 176, 7, 128, "PrefaceTitle"],
Cell[1896, 58, 83, 1, 73, "Title"],

Cell[CellGroupData[{
Cell[2004, 63, 40, 0, 54, "Subsubsection"],
Cell[2047, 65, 681, 27, 372, "Input"],
Cell[2731, 94, 5289, 139, 2218, "Input"],
Cell[8023, 235, 130, 5, 59, "Input"],

Cell[CellGroupData[{
Cell[8178, 244, 73, 1, 23, "Input"],
Cell[8254, 247, 282, 5, 70, "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8585, 258, 35, 0, 56, "Subsubtitle"],
Cell[8623, 260, 1237, 25, 268, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9897, 290, 59, 0, 56, "Subsubtitle"],
Cell[9959, 292, 502, 8, 138, "Text"],
Cell[10464, 302, 690, 12, 138, "Text"],
Cell[11157, 316, 307, 6, 86, "Text"],
Cell[11467, 324, 785, 16, 164, "Text"],
Cell[12255, 342, 10817, 233, 217, 2216, 122, "GraphicsData", "PostScript", \
"Graphics"],
Cell[23075, 577, 345, 6, 86, "Text"],
Cell[23423, 585, 130343, 3045, 184, 126213, 2990, "GraphicsData", \
"PostScript", "Graphics"],
Cell[153769, 3632, 101, 2, 17, "Caption"],
Cell[153873, 3636, 125963, 2742, 156, 120118, 2665, "GraphicsData", \
"PostScript", "Graphics"],
Cell[279839, 6380, 110, 2, 17, "Caption"],
Cell[279952, 6384, 667, 15, 138, "Text"],
Cell[280622, 6401, 615, 11, 138, "Text"],

Cell[CellGroupData[{
Cell[281262, 6416, 50, 0, 48, "Subsection"],

Cell[CellGroupData[{
Cell[281337, 6420, 45, 0, 42, "Subsubsection"],
Cell[281385, 6422, 924, 23, 190, "Text"],
Cell[282312, 6447, 275, 8, 30, "Text"],
Cell[282590, 6457, 1092, 33, 112, "Text"],
Cell[283685, 6492, 8071, 397, 73, 4424, 347, "GraphicsData", "PostScript", \
"Graphics"],
Cell[291759, 6891, 91, 2, 17, "Caption"],
Cell[291853, 6895, 9005, 409, 83, 4385, 347, "GraphicsData", "PostScript", \
"Graphics"],
Cell[300861, 7306, 93, 2, 17, "Caption"],
Cell[300957, 7310, 711, 22, 86, "Text"],
Cell[301671, 7334, 830, 23, 31, "Text"],
Cell[302504, 7359, 480, 20, 60, "Text"],
Cell[302987, 7381, 1987, 58, 43, "Text"],
Cell[304977, 7441, 560, 19, 60, "Text"],
Cell[305540, 7462, 275, 6, 54, "1ColumnBox"],
Cell[305818, 7470, 112, 5, 34, "Text"],
Cell[305933, 7477, 433, 8, 87, "Input"],
Cell[306369, 7487, 315, 13, 60, "Text"],
Cell[306687, 7502, 277, 5, 55, "Input"],
Cell[306967, 7509, 702, 24, 112, "Text"],
Cell[307672, 7535, 1096, 18, 295, "Input"],
Cell[308771, 7555, 338, 14, 34, "Text"],
Cell[309112, 7571, 127, 2, 23, "Input"],
Cell[309242, 7575, 131, 5, 34, "Text"],
Cell[309376, 7582, 425, 9, 87, "Input"],
Cell[309804, 7593, 1069, 36, 190, "Text"],
Cell[310876, 7631, 168, 3, 23, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[311081, 7639, 59, 0, 42, "Subsubsection"],
Cell[311143, 7641, 187, 5, 34, "Text"],
Cell[311333, 7648, 11202, 195, 244, 967, 64, "GraphicsData", "PostScript", \
"Graphics"],
Cell[322538, 7845, 266, 5, 86, "Text"],
Cell[322807, 7852, 19498, 303, 244, 1037, 70, "GraphicsData", "PostScript", \
"Graphics"],
Cell[342308, 8157, 75, 0, 34, "Text"],
Cell[342386, 8159, 164, 4, 38, "1ColumnBox"],
Cell[342553, 8165, 51, 0, 34, "Text"],
Cell[342607, 8167, 217, 5, 87, "Input"],
Cell[342827, 8174, 562, 29, 60, "Text"],
Cell[343392, 8205, 339, 7, 135, "Input"],
Cell[343734, 8214, 117, 5, 34, "Text"],
Cell[343854, 8221, 336, 8, 71, "Input"],
Cell[344193, 8231, 92, 4, 34, "Text"],
Cell[344288, 8237, 76, 1, 23, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[344401, 8243, 60, 0, 42, "Subsubsection"],
Cell[344464, 8245, 974, 35, 112, "Text"],
Cell[345441, 8282, 359, 12, 31, "ContentsText"],
Cell[345803, 8296, 549, 18, 45, "Text"],
Cell[346355, 8316, 831, 29, 49, "ContentsText"],
Cell[347189, 8347, 738, 20, 138, "Text"],
Cell[347930, 8369, 129, 2, 40, "1ColumnBox"],
Cell[348062, 8373, 401, 7, 119, "Input"],
Cell[348466, 8382, 47, 1, 23, "Input"],
Cell[348516, 8385, 3196, 57, 471, "Input"],
Cell[351715, 8444, 67, 1, 34, "Text"],
Cell[351785, 8447, 104, 3, 34, "Text"],
Cell[351892, 8452, 156, 2, 34, "Text"],
Cell[352051, 8456, 105, 2, 23, "Input"],
Cell[352159, 8460, 142, 2, 34, "Text"],
Cell[352304, 8464, 110, 2, 23, "Input"],
Cell[352417, 8468, 143, 2, 34, "Text"],
Cell[352563, 8472, 107, 2, 39, "Input"],
Cell[352673, 8476, 493, 20, 60, "Text"],
Cell[353169, 8498, 149, 2, 34, "Text"],
Cell[353321, 8502, 89, 1, 23, "Input"],
Cell[353413, 8505, 716, 21, 86, "Text"],
Cell[354132, 8528, 89, 1, 23, "Input"],
Cell[354224, 8531, 102, 2, 23, "Input"],
Cell[354329, 8535, 139, 3, 34, "Text"],
Cell[354471, 8540, 206, 4, 39, "Input"],
Cell[354680, 8546, 475, 8, 55, "Input"],
Cell[355158, 8556, 30, 0, 34, "Text"],
Cell[355191, 8558, 63, 1, 34, "Text"],
Cell[355257, 8561, 104, 3, 34, "Text"],
Cell[355364, 8566, 152, 2, 34, "Text"],
Cell[355519, 8570, 145, 3, 39, "Input"],
Cell[355667, 8575, 142, 2, 34, "Text"],
Cell[355812, 8579, 120, 2, 39, "Input"],
Cell[355935, 8583, 143, 2, 34, "Text"],
Cell[356081, 8587, 107, 2, 39, "Input"],
Cell[356191, 8591, 505, 20, 60, "Text"],
Cell[356699, 8613, 149, 2, 34, "Text"],
Cell[356851, 8617, 89, 1, 23, "Input"],
Cell[356943, 8620, 654, 21, 86, "Text"],
Cell[357600, 8643, 123, 2, 39, "Input"],
Cell[357726, 8647, 137, 3, 39, "Input"],
Cell[357866, 8652, 106, 3, 34, "Text"],
Cell[357975, 8657, 206, 4, 39, "Input"],
Cell[358184, 8663, 473, 8, 55, "Input"],
Cell[358660, 8673, 359, 8, 86, "Text"],
Cell[359022, 8683, 141, 2, 38, "1ColumnBox"],
Cell[359166, 8687, 219, 6, 60, "Text"],
Cell[359388, 8695, 168, 3, 39, "Input"],
Cell[359559, 8700, 145, 3, 39, "Input"],
Cell[359707, 8705, 206, 4, 39, "Input"],
Cell[359916, 8711, 186, 8, 34, "Text"],
Cell[360105, 8721, 717, 13, 103, "Input"],
Cell[360825, 8736, 76, 1, 23, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[360950, 8743, 52, 0, 48, "Subsection"],
Cell[361005, 8745, 517, 10, 138, "Text"],
Cell[361525, 8757, 1179, 33, 242, "Text"],
Cell[362707, 8792, 199, 4, 55, "Input"],
Cell[362909, 8798, 47, 1, 23, "Input"],
Cell[362959, 8801, 870, 29, 86, "Text"],
Cell[363832, 8832, 11637, 422, 53, 6735, 357, "GraphicsData", "PostScript", \
"Graphics"],
Cell[375472, 9256, 221, 10, 19, "Caption"],
Cell[375696, 9268, 34537, 854, 232, 8995, 534, "GraphicsData", "PostScript", \
"Graphics"],
Cell[410236, 10124, 183, 7, 19, "Caption"],
Cell[410422, 10133, 606, 19, 60, "Text"],
Cell[411031, 10154, 1139, 28, 68, "Text"],
Cell[412173, 10184, 503, 10, 112, "Text"],

Cell[CellGroupData[{
Cell[412701, 10198, 58, 0, 42, "Subsubsection"],
Cell[412762, 10200, 356, 9, 60, "Text"],
Cell[413121, 10211, 68, 0, 28, "ContentsText"],
Cell[413192, 10213, 8890, 253, 215, "TwoColumnBox"],
Cell[422085, 10468, 102, 3, 34, "Text"],
Cell[422190, 10473, 270, 5, 55, "Input"],
Cell[422463, 10480, 74, 1, 34, "Text"],
Cell[422540, 10483, 202, 5, 71, "Input"],
Cell[422745, 10490, 278, 11, 60, "Text"],
Cell[423026, 10503, 121, 5, 34, "Text"],
Cell[423150, 10510, 107, 2, 39, "Input"],
Cell[423260, 10514, 740, 29, 60, "Text"],
Cell[424003, 10545, 47, 1, 23, "Input"],
Cell[424053, 10548, 101, 1, 34, "Text"],
Cell[424157, 10551, 194, 7, 34, "Text"],
Cell[424354, 10560, 111, 1, 30, "ContentsText"],
Cell[424468, 10563, 275, 9, 60, "Text"],
Cell[424746, 10574, 98, 4, 30, "ContentsText"],
Cell[424847, 10580, 69, 0, 34, "Text"],
Cell[424919, 10582, 132, 2, 30, "ContentsText"],
Cell[425054, 10586, 233, 8, 34, "Text"],
Cell[425290, 10596, 99, 1, 30, "ContentsText"],
Cell[425392, 10599, 408, 12, 86, "Text"],
Cell[425803, 10613, 688, 13, 87, "Input"],
Cell[426494, 10628, 103, 2, 23, "Input"],
Cell[426600, 10632, 187, 4, 60, "Text"],
Cell[426790, 10638, 329, 6, 55, "Input"],
Cell[427122, 10646, 61, 1, 23, "Input"],
Cell[427186, 10649, 109, 4, 34, "Text"],
Cell[427298, 10655, 69, 0, 34, "Text"],
Cell[427370, 10657, 32171, 703, 270, 5270, 366, "GraphicsData", "PostScript", \
"Graphics"],
Cell[459544, 11362, 116, 2, 17, "Caption"],
Cell[459663, 11366, 11707, 413, 55, 6703, 347, "GraphicsData", "PostScript", \
"Graphics"],
Cell[471373, 11781, 158, 5, 17, "Caption"],
Cell[471534, 11788, 9425, 307, 65, 4334, 240, "GraphicsData", "PostScript", \
"Graphics"],
Cell[480962, 12097, 151, 5, 17, "Caption"],
Cell[481116, 12104, 377, 8, 54, "1ColumnBox"],
Cell[481496, 12114, 779, 14, 103, "Input"],
Cell[482278, 12130, 76, 1, 23, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[482403, 12137, 105, 3, 74, "Subsection"],
Cell[482511, 12142, 206, 4, 60, "Text"],
Cell[482720, 12148, 353, 14, 312, "ItemizedText"],
Cell[483076, 12164, 688, 17, 138, "Text"],
Cell[483767, 12183, 26337, 979, 196, 12533, 804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[510107, 13164, 39, 0, 34, "Text"],
Cell[510149, 13166, 316, 6, 34, "IndentedText"],
Cell[510468, 13174, 971, 14, 242, "Text"],

Cell[CellGroupData[{
Cell[511464, 13192, 36, 0, 42, "Subsubsection"],
Cell[511503, 13194, 617, 19, 112, "Text"],
Cell[512123, 13215, 18535, 444, 179, 3479, 254, "GraphicsData", "PostScript", \
"Graphics"],
Cell[530661, 13661, 475, 17, 19, "Caption"],
Cell[531139, 13680, 194, 6, 60, "Text"],
Cell[531336, 13688, 104, 2, 34, "Text"],
Cell[531443, 13692, 182, 3, 39, "Input"],
Cell[531628, 13697, 105, 2, 34, "Text"],
Cell[531736, 13701, 184, 3, 39, "Input"],
Cell[531923, 13706, 122, 2, 34, "Text"],
Cell[532048, 13710, 172, 3, 39, "Input"],
Cell[532223, 13715, 142, 2, 34, "Text"],
Cell[532368, 13719, 165, 3, 39, "Input"],
Cell[532536, 13724, 146, 2, 60, "Text"],
Cell[532685, 13728, 262, 4, 23, "Input"],
Cell[532950, 13734, 172, 3, 39, "Input"],
Cell[533125, 13739, 165, 3, 23, "Input"],
Cell[533293, 13744, 119, 2, 34, "Text"],
Cell[533415, 13748, 303, 5, 39, "Input"],
Cell[533721, 13755, 172, 3, 39, "Input"],
Cell[533896, 13760, 165, 3, 23, "Input"],
Cell[534064, 13765, 114, 3, 34, "Text"],
Cell[534181, 13770, 144, 3, 39, "Input"],
Cell[534328, 13775, 144, 3, 39, "Input"],
Cell[534475, 13780, 277, 5, 39, "Input"],
Cell[534755, 13787, 101, 3, 34, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[534893, 13795, 68, 0, 42, "Subsubsection"],
Cell[534964, 13797, 304, 5, 86, "Text"],
Cell[535271, 13804, 124, 2, 34, "Text"],
Cell[535398, 13808, 250, 5, 55, "Input"],
Cell[535651, 13815, 127, 2, 34, "Text"],
Cell[535781, 13819, 187, 3, 71, "Input"],
Cell[535971, 13824, 186, 5, 34, "Text"],
Cell[536160, 13831, 49, 1, 23, "Input"],
Cell[536212, 13834, 49, 1, 23, "Input"],
Cell[536264, 13837, 187, 5, 34, "Text"],
Cell[536454, 13844, 110, 2, 39, "Input"],
Cell[536567, 13848, 219, 5, 60, "Text"],
Cell[536789, 13855, 645, 13, 71, "Input"],
Cell[537437, 13870, 459, 16, 86, "Text"],
Cell[537899, 13888, 176, 4, 23, "Input"],
Cell[538078, 13894, 173, 4, 23, "Input"],
Cell[538254, 13900, 233, 4, 60, "Text"],
Cell[538490, 13906, 1037, 19, 183, "Input"],
Cell[539530, 13927, 330, 11, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[539897, 13943, 82, 1, 42, "Subsubsection"],
Cell[539982, 13946, 822, 24, 164, "Text"],
Cell[540807, 13972, 95, 3, 34, "Text"],
Cell[540905, 13977, 268, 7, 27, "Text"],
Cell[541176, 13986, 444, 21, 60, "Text"],
Cell[541623, 14009, 574, 15, 112, "Text"],
Cell[542200, 14026, 164, 5, 30, "ContentsText"],
Cell[542367, 14033, 1781, 59, 122, "Text"],
Cell[544151, 14094, 43549, 791, 296, 4624, 306, "GraphicsData", "PostScript", \
"Graphics"],
Cell[587703, 14887, 386, 14, 24, "Caption"],
Cell[588092, 14903, 1590, 47, 216, "Text"],
Cell[589685, 14952, 127, 5, 34, "Text"],
Cell[589815, 14959, 263, 5, 43, "Text"],
Cell[590081, 14966, 192, 5, 34, "Text"],
Cell[590276, 14973, 1346, 32, 51, "Text"],
Cell[591625, 15007, 223, 6, 34, "Text"],
Cell[591851, 15015, 733, 17, 43, "Text"],
Cell[592587, 15034, 660, 20, 138, "Text"],
Cell[593250, 15056, 336, 6, 87, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[593623, 15067, 78, 0, 42, "Subsubsection"],
Cell[593704, 15069, 462, 15, 86, "Text"],
Cell[594169, 15086, 130, 3, 23, "Input"],
Cell[594302, 15091, 588, 23, 86, "Text"],
Cell[594893, 15116, 473, 13, 45, "Text"],
Cell[595369, 15131, 52, 0, 34, "Text"],
Cell[595424, 15133, 78, 1, 23, "Input"],
Cell[595505, 15136, 264, 5, 39, "Input"],
Cell[595772, 15143, 100, 3, 34, "Text"],
Cell[595875, 15148, 473, 13, 45, "Text"],
Cell[596351, 15163, 87, 1, 23, "Input"],
Cell[596441, 15166, 265, 5, 39, "Input"],
Cell[596709, 15173, 389, 15, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[597135, 15193, 72, 1, 42, "Subsubsection"],
Cell[597210, 15196, 75, 1, 34, "Text"],
Cell[597288, 15199, 367, 8, 55, "Input"],
Cell[597658, 15209, 246, 9, 34, "Text"],
Cell[597907, 15220, 217, 5, 23, "Input"],
Cell[598127, 15227, 216, 5, 23, "Input"],
Cell[598346, 15234, 62, 1, 34, "Text"],
Cell[598411, 15237, 1034, 17, 151, "Input"],
Cell[599448, 15256, 464, 13, 86, "Text"],
Cell[599915, 15271, 1649, 29, 215, "Input"],
Cell[601567, 15302, 76, 1, 23, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[601680, 15308, 48, 0, 42, "Subsubsection"],
Cell[601731, 15310, 289, 5, 86, "Text"],
Cell[602023, 15317, 484, 16, 86, "Text"],
Cell[602510, 15335, 2522, 47, 311, "Input"],
Cell[605035, 15384, 76, 1, 23, "Input"],
Cell[605114, 15387, 232, 6, 60, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[605395, 15399, 57, 0, 48, "Subsection"],
Cell[605455, 15401, 445, 16, 86, "Text"],
Cell[605903, 15419, 285, 5, 86, "Text"],

Cell[CellGroupData[{
Cell[606213, 15428, 35, 0, 54, "Subsubsection"],
Cell[606251, 15430, 89, 3, 34, "Text"],
Cell[606343, 15435, 290, 8, 27, "Text"],
Cell[606636, 15445, 370, 14, 34, "Text"],
Cell[607009, 15461, 694, 20, 138, "Text"],
Cell[607706, 15483, 418, 11, 97, "Text"],
Cell[608127, 15496, 601, 19, 93, "Text"],
Cell[608731, 15517, 105, 3, 34, "Text"],
Cell[608839, 15522, 557, 10, 169, "Input"],
Cell[609399, 15534, 601, 13, 190, "Text"],
Cell[610003, 15549, 272, 5, 86, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[610312, 15559, 36, 0, 34, "Subsubsection"],
Cell[610351, 15561, 104, 2, 34, "Text"],
Cell[610458, 15565, 269, 5, 55, "Input"],
Cell[610730, 15572, 110, 2, 34, "Text"],
Cell[610843, 15576, 185, 3, 39, "Input"],
Cell[611031, 15581, 127, 2, 34, "Text"],
Cell[611161, 15585, 185, 3, 39, "Input"],
Cell[611349, 15590, 147, 2, 34, "Text"],
Cell[611499, 15594, 175, 3, 39, "Input"],
Cell[611677, 15599, 146, 2, 34, "Text"],
Cell[611826, 15603, 387, 8, 39, "Input"],
Cell[612216, 15613, 354, 7, 23, "Input"],
Cell[612573, 15622, 174, 3, 23, "Input"],
Cell[612750, 15627, 174, 3, 23, "Input"],
Cell[612927, 15632, 244, 5, 60, "Text"],
Cell[613174, 15639, 209, 4, 39, "Input"],
Cell[613386, 15645, 207, 4, 39, "Input"],
Cell[613596, 15651, 512, 9, 87, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[614145, 15665, 49, 0, 42, "Subsubsection"],
Cell[614197, 15667, 128, 2, 34, "Text"],
Cell[614328, 15671, 313, 6, 55, "Input"],
Cell[614644, 15679, 132, 2, 34, "Text"],
Cell[614779, 15683, 250, 4, 71, "Input"],
Cell[615032, 15689, 191, 5, 34, "Text"],
Cell[615226, 15696, 112, 2, 23, "Input"],
Cell[615341, 15700, 112, 2, 23, "Input"],
Cell[615456, 15704, 192, 5, 34, "Text"],
Cell[615651, 15711, 173, 3, 39, "Input"],
Cell[615827, 15716, 1155, 21, 103, "Input"],
Cell[616985, 15739, 274, 5, 39, "Input"],
Cell[617262, 15746, 412, 7, 112, "Text"],
Cell[617677, 15755, 392, 9, 39, "Input"],
Cell[618072, 15766, 760, 13, 167, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[618869, 15784, 125, 2, 42, "Subsubsection"],
Cell[618997, 15788, 402, 14, 60, "Text"],
Cell[619402, 15804, 212, 4, 39, "Input"],
Cell[619617, 15810, 178, 3, 39, "Input"],
Cell[619798, 15815, 150, 2, 23, "Input"],
Cell[619951, 15819, 176, 5, 34, "Text"],
Cell[620130, 15826, 280, 6, 23, "Input"],
Cell[620413, 15834, 279, 6, 23, "Input"],
Cell[620695, 15842, 112, 2, 34, "Text"],
Cell[620810, 15846, 1952, 32, 311, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[622799, 15883, 123, 2, 42, "Subsubsection"],
Cell[622925, 15887, 61, 0, 34, "Text"],
Cell[622989, 15889, 3743, 63, 487, "Input"],
Cell[626735, 15954, 90, 3, 34, "Text"],
Cell[626828, 15959, 139, 2, 23, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[627028, 15968, 46, 0, 56, "Subsubtitle"],
Cell[627077, 15970, 484, 9, 112, "Text"],
Cell[627564, 15981, 400, 12, 60, "Text"],
Cell[627967, 15995, 560, 19, 61, "Text"],
Cell[628530, 16016, 457, 20, 60, "Text"],
Cell[628990, 16038, 571, 17, 112, "Text"],

Cell[CellGroupData[{
Cell[629586, 16059, 65, 0, 52, "Sub3title"],
Cell[629654, 16061, 22975, 1127, 287, 13953, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[652632, 17190, 80, 2, 17, "Caption"],
Cell[652715, 17194, 1393, 30, 268, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[654145, 17229, 32, 0, 52, "Sub3title"],
Cell[654180, 17231, 342, 7, 86, "Text"],
Cell[654525, 17240, 705, 24, 48, "ContentsText"],
Cell[655233, 17266, 1063, 35, 112, "Text"],
Cell[656299, 17303, 1078, 31, 46, "ContentsText"],
Cell[657380, 17336, 1822, 49, 27, "ContentsText"],
Cell[659205, 17387, 236, 6, 60, "Text"],
Cell[659444, 17395, 80, 1, 23, "Input"],
Cell[659527, 17398, 129, 2, 23, "Input"],
Cell[659659, 17402, 1059, 27, 107, "1ColumnBox"],
Cell[660721, 17431, 135, 3, 34, "Text"],
Cell[660859, 17436, 7153, 181, 183, "2ColumnBox"],
Cell[668015, 17619, 51, 0, 17, "Caption"],
Cell[668069, 17621, 7059, 180, 215, "2ColumnBox"],
Cell[675131, 17803, 57, 0, 17, "Caption"],
Cell[675191, 17805, 1495, 36, 86, "Text"],
Cell[676689, 17843, 155, 5, 34, "Text"],
Cell[676847, 17850, 453, 8, 71, "Input"],
Cell[677303, 17860, 216, 6, 60, "Text"],
Cell[677522, 17868, 1514, 52, 83, "ContentsText"],
Cell[679039, 17922, 158, 5, 34, "Text"],
Cell[679200, 17929, 91, 1, 38, "1ColumnBox"],
Cell[679294, 17932, 1963, 64, 166, "1ColumnBox"],
Cell[681260, 17998, 125, 2, 48, "Input"],
Cell[681388, 18002, 82, 1, 23, "Input"],
Cell[681473, 18005, 17, 0, 34, "Text"],
Cell[681493, 18007, 1478, 44, 73, "1ColumnBox"],
Cell[682974, 18053, 898, 27, 163, "Note"],
Cell[683875, 18082, 382, 12, 60, "Text"],
Cell[684260, 18096, 171, 4, 60, "Text"],
Cell[684434, 18102, 712, 26, 48, "ContentsText"],
Cell[685149, 18130, 70, 0, 34, "Text"],
Cell[685222, 18132, 1075, 29, 54, "ContentsText"],
Cell[686300, 18163, 149, 3, 60, "Text"],

Cell[CellGroupData[{
Cell[686474, 18170, 63, 0, 48, "Subsection"],
Cell[686540, 18172, 2284, 73, 139, "Text"],
Cell[688827, 18247, 165, 3, 39, "Input"],
Cell[688995, 18252, 165, 3, 39, "Input"],
Cell[689163, 18257, 160, 3, 39, "Input"],
Cell[689326, 18262, 289, 9, 60, "Text"],
Cell[689618, 18273, 437, 9, 73, "Text"],
Cell[690058, 18284, 390, 12, 42, "1ColumnBox"],
Cell[690451, 18298, 630, 11, 164, "Input"],
Cell[691084, 18311, 431, 17, 86, "Text"],
Cell[691518, 18330, 1182, 22, 140, "Text"],
Cell[692703, 18354, 290, 14, 60, "Text"],
Cell[692996, 18370, 242, 7, 40, "1ColumnBox"],
Cell[693241, 18379, 2017, 37, 407, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[695295, 18421, 72, 0, 48, "Subsection"],
Cell[695370, 18423, 466, 14, 112, "Text"],
Cell[695839, 18439, 984, 30, 138, "Text"],
Cell[696826, 18471, 18899, 427, 287, 5610, 259, "GraphicsData", "PostScript", \
"Graphics"],
Cell[715728, 18900, 548, 23, 17, "Caption"],
Cell[716279, 18925, 923, 38, 112, "Text"],
Cell[717205, 18965, 26070, 669, 287, 11408, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[743278, 19636, 354, 13, 60, "Text"],
Cell[743635, 19651, 231, 6, 34, "Text"],
Cell[743869, 19659, 389, 8, 86, "Text"],
Cell[744261, 19669, 446, 16, 60, "Text"],
Cell[744710, 19687, 19730, 647, 296, 11933, 546, "GraphicsData", \
"PostScript", "Graphics"],
Cell[764443, 20336, 394, 17, 17, "Caption"],
Cell[764840, 20355, 331, 15, 60, "Text"],
Cell[765174, 20372, 253, 7, 61, "Text"],
Cell[765430, 20381, 156, 8, 34, "Text"],
Cell[765589, 20391, 145, 3, 39, "Input"],
Cell[765737, 20396, 212, 6, 34, "Text"],
Cell[765952, 20404, 302, 6, 87, "Input"],
Cell[766257, 20412, 52, 0, 34, "Text"],
Cell[766312, 20414, 198, 3, 39, "Input"],
Cell[766513, 20419, 260, 9, 34, "Text"],
Cell[766776, 20430, 318, 6, 71, "Input"],
Cell[767097, 20438, 268, 9, 60, "Text"],
Cell[767368, 20449, 323, 6, 71, "Input"],
Cell[767694, 20457, 73, 1, 23, "Input"],

Cell[CellGroupData[{
Cell[767792, 20462, 84, 1, 42, "Subsubsection"],
Cell[767879, 20465, 506, 13, 112, "Text"],
Cell[768388, 20480, 664, 24, 112, "Text"],
Cell[769055, 20506, 288, 8, 43, "Text"],
Cell[769346, 20516, 525, 24, 86, "Text"],
Cell[769874, 20542, 1289, 22, 359, "Input"],
Cell[771166, 20566, 87, 3, 34, "Text"],
Cell[771256, 20571, 288, 6, 55, "Input"],
Cell[771547, 20579, 73, 1, 23, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[771669, 20586, 145, 5, 48, "Subsection"],
Cell[771817, 20593, 510, 17, 86, "Text"],
Cell[772330, 20612, 1998, 40, 398, "Text"],

Cell[CellGroupData[{
Cell[774353, 20656, 55, 0, 42, "Subsubsection"],
Cell[774411, 20658, 71, 0, 34, "Text"],
Cell[774485, 20660, 1412, 49, 64, "ContentsText"],
Cell[775900, 20711, 299, 10, 42, "1ColumnBox"],
Cell[776202, 20723, 325, 6, 87, "Input"],
Cell[776530, 20731, 99, 3, 34, "Text"],
Cell[776632, 20736, 1038, 34, 46, "ContentsText"],
Cell[777673, 20772, 247, 8, 41, "1ColumnBox"],
Cell[777923, 20782, 422, 8, 103, "Input"],
Cell[778348, 20792, 341, 12, 60, "Text"],
Cell[778692, 20806, 1719, 59, 46, "ContentsText"],
Cell[780414, 20867, 157, 4, 60, "Text"],
Cell[780574, 20873, 392, 7, 112, "Text"],
Cell[780969, 20882, 772, 25, 45, "Text"],
Cell[781744, 20909, 41, 0, 34, "Text"],
Cell[781788, 20911, 640, 22, 34, "Text"],
Cell[782431, 20935, 1353, 40, 34, "Text"],
Cell[783787, 20977, 1543, 49, 34, "Text"],
Cell[785333, 21028, 215, 4, 60, "Text"],
Cell[785551, 21034, 1609, 48, 109, "ContentsText"],
Cell[787163, 21084, 1041, 41, 60, "Text"],
Cell[788207, 21127, 249, 8, 41, "1ColumnBox"],
Cell[788459, 21137, 148, 3, 39, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[788644, 21145, 113, 5, 42, "Subsubsection"],
Cell[788760, 21152, 354, 13, 60, "Text"],
Cell[789117, 21167, 338, 12, 38, "1ColumnBox"],
Cell[789458, 21181, 1074, 19, 247, "Input"],
Cell[790535, 21202, 240, 5, 55, "Input"],
Cell[790778, 21209, 108, 3, 34, "Text"],
Cell[790889, 21214, 118, 4, 34, "Text"],
Cell[791010, 21220, 1654, 65, 60, "Text"],
Cell[792667, 21287, 188, 7, 34, "Text"],
Cell[792858, 21296, 444, 17, 34, "Text"],
Cell[793305, 21315, 278, 9, 26, "Text"],
Cell[793586, 21326, 496, 19, 34, "Text"],
Cell[794085, 21347, 555, 12, 33, "Text"],
Cell[794643, 21361, 278, 9, 26, "Text"],
Cell[794924, 21372, 251, 11, 34, "Text"],
Cell[795178, 21385, 389, 10, 33, "Text"],
Cell[795570, 21397, 216, 4, 52, "1ColumnBox"],
Cell[795789, 21403, 358, 7, 87, "Input"],
Cell[796150, 21412, 219, 5, 39, "Input"],
Cell[796372, 21419, 515, 23, 56, "1ColumnBox"],
Cell[796890, 21444, 133, 2, 23, "Input"],
Cell[797026, 21448, 249, 4, 55, "Input"],
Cell[797278, 21454, 93, 1, 23, "Input"],
Cell[797374, 21457, 3097, 126, 60, "Text"],
Cell[800474, 21585, 162, 4, 23, "Input"],
Cell[800639, 21591, 162, 4, 23, "Input"],
Cell[800804, 21597, 162, 4, 23, "Input"],
Cell[800969, 21603, 162, 4, 23, "Input"],
Cell[801134, 21609, 77, 0, 34, "Text"],
Cell[801214, 21611, 54, 1, 23, "Input"],
Cell[801271, 21614, 258, 4, 71, "Input"],
Cell[801532, 21620, 438, 13, 86, "Text"],
Cell[801973, 21635, 1471, 23, 295, "Input"],
Cell[803447, 21660, 128, 2, 23, "Input"],
Cell[803578, 21664, 364, 10, 86, "Text"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[804015, 21682, 36, 0, 49, "Referencetitle"],
Cell[804054, 21684, 333, 9, 82, "ReferenceEntry"],
Cell[804390, 21695, 197, 5, 46, "ReferenceEntry"],
Cell[804590, 21702, 159, 5, 46, "ReferenceEntry"],
Cell[804752, 21709, 289, 6, 82, "ReferenceEntry"],
Cell[805044, 21717, 219, 6, 46, "ReferenceEntry"],
Cell[805266, 21725, 245, 6, 64, "ReferenceEntry"],
Cell[805514, 21733, 178, 5, 46, "ReferenceEntry"],
Cell[805695, 21740, 228, 6, 64, "ReferenceEntry"],
Cell[805926, 21748, 201, 5, 46, "ReferenceEntry"],
Cell[806130, 21755, 180, 5, 46, "ReferenceEntry"],
Cell[806313, 21762, 194, 5, 46, "ReferenceEntry"],
Cell[806510, 21769, 223, 6, 64, "ReferenceEntry"],
Cell[806736, 21777, 213, 8, 46, "ReferenceEntry"],
Cell[806952, 21787, 71, 0, 34, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

